(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   2376605,      62062]*)
(*NotebookOutlinePosition[   2377768,      62099]*)
(*  CellTagsIndexPosition[   2377724,      62095]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[{
    \(<< Graphics`Graphics`\), "\n", 
    \(\(SetDirectory["\<D:\mathdata\>"];\)\), "\n", 
    \(\($TextStyle = {FontFamily \[Rule] "\<Times\>", 
          FontSize \[Rule] 14};\)\), "\[IndentingNewLine]", 
    \(\(c = 2.99\ 10^5;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(ndat = 157;\)\n (*\ 157\ Gold\ SN\ data\ from\ Riess\ *) \), "\n", 
    \(\(datanw = 
        ReadList["\<datar-g.txt\>", {Number, Number, Number}];\)\n (*\ 
      Prepare\ for\ construction\ of\ chi - 
        square\ *) \), "\[IndentingNewLine]", 
    \(Do[zz[i] = datanw[\([i, 1]\)], {i, 1, ndat}]\), "\n", 
    \(Do[ld[i] = datanw[\([i, 2]\)], {i, 1, ndat}]\), "\n", 
    \(Do[sld[i] = datanw[\([i, 3]\)], {i, 1, ndat}]\)}], "Input"],

Cell[BoxData[
    \( (*\ \(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(\
--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(\
--\(--\(--\(----\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\
\)\)\)\)\)\)\)\)\ *) \)], "Input"],

Cell[BoxData[{
    \( (*\ Cosmological\ Constant\ \((arbitrary\ omega)\) : \ 
        Evaluate\ integral\ for\ luminocity\ distance\ *) \[IndentingNewLine]\
\(Clear[aa, fi, a, aad, aadd, fidas, tas, f, rr, chi2fa, chi2fb, chi2fc, 
        chi2fm];\)\), "\[IndentingNewLine]", 
    \(\(f[z_, om_] := 
        1/Sqrt[om\ \((1 + z)\)^3\  + \ \((1 - om)\)];\)\), "\n", 
    \(\(rr[zz_, om_] := NIntegrate[f[z, om], {z, 0, zz}];\)\)}], "Input"],

Cell[BoxData[{
    \( (*\ Construct\ marginalization\ coefficients\ \((see\ astro - 
              ph/0401556\  .. )\)\ *) \[IndentingNewLine]\(chi2fa[om_] := 
        Sum[\((ld[i] - 5\ Log[10, rr[zz[i], om]*\((1 + zz[i])\)])\)^2/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\[IndentingNewLine]", 
    \(\(chi2fb[om_] := 
        Sum[\((ld[i] - 
                5\ Log[10, rr[zz[i], om]*\((1 + zz[i])\)])\)/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\[IndentingNewLine]", 
    \(\(chi2fc = Sum[1/\((sld[i]^2)\), {i, 1, ndat}];\)\)}], "Input"],

Cell[BoxData[
    \(\(\( (*\ 
      Construct\ function\ to\ minimized\ after\ marginalization\ *) \)\(\
\[IndentingNewLine]\)\(chi2fm[om_] := 
      chi2fa[om] - chi2fb[om]^2/chi2fc\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ 
      Minimize\ with\ respect\ to\ om\ and\ find\ same\ result\ as\ with\ mb\ \
minimization . \ 
          Minimization\ and\ marginalization\ have\ the\ same\ \(effect\ !!\)\
\ *) \)\(\[IndentingNewLine]\)\(chmin0m = 
      FindMinimum[chi2fm[om], {om, {0.3, 0.31}}]\)\)\)], "Input"],

Cell[BoxData[
    \({177.07214571814984`, {om \[Rule] 0.30896148480893704`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(chi2l = chi2fm[0.3]\)], "Input"],

Cell[BoxData[
    \(177.12737143505365`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ \(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(\
--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(-\(---\)\)\)\)\)\)\)\)\)\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)*) \[IndentingNewLine]\[IndentingNewLine] \
(*\ Find\ H \((z)\)\ for\ given\ slope\ s\ of\ the\ linear\ potential . \ 
            Present\ time\  = \ \(tt\ \((corresponds\ to\ a = 1)\) . \ 
              Run\ trials\ for\ initial\ condition\ for\ field\ fi\ \((f0)\)\ \
and\ initial\ time\ ti\ until\ we\ get\ field\ energy\ enf\  = \ \(0.7\ and\ \
H \((z = 0)\)\  = 
            1\ at\ present\ time\ \(\(tt\)\(.\)\)\)\)\ *) \[IndentingNewLine]\
\[IndentingNewLine] (*\ \(--\(--\(--\(--\ \ s\)\)\)\)\  = \ \(0.1\ \ \ --\) \
\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(---\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\ *) \
\[IndentingNewLine]\[IndentingNewLine]\(Clear[aa, fi, a, aad, aadd, fidas, 
        tas, f, rr, hht, hha];\)\), "\n", 
    \(aa = a[t]; \ fi = f[t];\), "\n", 
    \(\(aad = D[aa, t];\)\), "\n", 
    \(\(aadd = D[aa, {t, 2}];\)\), "\n", 
    \(\(fid = D[fi, t];\)\), "\n", 
    \(\(fidd = D[fi, {t, 2}];\)\), "\n", 
    \(ti = 0.000025; \ t0 = 2.25;\), "\n", 
    \(\(f0 = \(-7\);\)\ \), "\n", 
    \(om0m = 0.3; \ ss = 0.1;\), "\n", 
    \(\(eq1 = 
        aadd/aa\  \[Equal] \(-\ \ fid^2\)\  - \ ss\ fi\  - \ 
            om0m/\((2\ aa^3)\);\)\), "\n", 
    \(\(eq2 = 
        fidd\ \  + \ \ \ 3\ \ fid\ \((aad/aa)\)\  - \ ss \[Equal] 
          0;\)\), "\n", 
    \(\(eqb1 = f[ti] == f0;\)\), "\n", 
    \(\(eqb2 = \(f'\)[ti] == 0;\)\), "\n", 
    \(\(eqb3 = 
        a[ti] \[Equal] \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((2/3)\);\)\), "\n", 
    \(\(eqb4 = \(a'\)[
            ti] \[Equal] \((2/
                3)\)\ \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((\(-1\)/
                  3)\);\)\), "\n", 
    \(\(sol2 = 
        NDSolve[{eq1, eq2, eqb1, eqb2, eqb3, eqb4}, {aa, fi}, {t, ti, t0}, 
          MaxSteps \[Rule] 10000000];\)\), "\n", 
    \(\(asol = Part[Evaluate[a[t] /. sol2], 1];\)\), "\n", 
    \(\(fsol = Part[Evaluate[f[t] /. sol2], 1];\)\), "\n", 
    \(\(dfsol = D[fsol, t];\)\), "\n", 
    \(\(enf = 0.5\ dfsol^2\  - \ ss\ fsol;\)\), "\n", 
    \(\(as[t1_] := asol\  /. \ t -> t1\ ;\)\), "\n", 
    \(\(tt = Part[FindRoot[as[t] == 1, {t, 1}], 1, 2];\)\), "\n", 
    \(\(tas[a_] := 
        Part[FindRoot[as[t] \[Equal] a, {t, 1}], 1, 2];\)\), "\n", 
    \(\(hht[t1_] := D[asol, t]/asol\  /. \ t -> t1\ ;\)\), "\n", 
    \(\(hha[a_] := hht[tas[a]];\)\), "\n", 
    \(\(hhz[z_] := hha[1/\((z + 1)\)];\)\), "\n", 
    \(enf\  /. \ t \[Rule] tt\), "\n", 
    \(hhz[0]\), "\n", 
    \(\(enf = 0.5\ dfsol^2\  - \ ss\ fsol;\)\), "\n", 
    \(\(ppf = 0.5\ dfsol^2\  + \ ss\ fsol;\)\), "\n", 
    \(\(wft[t1_] := ppf/enf\  /. \ t -> t1\ ;\)\ \), "\n", 
    \(\(wfa[a_] := wft[tas[a]];\)\), "\n", 
    \(\(wfz[z_] := wfa[1/\((z + 1)\)];\)\), "\n", 
    \(\(plw01q = 
        Plot[wfz[z], {z, 0, 2}, Frame \[Rule] True, PlotRange \[Rule] All, 
          FrameLabel \[Rule] {"\<z\>", "\<w(z)\>"}];\)\)}], "Input"],

Cell[BoxData[
    \(1.0007625691815596`\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.476191 616.509 616.545 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.2619 -0.0125 -10.7813 -17.8125 ]
[.2619 -0.0125 10.7813 0 ]
[.5 -0.0125 -5.53125 -17.8125 ]
[.5 -0.0125 5.53125 0 ]
[.7381 -0.0125 -10.7813 -17.8125 ]
[.7381 -0.0125 10.7813 0 ]
[.97619 -0.0125 -5.53125 -17.8125 ]
[.97619 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.125 -35.625 ]
[.5 -0.0125 5.125 -17.8125 ]
[-0.0125 .08706 -52.4375 -8.90625 ]
[-0.0125 .08706 0 8.90625 ]
[-0.0125 .21037 -52.4375 -8.90625 ]
[-0.0125 .21037 0 8.90625 ]
[-0.0125 .33368 -52.4375 -8.90625 ]
[-0.0125 .33368 0 8.90625 ]
[-0.0125 .45699 -52.4375 -8.90625 ]
[-0.0125 .45699 0 8.90625 ]
[-0.0125 .5803 -45.375 -8.90625 ]
[-0.0125 .5803 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -70.25 -14.7188 ]
[-0.01875 .30902 -52.4375 14.7188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.125 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08706 m
.00625 .08706 L
s
gsave
-0.0125 .08706 -113.438 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9998) show
1.000 setlinewidth
grestore
0 .21037 m
.00625 .21037 L
s
gsave
-0.0125 .21037 -113.438 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9996) show
1.000 setlinewidth
grestore
0 .33368 m
.00625 .33368 L
s
gsave
-0.0125 .33368 -113.438 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9994) show
1.000 setlinewidth
grestore
0 .45699 m
.00625 .45699 L
s
gsave
-0.0125 .45699 -113.438 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9992) show
1.000 setlinewidth
grestore
0 .5803 m
.00625 .5803 L
s
gsave
-0.0125 .5803 -106.375 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.999) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .11789 m
.00375 .11789 L
s
0 .14872 m
.00375 .14872 L
s
0 .17955 m
.00375 .17955 L
s
0 .2412 m
.00375 .2412 L
s
0 .27203 m
.00375 .27203 L
s
0 .30285 m
.00375 .30285 L
s
0 .36451 m
.00375 .36451 L
s
0 .39534 m
.00375 .39534 L
s
0 .42616 m
.00375 .42616 L
s
0 .48782 m
.00375 .48782 L
s
0 .51865 m
.00375 .51865 L
s
0 .54947 m
.00375 .54947 L
s
0 .05624 m
.00375 .05624 L
s
0 .02541 m
.00375 .02541 L
s
0 .61113 m
.00375 .61113 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -137.063 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.7188 12.9063 translate
90 rotate
-75.7188 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.063 17.500 moveto
(H) show
77.625 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.875 17.500 moveto
(L) show
88.438 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08706 m
1 .08706 L
s
.99375 .21037 m
1 .21037 L
s
.99375 .33368 m
1 .33368 L
s
.99375 .45699 m
1 .45699 L
s
.99375 .5803 m
1 .5803 L
s
.125 Mabswid
.99625 .11789 m
1 .11789 L
s
.99625 .14872 m
1 .14872 L
s
.99625 .17955 m
1 .17955 L
s
.99625 .2412 m
1 .2412 L
s
.99625 .27203 m
1 .27203 L
s
.99625 .30285 m
1 .30285 L
s
.99625 .36451 m
1 .36451 L
s
.99625 .39534 m
1 .39534 L
s
.99625 .42616 m
1 .42616 L
s
.99625 .48782 m
1 .48782 L
s
.99625 .51865 m
1 .51865 L
s
.99625 .54947 m
1 .54947 L
s
.99625 .05624 m
1 .05624 L
s
.99625 .02541 m
1 .02541 L
s
.99625 .61113 m
1 .61113 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .08706 m
1 .08706 L
s
.5 Mabswid
.02381 .60332 m
.06244 .53269 L
.10458 .46337 L
.14415 .40549 L
.18221 .35611 L
.22272 .30981 L
.26171 .27076 L
.30316 .23455 L
.34309 .20421 L
.3815 .1787 L
.42237 .155 L
.46172 .13509 L
.49955 .11827 L
.53984 .10254 L
.57861 .08924 L
.61984 .07679 L
.65954 .06624 L
.69774 .05724 L
.73838 .04874 L
.77751 .04146 L
.81909 .03458 L
.85916 .02868 L
.89771 .02359 L
.93871 .01872 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{498.25, 307.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007b0001<b000`400?l00000o`00003oo`3ooooc
0?ooo`00o`3ooooc0?ooo`00o`3ooooc0?ooo`00o`3ooooc0?ooo`00o`3ooooc0?ooo`00o`3ooooc
0?ooo`00o`3ooooc0?ooo`00o`3ooooc0?ooo`00o`3ooolM0?ooo`H00000d03oool00?l0oooo7P3o
ool01@000000oooo0?ooo`3oool000000=00oooo003o0?oooal0oooo00<000000?ooo`3oool0d@3o
ool00?l0oooo7`3oool00`000000oooo0?ooo`3A0?ooo`00o`3ooolP0?ooo`030000003oool0oooo
0=00oooo003o0?oooad0oooo00D000000?ooo`3oool0oooo0000003A0?ooo`00o`3ooolM0?ooo`H0
0000d03oool00?l0ooool`3oool00?l0ooool`3oool00?l0ooool`3oool00?l0ooool`3oool00?l0
ooool`3oool00?l0ooool`3oool00?l0ooool`3oool00?l0ooool`3oool00?l0ooool`3oool00?l0
ooool`3oool00?l0ooool`3oool005H0oooo0`00001L0?ooo`<000000`3oool010000000oooo0?oo
o`3oool3000005`0oooo0`00001K0?ooo`<000000`3oool010000000oooo0?ooo`3oool3000005/0
oooo1@0000090?ooo`00E@3oool01@000000oooo0?ooo`3oool0000005X0oooo00D000000?ooo`3o
ool0oooo000000090?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0F`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo05T0oooo00@000000?ooo`3oool000002@3oool0
05D0oooo00D000000?ooo`3oool0oooo0000001J0?ooo`050000003oool0oooo0?ooo`0000002P3o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo00T0oooo001E0?ooo`050000003oool0
oooo0?ooo`000000FP3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
FP3oool00`000000oooo0?ooo`080?ooo`00E@3oool01@000000oooo0?ooo`3oool0000005X0oooo
00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool0F`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool0203oool005D0oooo00D000000?ooo`3oool0oooo0000001J0?ooo`050000003oool0oooo0?oo
o`0000002@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00L0oooo001E0?ooo`05
0000003oool0oooo0?ooo`000000FP3oool01@000000oooo0?ooo`3oool0000000H0oooo0`00001M
0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool01P3oool3000005l0oooo00<00000
0?ooo`3oool01`3oool005D0oooo00D000000?ooo`3oool0oooo0000001J0?ooo`050000003oool0
oooo0?ooo`0000001P3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo05/0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00L0oooo001E
0?ooo`050000003oool0oooo0?ooo`000000FP3oool01@000000oooo0?ooo`3oool0000000L0oooo
00<000000?ooo`3oool0F`3oool2000005`0oooo0P0000090?ooo`030000003oool0oooo05X0oooo
00D000000?ooo`3oool0oooo000000090?ooo`00EP3oool3000005`0oooo0`0000080?ooo`@00000
F`3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00L0oooo1000001J0?ooo`<00000
2P3oool00?l0ooool`3oool00?l0ooool`3oool00?l0ooool`3oool00?l0ooool`3oool00?l0oooo
l`3oool00?l0ooool`3oool00?l0ooool`3oool00?l0ooool`3oool004h0ooooo`00002U00000000
CP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`070?ooo`400000001>0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00L0oooo0@00
000004h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0
oooo0640oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0
oooo00L0oooo0@00000004h0oooo00<000000?ooo`3oool0o`3ooonQ0?ooo`400000001>0?ooo`03
0000003oool0oooo0?l0ooooX@3oool100000000CP3oool00`000000oooo0?ooo`3o0?oooi@0oooo
100000090?ooo`400000001>0?ooo`030000003oool0oooo0?l0ooooS03oool8000000d0oooo0@00
000004h0oooo00<000000?ooo`3oool0o`3ooon30?ooo`T000005@3oool100000000CP3oool00`00
0000oooo0?ooo`3o0?ooog/0oooo2000000N0?ooo`400000001>0?ooo`030000003oool0oooo0?l0
ooooL`3oool8000002H0oooo0@00000004h0oooo0P00003o0?ooof`0oooo2000000/0?ooo`<00000
001>0?ooo`030000003oool0oooo0?l0ooooHP3oool9000003H0oooo0@00000004h0oooo00<00000
0?ooo`3oool0o`3ooomJ0?ooo`P00000?`3oool100000000CP3oool00`000000oooo0?ooo`3o0?oo
oe<0oooo1`0000170?ooo`400000001>0?ooo`030000003oool0oooo0?l0ooooC@3oool6000004h0
oooo0@00000004h0oooo00<000000?ooo`3oool0o`3ooom70?ooo`H00000E03oool100000000CP3o
ool00`000000oooo0?ooo`3o0?oood40oooo1P00001J0?ooo`400000001>0?ooo`030000003oool0
oooo0?l0oooo?03oool500000600oooo0@00000004h0oooo00<000000?ooo`3oool0o`3ooolf0?oo
o`H00000I@3oool100000000CP3oool00`000000oooo0?ooo`3o0?oooc40oooo1@00001[0?ooo`40
0000001>0?ooo`030000003oool0oooo0?l0oooo;@3oool400000700oooo0@00000004h0oooo00<0
00000?ooo`3oool0o`3ooolY0?ooo`@00000M03oool100000000CP3oool00`000000oooo0?ooo`3o
0?ooobD0oooo1000001h0?ooo`400000001>0?ooo`800000o`3ooolR0?ooo`@00000NP3oool30000
0000CP3oool00`000000oooo0?ooo`3o0?oooad0oooo100000200?ooo`400000001>0?ooo`030000
003oool0oooo0?l0oooo6@3oool4000008@0oooo0@00000004h0oooo00<000000?ooo`3oool0o`3o
oolE0?ooo`@00000R03oool100000000CP3oool00`000000oooo0?ooo`3o0?oooa00oooo1@00002<
0?ooo`400000001>0?ooo`030000003oool0oooo0?l0oooo303oool400000940oooo0@00000004h0
oooo00<000000?ooo`3oool0o`3oool80?ooo`@00000U@3oool100000000CP3oool00`000000oooo
0?ooo`3o0?ooo`@0oooo1000002I0?ooo`400000001>0?ooo`030000003oool0oooo0?l0oooo1000
002M0?ooo`400000000R0?ooo`<000000`3oool010000000oooo0?ooo`3oool2000000D0oooo0P00
00050?ooo`8000001P3oool3000000T0oooo00<000000?ooo`3oool0n`3oool400000:40oooo0@00
00000240oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
203oool00`000000oooo0?ooo`3h0?ooo`<00000Y@3oool1000000008@3oool01@000000oooo0?oo
o`3oool0000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?D0
oooo0`00002X0?ooo`400000000G0?ooo`L000000`3oool01@000000oooo0?ooo`3oool0000000L0
oooo100000030?ooo`@000000`3oool400000080oooo00D000000?ooo`3oool0oooo000000080?oo
ool00000Y@0000000240oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool0kP3oool300000:l0oooo
0@0000000240oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0k03oool200000;80oooo0@000000
0240oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0000000T0oooo00<000000?ooo`3oool0j@3oool300000;@0oooo0@0000000240oooo
00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003o
ool0oooo0?ooo`000000203oool00`000000oooo0?ooo`3V0?ooo`<00000]`3oool1000000008@3o
ool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D00000
0?ooo`3oool0oooo000000080?ooo`030000003oool0oooo0>@0oooo0P00002j0?ooo`400000000R
0?ooo`<00000203oool3000000@0oooo0`0000040?ooo`<00000103oool3000000T0oooo00<00000
0?ooo`3oool0h@3oool300000;`0oooo0@00000004h0oooo00<000000?ooo`3oool0gP3oool30000
0;l0oooo0@00000004h0oooo00<000000?ooo`3oool0g03oool200000<80oooo0@00000004h0oooo
00<000000?ooo`3oool0f@3oool300000<@0oooo0@00000004h0oooo00<000000?ooo`3oool0e`3o
ool200000<L0oooo0@00000004h0oooo00<000000?ooo`3oool0e@3oool200000<T0oooo0@000000
04h0oooo00<000000?ooo`3oool0dP3oool300000</0oooo0@00000004h0oooo0P00003A0?ooo`80
0000c03oool300000000CP3oool00`000000oooo0?ooo`3=0?ooo`<00000d03oool100000000CP3o
ool00`000000oooo0?ooo`3;0?ooo`800000d`3oool100000000CP3oool00`000000oooo0?ooo`39
0?ooo`800000e@3oool100000000CP3oool00`000000oooo0?ooo`370?ooo`800000e`3oool10000
0000CP3oool00`000000oooo0?ooo`340?ooo`<00000f@3oool100000000CP3oool00`000000oooo
0?ooo`320?ooo`800000g03oool100000000CP3oool00`000000oooo0?ooo`300?ooo`800000gP3o
ool100000000CP3oool00`000000oooo0?ooo`2n0?ooo`800000h03oool100000000CP3oool00`00
0000oooo0?ooo`2l0?ooo`800000hP3oool100000000CP3oool00`000000oooo0?ooo`2j0?ooo`80
0000i03oool100000000CP3oool00`000000oooo0?ooo`2h0?ooo`800000iP3oool100000000CP3o
ool00`000000oooo0?ooo`2f0?ooo`800000j03oool100000000CP3oool200000;D0oooo0P00003X
0?ooo`<00000001>0?ooo`030000003oool0oooo0;80oooo0P00003/0?ooo`400000001>0?ooo`03
0000003oool0oooo0;00oooo0P00003^0?ooo`400000001>0?ooo`030000003oool0oooo0:h0oooo
0P00003`0?ooo`400000001>0?ooo`030000003oool0oooo0:`0oooo0P00003b0?ooo`400000001>
0?ooo`030000003oool0oooo0:X0oooo0P00003d0?ooo`400000001>0?ooo`030000003oool0oooo
0:P0oooo0P00003f0?ooo`400000001>0?ooo`030000003oool0oooo0:H0oooo0P00003h0?ooo`40
0000001>0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0n03oool100000000CP3o
ool00`000000oooo0?ooo`2S0?ooo`800000n`3oool100000000CP3oool00`000000oooo0?ooo`2Q
0?ooo`800000o@3oool100000000CP3oool00`000000oooo0?ooo`2O0?ooo`800000o`3oool10000
0000CP3oool00`000000oooo0?ooo`2M0?ooo`800000o`3oool20?ooo`400000001>0?ooo`800000
W@3oool00`000000oooo0?ooo`3o0?ooo`<00000001>0?ooo`030000003oool0oooo09X0oooo0P00
003o0?ooo`D0oooo0@00000004h0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`3o
0?ooo`D0oooo0@00000004h0oooo00<000000?ooo`3oool0U`3oool200000?l0oooo203oool10000
0000CP3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo0?l0oooo203oool100000000
CP3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0?l0oooo2@3oool100000000CP3o
ool00`000000oooo0?ooo`2C0?ooo`800000o`3oool<0?ooo`400000001>0?ooo`030000003oool0
oooo0980oooo00<000000?ooo`3oool0o`3oool<0?ooo`400000001>0?ooo`030000003oool0oooo
0900oooo0P00003o0?ooo`l0oooo0@00000004h0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`3o0?ooo`l0oooo0@0000000280oooo0`0000030?ooo`040000003oool0oooo0?ooo`80
00001@3oool2000000D0oooo0P0000060?ooo`<000002@3oool00`000000oooo0?ooo`2=0?ooo`80
0000o`3ooolB0?ooo`400000000Q0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3o0?oo
oa80oooo0@0000000240oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo0?l0oooo4`3oool1
000000005`3oool7000000<0oooo00D000000?ooo`3oool0oooo000000070?ooo`@000000`3oool4
000000<0oooo100000020?ooo`050000003oool0oooo0?ooo`000000203oool3000008T0oooo0P00
003o0?oooa<0oooo100000000240oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003o
ool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3o
ool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`28
0?ooo`030000003oool0oooo0?l0oooo5P3oool1000000008@3oool01@000000oooo0?ooo`3oool0
000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000
0P3oool01@000000oooo0?ooo`3oool000000080oooo0P0000020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`3o0?oooaL0oooo0@0000000240oooo
00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool00000000000T0oooo00<000000?ooo`3oool0Q@3oool200000?l0oooo6P3oool1000000008@3o
ool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0?l0oooo6P3oool1
000000008@3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo0?l0
oooo6`3oool1000000008P3oool3000000P0oooo0`0000040?ooo`<00000103oool3000000H0oooo
0P0000080?ooo`030000003oool0oooo0840oooo0P00003o0?oooah0oooo0@00000004h0oooo00<0
00000?ooo`3oool0P03oool00`000000oooo0?ooo`3o0?oooah0oooo0@00000004h0oooo00<00000
0?ooo`3oool0O`3oool00`000000oooo0?ooo`3o0?oooal0oooo0@00000004h0oooo00<000000?oo
o`3oool0O@3oool200000?l0oooo8P3oool100000000CP3oool00`000000oooo0?ooo`1l0?ooo`03
0000003oool0oooo0?l0oooo8P3oool100000000CP3oool00`000000oooo0?ooo`1k0?ooo`030000
003oool0oooo0?l0oooo8`3oool100000000CP3oool00`000000oooo0?ooo`1j0?ooo`030000003o
ool0oooo0?l0oooo903oool100000000CP3oool2000007T0oooo0P00003o0?ooobD0oooo0`000000
04h0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`3o0?ooobL0oooo0@00000004h0
oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`3o0?ooobP0oooo0@00000004h0oooo
00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`3o0?ooobT0oooo0@00000004h0oooo00<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`3o0?ooobX0oooo0@00000004h0oooo00<00000
0?ooo`3oool0LP3oool200000?l0oooo;@3oool100000000CP3oool00`000000oooo0?ooo`1a0?oo
o`030000003oool0oooo0?l0oooo;@3oool100000000CP3oool00`000000oooo0?ooo`1`0?ooo`03
0000003oool0oooo0?l0oooo;P3oool100000000CP3oool00`000000oooo0?ooo`1_0?ooo`030000
003oool0oooo0?l0oooo;`3oool100000000CP3oool00`000000oooo0?ooo`1^0?ooo`030000003o
ool0oooo0?l0oooo<03oool100000000CP3oool00`000000oooo0?ooo`1/0?ooo`800000o`3ooolc
0?ooo`400000001>0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0o`3ooolc0?oo
o`400000001>0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0o`3ooold0?ooo`40
0000001>0?ooo`800000JP3oool00`000000oooo0?ooo`3o0?oooc<0oooo0`00000004h0oooo00<0
00000?ooo`3oool0J03oool00`000000oooo0?ooo`3o0?ooocH0oooo0@00000004h0oooo00<00000
0?ooo`3oool0I`3oool00`000000oooo0?ooo`3o0?ooocL0oooo0@00000004h0oooo00<000000?oo
o`3oool0IP3oool00`000000oooo0?ooo`3o0?ooocP0oooo0@00000000H0oooo00<000000?ooo`3o
ool0A@3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0?l0oooo>@3oool100000000
1P3oool3000004D0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`3o0?ooocX0oooo
0@00000000H0oooo00<000000?ooo`3oool00`0000120?ooo`030000003oool0oooo06<0oooo00<0
00000?ooo`3oool0o`3ooolk0?ooo`400000000;0?ooo`800000@@3oool00`000000oooo0?ooo`1R
0?ooo`030000003oool0oooo0?l0oooo?03oool1000000001P3oool00`000000oooo0?ooo`020000
04<0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`3o0?oooc`0oooo0@00000000H0
oooo0`0000150?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0o`3ooolm0?ooo`40
000000060?ooo`030000003oool0oooo00<00000@P3oool00`000000oooo0?ooo`1P0?ooo`030000
003oool0oooo0?l0oooo?P3oool1000000002`3oool200000440oooo00<000000?ooo`3oool0G`3o
ool00`000000oooo0?ooo`3o0?ooocl0oooo0@00000000H0oooo00<000000?ooo`3oool00P000013
0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0o`3ooom00?ooo`40000000060?oo
o`<00000A@3oool2000005h0oooo00<000000?ooo`3oool0o`3ooolo0?ooo`<0000000060?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`3o0?oood80
oooo0@00000000D0oooo2@0000100?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
o`3ooom30?ooo`40000000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0?@3o
ool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0?l0ooooA03oool1000000000`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0F@3oool0
0`000000oooo0?ooo`3o0?ooodD0oooo0@00000000H0oooo0P0000040?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3o0?ooodH0oooo0@00000000H0
oooo00<000000?ooo`3oool00P3oool200000440oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`3o0?ooodL0oooo0@00000000H0oooo00<000000?ooo`3oool00P0000000`3oool00000
0?ooo`100?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0o`3ooom80?ooo`400000
00060?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo0?l0ooooB03oool1000000001P3oool2000000@0oooo00<00000
0?ooo`3oool04`3oool3000000<0oooo00@000000?ooo`3oool0oooo0P0000050?ooo`8000001@3o
ool2000000P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1E0?ooo`030000003o
ool0oooo0?l0ooooB@3oool1000000001P3oool00`000000oooo0?ooo`020?ooo`800000503oool0
1@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo0?l0ooooBP3oool1000000008@3oool01@000000oooo0?ooo`3o
ool0000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1C0?ooo`030000003o
ool0oooo0?l0ooooB`3oool1000000000`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00D0oooo1`0000030?ooo`050000003oool0oooo0?ooo`0000001`3oool4000000<0oooo1000
00030?ooo`@0000000<0oooo000000000000100000080?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool0o`3ooom<0?ooo`40000000040?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0403oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`070?ooo`<00000D@3oool00`000000oooo0?ooo`3o
0?ooodX0oooo1000000000D0oooo2@00000C0?ooo`050000003oool0oooo0?ooo`0000001P3oool0
1@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
0500oooo00<000000?ooo`3oool0o`3ooom>0?ooo`400000000Q0?ooo`050000003oool0oooo0?oo
o`0000001P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000
00020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000090?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool0o`3ooom?0?ooo`400000000Q0?ooo`050000003o
ool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3o
ool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo00000009
0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0o`3ooom@0?ooo`400000000Q0?oo
o`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool000000080oooo00D0
00000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000103oool2000000T0
oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3o0?oooe40oooo0@0000000280oooo
0`0000080?ooo`<00000103oool3000000@0oooo0`0000060?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3o0?oooe40oooo0@00000004h0oooo00<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?oooe80oooo0@00000004h0oooo00<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?oooe<0oooo0@00000004h0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`3o0?oooe@0oooo0@00000004h0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`3o0?oooeD0oooo0@00000004h0oooo00<000000?ooo`3oool0
B03oool00`000000oooo0?ooo`3o0?oooeH0oooo0@00000004h0oooo00<000000?ooo`3oool0A`3o
ool00`000000oooo0?ooo`3o0?oooeL0oooo0@00000004h0oooo00<000000?ooo`3oool0A`3oool0
0`000000oooo0?ooo`3o0?oooeL0oooo0@00000004h0oooo0P0000170?ooo`030000003oool0oooo
0?l0ooooEP3oool300000000CP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0?l0
ooooF@3oool100000000CP3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0?l0oooo
FP3oool100000000CP3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0?l0ooooFP3o
ool100000000CP3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0?l0ooooF`3oool1
00000000CP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0?l0ooooG03oool10000
0000CP3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0?l0ooooG@3oool100000000
CP3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0?l0ooooG@3oool100000000CP3o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0?l0ooooGP3oool100000000CP3oool0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0?l0ooooG`3oool100000000CP3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo0?l0ooooH03oool100000000CP3oool00`000000
oooo0?ooo`0n0?ooo`030000003oool0oooo0?l0ooooH03oool100000000CP3oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo0?l0ooooH@3oool100000000CP3oool2000003d0oooo00<0
00000?ooo`3oool0o`3ooomP0?ooo`<00000001>0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool0o`3ooomS0?ooo`400000001>0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0o`3ooomS0?ooo`400000001>0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3o
ool0o`3ooomT0?ooo`400000001>0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
o`3ooomU0?ooo`400000001>0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0o`3o
oomV0?ooo`400000001>0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0o`3ooomV
0?ooo`400000001>0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0o`3ooomW0?oo
o`400000001>0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0o`3ooomX0?ooo`40
0000001>0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0o`3ooomY0?ooo`400000
001>0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0o`3ooomY0?ooo`400000001>
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0o`3ooomZ0?ooo`400000001>0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool0o`3ooom[0?ooo`400000001>0?ooo`80
0000=03oool00`000000oooo0?ooo`3o0?ooofT0oooo0`00000004h0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`3o0?ooof`0oooo0@00000004h0oooo00<000000?ooo`3oool0<@3o
ool00`000000oooo0?ooo`3o0?ooofd0oooo0@00000004h0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`3o0?ooofh0oooo0@00000004h0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`3o0?ooofh0oooo0@00000004h0oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`3o0?ooofl0oooo0@00000004h0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`3o0?ooog00oooo0@00000004h0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`3o0?ooog00oooo0@00000004h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`3o
0?ooog40oooo0@0000000280oooo0`0000030?ooo`040000003oool0oooo0?ooo`8000001@3oool2
000000D0oooo0P0000050?ooo`D00000203oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo0?l0ooooLP3oool1000000008@3oool01@000000oooo0?ooo`3oool0000000P0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0?l0ooooLP3o
ool1000000008@3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0ooooL`3oool1000000005`3oool7
000000<0oooo00D000000?ooo`3oool0oooo000000070?ooo`@000000`3oool4000000<0oooo1000
00050?ooo`030000003oool0oooo00L0oooo0`00000Z0?ooo`030000003oool0oooo0?l0ooooL@3o
ool4000000008@3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
0?l0ooooM@3oool1000000008@3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?oo
o`3oool0000000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo0?l0ooooM@3oool1000000008@3oool01@000000oooo0?ooo`3oool0000000H0oooo
00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo0?l0ooooMP3oool1000000008@3oool01@000000oooo0?ooo`3oool0
000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000
0P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo0?l0ooooM`3oool1000000008@3oool01@000000oooo
0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo
000000080?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0o`3ooomg0?ooo`400000
000R0?ooo`<00000203oool3000000@0oooo0`0000040?ooo`<00000103oool3000000T0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`3o0?ooogP0oooo0@00000004h0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`3o0?ooogP0oooo0@00000004h0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`3o0?ooogT0oooo0@00000004h0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`3o0?ooogX0oooo0@00000004h0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`3o0?ooogX0oooo0@00000004h0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`3o0?ooog/0oooo0@00000004h0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`3o0?ooog/0oooo0@00000004h0oooo0P00000S0?ooo`030000003oool0oooo
0?l0ooooNP3oool300000000CP3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0?l0
ooooO03oool100000000CP3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0oooo
O@3oool100000000CP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0?l0ooooOP3o
ool100000000CP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0?l0ooooOP3oool1
00000000CP3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0ooooO`3oool10000
0000CP3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0ooooO`3oool100000000
CP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0?l0ooooP03oool100000000CP3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0?l0ooooP@3oool100000000CP3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0?l0ooooP@3oool100000000CP3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo0?l0ooooPP3oool100000000CP3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo0?l0ooooPP3oool100000000CP3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo0?l0ooooP`3oool100000000CP3oool2000001`0oooo00<0
00000?ooo`3oool0o`3ooon10?ooo`<00000001>0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0o`3ooon40?ooo`400000001>0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0o`3ooon50?ooo`400000001>0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0o`3ooon50?ooo`400000001>0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
o`3ooon60?ooo`400000001>0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3o
oon60?ooo`400000001>0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0o`3ooon7
0?ooo`400000001>0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0o`3ooon80?oo
o`400000001>0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0o`3ooon80?ooo`40
0000001>0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3ooon90?ooo`400000
001>0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3ooon90?ooo`400000001>
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0o`3ooon:0?ooo`400000001>0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0o`3ooon:0?ooo`400000001>0?ooo`80
0000503oool00`000000oooo0?ooo`3o0?ooohT0oooo0`00000004h0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`3o0?oooh/0oooo0@00000004h0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`3o0?oooh`0oooo0@00000004h0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3o0?oooh`0oooo0@00000004h0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`3o0?ooohd0oooo0@00000004h0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`3o0?ooohd0oooo0@00000004h0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`3o0?ooohh0oooo0@00000004h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`3o0?ooohh0oooo0@00000004h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o
0?ooohl0oooo0@00000004h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?oo
oi00oooo0@00000002T0oooo0`0000030?ooo`040000003oool0oooo0?ooo`8000001@3oool20000
00D0oooo0P00000;0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooon@0?oo
o`400000000X0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0?l0ooooT@3oool100000000:03oool01@000000oooo0?ooo`3oool00000
00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?oooi40oooo0@00000001h0
oooo1`0000030?ooo`050000003oool0oooo0?ooo`0000001`3oool4000000<0oooo100000030?oo
o`@00000203oool3000000`0oooo00<000000?ooo`3oool0o`3ooon?0?ooo`@00000000X0?ooo`05
0000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool000000080oooo00D00000
0?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooTP3oool100000000:03oool01@000000oooo0?oo
o`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`3o0?oooi<0oooo0@00000002P0oooo00D000000?ooo`3oool0oooo00000006
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo
00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0o`3ooonC0?ooo`400000000X0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000
oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`000000203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooU03o
ool100000000:03oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?oooi@0oooo0@00000002T0
oooo0`0000080?ooo`<00000103oool3000000@0oooo0`0000090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0o`3ooonE0?ooo`400000001>0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0o`3ooonE0?ooo`400000001>0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0o`3ooonF0?ooo`400000001>0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0o`3ooonF0?ooo`400000001>0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0o`3ooonG0?ooo`400000001>0?ooo`030000003oool0oooo0?l0ooooX@3oool100000000
CP3oool00`000000oooo0?ooo`3o0?oooj40oooo0@00000004h0oooo0P0000080?ooo`030000003o
ool0oooo0600oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1Q0?ooo`030000003o
ool0oooo0640oooo00<000000?ooo`3oool01@3oool300000000CP3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`07
0?ooo`400000001>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00L0oooo0@00000004h0ooooo`00002U00000000
o`3ooooc0?ooo`00o`3ooooc0?ooo`00o`3ooooc0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 497.25}, {306.938, 0}} -> {-0.441462, -1.00011, \
0.00501176, 3.87085*^-06}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ 
      Find\ chi\ square\ for\ given\ H \((z)\)\ \ *) \[IndentingNewLine]\(f[
          z_] := 1/hhz[z];\)\), "\n", 
    \(\(rr[zz_] := NIntegrate[f[z], {z, 0, zz}];\)\[IndentingNewLine]\n (*\ 
      Construct\ marginalization\ coefficients\ \((see\ \ astro - 
              ph/0401556\  .. )\)\ *) \), "\[IndentingNewLine]", 
    \(Clear[chi2fa, chi2fb, chi2fc]\), "\n", 
    \(\(chi2fa = 
        Sum[\((ld[i] - 5\ Log[10, rr[zz[i]]*\((1 + zz[i])\)])\)^2/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\n", 
    \(\(chi2fb = 
        Sum[\((ld[i] - 
                5\ Log[10, rr[zz[i]]*\((1 + zz[i])\)])\)/\((sld[i]^2)\), {i, 
            1, ndat}];\)\), "\n", 
    \(\(chi2fc = 
        Sum[1/\((sld[i]^2)\), {i, 1, ndat}];\)\[IndentingNewLine]\n (*\ 
      Construct\ function\ after\ marginalization, \ 
      find\ same\ result\ as\ with\ mb\ minimization\ *) \), "\
\[IndentingNewLine]", 
    \(chi2fm = chi2fa - chi2fb^2/chi2fc\), "\[IndentingNewLine]", 
    \(dchi2q01 = chi2fm - chi2l\)}], "Input"],

Cell[BoxData[
    \(177.13361215218902`\)], "Output"],

Cell[BoxData[
    \(0.006240717135369778`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ \(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(\
--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(-\(---\)\)\)\)\)\)\)\)\)\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)*) \[IndentingNewLine]\[IndentingNewLine] \
(*\ Find\ H \((z)\)\ for\ given\ slope\ s\ of\ the\ linear\ potential . \ 
            Present\ time\  = \ \(tt\ \((corresponds\ to\ a = 1)\) . \ 
              Run\ trials\ for\ initial\ condition\ for\ field\ fi\ \((f0)\)\ \
and\ initial\ time\ ti\ until\ we\ get\ field\ energy\ enf\  = \ \(0.7\ and\ \
H \((z = 0)\)\  = 
            1\ at\ present\ time\ \(\(tt\)\(.\)\)\)\)\ *) \[IndentingNewLine]\
\[IndentingNewLine] (*\ \(--\(--\(--\(--\ \ s\)\)\)\)\  = \ \(0.2\ \ \ --\) \
\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(---\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\ *) \
\[IndentingNewLine]\[IndentingNewLine]\(Clear[aa, fi, a, aad, aadd, fidas, 
        tas, f, rr, hht, hha];\)\), "\[IndentingNewLine]", 
    \(aa = a[t]; \ fi = f[t];\), "\n", 
    \(\(aad = D[aa, t];\)\), "\n", 
    \(\(aadd = D[aa, {t, 2}];\)\), "\n", 
    \(\(fid = D[fi, t];\)\), "\n", 
    \(\(fidd = D[fi, {t, 2}];\)\), "\n", 
    \(ti = 0.000025; \ t0 = 2.25;\), "\n", 
    \(\(f0 = \(-3.51\);\)\ \), "\n", 
    \(om0m = 0.3; \ ss = 0.2;\), "\n", 
    \(\(eq1 = 
        aadd/aa\  \[Equal] \(-\ \ fid^2\)\  - \ ss\ fi\  - \ 
            om0m/\((2\ aa^3)\);\)\), "\n", 
    \(\(eq2 = 
        fidd\ \  + \ \ \ 3\ \ fid\ \((aad/aa)\)\  - \ ss \[Equal] 
          0;\)\), "\n", 
    \(\(eqb1 = f[ti] == f0;\)\), "\n", 
    \(\(eqb2 = \(f'\)[ti] == 0;\)\), "\n", 
    \(\(eqb3 = 
        a[ti] \[Equal] \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((2/3)\);\)\), "\n", 
    \(\(eqb4 = \(a'\)[
            ti] \[Equal] \((2/
                3)\)\ \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((\(-1\)/
                  3)\);\)\), "\n", 
    \(\(sol2 = 
        NDSolve[{eq1, eq2, eqb1, eqb2, eqb3, eqb4}, {aa, fi}, {t, ti, t0}, 
          MaxSteps \[Rule] 10000000];\)\), "\n", 
    \(\(asol = Part[Evaluate[a[t] /. sol2], 1];\)\), "\n", 
    \(\(fsol = Part[Evaluate[f[t] /. sol2], 1];\)\), "\[IndentingNewLine]", 
    \(\(Plot[asol, {t, ti, t0}, PlotRange -> All];\)\), "\n", 
    \(\(dfsol = D[fsol, t];\)\), "\[IndentingNewLine]", 
    \(\(enf = 0.5\ dfsol^2\  - \ ss\ fsol;\)\), "\[IndentingNewLine]", 
    \(\(as[t1_] := asol\  /. \ t -> t1\ ;\)\), "\[IndentingNewLine]", 
    \(\(tt = Part[FindRoot[as[t] == 1, {t, 1}], 1, 2];\)\), "\n", 
    \(\(tas[a_] := 
        Part[FindRoot[as[t] \[Equal] a, {t, 1}], 1, 2];\)\), "\n", 
    \(\(hht[t1_] := D[asol, t]/asol\  /. \ t -> t1\ ;\)\), "\n", 
    \(\(hha[a_] := hht[tas[a]];\)\), "\[IndentingNewLine]", 
    \(\(hhz[z_] := hha[1/\((z + 1)\)];\)\), "\[IndentingNewLine]", 
    \(enf\  /. \ t \[Rule] tt\), "\[IndentingNewLine]", 
    \(hhz[0]\), "\[IndentingNewLine]", 
    \(\(enf = 0.5\ dfsol^2\  - \ ss\ fsol;\)\), "\n", 
    \(\(ppf = 0.5\ dfsol^2\  + \ ss\ fsol;\)\), "\n", 
    \(\(wft[t1_] := ppf/enf\  /. \ t -> t1\ ;\)\ \), "\n", 
    \(\(wfa[a_] := wft[tas[a]];\)\), "\n", 
    \(\(wfz[z_] := wfa[1/\((z + 1)\)];\)\), "\n", 
    \(\(plw02q = 
        Plot[wfz[z], {z, 0, 2}, Frame \[Rule] True, PlotRange \[Rule] All, 
          FrameLabel \[Rule] {"\<z\>", "\<w(z)\>"}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0237989 0.423285 0.0145721 0.190132 [
[.23544 .00207 -10.7813 -17.8125 ]
[.23544 .00207 10.7813 0 ]
[.44708 .00207 -5.53125 -17.8125 ]
[.44708 .00207 5.53125 0 ]
[.65873 .00207 -10.7813 -17.8125 ]
[.65873 .00207 10.7813 0 ]
[.87037 .00207 -5.53125 -17.8125 ]
[.87037 .00207 5.53125 0 ]
[.0113 .10964 -21.5625 -8.90625 ]
[.0113 .10964 0 8.90625 ]
[.0113 .2047 -11.0625 -8.90625 ]
[.0113 .2047 0 8.90625 ]
[.0113 .29977 -21.5625 -8.90625 ]
[.0113 .29977 0 8.90625 ]
[.0113 .39484 -11.0625 -8.90625 ]
[.0113 .39484 0 8.90625 ]
[.0113 .4899 -21.5625 -8.90625 ]
[.0113 .4899 0 8.90625 ]
[.0113 .58497 -11.0625 -8.90625 ]
[.0113 .58497 0 8.90625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23544 .01457 m
.23544 .02082 L
s
gsave
.23544 .00207 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.44708 .01457 m
.44708 .02082 L
s
gsave
.44708 .00207 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.65873 .01457 m
.65873 .02082 L
s
gsave
.65873 .00207 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.87037 .01457 m
.87037 .02082 L
s
gsave
.87037 .00207 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.06613 .01457 m
.06613 .01832 L
s
.10846 .01457 m
.10846 .01832 L
s
.15078 .01457 m
.15078 .01832 L
s
.19311 .01457 m
.19311 .01832 L
s
.27777 .01457 m
.27777 .01832 L
s
.3201 .01457 m
.3201 .01832 L
s
.36243 .01457 m
.36243 .01832 L
s
.40476 .01457 m
.40476 .01832 L
s
.48941 .01457 m
.48941 .01832 L
s
.53174 .01457 m
.53174 .01832 L
s
.57407 .01457 m
.57407 .01832 L
s
.6164 .01457 m
.6164 .01832 L
s
.70106 .01457 m
.70106 .01832 L
s
.74338 .01457 m
.74338 .01832 L
s
.78571 .01457 m
.78571 .01832 L
s
.82804 .01457 m
.82804 .01832 L
s
.9127 .01457 m
.9127 .01832 L
s
.95503 .01457 m
.95503 .01832 L
s
.99735 .01457 m
.99735 .01832 L
s
.25 Mabswid
0 .01457 m
1 .01457 L
s
.0238 .10964 m
.03005 .10964 L
s
gsave
.0113 .10964 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.0238 .2047 m
.03005 .2047 L
s
gsave
.0113 .2047 -72.0625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.0238 .29977 m
.03005 .29977 L
s
gsave
.0113 .29977 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.0238 .39484 m
.03005 .39484 L
s
gsave
.0113 .39484 -72.0625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.0238 .4899 m
.03005 .4899 L
s
gsave
.0113 .4899 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.0238 .58497 m
.03005 .58497 L
s
gsave
.0113 .58497 -72.0625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.0238 .03359 m
.02755 .03359 L
s
.0238 .0526 m
.02755 .0526 L
s
.0238 .07161 m
.02755 .07161 L
s
.0238 .09062 m
.02755 .09062 L
s
.0238 .12865 m
.02755 .12865 L
s
.0238 .14766 m
.02755 .14766 L
s
.0238 .16668 m
.02755 .16668 L
s
.0238 .18569 m
.02755 .18569 L
s
.0238 .22372 m
.02755 .22372 L
s
.0238 .24273 m
.02755 .24273 L
s
.0238 .26174 m
.02755 .26174 L
s
.0238 .28076 m
.02755 .28076 L
s
.0238 .31878 m
.02755 .31878 L
s
.0238 .3378 m
.02755 .3378 L
s
.0238 .35681 m
.02755 .35681 L
s
.0238 .37582 m
.02755 .37582 L
s
.0238 .41385 m
.02755 .41385 L
s
.0238 .43286 m
.02755 .43286 L
s
.0238 .45188 m
.02755 .45188 L
s
.0238 .47089 m
.02755 .47089 L
s
.0238 .50891 m
.02755 .50891 L
s
.0238 .52793 m
.02755 .52793 L
s
.0238 .54694 m
.02755 .54694 L
s
.0238 .56595 m
.02755 .56595 L
s
.0238 .60398 m
.02755 .60398 L
s
.25 Mabswid
.0238 0 m
.0238 .61803 L
s
.5 Mabswid
.02381 .01472 m
.02499 .01789 L
.02605 .01966 L
.02846 .02282 L
.03279 .02736 L
.04262 .03551 L
.06244 .04845 L
.10458 .07024 L
.14451 .08791 L
.18292 .10368 L
.22379 .11983 L
.26314 .1352 L
.30098 .15008 L
.34126 .16626 L
.38004 .18235 L
.42126 .2002 L
.46097 .21827 L
.49916 .23662 L
.53981 .25733 L
.57894 .27858 L
.62052 .30272 L
.66059 .32768 L
.69914 .35341 L
.74014 .38281 L
.77963 .41328 L
.8176 .44475 L
.85802 .48079 L
.89693 .51816 L
.93829 .56101 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{526.063, 325.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003oo`3ooooo
0?oooa00oooo003o0?ooool0oooo403oool00?l0ooooo`3oool@0?ooo`00o`3ooooo0?oooa00oooo
003o0?ooool0oooo403oool00?l0ooooo`3oool@0?ooo`00Q03oool3000000<0oooo00@000000?oo
o`3oool0oooo0`00001Q0?ooo`<00000H@3oool3000000<0oooo00@000000?ooo`3oool0oooo0`00
001Q0?ooo`D00000A@3oool008<0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003o
ool0oooo05l0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo05l0oooo00@000000?ooo`3oool00000A@3oool008<0oooo00D000000?ooo`3oool0oooo
0000000:0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0A@3oool008<0oooo00D0
00000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0
H@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0
A03oool008<0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo05h0oooo
00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0600oooo
00<000000?ooo`3oool0A03oool008<0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000
003oool0oooo05l0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0680oooo00<000000?ooo`3oool0@`3oool008<0oooo00D000000?ooo`3oool0oooo
000000060?ooo`<00000HP3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00H0oooo
0`00001U0?ooo`030000003oool0oooo04<0oooo00230?ooo`050000003oool0oooo0?ooo`000000
1P3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo04<0oooo00230?ooo`050000003o
ool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`1P0?ooo`800000HP3oool2000000T0oooo
00<000000?ooo`3oool0H03oool01@000000oooo0?ooo`3oool0000004D0oooo00240?ooo`<00000
203oool400000600oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`070?ooo`@00000
H03oool3000004H0oooo003o0?ooool0oooo403oool00240oooo00<000000?ooo`3oool0o`3oooo[
0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooon/0oooo000Q0?ooo`030000003oool0oooo0?l0
ooooj`3oool00240oooo00<000000?ooo`3oool0o`3oooo[0?ooo`008@3oool00`000000oooo0?oo
o`3o0?ooon/0oooo000Q0?ooo`030000003oool0oooo0?l0ooooj`3oool00240oooo00<000000?oo
o`3oool0o`3oooo[0?ooo`005@3ooooo00000?@000001P3oool00240oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00H0oooo000Q0?ooo`8000004`3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00H0oooo000Q0?ooo`800000I`3oool0
0`000000oooo0?ooo`1W0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0IP3oool0
0`000000oooo0?ooo`150?ooo`008@3oool00`000000oooo0000001V0?ooo`030000003oool0oooo
06L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo
04D0oooo000Q0?ooo`040000003oool0oooo00000?l0oooojP3oool00240oooo00D000000?ooo`3o
ool0oooo0000003o0?ooonT0oooo000Q0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0o`3ooooV0?ooo`008@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo
i@3oool00240oooo00<000000?ooo`3oool0103oool200000?l0ooooi@3oool00240oooo0`000006
0?ooo`030000003oool0oooo0?l0oooohP3oool00240oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`3o0?ooon40oooo000Q0?ooo`030000003oool0oooo00P0oooo0P00003o0?ooon40
oooo000Q0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooooN0?ooo`008@3o
ool00`000000oooo0?ooo`0;0?ooo`800000o`3ooooN0?ooo`008@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo0?l0oooof`3oool00240oooo00<000000?ooo`3oool03P3oool20000
0?l0oooof`3oool00240oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?ooomP0
oooo000Q0?ooo`030000003oool0oooo0140oooo0P00003o0?ooomP0oooo000Q0?ooo`<000004`3o
ool200000?l0ooooeP3oool00240oooo00<000000?ooo`3oool05@3oool200000?l0ooooe03oool0
0240oooo00<000000?ooo`3oool05`3oool200000?l0oooodP3oool00240oooo00<000000?ooo`3o
ool06@3oool200000?l0ooood03oool00240oooo00<000000?ooo`3oool06`3oool200000?l0oooo
cP3oool00240oooo00<000000?ooo`3oool07@3oool200000?l0ooooc03oool00240oooo00<00000
0?ooo`3oool07`3oool200000?l0oooobP3oool00240oooo00<000000?ooo`3oool08@3oool20000
0?l0oooob03oool00240oooo00<000000?ooo`3oool08`3oool200000?l0ooooaP3oool00240oooo
00<000000?ooo`3oool09@3oool200000?l0ooooa03oool00240oooo0`00000W0?ooo`800000o`3o
ooo20?ooo`008@3oool00`000000oooo0?ooo`0Y0?ooo`800000o`3oooo00?ooo`008@3oool00`00
0000oooo0?ooo`0[0?ooo`800000o`3ooonn0?ooo`008@3oool00`000000oooo0?ooo`0]0?ooo`80
0000o`3ooonl0?ooo`008@3oool00`000000oooo0?ooo`0_0?ooo`<00000o`3oooni0?ooo`008@3o
ool00`000000oooo0?ooo`0b0?ooo`800000o`3ooong0?ooo`008@3oool00`000000oooo0?ooo`0d
0?ooo`800000o`3ooone0?ooo`008@3oool00`000000oooo0?ooo`0f0?ooo`800000o`3ooonc0?oo
o`008@3oool00`000000oooo0?ooo`0h0?ooo`<00000o`3ooon`0?ooo`008@3oool3000003/0oooo
0P00003o0?ooojh0oooo000Q0?ooo`030000003oool0oooo03d0oooo0P00003o0?oooj`0oooo000Q
0?ooo`030000003oool0oooo03l0oooo0`00003o0?ooojT0oooo000Q0?ooo`030000003oool0oooo
0480oooo0P00003o0?ooojL0oooo000Q0?ooo`030000003oool0oooo04@0oooo0`00003o0?oooj@0
oooo000Q0?ooo`030000003oool0oooo04L0oooo0P00003o0?oooj80oooo00090?ooo`<000000`3o
ool010000000oooo0?ooo`3oool3000000/0oooo00<000000?ooo`3oool0B@3oool200000?l0oooo
X03oool000P0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0B`3oool300000?l0ooooW@3oool000P0oooo00D000000?ooo`3oool0oooo
0000000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0CP3oool200000?l0oooo
V`3oool000P0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0D03oool300000?l0ooooV03oool000P0oooo00D000000?ooo`3oool0oooo
0000000:0?ooo`030000003oool0oooo00L0oooo1000001B0?ooo`<00000o`3ooonE0?ooo`00203o
ool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`1F0?ooo`800000o`3ooonC0?ooo`00203oool01@000000oooo0?ooo`3oool0000000H0oooo
0`00000;0?ooo`030000003oool0oooo05P0oooo0`00003o0?oooi00oooo00080?ooo`050000003o
ool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05/0oooo
0`00003o0?ooohd0oooo00080?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo05h0oooo0P00003o0?oooh/0oooo00090?ooo`<00000203o
ool4000000T0oooo00<000000?ooo`3oool0H03oool300000?l0ooooR03oool00240oooo00<00000
0?ooo`3oool0H`3oool300000?l0ooooQ@3oool00240oooo00<000000?ooo`3oool0IP3oool20000
0?l0ooooP`3oool00240oooo00<000000?ooo`3oool0J03oool300000?l0ooooP03oool00240oooo
0`00001[0?ooo`<00000o`3ooomm0?ooo`008@3oool00`000000oooo0?ooo`1^0?ooo`800000o`3o
oomk0?ooo`008@3oool00`000000oooo0?ooo`1`0?ooo`<00000o`3ooomh0?ooo`008@3oool00`00
0000oooo0?ooo`1c0?ooo`<00000o`3ooome0?ooo`008@3oool00`000000oooo0?ooo`1f0?ooo`80
0000o`3ooomc0?ooo`008@3oool00`000000oooo0?ooo`1h0?ooo`800000o`3oooma0?ooo`008@3o
ool00`000000oooo0?ooo`1j0?ooo`<00000o`3ooom^0?ooo`008@3oool00`000000oooo0?ooo`1m
0?ooo`800000o`3ooom/0?ooo`008@3oool00`000000oooo0?ooo`1o0?ooo`<00000o`3ooomY0?oo
o`008@3oool00`000000oooo0?ooo`220?ooo`800000o`3ooomW0?ooo`008@3oool3000008@0oooo
0P00003o0?ooofD0oooo000Q0?ooo`030000003oool0oooo08H0oooo0`00003o0?ooof80oooo000Q
0?ooo`030000003oool0oooo08T0oooo0P00003o0?ooof00oooo000Q0?ooo`030000003oool0oooo
08/0oooo0`00003o0?oooed0oooo000Q0?ooo`030000003oool0oooo08h0oooo0P00003o0?oooe/0
oooo000Q0?ooo`030000003oool0oooo0900oooo0`00003o0?oooeP0oooo000Q0?ooo`030000003o
ool0oooo09<0oooo0P00003o0?oooeH0oooo000Q0?ooo`030000003oool0oooo09D0oooo0`00003o
0?oooe<0oooo000Q0?ooo`030000003oool0oooo09P0oooo0P00003o0?oooe40oooo000Q0?ooo`<0
0000VP3oool300000?l0ooooCP3oool00240oooo00<000000?ooo`3oool0W@3oool200000?l0oooo
C03oool00240oooo00<000000?ooo`3oool0W`3oool200000?l0ooooBP3oool00240oooo00<00000
0?ooo`3oool0X@3oool300000?l0ooooA`3oool00240oooo00<000000?ooo`3oool0Y03oool20000
0?l0ooooA@3oool00240oooo00<000000?ooo`3oool0YP3oool300000?l0oooo@P3oool00240oooo
00<000000?ooo`3oool0Z@3oool200000?l0oooo@03oool00240oooo00<000000?ooo`3oool0Z`3o
ool200000?l0oooo?P3oool00240oooo00<000000?ooo`3oool0[@3oool300000?l0oooo>`3oool0
0240oooo0`00002`0?ooo`800000o`3oooli0?ooo`008@3oool00`000000oooo0?ooo`2b0?ooo`80
0000o`3ooolg0?ooo`008@3oool00`000000oooo0?ooo`2d0?ooo`<00000o`3ooold0?ooo`008@3o
ool00`000000oooo0?ooo`2g0?ooo`800000o`3ooolb0?ooo`008@3oool00`000000oooo0?ooo`2i
0?ooo`800000o`3oool`0?ooo`008@3oool00`000000oooo0?ooo`2k0?ooo`<00000o`3oool]0?oo
o`00503oool3000000X0oooo00<000000?ooo`3oool0_P3oool200000?l0oooo:`3oool001D0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`300?ooo`800000o`3ooolY0?ooo`005@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0<80oooo0`00003o0?ooobH0oooo000E
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0a@3oool200000?l0oooo903oool0
01D0oooo00<000000?ooo`3oool02@3oool400000<H0oooo0P00003o0?ooob80oooo000E0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0b@3oool200000?l0oooo803oool001D0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3;0?ooo`800000o`3ooolN0?ooo`005@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0<d0oooo0`00003o0?oooa/0oooo000D
0?ooo`8000002`3oool00`000000oooo0?ooo`3@0?ooo`800000o`3ooolI0?ooo`005@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0=80oooo0P00003o0?oooaL0oooo000Q0?ooo`03
0000003oool0oooo0=@0oooo0P00003o0?oooaD0oooo000Q0?ooo`030000003oool0oooo0=H0oooo
0`00003o0?oooa80oooo000Q0?ooo`030000003oool0oooo0=T0oooo0P00003o0?oooa00oooo000Q
0?ooo`<00000f`3oool200000?l0oooo3P3oool00240oooo00<000000?ooo`3oool0g@3oool20000
0?l0oooo303oool00240oooo00<000000?ooo`3oool0g`3oool200000?l0oooo2P3oool00240oooo
00<000000?ooo`3oool0h@3oool200000?l0oooo203oool00240oooo00<000000?ooo`3oool0h`3o
ool200000?l0oooo1P3oool00240oooo00<000000?ooo`3oool0i@3oool200000?l0oooo103oool0
0240oooo00<000000?ooo`3oool0i`3oool200000?l0oooo0P3oool00240oooo00<000000?ooo`3o
ool0j@3oool200000?l0oooo000Q0?ooo`030000003oool0oooo0>/0oooo0P00003m0?ooo`008@3o
ool00`000000oooo0?ooo`3]0?ooo`800000n`3oool00240oooo0`00003_0?ooo`800000n@3oool0
0240oooo00<000000?ooo`3oool0l@3oool200000?L0oooo000Q0?ooo`030000003oool0oooo0?<0
oooo0P00003e0?ooo`008@3oool00`000000oooo0?ooo`3e0?ooo`800000l`3oool00240oooo00<0
00000?ooo`3oool0m`3oool200000?40oooo000Q0?ooo`030000003oool0oooo0?T0oooo0P00003_
0?ooo`008@3oool00`000000oooo0?ooo`3k0?ooo`800000k@3oool00240oooo00<000000?ooo`3o
ool0o@3oool200000>/0oooo000Q0?ooo`030000003oool0oooo0?l0oooo0P00003Y0?ooo`008@3o
ool300000?l0oooo0P3oool200000>L0oooo000Q0?ooo`030000003oool0oooo0?l0oooo103oool2
00000>D0oooo000Q0?ooo`030000003oool0oooo0?l0oooo1P3oool00`000000oooo0?ooo`3R0?oo
o`008@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0P00003R0?ooo`008@3oool00`000000oooo
0?ooo`3o0?ooo`T0oooo0P00003P0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo`/0oooo00<0
00000?ooo`3oool0g@3oool00240oooo00<000000?ooo`3oool0o`3oool<0?ooo`800000g@3oool0
0240oooo00<000000?ooo`3oool0o`3oool>0?ooo`800000f`3oool00240oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`800000f@3oool00240oooo00<000000?ooo`3oool0o`3ooolB0?ooo`030000
003oool0oooo0=H0oooo000Q0?ooo`<00000o`3ooolC0?ooo`800000eP3oool00240oooo00<00000
0?ooo`3oool0o`3ooolE0?ooo`800000e03oool00240oooo00<000000?ooo`3oool0o`3ooolG0?oo
o`800000dP3oool00240oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030000003oool0oooo0<l0
oooo000Q0?ooo`030000003oool0oooo0?l0oooo6P3oool200000<l0oooo000Q0?ooo`030000003o
ool0oooo0?l0oooo703oool200000<d0oooo00090?ooo`<000000`3oool010000000oooo0?ooo`3o
ool3000000/0oooo00<000000?ooo`3oool0o`3ooolN0?ooo`800000b`3oool000X0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo803oool0
0`000000oooo0?ooo`380?ooo`002P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`800000b03oool000X0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`070?ooo`@00000o`3ooolR0?ooo`800000aP3oool000X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0oooo
9@3oool200000<@0oooo000:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0`@3oool000X0oooo00<00000
0?ooo`3oool01P3oool3000000/0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`800000`@3oool0
00X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0?l0oooo:P3oool200000;l0oooo00090?ooo`8000002@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0?l0oooo;03oool00`000000oooo0?ooo`2l0?ooo`002P3oool00`000000oooo
0?ooo`070?ooo`@000002@3oool00`000000oooo0?ooo`3o0?ooobd0oooo0P00002l0?ooo`008@3o
ool00`000000oooo0?ooo`3o0?ooobl0oooo0P00002j0?ooo`008@3oool00`000000oooo0?ooo`3o
0?oooc40oooo00<000000?ooo`3oool0]`3oool00240oooo00<000000?ooo`3oool0o`3ooolb0?oo
o`800000]`3oool00240oooo0`00003o0?oooc@0oooo0P00002e0?ooo`008@3oool00`000000oooo
0?ooo`3o0?ooocH0oooo00<000000?ooo`3oool0/P3oool00240oooo00<000000?ooo`3oool0o`3o
oolg0?ooo`800000/P3oool00240oooo00<000000?ooo`3oool0o`3oooli0?ooo`800000/03oool0
0240oooo00<000000?ooo`3oool0o`3ooolk0?ooo`030000003oool0oooo0:d0oooo000Q0?ooo`03
0000003oool0oooo0?l0oooo?03oool200000:d0oooo000Q0?ooo`030000003oool0oooo0?l0oooo
?P3oool00`000000oooo0?ooo`2Z0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooocl0oooo0P00
002Z0?ooo`008@3oool00`000000oooo0?ooo`3o0?oood40oooo00<000000?ooo`3oool0Y`3oool0
0240oooo0`00003o0?oood80oooo0P00002W0?ooo`008@3oool00`000000oooo0?ooo`3o0?oood@0
oooo00<000000?ooo`3oool0Y03oool00240oooo00<000000?ooo`3oool0o`3ooom50?ooo`030000
003oool0oooo0:<0oooo000Q0?ooo`030000003oool0oooo0?l0ooooAP3oool200000:<0oooo000Q
0?ooo`030000003oool0oooo0?l0ooooB03oool00`000000oooo0?ooo`2P0?ooo`008@3oool00`00
0000oooo0?ooo`3o0?ooodT0oooo0P00002P0?ooo`008@3oool00`000000oooo0?ooo`3o0?oood/0
oooo00<000000?ooo`3oool0W@3oool00240oooo00<000000?ooo`3oool0o`3ooom<0?ooo`800000
W@3oool00240oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo09X0oooo000Q
0?ooo`030000003oool0oooo0?l0ooooC`3oool00`000000oooo0?ooo`2I0?ooo`008@3oool30000
0?l0ooooD03oool2000009T0oooo000Q0?ooo`030000003oool0oooo0?l0ooooDP3oool00`000000
oooo0?ooo`2F0?ooo`008@3oool00`000000oooo0?ooo`3o0?oooe<0oooo00<000000?ooo`3oool0
U@3oool00240oooo00<000000?ooo`3oool0o`3ooomD0?ooo`800000U@3oool00240oooo00<00000
0?ooo`3oool0o`3ooomF0?ooo`030000003oool0oooo0980oooo000Q0?ooo`030000003oool0oooo
0?l0ooooE`3oool00`000000oooo0?ooo`2A0?ooo`008@3oool00`000000oooo0?ooo`3o0?oooeP0
oooo0P00002A0?ooo`008@3oool00`000000oooo0?ooo`3o0?oooeX0oooo00<000000?ooo`3oool0
SP3oool00240oooo00<000000?ooo`3oool0o`3ooomK0?ooo`030000003oool0oooo08d0oooo000Q
0?ooo`<00000o`3ooomL0?ooo`800000S@3oool00240oooo00<000000?ooo`3oool0o`3ooomN0?oo
o`030000003oool0oooo08X0oooo000Q0?ooo`030000003oool0oooo0?l0ooooG`3oool00`000000
oooo0?ooo`290?ooo`008@3oool00`000000oooo0?ooo`3o0?ooof00oooo0P0000290?ooo`008@3o
ool00`000000oooo0?ooo`3o0?ooof80oooo00<000000?ooo`3oool0QP3oool00240oooo00<00000
0?ooo`3oool0o`3ooomS0?ooo`030000003oool0oooo08D0oooo000C0?ooo`D000002@3oool00`00
0000oooo0?ooo`3o0?ooof@0oooo0P0000250?ooo`00503oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo0?l0ooooIP3oool00`000000oooo0?ooo`220?ooo`005@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`210?ooo`00
5P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooJ03oool200000840oooo
000F0?ooo`030000003oool0oooo00P0oooo1000003o0?ooofT0oooo00<000000?ooo`3oool0OP3o
ool001L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooof/0oooo00<00000
0?ooo`3oool0O@3oool001L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oo
of`0oooo0P00001m0?ooo`005`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0
ooooKP3oool00`000000oooo0?ooo`1j0?ooo`004`3oool01@000000oooo0?ooo`3oool0000000T0
oooo00<000000?ooo`3oool0o`3ooom_0?ooo`030000003oool0oooo07T0oooo000D0?ooo`<00000
2P3oool00`000000oooo0?ooo`3o0?ooog00oooo0P00001i0?ooo`008@3oool00`000000oooo0?oo
o`3o0?ooog80oooo00<000000?ooo`3oool0MP3oool00240oooo00<000000?ooo`3oool0o`3ooomc
0?ooo`030000003oool0oooo07D0oooo000Q0?ooo`030000003oool0oooo0?l0ooooM03oool20000
07D0oooo000Q0?ooo`<00000o`3ooomf0?ooo`030000003oool0oooo0780oooo000Q0?ooo`030000
003oool0oooo0?l0ooooM`3oool00`000000oooo0?ooo`1a0?ooo`008@3oool00`000000oooo0?oo
o`3o0?ooogP0oooo0P00001a0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooogX0oooo00<00000
0?ooo`3oool0KP3oool00240oooo00<000000?ooo`3oool0o`3ooomk0?ooo`030000003oool0oooo
06d0oooo000Q0?ooo`030000003oool0oooo0?l0ooooO03oool00`000000oooo0?ooo`1/0?ooo`00
8@3oool00`000000oooo0?ooo`3o0?ooogd0oooo0P00001/0?ooo`008@3oool00`000000oooo0?oo
o`3o0?ooogl0oooo00<000000?ooo`3oool0J@3oool00240oooo00<000000?ooo`3oool0o`3ooon0
0?ooo`030000003oool0oooo06P0oooo000Q0?ooo`<00000o`3ooon10?ooo`800000J03oool00240
oooo00<000000?ooo`3oool0o`3ooon30?ooo`030000003oool0oooo06D0oooo000Q0?ooo`030000
003oool0oooo0?l0ooooQ03oool00`000000oooo0?ooo`1T0?ooo`008@3oool00`000000oooo0?oo
o`3o0?ooohD0oooo00<000000?ooo`3oool0H`3oool00240oooo00<000000?ooo`3oool0o`3ooon6
0?ooo`800000H`3oool00240oooo00<000000?ooo`3oool0o`3ooon80?ooo`030000003oool0oooo
0600oooo000Q0?ooo`030000003oool0oooo0?l0ooooR@3oool00`000000oooo0?ooo`1O0?ooo`00
8@3oool00`000000oooo0?ooo`3o0?ooohX0oooo00<000000?ooo`3oool0GP3oool00240oooo00<0
00000?ooo`3oool0o`3ooon;0?ooo`030000003oool0oooo05d0oooo000Q0?ooo`030000003oool0
oooo0?l0ooooS03oool00`000000oooo0?ooo`1L0?ooo`008@3oool300000?l0ooooS@3oool00`00
0000oooo0?ooo`1K0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooohh0oooo0P00001K0?ooo`00
8@3oool00`000000oooo0?ooo`3o0?oooi00oooo00<000000?ooo`3oool0F03oool00240oooo00<0
00000?ooo`3oool0o`3ooonA0?ooo`030000003oool0oooo05L0oooo000Q0?ooo`030000003oool0
oooo0?l0ooooTP3oool00`000000oooo0?ooo`1F0?ooo`008@3oool00`000000oooo0?ooo`3o0?oo
oi<0oooo00<000000?ooo`3oool0E@3oool00240oooo00<000000?ooo`3oool0o`3ooonD0?ooo`03
0000003oool0oooo05@0oooo000Q0?ooo`030000003oool0oooo0?l0ooooU@3oool00`000000oooo
0?ooo`1C0?ooo`008@3oool00`000000oooo0?ooo`3o0?oooiH0oooo00<000000?ooo`3oool0DP3o
ool00240oooo0`00003o0?oooiL0oooo00<000000?ooo`3oool0D@3oool00240oooo00<000000?oo
o`3oool0o`3ooonH0?ooo`800000D@3oool00240oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`03
0000003oool0oooo04h0oooo000Q0?ooo`030000003oool0oooo0?l0ooooV`3oool00`000000oooo
0?ooo`1=0?ooo`008@3oool00`000000oooo0?ooo`3o0?oooi`0oooo00<000000?ooo`3oool0C03o
ool00240oooo00<000000?ooo`3oool0o`3ooonM0?ooo`030000003oool0oooo04/0oooo00080?oo
o`D000000P3oool010000000oooo0?ooo`3oool3000000/0oooo00<000000?ooo`3oool0o`3ooonN
0?ooo`030000003oool0oooo04X0oooo00090?ooo`040000003oool0oooo000000T0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`3o0?oooil0oooo00<000000?ooo`3oool0B@3oool0
00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0?l0ooooX03oool00`000000oooo0?ooo`180?ooo`002`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooonQ0?ooo`030000003oool0oooo04L0
oooo000;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool400000?l0oooo
X@3oool00`000000oooo0?ooo`160?ooo`00303oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0o`3ooonS0?ooo`030000003oool0oooo04D0oooo000<
0?ooo`030000003oool0oooo00@0oooo0`00000;0?ooo`030000003oool0oooo0?l0ooooY03oool0
0`000000oooo0?ooo`140?ooo`00303oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0o`3ooonU0?ooo`030000003oool0oooo04<0oooo00080?ooo`05
0000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0?l0ooooYP3oool00`000000oooo0?ooo`120?ooo`002@3oool3000000P0oooo100000090?ooo`03
0000003oool0oooo0?l0ooooY`3oool00`000000oooo0?ooo`110?ooo`008@3oool00`000000oooo
0?ooo`3o0?ooojP0oooo00<000000?ooo`3oool0@03oool00240oooo00<000000?ooo`3oool0o`3o
oonY0?ooo`030000003oool0oooo03l0oooo000Q0?ooo`030000003oool0oooo0?l0ooooZP3oool0
0`000000oooo0?ooo`0n0?ooo`008@3oool300000?l0ooooZ`3oool00`000000oooo0?ooo`0m0?oo
o`008@3oool00`000000oooo0?ooo`3o0?oooj`0oooo00<000000?ooo`3oool0?03oool00240oooo
00<000000?ooo`3oool0o`3ooon]0?ooo`030000003oool0oooo03/0oooo000Q0?ooo`030000003o
ool0oooo0?l0oooo[P3oool00`000000oooo0?ooo`0j0?ooo`008@3oool00`000000oooo0?ooo`3o
0?ooojl0oooo00<000000?ooo`3oool0>@3oool00240oooo00<000000?ooo`3oool0o`3ooon`0?oo
o`030000003oool0oooo03P0oooo000Q0?ooo`030000003oool0oooo0?l0oooo/@3oool00`000000
oooo0?ooo`0g0?ooo`008@3oool00`000000oooo0?ooo`3o0?oook80oooo00<000000?ooo`3oool0
=P3oool00240oooo00<000000?ooo`3oool0o`3ooonc0?ooo`030000003oool0oooo03D0oooo000Q
0?ooo`030000003oool0oooo0?l0oooo]03oool00`000000oooo0?ooo`0d0?ooo`008@3oool30000
0?l0oooo]@3oool00`000000oooo0?ooo`0c0?ooo`008@3oool00`000000oooo0?ooo`3o0?oookH0
oooo00<000000?ooo`3oool0<P3oool00240oooo00<000000?ooo`3oool0o`3ooong0?ooo`030000
003oool0oooo0340oooo000Q0?ooo`030000003oool0oooo0?l0oooo^03oool00`000000oooo0?oo
o`0`0?ooo`008@3oool00`000000oooo0?ooo`3o0?oookT0oooo00<000000?ooo`3oool0;`3oool0
0240oooo00<000000?ooo`3oool0o`3ooonj0?ooo`030000003oool0oooo02h0oooo000Q0?ooo`03
0000003oool0oooo0?l0oooo^`3oool00`000000oooo0?ooo`0]0?ooo`008@3oool00`000000oooo
0?ooo`3o0?oook`0oooo00<000000?ooo`3oool0;03oool00240oooo00<000000?ooo`3oool0o`3o
oonm0?ooo`030000003oool0oooo02/0oooo000Q0?ooo`<00000o`3ooonn0?ooo`030000003oool0
oooo02X0oooo000Q0?ooo`030000003oool0oooo0?l0oooo_`3oool00`000000oooo0?ooo`0Y0?oo
o`008@3oool00`000000oooo0?ooo`3o0?oool00oooo00<000000?ooo`3oool0:03oool00240oooo
00<000000?ooo`3oool0o`3oooo10?ooo`030000003oool0oooo02L0oooo000Q0?ooo`030000003o
ool0oooo0?l0oooo`P3oool00`000000oooo0?ooo`0V0?ooo`008@3oool00`000000oooo0?ooo`3o
0?oool<0oooo00<000000?ooo`3oool09@3oool00240oooo00<000000?ooo`3oool0o`3oooo40?oo
o`030000003oool0oooo02@0oooo000Q0?ooo`030000003oool0oooo0?l0ooooa@3oool00`000000
oooo0?ooo`0S0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooolH0oooo00<000000?ooo`3oool0
8P3oool00240oooo00<000000?ooo`3oool0o`3oooo70?ooo`030000003oool0oooo0240oooo000Q
0?ooo`<00000o`3oooo80?ooo`030000003oool0oooo0200oooo000Q0?ooo`030000003oool0oooo
0?l0oooob@3oool00`000000oooo0?ooo`0O0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooolX0
oooo00<000000?ooo`3oool07P3oool00240oooo00<000000?ooo`3oool0o`3oooo:0?ooo`030000
003oool0oooo01h0oooo000Q0?ooo`030000003oool0oooo0?l0oooob`3oool00`000000oooo0?oo
o`0M0?ooo`004`3oool4000000X0oooo00<000000?ooo`3oool0o`3oooo<0?ooo`030000003oool0
oooo01`0oooo000G0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3oooo=0?oo
o`030000003oool0oooo01/0oooo000G0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0o`3oooo>0?ooo`030000003oool0oooo01X0oooo000G0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo01T0oooo000G0?ooo`030000003o
ool0oooo00L0oooo1000003o0?oooll0oooo00<000000?ooo`3oool0603oool001D0oooo0P00000:
0?ooo`030000003oool0oooo0?l0ooood@3oool00`000000oooo0?ooo`0G0?ooo`005P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooodP3oool00`000000oooo0?ooo`0F0?oo
o`005`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooood`3oool00`000000
oooo0?ooo`0E0?ooo`004`3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3o
ool0o`3ooooC0?ooo`030000003oool0oooo01D0oooo000D0?ooo`<000002P3oool00`000000oooo
0?ooo`3o0?ooom@0oooo00<000000?ooo`3oool0503oool00240oooo00<000000?ooo`3oool0o`3o
oooE0?ooo`030000003oool0oooo01<0oooo000Q0?ooo`030000003oool0oooo0?l0ooooeP3oool0
0`000000oooo0?ooo`0B0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooomL0oooo00<000000?oo
o`3oool04@3oool00240oooo00<000000?ooo`3oool0o`3ooooH0?ooo`030000003oool0oooo0100
oooo000Q0?ooo`<00000o`3oooo[0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooon/0oooo000Q
0?ooo`030000003oool0oooo0?l0ooooj`3oool00240oooo00<000000?ooo`3oool0o`3oooo[0?oo
o`008@3oool00`000000oooo0?ooo`3o0?ooon/0oooo000Q0?ooo`030000003oool0oooo0?l0oooo
j`3oool00240oooo00<000000?ooo`3oool0o`3oooo[0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 525.063}, {324.125, 0}} -> {-0.16007, -0.254163, \
0.00475072, 0.0105764}}],

Cell[BoxData[
    \(0.6978012294908218`\)], "Output"],

Cell[BoxData[
    \(1.0001884358522113`\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.476191 153.762 153.798 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.2619 -0.0125 -10.7813 -17.8125 ]
[.2619 -0.0125 10.7813 0 ]
[.5 -0.0125 -5.53125 -17.8125 ]
[.5 -0.0125 5.53125 0 ]
[.7381 -0.0125 -10.7813 -17.8125 ]
[.7381 -0.0125 10.7813 0 ]
[.97619 -0.0125 -5.53125 -17.8125 ]
[.97619 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.125 -35.625 ]
[.5 -0.0125 5.125 -17.8125 ]
[-0.0125 .1178 -45.375 -8.90625 ]
[-0.0125 .1178 0 8.90625 ]
[-0.0125 .2716 -45.375 -8.90625 ]
[-0.0125 .2716 0 8.90625 ]
[-0.0125 .4254 -45.375 -8.90625 ]
[-0.0125 .4254 0 8.90625 ]
[-0.0125 .5792 -45.375 -8.90625 ]
[-0.0125 .5792 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -63.1875 -14.7188 ]
[-0.01875 .30902 -45.375 14.7188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.125 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .1178 m
.00625 .1178 L
s
gsave
-0.0125 .1178 -106.375 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.999) show
1.000 setlinewidth
grestore
0 .2716 m
.00625 .2716 L
s
gsave
-0.0125 .2716 -106.375 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.998) show
1.000 setlinewidth
grestore
0 .4254 m
.00625 .4254 L
s
gsave
-0.0125 .4254 -106.375 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.997) show
1.000 setlinewidth
grestore
0 .5792 m
.00625 .5792 L
s
gsave
-0.0125 .5792 -106.375 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.996) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .14856 m
.00375 .14856 L
s
0 .17932 m
.00375 .17932 L
s
0 .21008 m
.00375 .21008 L
s
0 .24084 m
.00375 .24084 L
s
0 .30236 m
.00375 .30236 L
s
0 .33312 m
.00375 .33312 L
s
0 .36388 m
.00375 .36388 L
s
0 .39464 m
.00375 .39464 L
s
0 .45616 m
.00375 .45616 L
s
0 .48692 m
.00375 .48692 L
s
0 .51768 m
.00375 .51768 L
s
0 .54844 m
.00375 .54844 L
s
0 .08704 m
.00375 .08704 L
s
0 .05628 m
.00375 .05628 L
s
0 .02552 m
.00375 .02552 L
s
0 .60996 m
.00375 .60996 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -130 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.7188 12.9063 translate
90 rotate
-75.7188 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.063 17.500 moveto
(H) show
77.625 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.875 17.500 moveto
(L) show
88.438 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .1178 m
1 .1178 L
s
.99375 .2716 m
1 .2716 L
s
.99375 .4254 m
1 .4254 L
s
.99375 .5792 m
1 .5792 L
s
.125 Mabswid
.99625 .14856 m
1 .14856 L
s
.99625 .17932 m
1 .17932 L
s
.99625 .21008 m
1 .21008 L
s
.99625 .24084 m
1 .24084 L
s
.99625 .30236 m
1 .30236 L
s
.99625 .33312 m
1 .33312 L
s
.99625 .36388 m
1 .36388 L
s
.99625 .39464 m
1 .39464 L
s
.99625 .45616 m
1 .45616 L
s
.99625 .48692 m
1 .48692 L
s
.99625 .51768 m
1 .51768 L
s
.99625 .54844 m
1 .54844 L
s
.99625 .08704 m
1 .08704 L
s
.99625 .05628 m
1 .05628 L
s
.99625 .02552 m
1 .02552 L
s
.99625 .60996 m
1 .60996 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .1178 m
1 .1178 L
s
.5 Mabswid
.02381 .60332 m
.06244 .53219 L
.10458 .46256 L
.14415 .40456 L
.18221 .35514 L
.22272 .30886 L
.26171 .26986 L
.30316 .23373 L
.34309 .20346 L
.3815 .17803 L
.42237 .15441 L
.46172 .13457 L
.49955 .11782 L
.53984 .10215 L
.57861 .0889 L
.61984 .07651 L
.65954 .066 L
.69774 .05704 L
.73838 .04858 L
.77751 .04134 L
.81909 .03449 L
.85916 .02861 L
.89771 .02354 L
.93871 .0187 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{526.063, 325.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003oo`3ooooo
0?oooa00oooo003o0?ooool0oooo403oool00?l0ooooo`3oool@0?ooo`00o`3ooooo0?oooa00oooo
003o0?ooool0oooo403oool00?l0ooooo`3oool@0?ooo`00o`3ooooo0?oooa00oooo003o0?ooobP0
oooo1P00003Q0?ooo`00o`3ooolY0?ooo`050000003oool0oooo0?ooo`000000h@3oool00?l0oooo
:P3oool00`000000oooo0?ooo`3R0?ooo`00o`3ooolZ0?ooo`030000003oool0oooo0>80oooo003o
0?ooob/0oooo00<000000?ooo`3oool0h@3oool00?l0oooo:03oool01@000000oooo0?ooo`3oool0
00000>80oooo003o0?ooobP0oooo1P00003Q0?ooo`00o`3ooooo0?oooa00oooo003o0?ooool0oooo
403oool00?l0ooooo`3oool@0?ooo`00o`3ooooo0?oooa00oooo003o0?ooool0oooo403oool00?l0
ooooo`3oool@0?ooo`00o`3ooooo0?oooa00oooo003o0?ooool0oooo403oool00?l0ooooo`3oool@
0?ooo`00o`3ooooo0?oooa00oooo003o0?ooool0oooo403oool00500oooo0`00001T0?ooo`<00000
0`3oool010000000oooo0?ooo`3oool3000006@0oooo0`00001T0?ooo`<000000`3oool010000000
oooo0?ooo`3oool3000006<0oooo1@00000:0?ooo`00C`3oool01@000000oooo0?ooo`3oool00000
0680oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo0680oooo00<00000
0?ooo`3oool0I03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0640oooo00@00000
0?ooo`3oool000002P3oool004l0oooo00D000000?ooo`3oool0oooo0000001R0?ooo`050000003o
ool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo06@0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00X0oooo
001?0?ooo`050000003oool0oooo0?ooo`000000HP3oool01@000000oooo0?ooo`3oool0000000X0
oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`090?ooo`00C`3oool01@000000oooo
0?ooo`3oool000000680oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo
0640oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0680oooo00<000000?ooo`3oool02@3oool004l0oooo00D000000?ooo`3oool0oooo0000001R0?oo
o`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0
oooo06@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0
oooo00P0oooo001?0?ooo`050000003oool0oooo0?ooo`000000HP3oool01@000000oooo0?ooo`3o
ool0000000H0oooo0`00001U0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool01P3o
ool3000006L0oooo00<000000?ooo`3oool0203oool004l0oooo00D000000?ooo`3oool0oooo0000
001R0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`1U0?ooo`030000
003oool0oooo06@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1W0?ooo`030000
003oool0oooo00P0oooo001?0?ooo`050000003oool0oooo0?ooo`000000HP3oool01@000000oooo
0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0H`3oool2000006D0oooo0P0000090?ooo`03
0000003oool0oooo0680oooo00D000000?ooo`3oool0oooo0000000:0?ooo`00D03oool3000006@0
oooo0`0000080?ooo`@00000H`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00L0
oooo1000001R0?ooo`<000002`3oool00?l0ooooo`3oool@0?ooo`00o`3ooooo0?oooa00oooo003o
0?ooool0oooo403oool00?l0ooooo`3oool@0?ooo`00o`3ooooo0?oooa00oooo003o0?ooool0oooo
403oool00?l0ooooo`3oool@0?ooo`00o`3ooooo0?oooa00oooo00170?ooool00000a`0000010?oo
o`00A`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`070?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
1`3oool100000040oooo00170?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0J@3o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0J@3o
ool00`000000oooo0?ooo`070?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool0o`3oooo3
0?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool0o`3oooo30?ooo`4000000@3oool004L0
oooo00<000000?ooo`3oool0o`3oooo30?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool0
o`3ooona0?ooo`T000002@3oool100000040oooo00170?ooo`030000003oool0oooo0?l0ooooY@3o
ool<00000180oooo0@0000010?ooo`00A`3oool00`000000oooo0?ooo`3o0?oooil0oooo1P00000N
0?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool0o`3ooonI0?ooo`H00000903oool10000
0040oooo00170?ooo`030000003oool0oooo0?l0ooooT@3oool8000002X0oooo0@0000010?ooo`00
A`3oool300000?l0ooooR@3oool800000340oooo0P0000010?ooo`00A`3oool00`000000oooo0?oo
o`3o0?oooh40oooo2000000j0?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool0o`3ooomk
0?ooo`H00000@P3oool100000040oooo00170?ooo`030000003oool0oooo0?l0ooooM@3oool60000
04P0oooo0@0000010?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooofl0oooo1P00001>0?ooo`40
00000@3oool004L0oooo00<000000?ooo`3oool0o`3ooomY0?ooo`H00000E03oool100000040oooo
00170?ooo`030000003oool0oooo0?l0ooooH`3oool6000005X0oooo0@0000010?ooo`00A`3oool0
0`000000oooo0?ooo`3o0?oooed0oooo1P00001P0?ooo`4000000@3oool004L0oooo00<000000?oo
o`3oool0o`3ooomG0?ooo`H00000IP3oool100000040oooo00170?ooo`030000003oool0oooo0?l0
ooooD@3oool6000006`0oooo0@0000010?ooo`00A`3oool00`000000oooo0?ooo`3o0?oood/0oooo
1P00001b0?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool0o`3ooom60?ooo`D00000N03o
ool100000040oooo00170?ooo`030000003oool0oooo0?l0oooo@P3oool4000007d0oooo0@000001
0?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooocd0oooo1@0000210?ooo`4000000@3oool004L0
oooo0`00003o0?ooocP0oooo1@0000250?ooo`8000000@3oool004L0oooo00<000000?ooo`3oool0
o`3ooold0?ooo`@00000R`3oool100000040oooo00170?ooo`030000003oool0oooo0?l0oooo<03o
ool4000008l0oooo0@0000010?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooob`0oooo1000002C
0?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`@00000U`3oool10000
0040oooo00170?ooo`030000003oool0oooo0?l0oooo903oool4000009/0oooo0@0000010?ooo`00
A`3oool00`000000oooo0?ooo`3o0?ooob40oooo0`00002O0?ooo`4000000@3oool004L0oooo00<0
00000?ooo`3oool0o`3ooolM0?ooo`@00000XP3oool100000040oooo00170?ooo`030000003oool0
oooo0?l0oooo6@3oool400000:H0oooo0@0000010?ooo`00A`3oool00`000000oooo0?ooo`3o0?oo
oaH0oooo0`00002Z0?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`@0
0000[@3oool100000040oooo00170?ooo`030000003oool0oooo0?l0oooo3P3oool400000;40oooo
0@0000010?ooo`00A`3oool00`000000oooo0?ooo`3o0?ooo`X0oooo1000002e0?ooo`4000000@3o
ool004L0oooo0`00003o0?ooo`H0oooo1000002h0?ooo`8000000@3oool004L0oooo00<000000?oo
o`3oool0o`3oool30?ooo`<00000_@3oool100000040oooo00170?ooo`030000003oool0oooo0?l0
oooo0`0000300?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool0o03oool300000<<0oooo
0@0000010?ooo`00A`3oool00`000000oooo0?ooo`3j0?ooo`800000aP3oool100000040oooo0017
0?ooo`030000003oool0oooo0?L0oooo0`0000380?ooo`4000000@3oool004L0oooo00<000000?oo
o`3oool0m03oool300000</0oooo0@0000010?ooo`00A`3oool00`000000oooo0?ooo`3a0?ooo`<0
0000cP3oool100000040oooo00170?ooo`030000003oool0oooo0>l0oooo0P00003A0?ooo`400000
0@3oool004L0oooo00<000000?ooo`3oool0k03oool300000=<0oooo0@0000010?ooo`00A`3oool0
0`000000oooo0?ooo`3Z0?ooo`800000eP3oool100000040oooo000R0?ooo`<000000`3oool01000
0000oooo0?ooo`3oool2000000D0oooo0P0000050?ooo`8000002`3oool00`000000oooo0?ooo`3W
0?ooo`<00000f03oool100000040oooo000Q0?ooo`050000003oool0oooo0?ooo`000000203oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`3T0?ooo`<00000f`3oool100000040oooo000Q0?ooo`050000003oool0oooo
0?ooo`0000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`3R0?ooo`800000gP3oool100000040oooo000G0?oo
o`L000000`3oool01@000000oooo0?ooo`3oool0000000L0oooo100000030?ooo`@000000`3oool4
000000P0ooooo`00003700000040oooo000Q0?ooo`050000003oool0oooo0?ooo`0000001P3oool0
1@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`3M0?ooo`800000h`3oool100000040
oooo000Q0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000203o
ool00`000000oooo0?ooo`3K0?ooo`800000i@3oool100000040oooo000Q0?ooo`050000003oool0
oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo000000020?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`3I0?oo
o`800000i`3oool100000040oooo000Q0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@00
0000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003o
ool0oooo0?ooo`000000203oool00`000000oooo0?ooo`3F0?ooo`<00000j@3oool100000040oooo
000Q0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool000000080
oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000203oool0
0`000000oooo0?ooo`3D0?ooo`800000k03oool100000040oooo000R0?ooo`<00000203oool30000
00@0oooo0`0000040?ooo`<000002@3oool00`000000oooo0?ooo`3B0?ooo`800000kP3oool10000
0040oooo00170?ooo`030000003oool0oooo0=00oooo0P00003`0?ooo`4000000@3oool004L0oooo
00<000000?ooo`3oool0cP3oool200000?80oooo0@0000010?ooo`00A`3oool00`000000oooo0?oo
o`3<0?ooo`800000m03oool100000040oooo00170?ooo`030000003oool0oooo0<X0oooo0P00003f
0?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool0b03oool200000?P0oooo0@0000010?oo
o`00A`3oool00`000000oooo0?ooo`360?ooo`800000nP3oool100000040oooo00170?ooo`030000
003oool0oooo0<@0oooo0P00003l0?ooo`4000000@3oool004L0oooo0`0000320?ooo`800000o@3o
ool200000040oooo00170?ooo`030000003oool0oooo0<00oooo0P00003o0?ooo`40oooo0@000001
0?ooo`00A`3oool00`000000oooo0?ooo`2n0?ooo`800000o`3oool30?ooo`4000000@3oool004L0
oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`3o0?ooo`<0oooo0@0000010?ooo`00
A`3oool00`000000oooo0?ooo`2k0?ooo`800000o`3oool60?ooo`4000000@3oool004L0oooo00<0
00000?ooo`3oool0^@3oool200000?l0oooo203oool100000040oooo00170?ooo`030000003oool0
oooo0;L0oooo0P00003o0?ooo`X0oooo0@0000010?ooo`00A`3oool00`000000oooo0?ooo`2f0?oo
o`030000003oool0oooo0?l0oooo2P3oool100000040oooo00170?ooo`030000003oool0oooo0;@0
oooo0P00003o0?ooo`d0oooo0@0000010?ooo`00A`3oool00`000000oooo0?ooo`2b0?ooo`800000
o`3oool?0?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?oo
o`3o0?ooo`l0oooo0@0000010?ooo`00A`3oool00`000000oooo0?ooo`2_0?ooo`800000o`3ooolB
0?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool0[@3oool200000?l0oooo503oool10000
0040oooo00170?ooo`030000003oool0oooo0:/0oooo0P00003o0?oooaH0oooo0@0000010?ooo`00
A`3oool300000:X0oooo00<000000?ooo`3oool0o`3ooolE0?ooo`8000000@3oool004L0oooo00<0
00000?ooo`3oool0Z03oool200000?l0oooo6@3oool100000040oooo00170?ooo`030000003oool0
oooo0:L0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`4000000@3oool004L0oooo00<000000?oo
o`3oool0Y@3oool200000?l0oooo703oool100000040oooo00170?ooo`030000003oool0oooo0:@0
oooo00<000000?ooo`3oool0o`3ooolL0?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool0
XP3oool200000?l0oooo7`3oool100000040oooo00170?ooo`030000003oool0oooo0:00oooo0P00
003o0?ooob40oooo0@0000010?ooo`00A`3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0
oooo0?l0oooo8@3oool100000040oooo00170?ooo`030000003oool0oooo09d0oooo0P00003o0?oo
ob@0oooo0@0000010?ooo`00A`3oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0?l0
oooo903oool100000040oooo00170?ooo`030000003oool0oooo09X0oooo0P00003o0?ooobL0oooo
0@0000010?ooo`00A`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo0?l0oooo9`3o
ool100000040oooo00170?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0o`3ooolX
0?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool0UP3oool200000?l0oooo:`3oool10000
0040oooo00170?ooo`<00000U@3oool00`000000oooo0?ooo`3o0?ooobX0oooo0P0000010?ooo`00
A`3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo0?l0oooo;03oool100000040oooo
00170?ooo`030000003oool0oooo0980oooo0P00003o0?ooobl0oooo0@0000010?ooo`00A`3oool0
0`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0?l0oooo;`3oool100000040oooo00170?oo
o`030000003oool0oooo0900oooo00<000000?ooo`3oool0o`3oool`0?ooo`4000000@3oool004L0
oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`3o0?oooc40oooo0@0000010?ooo`00
A`3oool00`000000oooo0?ooo`2=0?ooo`800000o`3ooold0?ooo`4000000@3oool004L0oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`3o0?oooc@0oooo0@0000010?ooo`00A`3oool0
0`000000oooo0?ooo`2;0?ooo`030000003oool0oooo0?l0oooo=@3oool100000040oooo00170?oo
o`030000003oool0oooo08T0oooo0P00003o0?ooocP0oooo0@0000010?ooo`00A`3oool00`000000
oooo0?ooo`280?ooo`030000003oool0oooo0?l0oooo>03oool100000040oooo00170?ooo`030000
003oool0oooo08L0oooo00<000000?ooo`3oool0o`3oooli0?ooo`4000000@3oool004L0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`3o0?ooocX0oooo0@0000010?ooo`00A`3oool0
0`000000oooo0?ooo`250?ooo`030000003oool0oooo0?l0oooo>`3oool100000040oooo00170?oo
o`<00000P`3oool200000?l0oooo?@3oool200000040oooo00170?ooo`030000003oool0oooo0880
oooo00<000000?ooo`3oool0o`3oooln0?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool0
P@3oool00`000000oooo0?ooo`3o0?ooocl0oooo0@0000010?ooo`00A`3oool00`000000oooo0?oo
o`200?ooo`030000003oool0oooo0?l0oooo@03oool100000040oooo00170?ooo`030000003oool0
oooo07l0oooo00<000000?ooo`3oool0o`3ooom10?ooo`4000000@3oool004L0oooo00<000000?oo
o`3oool0O@3oool200000?l0ooooA03oool100000040oooo00170?ooo`030000003oool0oooo07`0
oooo00<000000?ooo`3oool0o`3ooom40?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool0
N`3oool00`000000oooo0?ooo`3o0?ooodD0oooo0@0000010?ooo`00A`3oool00`000000oooo0?oo
o`1j0?ooo`030000003oool0oooo0?l0ooooAP3oool100000040oooo00170?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool0o`3ooom70?ooo`4000000@3oool004L0oooo00<000000?oo
o`3oool0M`3oool200000?l0ooooBP3oool100000040oooo000R0?ooo`<000000`3oool010000000
oooo0?ooo`3oool2000000D0oooo0P0000060?ooo`<000002@3oool00`000000oooo0?ooo`1f0?oo
o`030000003oool0oooo0?l0ooooBP3oool100000040oooo000Q0?ooo`050000003oool0oooo0?oo
o`000000203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000080?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0o`3ooom;
0?ooo`4000000@3oool00240oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0
oooo00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`3o0?oood`0oooo0@0000010?ooo`005`3oool7
000000<0oooo00D000000?ooo`3oool0oooo000000070?ooo`@000000`3oool400000080oooo00D0
00000?ooo`3oool0oooo000000080?ooo`@00000LP3oool00`000000oooo0?ooo`3o0?oood/0oooo
0`0000010?ooo`008@3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0
oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000090?oo
o`030000003oool0oooo0780oooo00<000000?ooo`3oool0o`3ooom>0?ooo`4000000@3oool00240
oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`1a0?ooo`030000003oool0oooo0?l0ooooC`3oool100000040oooo000Q0?ooo`050000003oool0
oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool0L03oool00`000000
oooo0?ooo`3o0?oooe00oooo0@0000010?ooo`008@3oool01@000000oooo0?ooo`3oool0000000H0
oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?oo
o`3o0?oooe40oooo0@0000010?ooo`001P3oool00`000000oooo0?ooo`0H0?ooo`050000003oool0
oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo000000020?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`1^0?oo
o`030000003oool0oooo0?l0ooooDP3oool100000040oooo00060?ooo`<000006@3oool3000000P0
oooo0`0000040?ooo`<00000103oool3000000T0oooo00<000000?ooo`3oool0K@3oool00`000000
oooo0?ooo`3o0?oooe<0oooo0@0000010?ooo`001P3oool00`000000oooo0?ooo`03000003/0oooo
00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`3o0?oooe@0oooo0@0000010?ooo`002`3o
ool2000003X0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`3o0?oooeD0oooo0@00
00010?ooo`001P3oool00`000000oooo0?ooo`02000003`0oooo00<000000?ooo`3oool0JP3oool0
0`000000oooo0?ooo`3o0?oooeH0oooo0@0000010?ooo`001P3oool3000003h0oooo00<000000?oo
o`3oool0J@3oool00`000000oooo0?ooo`3o0?oooeL0oooo0@0000010?ooo`001P3oool00`000000
oooo0?ooo`03000003/0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`3o0?oooeP0
oooo0@0000010?ooo`002`3oool2000003X0oooo00<000000?ooo`3oool0I`3oool00`000000oooo
0?ooo`3o0?oooeT0oooo0@0000010?ooo`001P3oool00`000000oooo0?ooo`02000003`0oooo00<0
00000?ooo`3oool0IP3oool00`000000oooo0?ooo`3o0?oooeX0oooo0@0000010?ooo`001P3oool3
000003h0oooo0`00001U0?ooo`030000003oool0oooo0?l0ooooFP3oool200000040oooo00060?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`3o0?oo
oe`0oooo0@0000010?ooo`001@3oool9000003T0oooo00<000000?ooo`3oool0H`3oool00`000000
oooo0?ooo`3o0?oooed0oooo0@0000010?ooo`00103oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo03H0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`3o0?oooeh0oooo
0@0000010?ooo`000`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool0H@3oool00`000000oooo0?ooo`3o0?oooel0oooo0@0000010?ooo`00A`3oool0
0`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0?l0ooooH03oool100000040oooo00060?oo
o`800000103oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo05l0oooo00<000000?oo
o`3oool0o`3ooomQ0?ooo`4000000@3oool000H0oooo00<000000?ooo`3oool00P3oool2000003X0
oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`3o0?ooof40oooo0@0000010?ooo`00
1P3oool00`000000oooo0?ooo`02000000030?ooo`000000oooo03T0oooo00<000000?ooo`3oool0
GP3oool00`000000oooo0?ooo`3o0?ooof80oooo0@0000010?ooo`001P3oool00`000000oooo0000
00030?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?oo
o`3o0?ooof<0oooo0@0000010?ooo`001P3oool2000000@0oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0?l0ooooI03oool100000040oooo00060?oo
o`030000003oool0oooo0080oooo0P00000j0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool0o`3ooomU0?ooo`4000000@3oool000<0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0o`3ooomV0?ooo`40
00000@3oool000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo05T0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`4000000@3oool000D0oooo2@00
000i0?ooo`<00000F@3oool00`000000oooo0?ooo`3o0?ooofH0oooo0P0000010?ooo`00A`3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0?l0ooooJ03oool100000040oooo00170?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool0o`3ooomY0?ooo`4000000@3oool004L0
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`3o0?ooofX0oooo0@0000010?ooo`00
A`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0?l0ooooJ`3oool100000040oooo
00170?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0o`3ooom/0?ooo`4000000@3o
ool004L0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`3o0?ooofd0oooo0@000001
0?ooo`00A`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0?l0ooooK@3oool10000
0040oooo00170?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0o`3ooom^0?ooo`40
00000@3oool004L0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`3o0?ooofl0oooo
0@0000010?ooo`00A`3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0?l0ooooL03o
ool100000040oooo00170?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0o`3oooma
0?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`3o0?oo
og80oooo0@0000010?ooo`00A`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0?l0
ooooLP3oool100000040oooo00170?ooo`<00000C@3oool00`000000oooo0?ooo`3o0?ooog80oooo
0P0000010?ooo`00A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0?l0ooooM03o
ool100000040oooo00170?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0o`3ooome
0?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?oo
ogD0oooo0@0000010?ooo`00A`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0?l0
ooooMP3oool100000040oooo00170?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
o`3ooomg0?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?oo
o`3o0?ooogP0oooo0@0000010?ooo`00A`3oool00`000000oooo0?ooo`170?ooo`030000003oool0
oooo0?l0ooooN@3oool100000040oooo00170?ooo`030000003oool0oooo04L0oooo00<000000?oo
o`3oool0o`3ooomi0?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`3o0?ooogX0oooo0@0000010?ooo`00A`3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo0?l0ooooN`3oool100000040oooo00170?ooo`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool0o`3oooml0?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`3o0?ooog`0oooo0@0000010?ooo`00A`3oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo0?l0ooooO@3oool100000040oooo00170?ooo`<00000@P3oool00`000000
oooo0?ooo`3o0?ooogd0oooo0P0000010?ooo`00A`3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo0?l0ooooO`3oool100000040oooo00170?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0o`3ooomo0?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`3o0?oooh00oooo0@0000010?ooo`00A`3oool00`000000oooo0?ooo`0o0?oo
o`030000003oool0oooo0?l0ooooP@3oool100000040oooo00170?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`3oool0o`3ooon20?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool0
?P3oool00`000000oooo0?ooo`3o0?oooh80oooo0@0000010?ooo`00A`3oool00`000000oooo0?oo
o`0m0?ooo`030000003oool0oooo0?l0ooooP`3oool100000040oooo00170?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool0o`3ooon40?ooo`4000000@3oool004L0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`3o0?oooh@0oooo0@0000010?ooo`008P3oool3000000<0
oooo00@000000?ooo`3oool0oooo0P0000050?ooo`8000001P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooon50?ooo`4000000@3oool00240
oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0o`3ooon60?ooo`4000000@3oool00240oooo00D000000?ooo`3oool0oooo000000090?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0o`3ooon60?ooo`4000000@3oool001L0
oooo1`0000030?ooo`050000003oool0oooo0?ooo`0000001`3oool4000000<0oooo100000040?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`3o0?oo
ohL0oooo0@0000010?ooo`008@3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`080?ooo`@00000=`3oool00`000000oooo0?ooo`3o0?ooohH0oooo0`0000010?ooo`008@3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0o`3ooon80?ooo`4000000@3oool00240oooo00D000000?ooo`3oool0
oooo000000060?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
000000D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo0?l0ooooR@3oool100000040oooo000Q0?ooo`050000003oool0oooo0?ooo`0000001P3oool0
1@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`3o0?ooohX0oooo
0@0000010?ooo`008@3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0
oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`3o0?ooohX0oooo0@000001
0?ooo`008P3oool3000000P0oooo0`0000040?ooo`<000000`3oool5000000P0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`3o0?oooh/0oooo0@0000010?ooo`00A`3oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo0?l0ooooS03oool100000040oooo00170?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0o`3ooon<0?ooo`4000000@3oool004L0oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`3o0?ooohd0oooo0@0000010?ooo`00A`3oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0?l0ooooSP3oool100000040oooo00170?oo
o`030000003oool0oooo0380oooo00<000000?ooo`3oool0o`3ooon>0?ooo`4000000@3oool004L0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`3o0?ooohl0oooo0@0000010?ooo`00
A`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0?l0ooooT03oool100000040oooo
00170?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0o`3ooon@0?ooo`4000000@3o
ool004L0oooo0`00000_0?ooo`030000003oool0oooo0?l0ooooT03oool200000040oooo00170?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool0o`3ooonB0?ooo`4000000@3oool004L0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`3o0?oooi80oooo0@0000010?ooo`00
A`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0ooooT`3oool100000040oooo
00170?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0o`3ooonD0?ooo`4000000@3o
ool004L0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`3o0?oooi@0oooo0@000001
0?ooo`00A`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0ooooU@3oool10000
0040oooo00170?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0o`3ooonF0?ooo`40
00000@3oool004L0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`3o0?oooiH0oooo
0@0000010?ooo`00A`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0ooooU`3o
ool100000040oooo00170?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0o`3ooonH
0?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`3o0?oo
oiP0oooo0@0000010?ooo`00A`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0?l0
ooooV@3oool100000040oooo00170?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
o`3ooonI0?ooo`4000000@3oool004L0oooo0`00000V0?ooo`030000003oool0oooo0?l0ooooV@3o
ool200000040oooo00170?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0o`3ooonK
0?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3o0?oo
oi/0oooo0@0000010?ooo`00A`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0?l0
ooooW03oool100000040oooo00170?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
o`3ooonM0?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`3o0?oooid0oooo0@0000010?ooo`00A`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo0?l0ooooWP3oool100000040oooo00170?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool0o`3ooonO0?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`3o0?oooil0oooo0@0000010?ooo`00A`3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo0?l0ooooX03oool100000040oooo00170?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0o`3ooonQ0?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`3o0?oooj40oooo0@0000010?ooo`00A`3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo0?l0ooooXP3oool100000040oooo00170?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0o`3ooonR0?ooo`4000000@3oool004L0oooo0`00000M0?ooo`030000
003oool0oooo0?l0ooooXP3oool200000040oooo00170?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0o`3ooonT0?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`3o0?oooj@0oooo0@0000010?ooo`00A`3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo0?l0ooooY@3oool100000040oooo00170?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool0o`3ooonV0?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`3o0?ooojH0oooo0@0000010?ooo`00A`3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo0?l0ooooY`3oool100000040oooo00170?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0o`3ooonX0?ooo`4000000@3oool004L0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`3o0?ooojP0oooo0@0000010?ooo`00A`3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo0?l0ooooZ@3oool100000040oooo00170?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0o`3ooonY0?ooo`4000000@3oool004L0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`3o0?ooojX0oooo0@0000010?ooo`00A`3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0ooooZP3oool100000040oooo00170?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3ooon[0?ooo`4000000@3oool004L0
oooo0`00000E0?ooo`030000003oool0oooo0?l0ooooZP3oool200000040oooo00170?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0o`3ooon/0?ooo`4000000@3oool004L0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`3o0?oooj`0oooo0@0000010?ooo`00A`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0oooo[@3oool100000040oooo00170?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0o`3ooon]0?ooo`4000000@3oool004L0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3o0?ooojh0oooo0@0000010?ooo`00
A`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0oooo[P3oool100000040oooo
00170?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0o`3ooon_0?ooo`4000000@3o
ool004L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?oook00oooo0@000001
0?ooo`00A`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0oooo/03oool10000
0040oooo000R0?ooo`<000000`3oool010000000oooo0?ooo`3oool2000000D0oooo0P0000060?oo
o`<000002@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0oooo/@3oool10000
0040oooo000Q0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0o`3ooona0?ooo`4000000@3oool00240oooo00D000000?oo
o`3oool0oooo000000090?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`3o0?oook80oooo0@0000010?ooo`005`3oool7000000<0oooo00D000000?ooo`3oool0oooo0000
00070?ooo`@000000`3oool400000080oooo00D000000?ooo`3oool0oooo000000080?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooonb0?ooo`4000000@3oool00240oooo00D0
00000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000
oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000080?ooo`@00000303oool0
0`000000oooo0?ooo`3o0?oook40oooo0`0000010?ooo`008@3oool01@000000oooo0?ooo`3oool0
000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000
0P3oool200000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo0?l0oooo/`3oool100000040oooo000Q0?ooo`050000003oool0oooo0?ooo`000000
1P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool00000000000T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o
0?oook@0oooo0@0000010?ooo`008@3oool01@000000oooo0?ooo`3oool0000000H0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooond0?ooo`400000
0@3oool00240oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo]@3oool100000040oooo000R0?ooo`<0
0000203oool3000000@0oooo0`0000060?ooo`800000203oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo0?l0oooo]@3oool100000040oooo00170?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0o`3ooonf0?ooo`4000000@3oool004L0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`3o0?oookH0oooo0@0000010?ooo`00A`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0?l0oooo]`3oool100000040oooo00170?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0o`3ooong0?ooo`4000000@3oool004L0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`3o0?oookP0oooo0@0000010?ooo`00A`3oool00`000000oooo
0?ooo`3o0?oool<0oooo0@0000010?ooo`00A`3oool00`000000oooo0?ooo`3o0?oool<0oooo0@00
00010?ooo`00A`3oool300000?l0oooo`P3oool200000040oooo00170?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo
06T0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`070?ooo`4000000@3oool004L0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool01`3oool100000040oooo00170?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo
0@0000010?ooo`00A`3ooooo00000<L000000@3oool00?l0ooooo`3oool@0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 525.063}, {324.125, 0}} -> {-0.382148, -1.00038, \
0.00463323, 1.43455*^-05}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ 
      Find\ chi\ square\ for\ given\ H \((z)\)\ \ *) \[IndentingNewLine]\(f[
          z_] := 1/hhz[z];\)\), "\n", 
    \(\(rr[zz_] := NIntegrate[f[z], {z, 0, zz}];\)\[IndentingNewLine]\n (*\ 
      Construct\ marginalization\ coefficients\ \((see\ \ astro - 
              ph/0401556\  .. )\)\ *) \), "\[IndentingNewLine]", 
    \(Clear[chi2fa, chi2fb, chi2fc]\), "\n", 
    \(\(chi2fa = 
        Sum[\((ld[i] - 5\ Log[10, rr[zz[i]]*\((1 + zz[i])\)])\)^2/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\n", 
    \(\(chi2fb = 
        Sum[\((ld[i] - 
                5\ Log[10, rr[zz[i]]*\((1 + zz[i])\)])\)/\((sld[i]^2)\), {i, 
            1, ndat}];\)\), "\n", 
    \(\(chi2fc = 
        Sum[1/\((sld[i]^2)\), {i, 1, ndat}];\)\[IndentingNewLine]\n (*\ 
      Construct\ function\ after\ marginalization, \ 
      find\ same\ result\ as\ with\ mb\ minimization\ *) \), "\
\[IndentingNewLine]", 
    \(chi2fm = chi2fa - chi2fb^2/chi2fc\), "\[IndentingNewLine]", 
    \(dchi2q02 = chi2fm - chi2l\)}], "Input"],

Cell[BoxData[
    \(177.14843723364174`\)], "Output"],

Cell[BoxData[
    \(0.021065798588097095`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ \(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(\
--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(-\(---\)\)\)\)\)\)\)\)\)\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)*) \[IndentingNewLine]\[IndentingNewLine] \
(*\ Find\ H \((z)\)\ for\ given\ slope\ s\ of\ the\ linear\ potential . \ 
            Present\ time\  = \ \(tt\ \((corresponds\ to\ a = 1)\) . \ 
              Run\ trials\ for\ initial\ condition\ for\ field\ fi\ \((f0)\)\ \
and\ initial\ time\ ti\ until\ we\ get\ field\ energy\ enf\  = \ \(0.7\ and\ \
H \((z = 0)\)\  = 
            1\ at\ present\ time\ \(\(tt\)\(.\)\)\)\)\ *) \[IndentingNewLine]\
\[IndentingNewLine] (*\ \(--\(--\(--\(--\ \ s\)\)\)\)\  = \ \(0.5\ \ \ --\) \
\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(---\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\ *) \
\[IndentingNewLine]\[IndentingNewLine]\(Clear[aa, fi, a, aad, aadd, fidas, 
        tas, f, rr, hht, hha];\)\), "\[IndentingNewLine]", 
    \(aa = a[t]; \ fi = f[t];\), "\n", 
    \(\(aad = D[aa, t];\)\), "\n", 
    \(\(aadd = D[aa, {t, 2}];\)\), "\n", 
    \(\(fid = D[fi, t];\)\), "\n", 
    \(\(fidd = D[fi, {t, 2}];\)\), "\n", 
    \(ti = 0.000025; \ t0 = 2.25;\), "\n", 
    \(\(f0 = \(-1.45\);\)\ \), "\n", 
    \(om0m = 0.3; \ ss = 0.5;\), "\n", 
    \(\(eq1 = 
        aadd/aa\  \[Equal] \(-\ \ fid^2\)\  - \ ss\ fi\  - \ 
            om0m/\((2\ aa^3)\);\)\), "\n", 
    \(\(eq2 = 
        fidd\ \  + \ \ \ 3\ \ fid\ \((aad/aa)\)\  - \ ss \[Equal] 
          0;\)\), "\n", 
    \(\(eqb1 = f[ti] == f0;\)\), "\n", 
    \(\(eqb2 = \(f'\)[ti] == 0;\)\), "\n", 
    \(\(eqb3 = 
        a[ti] \[Equal] \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((2/3)\);\)\), "\n", 
    \(\(eqb4 = \(a'\)[
            ti] \[Equal] \((2/
                3)\)\ \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((\(-1\)/
                  3)\);\)\), "\n", 
    \(\(sol2 = 
        NDSolve[{eq1, eq2, eqb1, eqb2, eqb3, eqb4}, {aa, fi}, {t, ti, t0}, 
          MaxSteps \[Rule] 10000000];\)\), "\n", 
    \(\(asol = Part[Evaluate[a[t] /. sol2], 1];\)\), "\n", 
    \(\(fsol = Part[Evaluate[f[t] /. sol2], 1];\)\), "\n", 
    \(\(dfsol = D[fsol, t];\)\), "\[IndentingNewLine]", 
    \(\(enf = 0.5\ dfsol^2\  - \ ss\ fsol;\)\), "\[IndentingNewLine]", 
    \(\(as[t1_] := asol\  /. \ t -> t1\ ;\)\), "\[IndentingNewLine]", 
    \(\(tt = Part[FindRoot[as[t] == 1, {t, 1}], 1, 2];\)\), "\n", 
    \(\(tas[a_] := 
        Part[FindRoot[as[t] \[Equal] a, {t, 1}], 1, 2];\)\), "\n", 
    \(\(hht[t1_] := D[asol, t]/asol\  /. \ t -> t1\ ;\)\), "\n", 
    \(\(hha[a_] := hht[tas[a]];\)\), "\[IndentingNewLine]", 
    \(\(hhz[z_] := hha[1/\((z + 1)\)];\)\), "\[IndentingNewLine]", 
    \(enf\  /. \ t \[Rule] tt\), "\[IndentingNewLine]", 
    \(hhz[0]\), "\[IndentingNewLine]", 
    \(\(enf = 0.5\ dfsol^2\  - \ ss\ fsol;\)\), "\n", 
    \(\(ppf = 0.5\ dfsol^2\  + \ ss\ fsol;\)\), "\n", 
    \(\(wft[t1_] := ppf/enf\  /. \ t -> t1\ ;\)\ \), "\n", 
    \(\(wfa[a_] := wft[tas[a]];\)\), "\n", 
    \(\(wfz[z_] := wfa[1/\((z + 1)\)];\)\), "\n", 
    \(\(plw05q = 
        Plot[wfz[z], {z, 0, 2}, Frame \[Rule] True, PlotRange \[Rule] All, 
          FrameLabel \[Rule] {"\<z\>", "\<w(z)\>"}];\)\)}], "Input"],

Cell[BoxData[
    \(0.6989088688695329`\)], "Output"],

Cell[BoxData[
    \(1.0007419559500363`\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.476191 24.7004 24.735 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.2619 -0.0125 -10.7813 -17.8125 ]
[.2619 -0.0125 10.7813 0 ]
[.5 -0.0125 -5.53125 -17.8125 ]
[.5 -0.0125 5.53125 0 ]
[.7381 -0.0125 -10.7813 -17.8125 ]
[.7381 -0.0125 10.7813 0 ]
[.97619 -0.0125 -5.53125 -17.8125 ]
[.97619 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.125 -35.625 ]
[.5 -0.0125 5.125 -17.8125 ]
[-0.0125 .08903 -45.375 -8.90625 ]
[-0.0125 .08903 0 8.90625 ]
[-0.0125 .2127 -38.3125 -8.90625 ]
[-0.0125 .2127 0 8.90625 ]
[-0.0125 .33638 -45.375 -8.90625 ]
[-0.0125 .33638 0 8.90625 ]
[-0.0125 .46005 -38.3125 -8.90625 ]
[-0.0125 .46005 0 8.90625 ]
[-0.0125 .58373 -45.375 -8.90625 ]
[-0.0125 .58373 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -63.1875 -14.7188 ]
[-0.01875 .30902 -45.375 14.7188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.125 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08903 m
.00625 .08903 L
s
gsave
-0.0125 .08903 -106.375 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.995) show
1.000 setlinewidth
grestore
0 .2127 m
.00625 .2127 L
s
gsave
-0.0125 .2127 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.99) show
1.000 setlinewidth
grestore
0 .33638 m
.00625 .33638 L
s
gsave
-0.0125 .33638 -106.375 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.985) show
1.000 setlinewidth
grestore
0 .46005 m
.00625 .46005 L
s
gsave
-0.0125 .46005 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.98) show
1.000 setlinewidth
grestore
0 .58373 m
.00625 .58373 L
s
gsave
-0.0125 .58373 -106.375 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.975) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .11376 m
.00375 .11376 L
s
0 .1385 m
.00375 .1385 L
s
0 .16323 m
.00375 .16323 L
s
0 .18797 m
.00375 .18797 L
s
0 .23744 m
.00375 .23744 L
s
0 .26217 m
.00375 .26217 L
s
0 .28691 m
.00375 .28691 L
s
0 .31164 m
.00375 .31164 L
s
0 .36111 m
.00375 .36111 L
s
0 .38585 m
.00375 .38585 L
s
0 .41058 m
.00375 .41058 L
s
0 .43532 m
.00375 .43532 L
s
0 .48479 m
.00375 .48479 L
s
0 .50952 m
.00375 .50952 L
s
0 .53426 m
.00375 .53426 L
s
0 .55899 m
.00375 .55899 L
s
0 .06429 m
.00375 .06429 L
s
0 .03956 m
.00375 .03956 L
s
0 .01482 m
.00375 .01482 L
s
0 .60846 m
.00375 .60846 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -130 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.7188 12.9063 translate
90 rotate
-75.7188 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.063 17.500 moveto
(H) show
77.625 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.875 17.500 moveto
(L) show
88.438 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08903 m
1 .08903 L
s
.99375 .2127 m
1 .2127 L
s
.99375 .33638 m
1 .33638 L
s
.99375 .46005 m
1 .46005 L
s
.99375 .58373 m
1 .58373 L
s
.125 Mabswid
.99625 .11376 m
1 .11376 L
s
.99625 .1385 m
1 .1385 L
s
.99625 .16323 m
1 .16323 L
s
.99625 .18797 m
1 .18797 L
s
.99625 .23744 m
1 .23744 L
s
.99625 .26217 m
1 .26217 L
s
.99625 .28691 m
1 .28691 L
s
.99625 .31164 m
1 .31164 L
s
.99625 .36111 m
1 .36111 L
s
.99625 .38585 m
1 .38585 L
s
.99625 .41058 m
1 .41058 L
s
.99625 .43532 m
1 .43532 L
s
.99625 .48479 m
1 .48479 L
s
.99625 .50952 m
1 .50952 L
s
.99625 .53426 m
1 .53426 L
s
.99625 .55899 m
1 .55899 L
s
.99625 .06429 m
1 .06429 L
s
.99625 .03956 m
1 .03956 L
s
.99625 .01482 m
1 .01482 L
s
.99625 .60846 m
1 .60846 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .08903 m
1 .08903 L
s
.5 Mabswid
.02381 .60332 m
.06244 .52905 L
.10458 .45763 L
.14415 .39891 L
.18221 .34934 L
.22272 .30323 L
.26171 .2646 L
.30316 .22894 L
.34309 .19916 L
.3815 .17419 L
.42237 .15105 L
.46172 .13163 L
.49955 .11526 L
.53984 .09996 L
.57861 .08702 L
.61984 .07493 L
.65954 .06469 L
.69774 .05595 L
.73838 .0477 L
.77751 .04064 L
.81909 .03398 L
.85916 .02825 L
.89771 .02331 L
.93871 .0186 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{558.375, 345.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008^0001FB000`400?l00000o`00003oo`3ooooo
0?oooc00oooo003o0?ooool0oooo<03oool00?l0ooooo`3oool`0?ooo`00o`3ooooo0?oooc00oooo
003o0?ooool0oooo<03oool00?l0ooooo`3oool`0?ooo`00o`3ooooo0?oooc00oooo003o0?ooocP0
oooo1P00003a0?ooo`00o`3oooli0?ooo`050000003oool0oooo0?ooo`000000l@3oool00?l0oooo
>P3oool00`000000oooo0?ooo`3b0?ooo`00o`3ooolj0?ooo`030000003oool0oooo0?80oooo003o
0?oooc/0oooo00<000000?ooo`3oool0l@3oool00?l0oooo>03oool01@000000oooo0?ooo`3oool0
00000?80oooo003o0?ooocP0oooo1P00003a0?ooo`00o`3ooooo0?oooc00oooo003o0?ooool0oooo
<03oool00?l0ooooo`3oool`0?ooo`00o`3ooooo0?oooc00oooo003o0?ooool0oooo<03oool00?l0
ooooo`3oool`0?ooo`00o`3ooooo0?oooc00oooo003o0?ooool0oooo<03oool00?l0ooooo`3oool`
0?ooo`00o`3ooooo0?oooc00oooo003o0?ooool0oooo<03oool00580oooo0`00001[0?ooo`<00000
0`3oool010000000oooo0?ooo`3oool3000006`0oooo0`00001[0?ooo`<000000`3oool010000000
oooo0?ooo`3oool3000006/0oooo1@00000:0?ooo`00D@3oool01@000000oooo0?ooo`3oool00000
06T0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo06X0oooo00<00000
0?ooo`3oool0J`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo06T0oooo00@00000
0?ooo`3oool000002P3oool00540oooo00D000000?ooo`3oool0oooo0000001Y0?ooo`050000003o
ool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo06/0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo00X0oooo
001A0?ooo`050000003oool0oooo0?ooo`000000J@3oool01@000000oooo0?ooo`3oool0000000X0
oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`090?ooo`00D@3oool01@000000oooo
0?ooo`3oool0000006T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo
06T0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
06X0oooo00<000000?ooo`3oool02@3oool00540oooo00D000000?ooo`3oool0oooo0000001Y0?oo
o`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0
oooo06/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0
oooo00P0oooo001A0?ooo`050000003oool0oooo0?ooo`000000J@3oool01@000000oooo0?ooo`3o
ool0000000H0oooo0`00001]0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool01P3o
ool3000006l0oooo00<000000?ooo`3oool0203oool00540oooo00D000000?ooo`3oool0oooo0000
001Y0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`1]0?ooo`030000
003oool0oooo06/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1_0?ooo`030000
003oool0oooo00P0oooo001A0?ooo`050000003oool0oooo0?ooo`000000J@3oool01@000000oooo
0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0J`3oool2000006`0oooo0P0000090?ooo`03
0000003oool0oooo06X0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`00DP3oool3000006/0
oooo0`0000080?ooo`@00000J`3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00L0
oooo1000001Z0?ooo`<000002`3oool00?l0ooooo`3oool`0?ooo`00o`3ooooo0?oooc00oooo003o
0?ooool0oooo<03oool00?l0ooooo`3oool`0?ooo`00o`3ooooo0?oooc00oooo003o0?ooool0oooo
<03oool00?l0ooooo`3oool`0?ooo`00o`3ooooo0?oooc00oooo00180?ooool00000i`00000004P0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool02@3oool100000000B03oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`090?ooo`400000
00180?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?oo
o`1`0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0L03oool00`000000oooo0?oo
o`090?ooo`40000000180?ooo`030000003oool0oooo0?l0ooooh`3oool100000000B03oool00`00
0000oooo0?ooo`3o0?ooon<0oooo0@00000004P0oooo00<000000?ooo`3oool0o`3ooooS0?ooo`40
000000180?ooo`030000003oool0oooo0?l0ooooh`3oool100000000B03oool300000?l0ooooc`3o
ool9000000T0oooo0`00000004P0oooo00<000000?ooo`3oool0o`3oooo20?ooo`d00000503oool1
00000000B03oool00`000000oooo0?ooo`3o0?oook`0oooo1P00000Q0?ooo`40000000180?ooo`03
0000003oool0oooo0?l0oooo]@3oool7000002L0oooo0@00000004P0oooo00<000000?ooo`3oool0
o`3ooon]0?ooo`P00000;P3oool100000000B03oool00`000000oooo0?ooo`3o0?oooj<0oooo2P00
000f0?ooo`40000000180?ooo`030000003oool0oooo0?l0ooooV`3oool800000400oooo0@000000
04P0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`H00000B03oool100000000B03oool00`000000
oooo0?ooo`3o0?ooohl0oooo1P00001>0?ooo`40000000180?ooo`030000003oool0oooo0?l0oooo
R03oool7000005@0oooo0@00000004P0oooo00<000000?ooo`3oool0o`3ooon20?ooo`H00000F`3o
ool100000000B03oool00`000000oooo0?ooo`3o0?ooog/0oooo1`00001Q0?ooo`40000000180?oo
o`<00000o`3ooome0?ooo`H00000IP3oool300000000B03oool00`000000oooo0?ooo`3o0?ooog00
oooo1@00001^0?ooo`40000000180?ooo`030000003oool0oooo0?l0ooooK03oool4000007<0oooo
0@00000004P0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`D00000M`3oool100000000B03oool0
0`000000oooo0?ooo`3o0?ooof80oooo1@00001l0?ooo`40000000180?ooo`030000003oool0oooo
0?l0ooooG@3oool500000840oooo0@00000004P0oooo00<000000?ooo`3oool0o`3ooomH0?ooo`D0
0000QP3oool100000000B03oool00`000000oooo0?ooo`3o0?oooe<0oooo1@00002;0?ooo`400000
00180?ooo`030000003oool0oooo0?l0ooooCP3oool500000900oooo0@00000004P0oooo00<00000
0?ooo`3oool0o`3ooom:0?ooo`@00000U@3oool100000000B03oool00`000000oooo0?ooo`3o0?oo
odD0oooo1@00002I0?ooo`40000000180?ooo`030000003oool0oooo0?l0oooo@@3oool4000009h0
oooo0@00000004P0oooo0`00003o0?ooocd0oooo1000002P0?ooo`<0000000180?ooo`030000003o
ool0oooo0?l0oooo>@3oool400000:H0oooo0@00000004P0oooo00<000000?ooo`3oool0o`3ooole
0?ooo`@00000ZP3oool100000000B03oool00`000000oooo0?ooo`3o0?oooc40oooo1000002^0?oo
o`40000000180?ooo`030000003oool0oooo0?l0oooo;@3oool400000;80oooo0@00000004P0oooo
00<000000?ooo`3oool0o`3ooolY0?ooo`@00000]P3oool100000000B03oool00`000000oooo0?oo
o`3o0?ooobH0oooo0`00002j0?ooo`40000000180?ooo`030000003oool0oooo0?l0oooo8P3oool4
00000;d0oooo0@0000000280oooo0`0000030?ooo`040000003oool0oooo0?ooo`8000001@3oool2
000000D0oooo0`00000;0?ooo`030000003oool0oooo0?l0oooo7`3oool300000<40oooo0@000000
0240oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo703oool3
00000<@0oooo0@0000000240oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0?l0oooo603oool400000<L0oooo0@00000001L0oooo1`0000030?ooo`050000003oool0oooo
0?ooo`0000001`3oool4000000<0oooo100000060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0o`3ooolE0?ooo`<00000b`3oool1000000008@3oool01@000000oooo0?ooo`3oool0
000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000
1P3oool00`000000oooo0?ooo`070?ooool00000i`0000000240oooo00D000000?ooo`3oool0oooo
000000060?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooo`l0oooo0`00003A0?oo
o`400000000Q0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0
00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`<000002`3oool00`000000oooo0?oo
o`3o0?ooo``0oooo0`00003D0?ooo`400000000Q0?ooo`050000003oool0oooo0?ooo`0000001P3o
ool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3oool90?ooo`<00000e`3oool100000000
8@3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000020?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0?l0oooo1P3oool300000=X0oooo0@0000000280oooo0`0000080?ooo`<00000103oool30000
00@0oooo100000090?ooo`030000003oool0oooo0?l0oooo0`3oool300000=d0oooo0@00000004P0
oooo00<000000?ooo`3oool0o`3oool300000>00oooo0@00000004P0oooo00<000000?ooo`3oool0
o03oool300000><0oooo0@00000004P0oooo00<000000?ooo`3oool0nP3oool200000>H0oooo0@00
000004P0oooo00<000000?ooo`3oool0m`3oool300000>P0oooo0@00000004P0oooo00<000000?oo
o`3oool0m03oool300000>/0oooo0@00000004P0oooo00<000000?ooo`3oool0l@3oool300000>h0
oooo0@00000004P0oooo0`00003^0?ooo`<00000k`3oool300000000B03oool00`000000oooo0?oo
o`3/0?ooo`800000m03oool100000000B03oool00`000000oooo0?ooo`3Z0?ooo`800000mP3oool1
00000000B03oool00`000000oooo0?ooo`3X0?ooo`800000n03oool100000000B03oool00`000000
oooo0?ooo`3U0?ooo`<00000nP3oool100000000B03oool00`000000oooo0?ooo`3S0?ooo`800000
o@3oool100000000B03oool00`000000oooo0?ooo`3Q0?ooo`800000o`3oool100000000B03oool0
0`000000oooo0?ooo`3O0?ooo`800000o`3oool20?ooo`40000000180?ooo`030000003oool0oooo
0=d0oooo0P00003o0?ooo`@0oooo0@00000004P0oooo00<000000?ooo`3oool0f`3oool200000?l0
oooo1P3oool100000000B03oool00`000000oooo0?ooo`3I0?ooo`800000o`3oool80?ooo`400000
00180?ooo`030000003oool0oooo0=L0oooo0P00003o0?ooo`X0oooo0@00000004P0oooo0`00003E
0?ooo`800000o`3oool:0?ooo`<0000000180?ooo`030000003oool0oooo0=<0oooo0P00003o0?oo
o`h0oooo0@00000004P0oooo00<000000?ooo`3oool0d@3oool200000?l0oooo403oool100000000
B03oool00`000000oooo0?ooo`3?0?ooo`800000o`3ooolB0?ooo`40000000180?ooo`030000003o
ool0oooo0<d0oooo0P00003o0?oooa@0oooo0@00000004P0oooo00<000000?ooo`3oool0b`3oool2
00000?l0oooo5P3oool100000000B03oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
0?l0oooo5P3oool100000000B03oool00`000000oooo0?ooo`380?ooo`800000o`3ooolI0?ooo`40
000000180?ooo`030000003oool0oooo0<H0oooo0P00003o0?oooa/0oooo0@00000004P0oooo00<0
00000?ooo`3oool0a03oool200000?l0oooo7@3oool100000000B03oool00`000000oooo0?ooo`32
0?ooo`800000o`3ooolO0?ooo`40000000180?ooo`030000003oool0oooo0<40oooo00<000000?oo
o`3oool0o`3ooolO0?ooo`40000000180?ooo`<00000_`3oool200000?l0oooo803oool300000000
B03oool00`000000oooo0?ooo`2m0?ooo`800000o`3ooolT0?ooo`40000000180?ooo`030000003o
ool0oooo0;/0oooo0P00003o0?ooobH0oooo0@00000004P0oooo00<000000?ooo`3oool0^@3oool2
00000?l0oooo:03oool100000000B03oool00`000000oooo0?ooo`2g0?ooo`800000o`3ooolZ0?oo
o`40000000180?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0o`3ooolZ0?ooo`40
000000180?ooo`030000003oool0oooo0;@0oooo0P00003o0?ooobd0oooo0@00000004P0oooo00<0
00000?ooo`3oool0/`3oool00`000000oooo0?ooo`3o0?ooobd0oooo0@00000004P0oooo00<00000
0?ooo`3oool0/@3oool200000?l0oooo<03oool100000000B03oool00`000000oooo0?ooo`2_0?oo
o`800000o`3ooolb0?ooo`40000000180?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3o
ool0o`3ooolb0?ooo`40000000180?ooo`030000003oool0oooo0:`0oooo0P00003o0?ooocD0oooo
0@00000004P0oooo0`00002[0?ooo`030000003oool0oooo0?l0oooo<`3oool300000000B03oool0
0`000000oooo0?ooo`2Y0?ooo`800000o`3ooolh0?ooo`40000000180?ooo`030000003oool0oooo
0:L0oooo0P00003o0?ooocX0oooo0@00000004P0oooo00<000000?ooo`3oool0YP3oool00`000000
oooo0?ooo`3o0?ooocX0oooo0@00000004P0oooo00<000000?ooo`3oool0Y03oool200000?l0oooo
?@3oool100000000B03oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo0?l0oooo?@3o
ool100000000B03oool00`000000oooo0?ooo`2Q0?ooo`800000o`3ooom00?ooo`40000000180?oo
o`030000003oool0oooo0:00oooo00<000000?ooo`3oool0o`3ooom00?ooo`400000000Y0?ooo`<0
00000`3oool010000000oooo0?ooo`3oool2000000D0oooo0P00000<0?ooo`030000003oool0oooo
09l0oooo00<000000?ooo`3oool0o`3ooom10?ooo`400000000X0?ooo`050000003oool0oooo0?oo
o`000000203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0W@3oool200000?l0ooooA03oool100000000:03oool01@000000oooo0?ooo`3oool00000
00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
09`0oooo00<000000?ooo`3oool0o`3ooom40?ooo`400000000N0?ooo`L000000`3oool01@000000
oooo0?ooo`3oool0000000L0oooo100000030?ooo`@000002@3oool00`000000oooo0?ooo`2K0?oo
o`030000003oool0oooo0?l0ooooA@3oool100000000:03oool01@000000oooo0?ooo`3oool00000
00H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000002@3o
ool4000009P0oooo0P00003o0?ooodD0oooo1000000002P0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000T0
oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`3o0?ooodP0oooo0@00000002P0oooo
00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`3o
0?ooodT0oooo0@00000002P0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0
oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0
U@3oool200000?l0ooooC03oool100000000:03oool01@000000oooo0?ooo`3oool0000000H0oooo
00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000002@3oool00`00
0000oooo0?ooo`2D0?ooo`030000003oool0oooo0?l0ooooC03oool100000000:@3oool3000000P0
oooo0`0000040?ooo`<000002P3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0?l0
ooooC@3oool100000000B03oool00`000000oooo0?ooo`2A0?ooo`800000o`3ooom@0?ooo`400000
00180?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0o`3ooom@0?ooo`4000000018
0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`40000000180?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool0o`3ooomB0?ooo`40000000180?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0o`3ooomC0?ooo`40000000180?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool0o`3ooomD0?ooo`40000000180?ooo`<00000RP3o
ool200000?l0ooooE@3oool300000000B03oool00`000000oooo0?ooo`290?ooo`030000003oool0
oooo0?l0ooooE`3oool100000000B03oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo
0?l0ooooF03oool100000000B03oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo0?l0
ooooF@3oool100000000B03oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0?l0oooo
FP3oool100000000B03oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0?l0ooooF`3o
ool100000000B03oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0?l0ooooG03oool1
00000000B03oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo0?l0ooooG@3oool10000
0000B03oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo0?l0ooooGP3oool100000000
B03oool00`000000oooo0?ooo`200?ooo`800000o`3ooomQ0?ooo`40000000180?ooo`030000003o
ool0oooo07l0oooo00<000000?ooo`3oool0o`3ooomQ0?ooo`40000000180?ooo`030000003oool0
oooo07h0oooo00<000000?ooo`3oool0o`3ooomR0?ooo`40000000180?ooo`<00000O@3oool00`00
0000oooo0?ooo`3o0?ooof40oooo0`00000004P0oooo00<000000?ooo`3oool0O03oool00`000000
oooo0?ooo`3o0?ooof@0oooo0@00000004P0oooo00<000000?ooo`3oool0N`3oool00`000000oooo
0?ooo`3o0?ooofD0oooo0@00000004P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?oo
o`3o0?ooofH0oooo0@00000004P0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`3o
0?ooofL0oooo0@00000004P0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`3o0?oo
ofP0oooo0@00000004P0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`3o0?ooofT0
oooo0@00000004P0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`3o0?ooofX0oooo
0@00000004P0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`3o0?ooof/0oooo0@00
000004P0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`3o0?ooof`0oooo0@000000
04P0oooo00<000000?ooo`3oool0LP3oool200000?l0ooooK`3oool1000000001P3oool00`000000
oooo0?ooo`0o0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0o`3ooom_0?ooo`40
000000060?ooo`<00000?`3oool300000700oooo00<000000?ooo`3oool0o`3ooom^0?ooo`<00000
00060?ooo`030000003oool0oooo00<00000?03oool00`000000oooo0?ooo`1_0?ooo`030000003o
ool0oooo0?l0ooooL@3oool1000000002`3oool2000003/0oooo00<000000?ooo`3oool0KP3oool0
0`000000oooo0?ooo`3o0?ooog80oooo0@00000000H0oooo00<000000?ooo`3oool00P00000m0?oo
o`030000003oool0oooo06d0oooo00<000000?ooo`3oool0o`3ooomc0?ooo`40000000060?ooo`<0
0000?`3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo0?l0ooooM03oool100000000
1P3oool00`000000oooo0?ooo`03000003`0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`3o0?ooogD0oooo0@00000000/0oooo0P00000k0?ooo`030000003oool0oooo06X0oooo00<0
00000?ooo`3oool0o`3ooomf0?ooo`40000000060?ooo`030000003oool0oooo00800000?@3oool0
0`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0?l0ooooM`3oool1000000001P3oool30000
03l0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`3o0?ooogP0oooo0@00000000H0
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0?l0
ooooN@3oool1000000001@3oool9000003X0oooo00<000000?ooo`3oool0IP3oool00`000000oooo
0?ooo`3o0?ooogX0oooo0@00000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0o`3ooomj0?ooo`4000000003
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0=P3oool3000006D0oooo00<00000
0?ooo`3oool0o`3ooomi0?ooo`<0000000060?ooo`800000103oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo06@0oooo00<000000?ooo`3oool0o`3oooml0?ooo`40000000060?ooo`03
0000003oool0oooo0080oooo0P00000k0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool0o`3ooomm0?ooo`40000000060?ooo`030000003oool0oooo0080000000<0oooo0000003oool0
>P3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0?l0ooooOP3oool1000000001P3o
ool00`000000oooo000000030?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0H@3o
ool00`000000oooo0?ooo`3o0?ooogl0oooo0@00000000H0oooo0P0000040?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`3o0?oooh00oooo0@000000
00H0oooo00<000000?ooo`3oool00P3oool2000003/0oooo00<000000?ooo`3oool0G`3oool00`00
0000oooo0?ooo`3o0?oooh40oooo0@00000000<0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0o`3ooon10?ooo`40
000000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool3000000<0oooo
00@000000?ooo`3oool0oooo0P0000060?ooo`<000000`3oool3000000/0oooo00<000000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`3o0?oooh80oooo0@00000000D0oooo2@00000C0?ooo`050000
003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`0000001@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo05d0oooo00<000000?oo
o`3oool0o`3ooon30?ooo`400000000Q0?ooo`050000003oool0oooo0?ooo`0000002@3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0o`3ooon40?ooo`400000000G0?oo
o`L000000`3oool01@000000oooo0?ooo`3oool0000000L0oooo100000020?ooo`050000003oool0
oooo0?ooo`0000001P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo05/0oooo00<0
00000?ooo`3oool0o`3ooon50?ooo`400000000Q0?ooo`050000003oool0oooo0?ooo`0000001P3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000001`3oool00`000000oooo
0?ooo`070?ooo`@00000F@3oool00`000000oooo0?ooo`3o0?oooh<0oooo100000000240oooo00D0
00000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0F@3oool00`000000
oooo0?ooo`3o0?ooohL0oooo0@0000000240oooo00D000000?ooo`3oool0oooo000000060?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000030?ooo`<000002`3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo0?l0ooooR03oool1000000008@3oool01@000000
oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool0o`3ooon80?ooo`400000000Q0?ooo`050000003oool0oooo0?ooo`0000001P3o
ool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3o0?ooohT0
oooo0@0000000280oooo0`0000080?ooo`<00000103oool3000000@0oooo100000090?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool0o`3ooon:0?ooo`40000000180?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool0o`3ooon;0?ooo`40000000180?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool0o`3ooon<0?ooo`40000000180?ooo`030000003oool0oooo
05<0oooo00<000000?ooo`3oool0o`3ooon=0?ooo`40000000180?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0o`3ooon=0?ooo`40000000180?ooo`030000003oool0oooo0580oooo
00<000000?ooo`3oool0o`3ooon>0?ooo`40000000180?ooo`030000003oool0oooo0540oooo00<0
00000?ooo`3oool0o`3ooon?0?ooo`40000000180?ooo`<00000D03oool00`000000oooo0?ooo`3o
0?ooohh0oooo0`00000004P0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`3o0?oo
oi00oooo0@00000004P0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`3o0?oooi40
oooo0@00000004P0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`3o0?oooi80oooo
0@00000004P0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3o0?oooi<0oooo0@00
000004P0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3o0?oooi<0oooo0@000000
04P0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?oooi@0oooo0@00000004P0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@00000004P0oooo
00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`3o0?oooiH0oooo0@00000004P0oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0?ooo`3o0?oooiH0oooo0@00000004P0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`3o0?oooiL0oooo0@00000004P0oooo00<000000?oo
o`3oool0B03oool00`000000oooo0?ooo`3o0?oooiP0oooo0@00000004P0oooo0`0000170?ooo`03
0000003oool0oooo0?l0ooooU`3oool300000000B03oool00`000000oooo0?ooo`170?ooo`030000
003oool0oooo0?l0ooooV@3oool100000000B03oool00`000000oooo0?ooo`160?ooo`030000003o
ool0oooo0?l0ooooVP3oool100000000B03oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo0?l0ooooV`3oool100000000B03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo
0?l0ooooW03oool100000000B03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0?l0
ooooW03oool100000000B03oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0?l0oooo
W@3oool100000000B03oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0?l0ooooWP3o
ool100000000B03oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0?l0ooooWP3oool1
00000000B03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0?l0ooooW`3oool10000
0000B03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0?l0ooooX03oool100000000
B03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0?l0ooooX03oool100000000B03o
ool3000003l0oooo00<000000?ooo`3oool0o`3ooonO0?ooo`<0000000180?ooo`030000003oool0
oooo03h0oooo00<000000?ooo`3oool0o`3ooonR0?ooo`40000000180?ooo`030000003oool0oooo
03h0oooo00<000000?ooo`3oool0o`3ooonR0?ooo`40000000180?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool0o`3ooonS0?ooo`40000000180?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0o`3ooonT0?ooo`40000000180?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool0o`3ooonT0?ooo`40000000180?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool0o`3ooonU0?ooo`40000000180?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0o`3ooonV0?ooo`40000000180?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0o`3ooonW0?ooo`40000000180?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
o`3ooonW0?ooo`40000000180?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0o`3o
oonX0?ooo`40000000180?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0o`3ooonY
0?ooo`40000000180?ooo`<00000=`3oool00`000000oooo0?ooo`3o0?ooojL0oooo0`00000004P0
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`3o0?ooojX0oooo0@00000004P0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`3o0?oooj/0oooo0@00000004P0oooo00<0
00000?ooo`3oool0=@3oool00`000000oooo0?ooo`3o0?oooj/0oooo0@00000004P0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`3o0?oooj`0oooo0@00000004P0oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`3o0?ooojd0oooo0@00000004P0oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`3o0?ooojd0oooo0@00000004P0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`3o0?ooojh0oooo0@00000002T0oooo0`0000030?ooo`040000003o
ool0oooo0?ooo`8000001P3oool3000000X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`3o0?ooojl0oooo0@00000002P0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool0o`3ooon_0?ooo`400000000X0?ooo`050000003oool0oooo0?ooo`00
00002@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo0?l0oooo/03oool1000000007P3oool7000000<0
oooo00D000000?ooo`3oool0oooo000000070?ooo`@000000P3oool01@000000oooo0?ooo`3oool0
000000T0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`3o0?oook40oooo0@000000
02P0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0000000:0?ooo`@00000;P3oool00`000000oooo0?ooo`3o0?ooojh0oooo1000
000002P0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
o`3ooonb0?ooo`400000000X0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo0?l0oooo/P3oool100000000:03oool01@000000oooo0?ooo`3oool0000000H0
oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000002@3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0oooo/`3oool100000000:03oool01@00
0000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003o
ool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0?l0oooo
]03oool100000000:@3oool3000000P0oooo0`0000040?ooo`<000002P3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo0?l0oooo]03oool100000000B03oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo0?l0oooo]@3oool100000000B03oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo0?l0oooo]@3oool100000000B03oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo0?l0oooo]P3oool100000000B03oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo0?l0oooo]`3oool100000000B03oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo0?l0oooo]`3oool100000000B03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo0?l0oooo^03oool100000000B03oool3000002P0oooo00<000000?ooo`3oool0o`3ooonf0?oo
o`<0000000180?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0o`3oooni0?ooo`40
000000180?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0o`3ooonj0?ooo`400000
00180?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0o`3ooonj0?ooo`4000000018
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0o`3ooonk0?ooo`40000000180?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0o`3ooonk0?ooo`40000000180?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0o`3ooonl0?ooo`40000000180?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0o`3ooonm0?ooo`40000000180?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0o`3ooonm0?ooo`40000000180?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0o`3ooonn0?ooo`40000000180?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool0o`3ooonn0?ooo`40000000180?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool0o`3ooono0?ooo`40000000180?ooo`<00000803oool00`000000oooo
0?ooo`3o0?oookh0oooo0`00000004P0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`3o0?oool00oooo0@00000004P0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3o
0?oool40oooo0@00000004P0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3o0?oo
ol40oooo0@00000004P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3o0?oool80
oooo0@00000004P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3o0?oool<0oooo
0@00000004P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3o0?oool<0oooo0@00
000004P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`3o0?oool@0oooo0@000000
04P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`3o0?oool@0oooo0@00000004P0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`3o0?ooolD0oooo0@00000004P0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`3o0?ooolH0oooo0@00000004P0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`3o0?ooolH0oooo0@00000004P0oooo0`00000I
0?ooo`030000003oool0oooo0?l0ooooa@3oool300000000B03oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo0?l0ooooa`3oool100000000B03oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo0?l0oooob03oool100000000B03oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo0?l0oooob03oool100000000B03oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo0?l0oooob@3oool100000000B03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo0?l0oooob@3oool100000000B03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
0?l0oooobP3oool100000000B03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0
oooobP3oool100000000B03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0oooo
b`3oool100000000B03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0oooob`3o
ool100000000B03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0ooooc03oool1
00000000B03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0ooooc03oool10000
0000B03oool3000001<0oooo00<000000?ooo`3oool0o`3oooo;0?ooo`<0000000180?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0o`3oooo=0?ooo`40000000180?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0o`3oooo>0?ooo`40000000180?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0o`3oooo?0?ooo`40000000180?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0o`3oooo?0?ooo`40000000180?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0o`3oooo@0?ooo`40000000180?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0o`3oooo@0?ooo`40000000180?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0o`3ooooA0?ooo`400000000R0?ooo`<000000`3oool010000000oooo0?ooo`3o
ool2000000H0oooo00<000000?ooo`3oool00`3oool3000000/0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`3o0?ooom40oooo0@0000000240oooo00D000000?ooo`3oool0oooo0000
00080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooooB0?ooo`400000000Q
0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0?l0oooodP3oool1000000005`3oool7000000<0oooo00D000000?ooo`3oool0oooo0000
00070?ooo`@00000103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?ooom<0oooo0@0000000240oooo00D00000
0?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo1000000<0?ooo`030000003oool0oooo0?l0oooo
d03oool4000000008@3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0
oooo000000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooe03oool1000000008@3oool01@000000oooo
0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000050?ooo`040000003oool0oooo
0?ooo`<000002`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooe03oool1
000000008@3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo0000
00050?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo0?l0ooooe@3oool1000000008@3oool01@000000oooo0?ooo`3oool0000000H0oooo
00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo0000000<
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooooE0?ooo`400000000R0?oo
o`<00000203oool3000000<0oooo1@0000030?ooo`@000002@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo0?l0ooooeP3oool100000000B03oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0?l0ooooeP3oool100000000B03oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0?l0ooooe`3oool100000000B03oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0?l0ooooe`3oool100000000B03oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0?l0oooof03oool100000000B03oool00`000000oooo0?ooo`3o0?ooon<0oooo0@00000004P0
oooo0`00003o0?ooon40oooo0`00000004P0oooo00<000000?ooo`3oool0o`3ooooS0?ooo`400000
00180?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?oo
o`1`0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0L03oool00`000000oooo0?oo
o`090?ooo`40000000180?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00T0oooo0@00000004P0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool02@3oool100000000B03ooooo00000>L00000003o0?ooool0oooo<03oool00001\
\>"],
  ImageRangeCache->{{{0, 557.375}, {344.125, 0}} -> {-0.363001, -1.00219, \
0.00433021, 8.33639*^-05}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ 
      Find\ chi\ square\ for\ given\ H \((z)\)\ \ *) \[IndentingNewLine]\(f[
          z_] := 1/hhz[z];\)\), "\n", 
    \(\(rr[zz_] := NIntegrate[f[z], {z, 0, zz}];\)\[IndentingNewLine]\n (*\ 
      Construct\ marginalization\ coefficients\ \((see\ \ astro - 
              ph/0401556\  .. )\)\ *) \), "\[IndentingNewLine]", 
    \(Clear[chi2fa, chi2fb, chi2fc]\), "\n", 
    \(\(chi2fa = 
        Sum[\((ld[i] - 5\ Log[10, rr[zz[i]]*\((1 + zz[i])\)])\)^2/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\n", 
    \(\(chi2fb = 
        Sum[\((ld[i] - 
                5\ Log[10, rr[zz[i]]*\((1 + zz[i])\)])\)/\((sld[i]^2)\), {i, 
            1, ndat}];\)\), "\n", 
    \(\(chi2fc = 
        Sum[1/\((sld[i]^2)\), {i, 1, ndat}];\)\[IndentingNewLine]\n (*\ 
      Construct\ function\ after\ marginalization, \ 
      find\ same\ result\ as\ with\ mb\ minimization\ *) \), "\
\[IndentingNewLine]", 
    \(chi2fm = chi2fa - chi2fb^2/chi2fc\), "\[IndentingNewLine]", 
    \(dchi2q05 = chi2fm - chi2l\)}], "Input"],

Cell[BoxData[
    \(177.3020829372108`\)], "Output"],

Cell[BoxData[
    \(0.1747115021571517`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ \(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(\
--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(-\(---\)\)\)\)\)\)\)\)\)\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)*) \[IndentingNewLine]\[IndentingNewLine] \
(*\ Find\ H \((z)\)\ for\ given\ slope\ s\ of\ the\ linear\ potential . \ 
            Present\ time\  = \ \(tt\ \((corresponds\ to\ a = 1)\) . \ 
              Run\ trials\ for\ initial\ condition\ for\ field\ fi\ \((f0)\)\ \
and\ initial\ time\ ti\ until\ we\ get\ field\ energy\ enf\  = \ \(0.7\ and\ \
H \((z = 0)\)\  = 
            1\ at\ present\ time\ \(\(tt\)\(.\)\)\)\)\ *) \[IndentingNewLine]\
\[IndentingNewLine] (*\ \(--\(--\(--\(--\ \ s\)\)\)\)\  = \ \(0.75\ \ \ --\) \
\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(---\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\ *) \
\[IndentingNewLine]\[IndentingNewLine]\(Clear[aa, fi, a, aad, aadd, fidas, 
        tas, f, rr, hht, hha];\)\), "\[IndentingNewLine]", 
    \(aa = a[t]; \ fi = f[t];\), "\n", 
    \(\(aad = D[aa, t];\)\), "\n", 
    \(\(aadd = D[aa, {t, 2}];\)\), "\n", 
    \(\(fid = D[fi, t];\)\), "\n", 
    \(\(fidd = D[fi, {t, 2}];\)\), "\n", 
    \(ti = 0.000025; \ t0 = 2.25;\), "\n", 
    \(\(f0 = \(-1.01\);\)\ \), "\n", 
    \(om0m = 0.3; \ ss = 0.75;\), "\n", 
    \(\(eq1 = 
        aadd/aa\  \[Equal] \(-\ \ fid^2\)\  - \ ss\ fi\  - \ 
            om0m/\((2\ aa^3)\);\)\), "\n", 
    \(\(eq2 = 
        fidd\ \  + \ \ \ 3\ \ fid\ \((aad/aa)\)\  - \ ss \[Equal] 
          0;\)\), "\n", 
    \(\(eqb1 = f[ti] == f0;\)\), "\n", 
    \(\(eqb2 = \(f'\)[ti] == 0;\)\), "\n", 
    \(\(eqb3 = 
        a[ti] \[Equal] \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((2/3)\);\)\), "\n", 
    \(\(eqb4 = \(a'\)[
            ti] \[Equal] \((2/
                3)\)\ \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((\(-1\)/
                  3)\);\)\), "\n", 
    \(\(sol2 = 
        NDSolve[{eq1, eq2, eqb1, eqb2, eqb3, eqb4}, {aa, fi}, {t, ti, t0}, 
          MaxSteps \[Rule] 10000000];\)\), "\n", 
    \(\(asol = Part[Evaluate[a[t] /. sol2], 1];\)\), "\n", 
    \(\(fsol = Part[Evaluate[f[t] /. sol2], 1];\)\), "\n", 
    \(\(dfsol = D[fsol, t];\)\), "\[IndentingNewLine]", 
    \(\(enf = 0.5\ dfsol^2\  - \ ss\ fsol;\)\), "\[IndentingNewLine]", 
    \(\(as[t1_] := asol\  /. \ t -> t1\ ;\)\), "\[IndentingNewLine]", 
    \(\(tt = Part[FindRoot[as[t] == 1, {t, 1}], 1, 2];\)\), "\n", 
    \(\(tas[a_] := 
        Part[FindRoot[as[t] \[Equal] a, {t, 1}], 1, 2];\)\), "\n", 
    \(\(hht[t1_] := D[asol, t]/asol\  /. \ t -> t1\ ;\)\), "\n", 
    \(\(hha[a_] := hht[tas[a]];\)\), "\[IndentingNewLine]", 
    \(\(hhz[z_] := hha[1/\((z + 1)\)];\)\), "\[IndentingNewLine]", 
    \(enf\  /. \ t \[Rule] tt\), "\[IndentingNewLine]", 
    \(hhz[0]\), "\[IndentingNewLine]", 
    \(\(enf = 0.5\ dfsol^2\  - \ ss\ fsol;\)\), "\n", 
    \(\(ppf = 0.5\ dfsol^2\  + \ ss\ fsol;\)\), "\n", 
    \(\(wft[t1_] := ppf/enf\  /. \ t -> t1\ ;\)\ \), "\n", 
    \(\(wfa[a_] := wft[tas[a]];\)\), "\n", 
    \(\(wfz[z_] := wfa[1/\((z + 1)\)];\)\), "\n", 
    \(\(plw075q = 
        Plot[wfz[z], {z, 0, 2}, Frame \[Rule] True, PlotRange \[Rule] All, 
          FrameLabel \[Rule] {"\<z\>", "\<w(z)\>"}];\)\)}], "Input"],

Cell[BoxData[
    \(0.6992532158485435`\)], "Output"],

Cell[BoxData[
    \(1.0009140190383945`\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.476191 11.0141 11.0469 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.2619 -0.0125 -10.7813 -17.8125 ]
[.2619 -0.0125 10.7813 0 ]
[.5 -0.0125 -5.53125 -17.8125 ]
[.5 -0.0125 5.53125 0 ]
[.7381 -0.0125 -10.7813 -17.8125 ]
[.7381 -0.0125 10.7813 0 ]
[.97619 -0.0125 -5.53125 -17.8125 ]
[.97619 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.125 -35.625 ]
[.5 -0.0125 5.125 -17.8125 ]
[-0.0125 .0777 -38.3125 -8.90625 ]
[-0.0125 .0777 0 8.90625 ]
[-0.0125 .18817 -38.3125 -8.90625 ]
[-0.0125 .18817 0 8.90625 ]
[-0.0125 .29863 -38.3125 -8.90625 ]
[-0.0125 .29863 0 8.90625 ]
[-0.0125 .4091 -38.3125 -8.90625 ]
[-0.0125 .4091 0 8.90625 ]
[-0.0125 .51957 -38.3125 -8.90625 ]
[-0.0125 .51957 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -56.125 -14.7188 ]
[-0.01875 .30902 -38.3125 14.7188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.125 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0777 m
.00625 .0777 L
s
gsave
-0.0125 .0777 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.99) show
1.000 setlinewidth
grestore
0 .18817 m
.00625 .18817 L
s
gsave
-0.0125 .18817 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.98) show
1.000 setlinewidth
grestore
0 .29863 m
.00625 .29863 L
s
gsave
-0.0125 .29863 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.97) show
1.000 setlinewidth
grestore
0 .4091 m
.00625 .4091 L
s
gsave
-0.0125 .4091 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.96) show
1.000 setlinewidth
grestore
0 .51957 m
.00625 .51957 L
s
gsave
-0.0125 .51957 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .09979 m
.00375 .09979 L
s
0 .12188 m
.00375 .12188 L
s
0 .14398 m
.00375 .14398 L
s
0 .16607 m
.00375 .16607 L
s
0 .21026 m
.00375 .21026 L
s
0 .23235 m
.00375 .23235 L
s
0 .25445 m
.00375 .25445 L
s
0 .27654 m
.00375 .27654 L
s
0 .32073 m
.00375 .32073 L
s
0 .34282 m
.00375 .34282 L
s
0 .36492 m
.00375 .36492 L
s
0 .38701 m
.00375 .38701 L
s
0 .4312 m
.00375 .4312 L
s
0 .45329 m
.00375 .45329 L
s
0 .47538 m
.00375 .47538 L
s
0 .49748 m
.00375 .49748 L
s
0 .0556 m
.00375 .0556 L
s
0 .03351 m
.00375 .03351 L
s
0 .01142 m
.00375 .01142 L
s
0 .54167 m
.00375 .54167 L
s
0 .56376 m
.00375 .56376 L
s
0 .58585 m
.00375 .58585 L
s
0 .60795 m
.00375 .60795 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -122.938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.7188 12.9063 translate
90 rotate
-75.7188 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.063 17.500 moveto
(H) show
77.625 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.875 17.500 moveto
(L) show
88.438 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0777 m
1 .0777 L
s
.99375 .18817 m
1 .18817 L
s
.99375 .29863 m
1 .29863 L
s
.99375 .4091 m
1 .4091 L
s
.99375 .51957 m
1 .51957 L
s
.125 Mabswid
.99625 .09979 m
1 .09979 L
s
.99625 .12188 m
1 .12188 L
s
.99625 .14398 m
1 .14398 L
s
.99625 .16607 m
1 .16607 L
s
.99625 .21026 m
1 .21026 L
s
.99625 .23235 m
1 .23235 L
s
.99625 .25445 m
1 .25445 L
s
.99625 .27654 m
1 .27654 L
s
.99625 .32073 m
1 .32073 L
s
.99625 .34282 m
1 .34282 L
s
.99625 .36492 m
1 .36492 L
s
.99625 .38701 m
1 .38701 L
s
.99625 .4312 m
1 .4312 L
s
.99625 .45329 m
1 .45329 L
s
.99625 .47538 m
1 .47538 L
s
.99625 .49748 m
1 .49748 L
s
.99625 .0556 m
1 .0556 L
s
.99625 .03351 m
1 .03351 L
s
.99625 .01142 m
1 .01142 L
s
.99625 .54167 m
1 .54167 L
s
.99625 .56376 m
1 .56376 L
s
.99625 .58585 m
1 .58585 L
s
.99625 .60795 m
1 .60795 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .0777 m
1 .0777 L
s
.5 Mabswid
.02381 .60332 m
.06244 .52448 L
.10458 .45052 L
.14415 .39081 L
.18221 .34107 L
.22272 .29525 L
.26171 .25714 L
.30316 .22217 L
.34309 .1931 L
.3815 .16879 L
.42237 .14632 L
.46172 .12751 L
.49955 .11167 L
.53984 .09688 L
.57861 .08439 L
.61984 .07272 L
.65954 .06284 L
.69774 .05442 L
.73838 .04647 L
.77751 .03968 L
.81909 .03325 L
.85916 .02774 L
.89771 .02299 L
.93871 .01845 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{516.5, 319.25},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000840001?b000`400?l00000o`00003oo`3ooooo
0?ooo`H0oooo003o0?ooool0oooo1P3oool00?l0ooooo`3oool60?ooo`00o`3ooooo0?ooo`H0oooo
003o0?ooool0oooo1P3oool00?l0ooooo`3oool60?ooo`00o`3ooolO0?ooo`H00000h03oool00?l0
oooo803oool01@000000oooo0?ooo`3oool000000>00oooo003o0?ooob40oooo00<000000?ooo`3o
ool0h@3oool00?l0oooo8@3oool00`000000oooo0?ooo`3Q0?ooo`00o`3ooolR0?ooo`030000003o
ool0oooo0>00oooo003o0?oooal0oooo00D000000?ooo`3oool0oooo0000003Q0?ooo`00o`3ooolO
0?ooo`H00000h03oool00?l0ooooo`3oool60?ooo`00o`3ooooo0?ooo`H0oooo003o0?ooool0oooo
1P3oool00?l0ooooo`3oool60?ooo`00o`3ooooo0?ooo`H0oooo003o0?ooool0oooo1P3oool00?l0
ooooo`3oool60?ooo`00o`3ooooo0?ooo`H0oooo003o0?ooool0oooo1P3oool00?l0ooooo`3oool6
0?ooo`00BP3oool3000006<0oooo0`0000030?ooo`040000003oool0oooo0?ooo`<00000H`3oool3
00000680oooo0`0000030?ooo`040000003oool0oooo0?ooo`<00000HP3oool5000000/0oooo0019
0?ooo`050000003oool0oooo0?ooo`000000H@3oool01@000000oooo0?ooo`3oool0000000T0oooo
00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0H03oool010000000oooo0?ooo`00000;0?ooo`00B@3oool01@000000oooo
0?ooo`3oool000000640oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo
0600oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0600oooo00<000000?ooo`3oool02`3oool004T0oooo00D000000?ooo`3oool0oooo0000001Q0?oo
o`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0
oooo0680oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0
oooo00X0oooo00190?ooo`050000003oool0oooo0?ooo`000000H@3oool01@000000oooo0?ooo`3o
ool0000000X0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`1R0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0:0?ooo`00B@3oool0
1@000000oooo0?ooo`3oool000000640oooo00D000000?ooo`3oool0oooo000000090?ooo`030000
003oool0oooo0640oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo06<0oooo00<000000?ooo`3oool02@3oool004T0oooo00D000000?ooo`3oool0oooo
0000001Q0?ooo`050000003oool0oooo0?ooo`0000001P3oool3000006@0oooo00<000000?ooo`3o
ool0HP3oool00`000000oooo0?ooo`060?ooo`<00000IP3oool00`000000oooo0?ooo`090?ooo`00
B@3oool01@000000oooo0?ooo`3oool000000640oooo00D000000?ooo`3oool0oooo000000060?oo
o`030000003oool0oooo06@0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo06H0oooo00<000000?ooo`3oool02@3oool004T0oooo00D000000?ooo`3o
ool0oooo0000001Q0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`1R
0?ooo`800000H`3oool2000000T0oooo00<000000?ooo`3oool0H@3oool01@000000oooo0?ooo`3o
ool0000000/0oooo001:0?ooo`<00000H`3oool3000000P0oooo1000001R0?ooo`030000003oool0
oooo0680oooo00<000000?ooo`3oool01`3oool400000640oooo0`00000<0?ooo`00o`3ooooo0?oo
o`H0oooo003o0?ooool0oooo1P3oool00?l0ooooo`3oool60?ooo`00o`3ooooo0?ooo`H0oooo003o
0?ooool0oooo1P3oool00?l0ooooo`3oool60?ooo`00o`3ooooo0?ooo`H0oooo003o0?ooool0oooo
1P3oool00440ooooo`00003300000040oooo00110?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00P0oooo0@000001
0?ooo`00@@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`080?ooo`4000000@3oool00440oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3o
ool0J03oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00P0oooo0@0000010?ooo`00
@@3oool00`000000oooo0?ooo`3o0?oookl0oooo0@0000010?ooo`00@@3oool00`000000oooo0?oo
o`3o0?oookl0oooo0@0000010?ooo`00@@3oool300000?l0oooo_@3oool300000040oooo00110?oo
o`030000003oool0oooo0?l0oooo/03oool5000000X0oooo0@0000010?ooo`00@@3oool00`000000
oooo0?ooo`3o0?ooojP0oooo2000000?0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0
o`3ooonO0?ooo`T000005`3oool100000040oooo00110?ooo`030000003oool0oooo0?l0ooooUP3o
ool900000200oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooohd0oooo2@00000Y
0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0o`3ooon40?ooo`T00000<P3oool10000
0040oooo00110?ooo`030000003oool0oooo0?l0ooooN`3oool9000003/0oooo0@0000010?ooo`00
@@3oool00`000000oooo0?ooo`3o0?ooog80oooo2@0000140?ooo`4000000@3oool00440oooo0`00
003o0?ooof/0oooo1`00001;0?ooo`<000000@3oool00440oooo00<000000?ooo`3oool0o`3ooomU
0?ooo`H00000E03oool100000040oooo00110?ooo`030000003oool0oooo0?l0ooooG`3oool60000
05X0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`3o0?oooeT0oooo1P00001P0?ooo`40
00000@3oool00440oooo00<000000?ooo`3oool0o`3ooomC0?ooo`H00000IP3oool100000040oooo
00110?ooo`030000003oool0oooo0?l0ooooC@3oool6000006`0oooo0@0000010?ooo`00@@3oool0
0`000000oooo0?ooo`3o0?ooodL0oooo1P00001b0?ooo`4000000@3oool00440oooo00<000000?oo
o`3oool0o`3ooom30?ooo`@00000N03oool100000040oooo00110?ooo`030000003oool0oooo0?l0
oooo?P3oool5000007`0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooocX0oooo
100000210?ooo`4000000@3oool00440oooo0`00003o0?ooocD0oooo1@0000230?ooo`<000000@3o
ool00440oooo00<000000?ooo`3oool0o`3ooola0?ooo`@00000RP3oool100000040oooo00110?oo
o`030000003oool0oooo0?l0oooo;@3oool4000008h0oooo0@0000010?ooo`00@@3oool00`000000
oooo0?ooo`3o0?ooobT0oooo1000002B0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0
o`3ooolT0?ooo`D00000UP3oool100000040oooo00110?ooo`030000003oool0oooo0?l0oooo803o
ool4000009/0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`3o0?oooa/0oooo1@00002O
0?ooo`4000000@3oool002<0oooo0`0000030?ooo`040000003oool0oooo0?ooo`8000001@3oool2
000000/0oooo00<000000?ooo`3oool0o`3ooolG0?ooo`@00000Y03oool100000040oooo000R0?oo
o`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`@00000Z03oool100000040oooo000R0?oo
o`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0o`3oool?0?ooo`@00000[03oool100000040oooo000H0?oo
o`L000000`3oool01@000000oooo0?ooo`3oool0000000L0oooo100000030?ooo`@00000203ooooo
00000<<000000@3oool00280oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0
oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0
o`3oool80?ooo`@00000/`3oool100000040oooo000R0?ooo`050000003oool0oooo0?ooo`000000
1P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000080?oo
o`030000003oool0oooo0?l0oooo103oool400000;L0oooo0@0000010?ooo`008P3oool01@000000
oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`000000203oool00`000000oooo0?ooo`3o0?ooo`40oooo0`00002k0?ooo`4000000@3o
ool00280oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`000000
0P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0o@3oool300000;h0
oooo0@0000010?ooo`008P3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`3j
0?ooo`<00000`@3oool100000040oooo000S0?ooo`<00000203oool3000000@0oooo0`0000090?oo
o`030000003oool0oooo0?L0oooo0`0000340?ooo`4000000@3oool00440oooo00<000000?ooo`3o
ool0m03oool300000<L0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`3a0?ooo`<00000
bP3oool100000040oooo00110?ooo`030000003oool0oooo0>h0oooo0`00003=0?ooo`4000000@3o
ool00440oooo0`00003/0?ooo`800000cP3oool300000040oooo00110?ooo`030000003oool0oooo
0>T0oooo0`00003B0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0i`3oool200000=D0
oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`3T0?ooo`<00000e`3oool100000040oooo
00110?ooo`030000003oool0oooo0>40oooo0`00003J0?ooo`4000000@3oool00440oooo00<00000
0?ooo`3oool0g`3oool200000=d0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`3L0?oo
o`<00000g`3oool100000040oooo00110?ooo`030000003oool0oooo0=X0oooo0P00003R0?ooo`40
00000@3oool00440oooo00<000000?ooo`3oool0e`3oool300000>@0oooo0@0000010?ooo`00@@3o
ool00`000000oooo0?ooo`3E0?ooo`800000i`3oool100000040oooo00110?ooo`<00000d`3oool2
00000>L0oooo0`0000010?ooo`00@@3oool00`000000oooo0?ooo`3@0?ooo`<00000j`3oool10000
0040oooo00110?ooo`030000003oool0oooo0<h0oooo0P00003^0?ooo`4000000@3oool00440oooo
00<000000?ooo`3oool0b`3oool300000?00oooo0@0000010?ooo`00@@3oool00`000000oooo0?oo
o`390?ooo`800000l`3oool100000040oooo00110?ooo`030000003oool0oooo0<L0oooo0P00003e
0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0a@3oool200000?L0oooo0@0000010?oo
o`00@@3oool00`000000oooo0?ooo`330?ooo`800000n@3oool100000040oooo00110?ooo`030000
003oool0oooo0<40oooo0P00003k0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0_`3o
ool200000?d0oooo0@0000010?ooo`00@@3oool300000;d0oooo0P00003m0?ooo`<000000@3oool0
0440oooo00<000000?ooo`3oool0^`3oool200000?l0oooo0P3oool100000040oooo00110?ooo`03
0000003oool0oooo0;T0oooo0P00003o0?ooo`@0oooo0@0000010?ooo`00@@3oool00`000000oooo
0?ooo`2g0?ooo`800000o`3oool60?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0]@3o
ool200000?l0oooo203oool100000040oooo00110?ooo`030000003oool0oooo0;<0oooo0P00003o
0?ooo`X0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`2a0?ooo`800000o`3oool<0?oo
o`4000000@3oool00440oooo00<000000?ooo`3oool0[`3oool200000?l0oooo3P3oool100000040
oooo00110?ooo`030000003oool0oooo0:d0oooo0P00003o0?oooa00oooo0@0000010?ooo`00@@3o
ool00`000000oooo0?ooo`2[0?ooo`800000o`3ooolB0?ooo`4000000@3oool00440oooo0`00002Y
0?ooo`800000o`3ooolB0?ooo`<000000@3oool00440oooo00<000000?ooo`3oool0Z03oool00`00
0000oooo0?ooo`3o0?oooa@0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`2V0?ooo`80
0000o`3ooolG0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0Y@3oool00`000000oooo
0?ooo`3o0?oooaL0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`2S0?ooo`800000o`3o
oolJ0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`3o
0?oooaX0oooo0@0000010?ooo`008`3oool3000000<0oooo00@000000?ooo`3oool0oooo0P000006
0?ooo`<000002@3oool00`000000oooo0?ooo`2P0?ooo`800000o`3ooolM0?ooo`4000000@3oool0
0280oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000080?ooo`030000003oool0oooo09h0oooo0P00003o0?oooal0oooo0@00
00010?ooo`008P3oool01@000000oooo0?ooo`3oool0000000T0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0W@3oool00`000000oooo
0?ooo`3o0?oooal0oooo0@0000010?ooo`00603oool7000000<0oooo00D000000?ooo`3oool0oooo
000000070?ooo`@000000P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3o
ool0V`3oool200000?l0oooo8P3oool100000040oooo000R0?ooo`050000003oool0oooo0?ooo`00
00001P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000002@3oool40000
09T0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`@000000@3oool00280oooo00D000000?ooo`3o
ool0oooo000000060?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo09P0oooo0P00003o0?ooobD0oooo0@0000010?ooo`008P3oool01@00
0000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0000000T0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`3o0?ooobD0oooo0@00
00010?ooo`008P3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`2E0?ooo`80
0000o`3ooolX0?ooo`4000000@3oool00280oooo00D000000?ooo`3oool0oooo000000060?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<00000
0?ooo`3oool0U03oool00`000000oooo0?ooo`3o0?ooobP0oooo0@0000010?ooo`008`3oool30000
00P0oooo0`0000040?ooo`<000002@3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo
0?l0oooo:@3oool100000040oooo00110?ooo`030000003oool0oooo0940oooo0P00003o0?ooob`0
oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0?l0oooo
;03oool100000040oooo00110?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0o`3o
ool]0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0S@3oool200000?l0oooo<03oool1
00000040oooo00110?ooo`<00000S03oool00`000000oooo0?ooo`3o0?ooobh0oooo0`0000010?oo
o`00@@3oool00`000000oooo0?ooo`2:0?ooo`800000o`3ooolc0?ooo`4000000@3oool00440oooo
00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`3o0?oooc<0oooo0@0000010?ooo`00@@3o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0?l0oooo=03oool100000040oooo0011
0?ooo`030000003oool0oooo08H0oooo0P00003o0?ooocL0oooo0@0000010?ooo`00@@3oool00`00
0000oooo0?ooo`250?ooo`030000003oool0oooo0?l0oooo=`3oool100000040oooo00110?ooo`03
0000003oool0oooo08@0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`4000000@3oool00440oooo
00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`3o0?ooocT0oooo0@0000010?ooo`00@@3o
ool00`000000oooo0?ooo`220?ooo`030000003oool0oooo0?l0oooo>P3oool100000040oooo0011
0?ooo`030000003oool0oooo0800oooo0P00003o0?ooocd0oooo0@0000010?ooo`00@@3oool30000
07l0oooo00<000000?ooo`3oool0o`3ooolk0?ooo`<000000@3oool00440oooo00<000000?ooo`3o
ool0OP3oool00`000000oooo0?ooo`3o0?oooch0oooo0@0000010?ooo`00@@3oool00`000000oooo
0?ooo`1m0?ooo`030000003oool0oooo0?l0oooo?`3oool100000040oooo00110?ooo`030000003o
ool0oooo07`0oooo00<000000?ooo`3oool0o`3ooom00?ooo`4000000@3oool00440oooo00<00000
0?ooo`3oool0N`3oool00`000000oooo0?ooo`3o0?oood40oooo0@0000010?ooo`00@@3oool00`00
0000oooo0?ooo`1j0?ooo`030000003oool0oooo0?l0oooo@P3oool100000040oooo00110?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool0o`3ooom30?ooo`4000000@3oool00440oooo
00<000000?ooo`3oool0M`3oool200000?l0ooooAP3oool100000040oooo00110?ooo`030000003o
ool0oooo07H0oooo00<000000?ooo`3oool0o`3ooom60?ooo`4000000@3oool00440oooo00<00000
0?ooo`3oool0M@3oool00`000000oooo0?ooo`3o0?ooodL0oooo0@0000010?ooo`00@@3oool30000
07@0oooo00<000000?ooo`3oool0o`3ooom60?ooo`<000000@3oool00440oooo00<000000?ooo`3o
ool0L`3oool00`000000oooo0?ooo`3o0?ooodT0oooo0@0000010?ooo`00@@3oool00`000000oooo
0?ooo`1b0?ooo`030000003oool0oooo0?l0ooooBP3oool100000040oooo00110?ooo`030000003o
ool0oooo0740oooo00<000000?ooo`3oool0o`3ooom;0?ooo`4000000@3oool00440oooo00<00000
0?ooo`3oool0L03oool00`000000oooo0?ooo`3o0?oood`0oooo0@0000010?ooo`00@@3oool00`00
0000oooo0?ooo`1_0?ooo`030000003oool0oooo0?l0ooooC@3oool100000040oooo00110?ooo`03
0000003oool0oooo06h0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`4000000@3oool00440oooo
00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`3o0?ooodl0oooo0@0000010?ooo`00@@3o
ool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo0?l0ooooD03oool100000040oooo0011
0?ooo`<00000J`3oool00`000000oooo0?ooo`3o0?ooodl0oooo0`0000010?ooo`00@@3oool00`00
0000oooo0?ooo`1Y0?ooo`800000o`3ooomD0?ooo`4000000@3oool00440oooo00<000000?ooo`3o
ool0J03oool00`000000oooo0?ooo`3o0?oooe@0oooo0@0000010?ooo`001`3oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`400000
0@3oool000L0oooo0`00000g0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0o`3o
oomF0?ooo`4000000@3oool000L0oooo00<000000?ooo`3oool00`00000d0?ooo`030000003oool0
oooo06D0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`4000000@3oool000`0oooo0P00000c0?oo
o`030000003oool0oooo06@0oooo00<000000?ooo`3oool0o`3ooomH0?ooo`4000000@3oool000L0
oooo00<000000?ooo`3oool00P00000G0?ooo`<000000`3oool010000000oooo0?ooo`3oool20000
00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo
0?l0ooooF@3oool100000040oooo00070?ooo`<00000603oool01@000000oooo0?ooo`3oool00000
00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0680oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`4000000@3oool000L0oooo00<000000?ooo`3o
ool00`00000E0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`3o0?oo
oe/0oooo0@0000010?ooo`00303oool2000000X0oooo1`0000030?ooo`050000003oool0oooo0?oo
o`0000001`3oool4000000@0oooo00<000000?ooo`3oool0203oool4000005l0oooo00<000000?oo
o`3oool0o`3ooomI0?ooo`@000000@3oool000L0oooo00<000000?ooo`3oool00P00000F0?ooo`05
0000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0?l0ooooG@3oool1
00000040oooo00070?ooo`<00000603oool01@000000oooo0?ooo`3oool0000000H0oooo00D00000
0?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0GP3o
ool00`000000oooo0?ooo`3o0?oooeh0oooo0@0000010?ooo`001`3oool00`000000oooo0?ooo`0H
0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000D0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0?l0oooo
G`3oool100000040oooo00060?ooo`T000004`3oool01@000000oooo0?ooo`3oool0000000H0oooo
00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0G03oool00`000000oooo0?ooo`3o0?ooof00oooo0@0000010?ooo`001@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo000000060?ooo`07
0000003oool0oooo0?ooo`000000oooo000000040?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0G03oool00`000000oooo0?ooo`3o0?ooof00oooo0@0000010?ooo`00103oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0100oooo0`0000080?ooo`<000000`3oool50000
00P0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`3o0?ooof40oooo0@0000010?oo
o`00@@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0?l0ooooHP3oool100000040
oooo00070?ooo`800000103oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo05T0oooo
00<000000?ooo`3oool0o`3ooomS0?ooo`4000000@3oool000L0oooo00<000000?ooo`3oool00P3o
ool2000003<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3o0?ooof@0oooo0@00
00010?ooo`001`3oool00`000000oooo0?ooo`02000000030?ooo`000000oooo0380oooo0`00001G
0?ooo`030000003oool0oooo0?l0ooooH`3oool300000040oooo00070?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
0?l0ooooIP3oool100000040oooo00070?ooo`800000103oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo05D0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`4000000@3oool000L0oooo
00<000000?ooo`3oool00P3oool2000003<0oooo00<000000?ooo`3oool0E03oool00`000000oooo
0?ooo`3o0?ooofP0oooo0@0000010?ooo`00103oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`3o0?ooofT0oooo0@00
00010?ooo`001@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool0D`3oool00`000000oooo0?ooo`3o0?ooofT0oooo0@0000010?ooo`001P3oool90000
0380oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`3o0?ooofX0oooo0@0000010?oo
o`00@@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0?l0ooooJ`3oool100000040
oooo00110?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0o`3ooom/0?ooo`400000
0@3oool00440oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`3o0?ooofd0oooo0@00
00010?ooo`00@@3oool3000004h0oooo00<000000?ooo`3oool0o`3ooom/0?ooo`<000000@3oool0
0440oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`3o0?ooofh0oooo0@0000010?oo
o`00@@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0?l0ooooK`3oool100000040
oooo00110?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0o`3ooom`0?ooo`400000
0@3oool00440oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?ooog40oooo0@00
00010?ooo`00@@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0ooooL@3oool1
00000040oooo00110?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0o`3ooomb0?oo
o`4000000@3oool00440oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3o0?ooog<0
oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0?l0oooo
M03oool100000040oooo00110?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0o`3o
oomd0?ooo`4000000@3oool00440oooo0`0000170?ooo`030000003oool0oooo0?l0ooooL`3oool3
00000040oooo00110?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0o`3ooomf0?oo
o`4000000@3oool00440oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`3o0?ooogL0
oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0?l0oooo
M`3oool100000040oooo00110?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0o`3o
oomh0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`3o
0?ooogT0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
0?l0ooooNP3oool100000040oooo00110?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool0o`3ooomj0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`3o0?ooog/0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`100?ooo`030000003o
ool0oooo0?l0ooooO03oool100000040oooo00110?ooo`<00000?`3oool00`000000oooo0?ooo`3o
0?ooog/0oooo0`0000010?ooo`00@@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
0?l0ooooO@3oool100000040oooo00110?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool0o`3ooomn0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`3o0?ooogl0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`0m0?ooo`030000003o
ool0oooo0?l0ooooO`3oool100000040oooo00110?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool0o`3ooon00?ooo`4000000@3oool002<0oooo0`0000030?ooo`040000003oool0oooo
0?ooo`8000001P3oool3000000T0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o
0?oooh40oooo0@0000010?ooo`008P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`3o0?oooh40oooo0@0000010?ooo`008P3oool01@000000oooo0?ooo`3o
ool0000000T0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`3o0?oooh80oooo0@0000010?ooo`00603o
ool7000000<0oooo00D000000?ooo`3oool0oooo000000070?ooo`@000000P3oool01@000000oooo
0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`3o0?oooh<0
oooo0@0000010?ooo`008P3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000203oool4000003L0oooo00<00000
0?ooo`3oool0o`3ooon10?ooo`@000000@3oool00280oooo00D000000?ooo`3oool0oooo00000006
0?ooo`050000003oool0oooo0?ooo`0000000P3oool200000080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0?l0ooooQ03oool100000040oooo000R
0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`00000000002@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0?l0
ooooQ@3oool100000040oooo000R0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo0?l0ooooQP3oool100000040oooo000R0?ooo`050000003oool0oooo0?oo
o`0000001P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0?l0ooooQP3oool100000040oooo000S0?oo
o`<00000203oool3000000H0oooo0P0000080?ooo`030000003oool0oooo03D0oooo00<000000?oo
o`3oool0o`3ooon70?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`3o0?ooohP0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo0?l0ooooR03oool100000040oooo00110?ooo`030000003oool0oooo03<0oooo00<0
00000?ooo`3oool0o`3ooon90?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`3o0?ooohX0oooo0@0000010?ooo`00@@3oool300000380oooo00<000000?oo
o`3oool0o`3ooon80?ooo`<000000@3oool00440oooo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`3o0?oooh/0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo0?l0ooooS03oool100000040oooo00110?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool0o`3ooon=0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`3o0?ooohd0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo0?l0ooooSP3oool100000040oooo00110?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool0o`3ooon?0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`3o0?ooohl0oooo0@0000010?ooo`00@@3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo0?l0ooooT03oool100000040oooo00110?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool0o`3ooonA0?ooo`4000000@3oool00440oooo0`00000[0?oo
o`030000003oool0oooo0?l0ooooS`3oool300000040oooo00110?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool0o`3ooonB0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`3o0?oooi80oooo0@0000010?ooo`00@@3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo0?l0ooooT`3oool100000040oooo00110?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0o`3ooonC0?ooo`4000000@3oool00440oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`3o0?oooi@0oooo0@0000010?ooo`00@@3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0?l0ooooU03oool100000040oooo00110?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool00440oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`3o0?oooiH0oooo0@0000010?ooo`00@@3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0?l0ooooUP3oool100000040oooo00110?oo
o`<000009@3oool00`000000oooo0?ooo`3o0?oooiD0oooo0`0000010?ooo`00@@3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo0?l0ooooU`3oool100000040oooo00110?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0o`3ooonH0?ooo`4000000@3oool00440oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`3o0?oooiP0oooo0@0000010?ooo`00@@3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0?l0ooooV@3oool100000040oooo00110?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`4000000@3oool00440
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3o0?oooiX0oooo0@0000010?ooo`00
@@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0ooooV`3oool100000040oooo
00110?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0o`3ooonK0?ooo`4000000@3o
ool00440oooo0`00000P0?ooo`030000003oool0oooo0?l0ooooVP3oool300000040oooo00110?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0o`3ooonL0?ooo`4000000@3oool00440
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3o0?oooid0oooo0@0000010?ooo`00
@@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0ooooW@3oool100000040oooo
00110?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0o`3ooonN0?ooo`4000000@3o
ool00440oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3o0?oooil0oooo0@000001
0?ooo`00@@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0?l0ooooW`3oool10000
0040oooo000S0?ooo`<000000`3oool010000000oooo0?ooo`3oool2000000D0oooo0`00000:0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0o`3ooonP0?ooo`4000000@3oool00280
oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0?l0ooooX03oool10000
0040oooo000R0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`3o0?oo
oj40oooo0@0000010?ooo`00603oool7000000<0oooo00D000000?ooo`3oool0oooo000000070?oo
o`@000001P3oool00`000000oooo0?ooo`060?ooo`@000006P3oool00`000000oooo0?ooo`3o0?oo
oih0oooo100000010?ooo`008P3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?oo
o`3oool0oooo000000060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`3o0?oooj80oooo0@0000010?ooo`008P3oool01@000000oooo0?ooo`3oool0
000000H0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`3o0?oooj80oooo0@0000010?ooo`008P3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`<00000
2P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0ooooX`3oool100000040oooo
000R0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0
ooooX`3oool100000040oooo000R0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo0?l0ooooY03oool100000040oooo000S0?ooo`<00000203oool3000000@0
oooo100000080?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3ooonT0?ooo`40
00000@3oool00440oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`3o0?ooojD0oooo
0@0000010?ooo`00@@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0?l0ooooY@3o
ool100000040oooo00110?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0o`3ooonV
0?ooo`4000000@3oool00440oooo0`00000F0?ooo`030000003oool0oooo0?l0ooooY03oool30000
0040oooo00110?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3ooonW0?ooo`40
00000@3oool00440oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3o0?ooojL0oooo
0@0000010?ooo`00@@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0ooooZ03o
ool100000040oooo00110?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0o`3ooonX
0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3o0?oo
ojT0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0
ooooZ@3oool100000040oooo00110?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
o`3ooonZ0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`3o0?ooojX0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0?l0ooooZ`3oool100000040oooo00110?ooo`<000004@3oool00`000000oooo0?ooo`3o0?oo
ojT0oooo0`0000010?ooo`00@@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0
oooo[03oool100000040oooo00110?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
o`3ooon/0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`3o0?ooojd0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0?l0oooo[@3oool100000040oooo00110?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0o`3ooon^0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`3o0?ooojh0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo0?l0oooo[`3oool100000040oooo00110?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0o`3ooon_0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`3o0?oook00oooo0@0000010?ooo`00@@3oool3000000`0oooo00<000000?oo
o`3oool0o`3ooon^0?ooo`<000000@3oool00440oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`3o0?oook40oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo0?l0oooo/@3oool100000040oooo00110?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0o`3ooonb0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`3o0?oook80oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0?l0oooo/`3oool100000040oooo00110?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0o`3ooonc0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`3o0?oook@0oooo0@0000010?ooo`00@@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0?l0oooo]03oool100000040oooo00110?ooo`030000003oool0
oooo0?l0oooo_`3oool100000040oooo00110?ooo`<00000o`3ooonm0?ooo`<000000@3oool00440
oooo00<000000?ooo`3oool0o`3ooono0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0
J03oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00P0oooo0@0000010?ooo`00@@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`080?ooo`4000000@3oool00440ooooo`00003300000040oooo0000\
\>"],
  ImageRangeCache->{{{0, 515.5}, {318.25, 0}} -> {-0.358454, -1.00536, \
0.00468509, 0.000201957}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ 
      Find\ chi\ square\ for\ given\ H \((z)\)\ \ *) \[IndentingNewLine]\(f[
          z_] := 1/hhz[z];\)\), "\n", 
    \(\(rr[zz_] := NIntegrate[f[z], {z, 0, zz}];\)\[IndentingNewLine]\n (*\ 
      Construct\ marginalization\ coefficients\ \((see\ \ astro - 
              ph/0401556\  .. )\)\ *) \), "\[IndentingNewLine]", 
    \(Clear[chi2fa, chi2fb, chi2fc]\), "\n", 
    \(\(chi2fa = 
        Sum[\((ld[i] - 5\ Log[10, rr[zz[i]]*\((1 + zz[i])\)])\)^2/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\n", 
    \(\(chi2fb = 
        Sum[\((ld[i] - 
                5\ Log[10, rr[zz[i]]*\((1 + zz[i])\)])\)/\((sld[i]^2)\), {i, 
            1, ndat}];\)\), "\n", 
    \(\(chi2fc = 
        Sum[1/\((sld[i]^2)\), {i, 1, ndat}];\)\[IndentingNewLine]\n (*\ 
      Construct\ function\ after\ marginalization, \ 
      find\ same\ result\ as\ with\ mb\ minimization\ *) \), "\
\[IndentingNewLine]", 
    \(chi2fm = chi2fa - chi2fb^2/chi2fc\), "\[IndentingNewLine]", 
    \(dchi2q075 = chi2fm - chi2l\)}], "Input"],

Cell[BoxData[
    \(177.59838569816202`\)], "Output"],

Cell[BoxData[
    \(0.4710142631083727`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ 
      Find\ H \((z)\)\ for\ given\ slope\ s\ of\ the\ linear\ potential . \ 
            Present\ time\  = \ \(tt\ \((corresponds\ to\ a = 1)\) . \ 
              Run\ trials\ for\ initial\ condition\ for\ field\ fi\ \((f0)\)\ \
and\ initial\ time\ ti\ until\ we\ get\ field\ energy\ enf\  = \ \(0.7\ and\ \
H \((z = 0)\)\  = 
            1\ at\ present\ time\ \(\(tt\)\(.\)\)\)\)\ *) \[IndentingNewLine]\
\[IndentingNewLine] (*\ \(--\(--\(--\(--\ \ s\)\)\)\)\  = \ \
\(\(\(\(\(\(\(\(\(\(\(\(\(\(\(\(\(\(\(\(1\ \ \ --\)--\)--\)--\)--\)--\)--\)\
--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)\(-\)\)\ *) \
\[IndentingNewLine]\[IndentingNewLine]\(Clear[aa, fi, a, aad, aadd, fidas, 
        tas, f, rr, hht, hha];\)\), "\[IndentingNewLine]", 
    \(aa = a[t]; \ fi = f[t];\), "\n", 
    \(\(aad = D[aa, t];\)\), "\n", 
    \(\(aadd = D[aa, {t, 2}];\)\), "\n", 
    \(\(fid = D[fi, t];\)\), "\n", 
    \(\(fidd = D[fi, {t, 2}];\)\), "\n", 
    \(ti = 0.000025; \ t0 = 3.8;\), "\n", 
    \(\(f0 = \(-0.8\);\)\ \), "\n", 
    \(om0m = 0.3; \ ss = 1;\), "\n", 
    \(\(eq1 = 
        aadd/aa\  \[Equal] \(-\ \ fid^2\)\  - \ ss\ fi\  - \ 
            om0m/\((2\ aa^3)\);\)\), "\n", 
    \(\(eq2 = 
        fidd\ \  + \ \ \ 3\ \ fid\ \((aad/aa)\)\  - \ ss \[Equal] 
          0;\)\), "\n", 
    \(\(eqb1 = f[ti] == f0;\)\), "\n", 
    \(\(eqb2 = \(f'\)[ti] == 0;\)\), "\n", 
    \(\(eqb3 = 
        a[ti] \[Equal] \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((2/3)\);\)\), "\n", 
    \(\(eqb4 = \(a'\)[
            ti] \[Equal] \((2/
                3)\)\ \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((\(-1\)/
                  3)\);\)\), "\n", 
    \(\(sol2 = 
        NDSolve[{eq1, eq2, eqb1, eqb2, eqb3, eqb4}, {aa, fi}, {t, ti, t0}, 
          MaxSteps \[Rule] 10000000];\)\), "\n", 
    \(\(asol = Part[Evaluate[a[t] /. sol2], 1];\)\), "\n", 
    \(\(fsol = Part[Evaluate[f[t] /. sol2], 1];\)\), "\[IndentingNewLine]", 
    \(\(fs[t1_] := fsol\  /. \ t -> t1\ ;\)\), "\[IndentingNewLine]", 
    \(\(plfsq1 = 
        Plot[\(-ss\)\ fs[t], {t, ti, t0}, Frame \[Rule] True, 
          PlotRange \[Rule] All, 
          FrameLabel \[Rule] {\*"\"\<\!\(H\_0\)t\>\"", \
"\<V(\[Phi](t))\>"}];\)\), "\[IndentingNewLine]", 
    \(\(plasq1 = 
        Plot[asol, {t, ti, t0}, Frame \[Rule] True, PlotRange \[Rule] All, 
          FrameLabel \[Rule] {\*"\"\<\!\(H\_0\)t\>\"", "\<a(t)\>"}];\)\), "\n\
", 
    \(\(dfsol = D[fsol, t];\)\), "\[IndentingNewLine]", 
    \(\(enf = 0.5\ dfsol^2\  - \ ss\ fsol;\)\), "\[IndentingNewLine]", 
    \(\(as[t1_] := asol\  /. \ t -> t1\ ;\)\), "\[IndentingNewLine]", 
    \(\(tt = Part[FindRoot[as[t] == 1, {t, 1}], 1, 2];\)\), "\n", 
    \(\(tas[a_] := 
        Part[FindRoot[as[t] \[Equal] a, {t, 1}], 1, 2];\)\), "\n", 
    \(\(hht[t1_] := D[asol, t]/asol\  /. \ t -> t1\ ;\)\), "\n", 
    \(\(hha[a_] := hht[tas[a]];\)\), "\[IndentingNewLine]", 
    \(\(hhz[z_] := hha[1/\((z + 1)\)];\)\), "\[IndentingNewLine]", 
    \(enf\  /. \ t \[Rule] tt\), "\[IndentingNewLine]", 
    \(hhz[0]\), "\[IndentingNewLine]", 
    \(\(enf = 0.5\ dfsol^2\  - \ ss\ fsol;\)\), "\n", 
    \(\(ppf = 0.5\ dfsol^2\  + \ ss\ fsol;\)\), "\n", 
    \(\(wft[t1_] := ppf/enf\  /. \ t -> t1\ ;\)\ \), "\n", 
    \(\(wfa[a_] := wft[tas[a]];\)\), "\n", 
    \(\(wfz[z_] := wfa[1/\((z + 1)\)];\)\), "\n", 
    \(\(plw10q = 
        Plot[wfz[z], {z, 0, 2}, Frame \[Rule] True, PlotRange \[Rule] All, 
          FrameLabel \[Rule] {"\<z\>", "\<w(z)\>"}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238032 0.250628 0.438866 0.205566 [
[.0238 -0.0125 -5.53125 -17.8125 ]
[.0238 -0.0125 5.53125 0 ]
[.14912 -0.0125 -10.7813 -17.8125 ]
[.14912 -0.0125 10.7813 0 ]
[.27443 -0.0125 -5.53125 -17.8125 ]
[.27443 -0.0125 5.53125 0 ]
[.39975 -0.0125 -10.7813 -17.8125 ]
[.39975 -0.0125 10.7813 0 ]
[.52506 -0.0125 -5.53125 -17.8125 ]
[.52506 -0.0125 5.53125 0 ]
[.65037 -0.0125 -10.7813 -17.8125 ]
[.65037 -0.0125 10.7813 0 ]
[.77569 -0.0125 -5.53125 -17.8125 ]
[.77569 -0.0125 5.53125 0 ]
[.901 -0.0125 -10.7813 -17.8125 ]
[.901 -0.0125 10.7813 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -11.75 -35.625 ]
[.5 -0.0125 11.75 -17.8125 ]
[-0.0125 .02774 -20.75 -8.90625 ]
[-0.0125 .02774 0 8.90625 ]
[-0.0125 .13052 -31.25 -8.90625 ]
[-0.0125 .13052 0 8.90625 ]
[-0.0125 .2333 -20.75 -8.90625 ]
[-0.0125 .2333 0 8.90625 ]
[-0.0125 .33608 -31.25 -8.90625 ]
[-0.0125 .33608 0 8.90625 ]
[-0.0125 .43887 -11.0625 -8.90625 ]
[-0.0125 .43887 0 8.90625 ]
[-0.0125 .54165 -21.5625 -8.90625 ]
[-0.0125 .54165 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -49.0625 -21.9688 ]
[-0.01875 .30902 -31.25 21.9688 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0238 0 m
.0238 .00625 L
s
gsave
.0238 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.14912 0 m
.14912 .00625 L
s
gsave
.14912 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.27443 0 m
.27443 .00625 L
s
gsave
.27443 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.39975 0 m
.39975 .00625 L
s
gsave
.39975 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.52506 0 m
.52506 .00625 L
s
gsave
.52506 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.65037 0 m
.65037 .00625 L
s
gsave
.65037 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.77569 0 m
.77569 .00625 L
s
gsave
.77569 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.901 0 m
.901 .00625 L
s
gsave
.901 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
1.000 setlinewidth
grestore
.125 Mabswid
.04887 0 m
.04887 .00375 L
s
.07393 0 m
.07393 .00375 L
s
.09899 0 m
.09899 .00375 L
s
.12405 0 m
.12405 .00375 L
s
.17418 0 m
.17418 .00375 L
s
.19924 0 m
.19924 .00375 L
s
.22431 0 m
.22431 .00375 L
s
.24937 0 m
.24937 .00375 L
s
.29949 0 m
.29949 .00375 L
s
.32456 0 m
.32456 .00375 L
s
.34962 0 m
.34962 .00375 L
s
.37468 0 m
.37468 .00375 L
s
.42481 0 m
.42481 .00375 L
s
.44987 0 m
.44987 .00375 L
s
.47493 0 m
.47493 .00375 L
s
.5 0 m
.5 .00375 L
s
.55012 0 m
.55012 .00375 L
s
.57519 0 m
.57519 .00375 L
s
.60025 0 m
.60025 .00375 L
s
.62531 0 m
.62531 .00375 L
s
.67544 0 m
.67544 .00375 L
s
.7005 0 m
.7005 .00375 L
s
.72556 0 m
.72556 .00375 L
s
.75063 0 m
.75063 .00375 L
s
.80075 0 m
.80075 .00375 L
s
.82581 0 m
.82581 .00375 L
s
.85088 0 m
.85088 .00375 L
s
.87594 0 m
.87594 .00375 L
s
.92606 0 m
.92606 .00375 L
s
.95113 0 m
.95113 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -72.75 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
73.063 19.750 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
78.563 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
82.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02774 m
.00625 .02774 L
s
gsave
-0.0125 .02774 -81.75 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .13052 m
.00625 .13052 L
s
gsave
-0.0125 .13052 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
0 .2333 m
.00625 .2333 L
s
gsave
-0.0125 .2333 -81.75 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .33608 m
.00625 .33608 L
s
gsave
-0.0125 .33608 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .43887 m
.00625 .43887 L
s
gsave
-0.0125 .43887 -72.0625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .54165 m
.00625 .54165 L
s
gsave
-0.0125 .54165 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04829 m
.00375 .04829 L
s
0 .06885 m
.00375 .06885 L
s
0 .0894 m
.00375 .0894 L
s
0 .10996 m
.00375 .10996 L
s
0 .15107 m
.00375 .15107 L
s
0 .17163 m
.00375 .17163 L
s
0 .19219 m
.00375 .19219 L
s
0 .21274 m
.00375 .21274 L
s
0 .25386 m
.00375 .25386 L
s
0 .27441 m
.00375 .27441 L
s
0 .29497 m
.00375 .29497 L
s
0 .31553 m
.00375 .31553 L
s
0 .35664 m
.00375 .35664 L
s
0 .3772 m
.00375 .3772 L
s
0 .39775 m
.00375 .39775 L
s
0 .41831 m
.00375 .41831 L
s
0 .45942 m
.00375 .45942 L
s
0 .47998 m
.00375 .47998 L
s
0 .50054 m
.00375 .50054 L
s
0 .52109 m
.00375 .52109 L
s
0 .00718 m
.00375 .00718 L
s
0 .56221 m
.00375 .56221 L
s
0 .58276 m
.00375 .58276 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -123.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
82.9688 12.9063 translate
90 rotate
-82.9688 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(V) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.063 17.500 moveto
(H) show
77.625 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
85.313 17.500 moveto
(H) show
89.875 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.813 17.500 moveto
(L) show
98.375 17.500 moveto
(L) show
102.938 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.0238 .61178 m
.0238 .61803 L
s
.14912 .61178 m
.14912 .61803 L
s
.27443 .61178 m
.27443 .61803 L
s
.39975 .61178 m
.39975 .61803 L
s
.52506 .61178 m
.52506 .61803 L
s
.65037 .61178 m
.65037 .61803 L
s
.77569 .61178 m
.77569 .61803 L
s
.901 .61178 m
.901 .61803 L
s
.125 Mabswid
.04887 .61428 m
.04887 .61803 L
s
.07393 .61428 m
.07393 .61803 L
s
.09899 .61428 m
.09899 .61803 L
s
.12405 .61428 m
.12405 .61803 L
s
.17418 .61428 m
.17418 .61803 L
s
.19924 .61428 m
.19924 .61803 L
s
.22431 .61428 m
.22431 .61803 L
s
.24937 .61428 m
.24937 .61803 L
s
.29949 .61428 m
.29949 .61803 L
s
.32456 .61428 m
.32456 .61803 L
s
.34962 .61428 m
.34962 .61803 L
s
.37468 .61428 m
.37468 .61803 L
s
.42481 .61428 m
.42481 .61803 L
s
.44987 .61428 m
.44987 .61803 L
s
.47493 .61428 m
.47493 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55012 .61428 m
.55012 .61803 L
s
.57519 .61428 m
.57519 .61803 L
s
.60025 .61428 m
.60025 .61803 L
s
.62531 .61428 m
.62531 .61803 L
s
.67544 .61428 m
.67544 .61803 L
s
.7005 .61428 m
.7005 .61803 L
s
.72556 .61428 m
.72556 .61803 L
s
.75063 .61428 m
.75063 .61803 L
s
.80075 .61428 m
.80075 .61803 L
s
.82581 .61428 m
.82581 .61803 L
s
.85088 .61428 m
.85088 .61803 L
s
.87594 .61428 m
.87594 .61803 L
s
.92606 .61428 m
.92606 .61803 L
s
.95113 .61428 m
.95113 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02774 m
1 .02774 L
s
.99375 .13052 m
1 .13052 L
s
.99375 .2333 m
1 .2333 L
s
.99375 .33608 m
1 .33608 L
s
.99375 .43887 m
1 .43887 L
s
.99375 .54165 m
1 .54165 L
s
.125 Mabswid
.99625 .04829 m
1 .04829 L
s
.99625 .06885 m
1 .06885 L
s
.99625 .0894 m
1 .0894 L
s
.99625 .10996 m
1 .10996 L
s
.99625 .15107 m
1 .15107 L
s
.99625 .17163 m
1 .17163 L
s
.99625 .19219 m
1 .19219 L
s
.99625 .21274 m
1 .21274 L
s
.99625 .25386 m
1 .25386 L
s
.99625 .27441 m
1 .27441 L
s
.99625 .29497 m
1 .29497 L
s
.99625 .31553 m
1 .31553 L
s
.99625 .35664 m
1 .35664 L
s
.99625 .3772 m
1 .3772 L
s
.99625 .39775 m
1 .39775 L
s
.99625 .41831 m
1 .41831 L
s
.99625 .45942 m
1 .45942 L
s
.99625 .47998 m
1 .47998 L
s
.99625 .50054 m
1 .50054 L
s
.99625 .52109 m
1 .52109 L
s
.99625 .00718 m
1 .00718 L
s
.99625 .56221 m
1 .56221 L
s
.99625 .58276 m
1 .58276 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .43887 m
1 .43887 L
s
.5 Mabswid
.02381 .60332 m
.02499 .60332 L
.02605 .60332 L
.02729 .60331 L
.02846 .60331 L
.03053 .60329 L
.03279 .60327 L
.03527 .60325 L
.0379 .60321 L
.04262 .60313 L
.04749 .60301 L
.05205 .60288 L
.06244 .60251 L
.07305 .602 L
.08274 .60144 L
.10458 .5998 L
.14429 .59561 L
.18248 .59019 L
.22313 .58308 L
.26226 .57507 L
.30384 .56545 L
.34391 .55523 L
.38246 .54459 L
.42346 .53246 L
.46295 .52001 L
.50092 .50733 L
.54134 .493 L
.58025 .47835 L
.62161 .4617 L
.66146 .44443 L
.69979 .42641 L
.74057 .40531 L
.77984 .38248 L
.81759 .3572 L
.85779 .32473 L
.89648 .28392 L
.91652 .25588 L
.92672 .23845 L
.93762 .21616 L
.94796 .18955 L
.95736 .15746 L
.96189 .13737 L
.96681 .10975 L
.96906 .09393 L
.97145 .07383 L
.97348 .05265 L
.97573 .02238 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{468.375, 289.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007D00018B000`400?l00000o`00003oo`3ooooE
0?ooo`00o`3ooooE0?ooo`00o`3ooooE0?ooo`00o`3oool80?ooo`800000b`3oool00?l0oooo1`3o
ool010000000oooo0?ooo`00003:0?ooo`00o03oool3000000<0oooo0`0000001@3oool000000?oo
o`3oool000000080oooo0P0000360?ooo`00o@3oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo00000080oooo00H000000?ooo`3oool000000?ooo`0000350?ooo`00o@3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000a`3oool0
0?d0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000<L0oooo003m0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P00
00030?ooo`030000003oool0oooo0<D0oooo003m0?ooo`L00000203oool00`000000oooo0?ooo`35
0?ooo`00o@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0`0000360?oo
o`00o@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0a@3oool00?d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0<D0oooo003l0?ooo`<000000`3oool300000<l0oooo003o0?ooomD0oooo003o0?oo
omD0oooo003o0?ooomD0oooo003o0?ooomD0oooo003o0?ooomD0oooo003o0?ooomD0oooo003o0?oo
omD0oooo003o0?ooomD0oooo00150?ooo`<00000:P3oool3000000<0oooo00@000000?ooo`3oool0
oooo0`00000Z0?ooo`<00000:P3oool3000000<0oooo00@000000?ooo`3oool0oooo0`00000Z0?oo
o`D00000:03oool500000080oooo00@000000?ooo`3oool0oooo0`00000Y0?ooo`@00000:@3oool4
000000<0oooo00@000000?ooo`3oool0oooo0`00000X0?ooo`00A03oool01@000000oooo0?ooo`3o
ool0000002P0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02P0oooo
00@000000?ooo`3oool00000:@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
02D0oooo00140?ooo`050000003oool0oooo0?ooo`000000:03oool01@000000oooo0?ooo`3oool0
000000X0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0903oool004@0oooo00D000000?ooo`3oool0oooo0000000X
0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0T0?ooo`00A03oool0
1@000000oooo0?ooo`3oool0000002P0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo02@0oooo00140?ooo`050000003oool0oooo0?ooo`000000:03oool01@000000oooo
0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0:03oool2000002/0oooo0P00000:0?ooo`03
0000003oool0oooo02D0oooo00140?ooo`050000003oool0oooo0?ooo`000000:03oool01@000000
oooo0?ooo`3oool0000000H0oooo0`00000[0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool01P3oool3000002h0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`040?oo
o`<00000;03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00D0oooo0`00000X0?oo
o`00A03oool01@000000oooo0?ooo`3oool0000002P0oooo00D000000?ooo`3oool0oooo00000006
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo02P0oooo00140?ooo`050000003oool0oooo0?ooo`000000:03oool0
1@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0:@3oool2000002/0oooo0P00
00090?ooo`030000003oool0oooo02T0oooo00D000000?ooo`3oool0oooo0000000X0?ooo`050000
003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`0X0?ooo`050000003oool0oooo0?oo
o`000000:03oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool09`3oool0
04D0oooo0`00000Z0?ooo`<00000203oool4000002T0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`070?ooo`@00000:@3oool3000002X0oooo0`0000080?ooo`@00000:03oool30000
02X0oooo0`0000080?ooo`@000009P3oool00?l0ooooe@3oool00?l0ooooe@3oool00?l0ooooe@3o
ool00?l0ooooe@3oool00?l0ooooe@3oool00?l0ooooe@3oool00?l0ooooe@3oool00?l0ooooe@3o
ool003d0ooooo`00002C000000D0oooo000m0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00`3oool003d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool00`3oool003d0oooo0P00003o0?ooohh0oooo
0`0000050?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooohl0oooo00<000000?ooo`3oool00`3o
ool003d0oooo00<000000?ooo`3oool0o`3ooon?0?ooo`030000003oool0oooo00<0oooo000m0?oo
o`030000003oool0oooo0?l0ooooQ@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00<0oooo000`0?ooo`D00000203oool00`000000oooo0?ooo`3o0?ooohD0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`030?ooo`00<@3oool010000000oooo0?ooo`0000080?ooo`03
0000003oool0oooo0?l0ooooQ@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0
oooo000b0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooon50?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool002H0oooo1`0000060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0o`3ooon50?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool00`3oool003<0oooo00<000000?ooo`3oool01`3oool300000?l0ooooQ@3oool0
0`000000oooo0?ooo`040?ooo`@000001@3oool003@0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`3o0?ooohD0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?oo
o`00=03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0ooooQ@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo000d0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0o`3ooon50?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
0`3oool00300oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo0?l0oooo
Q03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo000a0?ooo`<000002@3o
ool00`000000oooo0?ooo`3o0?oooh@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`030?ooo`00?@3oool00`000000oooo0?ooo`3o0?oooh@0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`030?ooo`00?@3oool00`000000oooo0?ooo`3o0?oooh@0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`030?ooo`00?@3oool200000?l0ooooQ@3oool00`000000
oooo0?ooo`060?ooo`<000001@3oool003d0oooo00<000000?ooo`3oool0o`3ooon40?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool003d0oooo00<000000?ooo`3oool0o`3o
oon40?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool003d0oooo00<00000
0?ooo`3oool0o`3ooon40?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool0
03d0oooo00<000000?ooo`3oool0o`3ooon40?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00`3oool003d0oooo00<000000?ooo`3oool0o`3ooon40?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00`3oool003d0oooo00<000000?ooo`3oool0o`3ooon30?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool003d0oooo00<000000?ooo`3oool0o`3o
oon30?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool003d0oooo0P00003o
0?oooh@0oooo00<000000?ooo`3oool01`3oool3000000D0oooo000m0?ooo`030000003oool0oooo
0?l0ooooP`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo000m0?ooo`03
0000003oool0oooo0?l0ooooP`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0
oooo000m0?ooo`030000003oool0oooo0?l0ooooP`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00<0oooo000m0?ooo`030000003oool0oooo0?l0ooooP`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00<0oooo000m0?ooo`030000003oool0oooo0?l0ooooP`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo000m0?ooo`030000003oool0oooo
0?l0ooooP`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo000m0?ooo`03
0000003oool0oooo0?l0ooooP`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0
oooo000m0?ooo`800000o`3ooon40?ooo`030000003oool0oooo00L0oooo0`0000050?ooo`00?@3o
ool00`000000oooo0?ooo`3o0?oooh<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`030?ooo`00?@3oool00`000000oooo0?ooo`3o0?oooh<0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`030?ooo`00?@3oool00`000000oooo0?ooo`3o0?oooh<0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`030?ooo`00?@3oool00`000000oooo0?ooo`3o0?oooh<0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00?@3oool00`000000oooo
0?ooo`3o0?oooh<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00?@3o
ool00`000000oooo0?ooo`3o0?oooh80oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`030?ooo`00?@3oool00`000000oooo0?ooo`3o0?oooh80oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`030?ooo`00?@3oool00`000000oooo0?ooo`3o0?oooh80oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`030?ooo`00?@3oool200000?l0ooooP`3oool00`000000
oooo0?ooo`080?ooo`<000001@3oool003d0oooo00<000000?ooo`3oool0o`3ooon20?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool003d0oooo00<000000?ooo`3oool0o`3o
oon20?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool003d0oooo00<00000
0?ooo`3oool0o`3ooon10?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool0
02H0oooo0`0000030?ooo`040000003oool0oooo0?ooo`<000002P3oool00`000000oooo0?ooo`3o
0?oooh40oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`009`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooon10?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool002L0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0ooooP@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo000L0?ooo`L00000103oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooon10?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool002L0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`060?ooo`<00000o`3ooon10?ooo`030000003oool0oooo00P0oooo1000
00050?ooo`009`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0o`3ooon00?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool0
02L0oooo00<000000?ooo`3oool01P3oool3000000X0oooo00<000000?ooo`3oool0o`3ooon00?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool002L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooP03oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo000V0?ooo`8000002@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0?l0ooooP03oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00<0oooo000W0?ooo`030000003oool0oooo00L0oooo100000080?ooo`030000003o
ool0oooo0?l0ooooO`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo000m
0?ooo`030000003oool0oooo0?l0ooooO`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00<0oooo000m0?ooo`030000003oool0oooo0?l0ooooO`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00<0oooo000m0?ooo`800000o`3ooon00?ooo`030000003oool0oooo00/0
oooo0`0000050?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooogh0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`030?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooogh0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00?@3oool00`000000oooo0?ooo`3o
0?ooogh0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00?@3oool00`00
0000oooo0?ooo`3o0?ooogh0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?oo
o`00?@3oool00`000000oooo0?ooo`3o0?ooogd0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`030?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooogd0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`030?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooogd0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`030?ooo`00?@3oool200000?l0ooooO@3oool0
0`000000oooo0?ooo`0>0?ooo`<000001@3oool003d0oooo00<000000?ooo`3oool0o`3oooml0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool00`3oool003d0oooo00<000000?ooo`3o
ool0o`3oooml0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00`3oool003d0oooo
00<000000?ooo`3oool0o`3oooml0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
0`3oool003d0oooo00<000000?ooo`3oool0o`3ooomk0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool00`3oool003d0oooo00<000000?ooo`3oool0o`3ooomk0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool00`3oool003d0oooo00<000000?ooo`3oool0o`3ooomk0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool00`3oool003d0oooo00<000000?ooo`3o
ool0o`3ooomj0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00`3oool003d0oooo
00<000000?ooo`3oool0o`3ooomj0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
0`3oool003d0oooo0P00003o0?ooog/0oooo00<000000?ooo`3oool0403oool3000000D0oooo000m
0?ooo`030000003oool0oooo0?l0ooooN@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00<0oooo000m0?ooo`030000003oool0oooo0?l0ooooN@3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo00<0oooo000m0?ooo`030000003oool0oooo0?l0ooooN03oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo00<0oooo000m0?ooo`030000003oool0oooo0?l0oooo
N03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00<0oooo000m0?ooo`030000003o
ool0oooo0?l0ooooN03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00<0oooo000m
0?ooo`030000003oool0oooo0?l0ooooM`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo00<0oooo000m0?ooo`030000003oool0oooo0?l0ooooM`3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo00<0oooo000m0?ooo`800000o`3ooomg0?ooo`030000003oool0oooo01@0
oooo0`0000050?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooogH0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`030?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooogH0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`00?@3oool00`000000oooo0?ooo`3o
0?ooogD0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`030?ooo`00?@3oool00`00
0000oooo0?ooo`3o0?ooogD0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`030?oo
o`00<@3oool3000000T0oooo00<000000?ooo`3oool0o`3ooomd0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool00`3oool00380oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`3o0?ooog@0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`030?ooo`00<P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooL`3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo00<0oooo000V0?ooo`L000001@3oool00`000000oooo0?ooo`08
0?ooo`<00000o`3ooomc0?ooo`030000003oool0oooo01H0oooo100000050?ooo`00<P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooLP3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00<0oooo000b0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0o`3ooomb0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00`3oool00380oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooog40oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`030?ooo`00<P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0?l0ooooL@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00<0oooo000a
0?ooo`8000002P3oool00`000000oooo0?ooo`3o0?ooog00oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`030?ooo`00<P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0?l0ooooK`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00<0oooo000m0?ooo`03
0000003oool0oooo0?l0ooooKP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00<0
oooo000m0?ooo`800000o`3ooom_0?ooo`030000003oool0oooo01`0oooo0`0000050?ooo`00?@3o
ool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`030?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooof`0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`030?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooof`0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`030?ooo`00203oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo0?l0ooooJ`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00<0
oooo00080?ooo`<00000<P3oool00`000000oooo0?ooo`3o0?ooofX0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`030?ooo`00203oool00`000000oooo0?ooo`03000002l0oooo00<0
00000?ooo`3oool0o`3ooomZ0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00`3o
ool000h0oooo0P00000]0?ooo`030000003oool0oooo0?l0ooooJ@3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo00<0oooo000@0?ooo`800000:`3oool00`000000oooo0?ooo`3o0?oo
ofP0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`030?ooo`003P3oool2000002d0
oooo0P00003o0?ooofT0oooo00<000000?ooo`3oool08P3oool3000000D0oooo00080?ooo`030000
003oool0oooo00<00000;`3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`030?ooo`00203oool300000380oooo00<000000?ooo`3oool0o`3o
oomV0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool00`3oool000P0oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`3o0?ooofH0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`030?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooofD0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`030?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooof@0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`030?ooo`002P3oool9000002X0oooo
00<000000?ooo`3oool0o`3ooomS0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
0`3oool000T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo0?l0ooooHP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00<0oooo0008
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool09P3oool200000?l0ooooHP3oool0
0`000000oooo0?ooo`0Y0?ooo`<000001@3oool000d0oooo1000000/0?ooo`030000003oool0oooo
0?l0ooooH03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00<0oooo000<0?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool00000:03oool00`000000oooo0?ooo`3o0?oo
oel0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`030?ooo`002`3oool00`000000
oooo0?ooo`020?ooo`@00000:@3oool00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`030?ooo`002`3oool5000000030?ooo`000000oooo02X0oooo
00<000000?ooo`3oool0o`3ooomM0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
0`3oool000T0oooo0`0000050?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3o
oomM0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool00`3oool000/0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0?l0ooooG03oool0
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00<0oooo000<0?ooo`@00000;@3oool00`00
0000oooo0?ooo`3o0?oooe/0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`030?oo
o`00?@3oool200000?l0ooooF`3oool00`000000oooo0?ooo`0`0?ooo`<000001@3oool003d0oooo
00<000000?ooo`3oool0o`3ooomI0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
0`3oool000X0oooo2@00000Z0?ooo`030000003oool0oooo0?l0ooooF03oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo00<0oooo00090?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`3o0?oooeL0oooo00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`030?ooo`00203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool0o`3ooomF0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool00`3oool000/0oooo00<000000?ooo`3oool0603oool3000000<0oooo00@000000?ooo`3o
ool0oooo0`00000:0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo00<0oooo00090?ooo`T000004`3oool01@000000oooo0?ooo`3oool00000
00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oooe<0oooo0P00000j0?oo
o`030000003oool0oooo00<0oooo000;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool04@3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`3o0?oooe80oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`030?oo
o`00403oool00`000000oooo0?ooo`090?ooo`L000000P3oool01@000000oooo0?ooo`3oool00000
00X0oooo00<000000?ooo`3oool01P3oool300000?l0ooooD@3oool00`000000oooo0?ooo`0h0?oo
o`@000001@3oool000P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?ooo`05
0000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0?l0ooooD03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00<0oooo00090?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool03`3oool01@000000oooo0?ooo`3oool00000
00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooodl0oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`030?ooo`002P3oool900000180oooo00D000000?ooo`3o
ool0oooo000000060?ooo`<000002P3oool00`000000oooo0?ooo`3o0?ooodd0oooo0P0000100?oo
o`030000003oool0oooo00<0oooo000U0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooC03oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo00<0oooo000U0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0?l0ooooB`3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo00<0oooo00080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool03`3oool3000000P0oooo100000080?ooo`030000003oool0oooo0?l0ooooBP3oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00<0oooo00090?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3o0?ooodP0oooo0P0000150?ooo`030000
003oool0oooo00<0oooo000:0?ooo`T00000:P3oool00`000000oooo0?ooo`3o0?ooodL0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`030?ooo`00?@3oool200000?l0ooooA`3oool0
0`000000oooo0?ooo`140?ooo`<000001@3oool003d0oooo00<000000?ooo`3oool0o`3ooom40?oo
o`800000B@3oool00`000000oooo0?ooo`030?ooo`00?@3oool00`000000oooo0?ooo`3o0?oood<0
oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`030?ooo`00?@3oool00`000000oooo
0?ooo`3o0?oood40oooo0P00001<0?ooo`030000003oool0oooo00<0oooo000m0?ooo`030000003o
ool0oooo0?l0oooo@03oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00<0oooo000m
0?ooo`030000003oool0oooo0?l0oooo?P3oool2000004l0oooo00<000000?ooo`3oool00`3oool0
03d0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool00`3oool003d0oooo00<000000?ooo`3oool0o`3ooolk0?ooo`800000DP3oool00`000000
oooo0?ooo`030?ooo`00?@3oool200000?l0oooo>`3oool00`000000oooo0?ooo`1@0?ooo`<00000
1@3oool003d0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`800000E@3oool00`000000oooo0?oo
o`030?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooocL0oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`030?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooocD0oooo0P00001H0?oo
o`030000003oool0oooo00<0oooo000m0?ooo`030000003oool0oooo0?l0oooo<`3oool2000005X0
oooo00<000000?ooo`3oool00`3oool003d0oooo00<000000?ooo`3oool0o`3ooola0?ooo`800000
G03oool00`000000oooo0?ooo`030?ooo`00?@3oool00`000000oooo0?ooo`3o0?oooc00oooo00<0
00000?ooo`3oool0G03oool00`000000oooo0?ooo`030?ooo`00?@3oool00`000000oooo0?ooo`3o
0?ooobh0oooo0P00001O0?ooo`030000003oool0oooo00<0oooo000m0?ooo`800000o`3oool]0?oo
o`800000G`3oool3000000D0oooo000m0?ooo`030000003oool0oooo0?l0oooo:P3oool2000006<0
oooo00<000000?ooo`3oool00`3oool003d0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`800000
I@3oool00`000000oooo0?ooo`030?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooobL0oooo00<0
00000?ooo`3oool0I@3oool00`000000oooo0?ooo`030?ooo`00?@3oool00`000000oooo0?ooo`3o
0?ooobD0oooo0P00001X0?ooo`030000003oool0oooo00<0oooo000m0?ooo`030000003oool0oooo
0?l0oooo8`3oool2000006X0oooo00<000000?ooo`3oool00`3oool003d0oooo00<000000?ooo`3o
ool0o`3ooolQ0?ooo`800000K03oool00`000000oooo0?ooo`030?ooo`00?@3oool00`000000oooo
0?ooo`3o0?ooob00oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`030?ooo`00?@3o
ool200000?l0oooo7`3oool2000006d0oooo0`0000050?ooo`00?@3oool00`000000oooo0?ooo`3o
0?oooa`0oooo0P00001a0?ooo`030000003oool0oooo00<0oooo000m0?ooo`030000003oool0oooo
0?l0oooo6P3oool2000007<0oooo00<000000?ooo`3oool00`3oool003d0oooo00<000000?ooo`3o
ool0o`3ooolH0?ooo`800000M@3oool00`000000oooo0?ooo`030?ooo`00?@3oool00`000000oooo
0?ooo`3o0?oooaH0oooo0P00001g0?ooo`030000003oool0oooo00<0oooo000a0?ooo`<000002@3o
ool00`000000oooo0?ooo`3o0?oooa@0oooo0P00001i0?ooo`030000003oool0oooo00<0oooo000`
0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`3o0?oooa80oooo0P00
001k0?ooo`030000003oool0oooo00<0oooo000`0?ooo`050000003oool0oooo0?ooo`000000203o
ool00`000000oooo0?ooo`3o0?oooa00oooo0P00001m0?ooo`030000003oool0oooo00<0oooo000`
0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`3o0?ooo`d0oooo0`00
001o0?ooo`030000003oool0oooo00<0oooo000`0?ooo`050000003oool0oooo0?ooo`000000203o
oooo000009<000001@3oool00300oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003o
ool0oooo0?l0oooo2@3oool2000008@0oooo00<000000?ooo`3oool00`3oool00300oooo00D00000
0?ooo`3oool0oooo000000080?ooo`030000003oool0oooo0?l0oooo1P3oool3000008H0oooo00<0
00000?ooo`3oool00`3oool00300oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003o
ool0oooo0?l0oooo103oool2000008T0oooo00<000000?ooo`3oool00`3oool00300oooo00D00000
0?ooo`3oool0oooo000000080?ooo`030000003oool0oooo0?l0oooo0P3oool2000008/0oooo00<0
00000?ooo`3oool00`3oool00340oooo0`0000090?ooo`030000003oool0oooo0?l0oooo0P00002=
0?ooo`030000003oool0oooo00<0oooo000m0?ooo`030000003oool0oooo0?`0oooo0`00002?0?oo
o`030000003oool0oooo00<0oooo000m0?ooo`030000003oool0oooo0?X0oooo0P00002B0?ooo`03
0000003oool0oooo00<0oooo000m0?ooo`800000n@3oool200000980oooo0`0000050?ooo`00?@3o
ool00`000000oooo0?ooo`3e0?ooo`<00000UP3oool00`000000oooo0?ooo`030?ooo`00?@3oool0
0`000000oooo0?ooo`3c0?ooo`800000V@3oool00`000000oooo0?ooo`030?ooo`00?@3oool00`00
0000oooo0?ooo`3`0?ooo`<00000V`3oool00`000000oooo0?ooo`030?ooo`00?@3oool00`000000
oooo0?ooo`3]0?ooo`<00000WP3oool00`000000oooo0?ooo`030?ooo`00?@3oool00`000000oooo
0?ooo`3[0?ooo`800000X@3oool00`000000oooo0?ooo`030?ooo`00?@3oool00`000000oooo0?oo
o`3X0?ooo`<00000X`3oool00`000000oooo0?ooo`030?ooo`00?@3oool00`000000oooo0?ooo`3U
0?ooo`<00000YP3oool00`000000oooo0?ooo`030?ooo`00?@3oool200000>@0oooo0P00002W0?oo
o`<000001@3oool003d0oooo00<000000?ooo`3oool0h03oool300000:/0oooo00<000000?ooo`3o
ool00`3oool003d0oooo00<000000?ooo`3oool0g@3oool300000:h0oooo00<000000?ooo`3oool0
0`3oool003d0oooo00<000000?ooo`3oool0f`3oool200000;40oooo00<000000?ooo`3oool00`3o
ool003d0oooo00<000000?ooo`3oool0f03oool300000;<0oooo00<000000?ooo`3oool00`3oool0
03d0oooo00<000000?ooo`3oool0e@3oool300000;H0oooo00<000000?ooo`3oool00`3oool003d0
oooo00<000000?ooo`3oool0d`3oool200000;T0oooo00<000000?ooo`3oool00`3oool003d0oooo
00<000000?ooo`3oool0d03oool300000;/0oooo00<000000?ooo`3oool00`3oool003d0oooo0P00
003>0?ooo`<00000_03oool3000000D0oooo000m0?ooo`030000003oool0oooo0</0oooo0P000031
0?ooo`030000003oool0oooo00<0oooo000m0?ooo`030000003oool0oooo0<P0oooo0`0000330?oo
o`030000003oool0oooo00<0oooo000m0?ooo`030000003oool0oooo0<D0oooo0`0000360?ooo`03
0000003oool0oooo00<0oooo000m0?ooo`030000003oool0oooo0<80oooo0`0000390?ooo`030000
003oool0oooo00<0oooo000m0?ooo`030000003oool0oooo0;l0oooo0`00003<0?ooo`030000003o
ool0oooo00<0oooo000m0?ooo`030000003oool0oooo0;`0oooo0`00003?0?ooo`030000003oool0
oooo00<0oooo000m0?ooo`030000003oool0oooo0;T0oooo0`00003B0?ooo`030000003oool0oooo
00<0oooo000m0?ooo`030000003oool0oooo0;H0oooo0`00003E0?ooo`030000003oool0oooo00<0
oooo000m0?ooo`800000]03oool300000=H0oooo0`0000050?ooo`00?@3oool00`000000oooo0?oo
o`2`0?ooo`<00000f`3oool00`000000oooo0?ooo`030?ooo`00?@3oool00`000000oooo0?ooo`2/
0?ooo`@00000gP3oool00`000000oooo0?ooo`030?ooo`00?@3oool00`000000oooo0?ooo`2Y0?oo
o`<00000hP3oool00`000000oooo0?ooo`030?ooo`009P3oool3000000<0oooo00@000000?ooo`3o
ool0oooo0`00000:0?ooo`030000003oool0oooo0:H0oooo0`00003U0?ooo`030000003oool0oooo
00<0oooo000U0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0:80oooo1000003X0?ooo`030000003oool0oooo00<0oooo000U0?ooo`05
0000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
09l0oooo0`00003/0?ooo`030000003oool0oooo00<0oooo000U0?ooo`050000003oool0oooo0?oo
o`0000002P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo09`0oooo0`00003_0?oo
o`030000003oool0oooo00<0oooo000U0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`00
0000oooo0?ooo`060?ooo`<00000V03oool400000>l0oooo100000050?ooo`009@3oool01@000000
oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2E0?oo
o`<00000mP3oool00`000000oooo0?ooo`030?ooo`009@3oool01@000000oooo0?ooo`3oool00000
00H0oooo0`00000:0?ooo`030000003oool0oooo0940oooo1000003i0?ooo`030000003oool0oooo
00<0oooo000U0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo08d0oooo1000003m0?ooo`030000003oool0oooo00<0oooo000U0?ooo`05
0000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
08T0oooo1000003o0?ooo`80oooo00<000000?ooo`3oool00`3oool002H0oooo0`0000080?ooo`@0
0000203oool00`000000oooo0?ooo`260?ooo`<00000o`3oool60?ooo`030000003oool0oooo00<0
oooo000m0?ooo`030000003oool0oooo0880oooo1000003o0?ooo`T0oooo00<000000?ooo`3oool0
0`3oool003d0oooo00<000000?ooo`3oool0OP3oool400000?l0oooo3@3oool00`000000oooo0?oo
o`030?ooo`00?@3oool2000007/0oooo1000003o0?ooo`l0oooo0`0000050?ooo`00?@3oool00`00
0000oooo0?ooo`1e0?ooo`D00000o`3ooolE0?ooo`030000003oool0oooo00<0oooo000m0?ooo`03
0000003oool0oooo0740oooo1000003o0?oooaX0oooo00<000000?ooo`3oool00`3oool003d0oooo
00<000000?ooo`3oool0K@3oool400000?l0oooo7P3oool00`000000oooo0?ooo`030?ooo`00?@3o
ool00`000000oooo0?ooo`1Y0?ooo`@00000o`3ooolR0?ooo`030000003oool0oooo00<0oooo000m
0?ooo`030000003oool0oooo06@0oooo1@00003o0?ooobH0oooo00<000000?ooo`3oool00`3oool0
03d0oooo00<000000?ooo`3oool0G`3oool500000?l0oooo:`3oool00`000000oooo0?ooo`030?oo
o`00?@3oool00`000000oooo0?ooo`1I0?ooo`H00000o`3oool`0?ooo`030000003oool0oooo00<0
oooo000m0?ooo`800000E@3oool500000?l0oooo=03oool3000000D0oooo000m0?ooo`030000003o
ool0oooo04l0oooo1@00003o0?oooc/0oooo00<000000?ooo`3oool00`3oool003d0oooo00<00000
0?ooo`3oool0B@3oool600000?l0oooo@03oool00`000000oooo0?ooo`030?ooo`00?@3oool00`00
0000oooo0?ooo`140?ooo`D00000o`3ooom60?ooo`030000003oool0oooo00<0oooo000m0?ooo`03
0000003oool0oooo03l0oooo1@00003o0?oood/0oooo00<000000?ooo`3oool00`3oool003d0oooo
00<000000?ooo`3oool0>P3oool500000?l0ooooD03oool00`000000oooo0?ooo`030?ooo`00?@3o
ool00`000000oooo0?ooo`0`0?ooo`X00000o`3ooomE0?ooo`030000003oool0oooo00<0oooo000m
0?ooo`030000003oool0oooo02<0oooo3@00003o0?oooel0oooo00<000000?ooo`3oool00`3oool0
03d0oooo00<000000?ooo`3oool0403ooolC00000?l0ooooK03oool00`000000oooo0?ooo`030?oo
o`00?@3oool2000000L0oooo2P00003o0?ooogd0oooo0`0000050?ooo`00?@3oool00`000000oooo
0?ooo`3o0?ooohl0oooo00<000000?ooo`3oool00`3oool003d0oooo00<000000?ooo`3oool0o`3o
oon?0?ooo`030000003oool0oooo00<0oooo000m0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00<0oooo000m0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool003d0ooooo`00002C000000D0
oooo0000\
\>"],
  ImageRangeCache->{{{0, 467.375}, {288.5, 0}} -> {-0.70576, -2.62786, \
0.00994889, 0.0121298}}],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(plasq1\)\" is similar \
to existing symbol \"\!\(plfsq1\)\"."\)], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238032 0.250628 0.014593 0.16212 [
[.0238 -0.0125 -5.53125 -17.8125 ]
[.0238 -0.0125 5.53125 0 ]
[.14912 -0.0125 -10.7813 -17.8125 ]
[.14912 -0.0125 10.7813 0 ]
[.27443 -0.0125 -5.53125 -17.8125 ]
[.27443 -0.0125 5.53125 0 ]
[.39975 -0.0125 -10.7813 -17.8125 ]
[.39975 -0.0125 10.7813 0 ]
[.52506 -0.0125 -5.53125 -17.8125 ]
[.52506 -0.0125 5.53125 0 ]
[.65037 -0.0125 -10.7813 -17.8125 ]
[.65037 -0.0125 10.7813 0 ]
[.77569 -0.0125 -5.53125 -17.8125 ]
[.77569 -0.0125 5.53125 0 ]
[.901 -0.0125 -10.7813 -17.8125 ]
[.901 -0.0125 10.7813 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -11.75 -35.625 ]
[.5 -0.0125 11.75 -17.8125 ]
[-0.0125 .01459 -11.0625 -8.90625 ]
[-0.0125 .01459 0 8.90625 ]
[-0.0125 .09565 -21.5625 -8.90625 ]
[-0.0125 .09565 0 8.90625 ]
[-0.0125 .17671 -11.0625 -8.90625 ]
[-0.0125 .17671 0 8.90625 ]
[-0.0125 .25777 -21.5625 -8.90625 ]
[-0.0125 .25777 0 8.90625 ]
[-0.0125 .33883 -11.0625 -8.90625 ]
[-0.0125 .33883 0 8.90625 ]
[-0.0125 .41989 -21.5625 -8.90625 ]
[-0.0125 .41989 0 8.90625 ]
[-0.0125 .50095 -11.0625 -8.90625 ]
[-0.0125 .50095 0 8.90625 ]
[-0.0125 .58201 -21.5625 -8.90625 ]
[-0.0125 .58201 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -39.375 -11.6563 ]
[-0.01875 .30902 -21.5625 11.6563 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0238 0 m
.0238 .00625 L
s
gsave
.0238 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.14912 0 m
.14912 .00625 L
s
gsave
.14912 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.27443 0 m
.27443 .00625 L
s
gsave
.27443 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.39975 0 m
.39975 .00625 L
s
gsave
.39975 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.52506 0 m
.52506 .00625 L
s
gsave
.52506 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.65037 0 m
.65037 .00625 L
s
gsave
.65037 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.77569 0 m
.77569 .00625 L
s
gsave
.77569 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.901 0 m
.901 .00625 L
s
gsave
.901 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
1.000 setlinewidth
grestore
.125 Mabswid
.04887 0 m
.04887 .00375 L
s
.07393 0 m
.07393 .00375 L
s
.09899 0 m
.09899 .00375 L
s
.12405 0 m
.12405 .00375 L
s
.17418 0 m
.17418 .00375 L
s
.19924 0 m
.19924 .00375 L
s
.22431 0 m
.22431 .00375 L
s
.24937 0 m
.24937 .00375 L
s
.29949 0 m
.29949 .00375 L
s
.32456 0 m
.32456 .00375 L
s
.34962 0 m
.34962 .00375 L
s
.37468 0 m
.37468 .00375 L
s
.42481 0 m
.42481 .00375 L
s
.44987 0 m
.44987 .00375 L
s
.47493 0 m
.47493 .00375 L
s
.5 0 m
.5 .00375 L
s
.55012 0 m
.55012 .00375 L
s
.57519 0 m
.57519 .00375 L
s
.60025 0 m
.60025 .00375 L
s
.62531 0 m
.62531 .00375 L
s
.67544 0 m
.67544 .00375 L
s
.7005 0 m
.7005 .00375 L
s
.72556 0 m
.72556 .00375 L
s
.75063 0 m
.75063 .00375 L
s
.80075 0 m
.80075 .00375 L
s
.82581 0 m
.82581 .00375 L
s
.85088 0 m
.85088 .00375 L
s
.87594 0 m
.87594 .00375 L
s
.92606 0 m
.92606 .00375 L
s
.95113 0 m
.95113 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -72.75 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
73.063 19.750 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
78.563 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
82.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01459 m
.00625 .01459 L
s
gsave
-0.0125 .01459 -72.0625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .09565 m
.00625 .09565 L
s
gsave
-0.0125 .09565 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .17671 m
.00625 .17671 L
s
gsave
-0.0125 .17671 -72.0625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .25777 m
.00625 .25777 L
s
gsave
-0.0125 .25777 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
0 .33883 m
.00625 .33883 L
s
gsave
-0.0125 .33883 -72.0625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .41989 m
.00625 .41989 L
s
gsave
-0.0125 .41989 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
0 .50095 m
.00625 .50095 L
s
gsave
-0.0125 .50095 -72.0625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
0 .58201 m
.00625 .58201 L
s
gsave
-0.0125 .58201 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .0308 m
.00375 .0308 L
s
0 .04702 m
.00375 .04702 L
s
0 .06323 m
.00375 .06323 L
s
0 .07944 m
.00375 .07944 L
s
0 .11186 m
.00375 .11186 L
s
0 .12808 m
.00375 .12808 L
s
0 .14429 m
.00375 .14429 L
s
0 .1605 m
.00375 .1605 L
s
0 .19292 m
.00375 .19292 L
s
0 .20914 m
.00375 .20914 L
s
0 .22535 m
.00375 .22535 L
s
0 .24156 m
.00375 .24156 L
s
0 .27398 m
.00375 .27398 L
s
0 .2902 m
.00375 .2902 L
s
0 .30641 m
.00375 .30641 L
s
0 .32262 m
.00375 .32262 L
s
0 .35504 m
.00375 .35504 L
s
0 .37126 m
.00375 .37126 L
s
0 .38747 m
.00375 .38747 L
s
0 .40368 m
.00375 .40368 L
s
0 .4361 m
.00375 .4361 L
s
0 .45232 m
.00375 .45232 L
s
0 .46853 m
.00375 .46853 L
s
0 .48474 m
.00375 .48474 L
s
0 .51716 m
.00375 .51716 L
s
0 .53338 m
.00375 .53338 L
s
0 .54959 m
.00375 .54959 L
s
0 .5658 m
.00375 .5658 L
s
0 .59822 m
.00375 .59822 L
s
0 .61444 m
.00375 .61444 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -103.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
72.6563 12.9063 translate
90 rotate
-72.6563 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.250 17.500 moveto
(H) show
73.813 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
77.750 17.500 moveto
(L) show
82.313 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.0238 .61178 m
.0238 .61803 L
s
.14912 .61178 m
.14912 .61803 L
s
.27443 .61178 m
.27443 .61803 L
s
.39975 .61178 m
.39975 .61803 L
s
.52506 .61178 m
.52506 .61803 L
s
.65037 .61178 m
.65037 .61803 L
s
.77569 .61178 m
.77569 .61803 L
s
.901 .61178 m
.901 .61803 L
s
.125 Mabswid
.04887 .61428 m
.04887 .61803 L
s
.07393 .61428 m
.07393 .61803 L
s
.09899 .61428 m
.09899 .61803 L
s
.12405 .61428 m
.12405 .61803 L
s
.17418 .61428 m
.17418 .61803 L
s
.19924 .61428 m
.19924 .61803 L
s
.22431 .61428 m
.22431 .61803 L
s
.24937 .61428 m
.24937 .61803 L
s
.29949 .61428 m
.29949 .61803 L
s
.32456 .61428 m
.32456 .61803 L
s
.34962 .61428 m
.34962 .61803 L
s
.37468 .61428 m
.37468 .61803 L
s
.42481 .61428 m
.42481 .61803 L
s
.44987 .61428 m
.44987 .61803 L
s
.47493 .61428 m
.47493 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55012 .61428 m
.55012 .61803 L
s
.57519 .61428 m
.57519 .61803 L
s
.60025 .61428 m
.60025 .61803 L
s
.62531 .61428 m
.62531 .61803 L
s
.67544 .61428 m
.67544 .61803 L
s
.7005 .61428 m
.7005 .61803 L
s
.72556 .61428 m
.72556 .61803 L
s
.75063 .61428 m
.75063 .61803 L
s
.80075 .61428 m
.80075 .61803 L
s
.82581 .61428 m
.82581 .61803 L
s
.85088 .61428 m
.85088 .61803 L
s
.87594 .61428 m
.87594 .61803 L
s
.92606 .61428 m
.92606 .61803 L
s
.95113 .61428 m
.95113 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01459 m
1 .01459 L
s
.99375 .09565 m
1 .09565 L
s
.99375 .17671 m
1 .17671 L
s
.99375 .25777 m
1 .25777 L
s
.99375 .33883 m
1 .33883 L
s
.99375 .41989 m
1 .41989 L
s
.99375 .50095 m
1 .50095 L
s
.99375 .58201 m
1 .58201 L
s
.125 Mabswid
.99625 .0308 m
1 .0308 L
s
.99625 .04702 m
1 .04702 L
s
.99625 .06323 m
1 .06323 L
s
.99625 .07944 m
1 .07944 L
s
.99625 .11186 m
1 .11186 L
s
.99625 .12808 m
1 .12808 L
s
.99625 .14429 m
1 .14429 L
s
.99625 .1605 m
1 .1605 L
s
.99625 .19292 m
1 .19292 L
s
.99625 .20914 m
1 .20914 L
s
.99625 .22535 m
1 .22535 L
s
.99625 .24156 m
1 .24156 L
s
.99625 .27398 m
1 .27398 L
s
.99625 .2902 m
1 .2902 L
s
.99625 .30641 m
1 .30641 L
s
.99625 .32262 m
1 .32262 L
s
.99625 .35504 m
1 .35504 L
s
.99625 .37126 m
1 .37126 L
s
.99625 .38747 m
1 .38747 L
s
.99625 .40368 m
1 .40368 L
s
.99625 .4361 m
1 .4361 L
s
.99625 .45232 m
1 .45232 L
s
.99625 .46853 m
1 .46853 L
s
.99625 .48474 m
1 .48474 L
s
.99625 .51716 m
1 .51716 L
s
.99625 .53338 m
1 .53338 L
s
.99625 .54959 m
1 .54959 L
s
.99625 .5658 m
1 .5658 L
s
.99625 .59822 m
1 .59822 L
s
.99625 .61444 m
1 .61444 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.02499 .01859 L
.02605 .02074 L
.02846 .02457 L
.03279 .03006 L
.04262 .03994 L
.06244 .0557 L
.10458 .08287 L
.14451 .10607 L
.18292 .12809 L
.22379 .15227 L
.26314 .17691 L
.30098 .20226 L
.34126 .23129 L
.38004 .26134 L
.42126 .29558 L
.46097 .33065 L
.49916 .36602 L
.53981 .40496 L
.57894 .44299 L
.62052 .48292 L
.66059 .51955 L
.69914 .5514 L
.71868 .56564 L
.74014 .57931 L
.76079 .59009 L
.77963 .59746 L
.78443 .59891 L
.78965 .60027 L
.79416 .60125 L
.79914 .60213 L
.80167 .60249 L
.8044 .6028 L
.80591 .60295 L
.80729 .60306 L
.80869 .60315 L
.81 .60322 L
.81113 .60327 L
.81234 .6033 L
.81303 .60331 L
.81368 .60332 L
.8149 .60332 L
.81618 .6033 L
.81737 .60327 L
.81867 .60322 L
.82005 .60314 L
.82258 .60295 L
.82498 .60269 L
.82949 .60203 L
.83434 .60103 L
Mistroke
.83963 .5996 L
.84913 .59606 L
.85794 .59157 L
.86853 .58446 L
.8785 .5759 L
.89712 .55416 L
.90691 .53917 L
.91724 .52008 L
.93572 .47508 L
.94523 .44447 L
.9554 .40307 L
.96033 .37829 L
.965 .35059 L
.96955 .31772 L
.97375 .27869 L
.97619 .24905 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{468.375, 289.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007D00018B000`400?l00000o`00003oo`3ooooE
0?ooo`00o`3ooooE0?ooo`00o`3ooooE0?ooo`00o`3oool30?ooo`800000d03oool00?l0oooo0P3o
ool010000000oooo0?ooo`00003?0?ooo`00m`3oool3000000<0oooo0`0000001@3oool000000?oo
o`3oool000000080oooo0P00003;0?ooo`00n03oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo00000080oooo00H000000?ooo`3oool000000?ooo`00003:0?ooo`00n03oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000c03oool0
0?P0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000<`0oooo003h0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P00
00030?ooo`030000003oool0oooo0<X0oooo003h0?ooo`L00000203oool00`000000oooo0?ooo`3:
0?ooo`00n03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0`00003;0?oo
o`00n03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0bP3oool00?P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0<X0oooo003g0?ooo`<000000`3oool300000=@0oooo003o0?ooomD0oooo003o0?oo
omD0oooo003o0?ooomD0oooo003o0?ooomD0oooo003o0?ooomD0oooo003o0?ooomD0oooo003o0?oo
omD0oooo003o0?ooomD0oooo00100?ooo`<00000:P3oool3000000<0oooo00@000000?ooo`3oool0
oooo0`00000[0?ooo`<00000:P3oool3000000<0oooo00@000000?ooo`3oool0oooo0`00000Y0?oo
o`D00000:03oool500000080oooo00@000000?ooo`3oool0oooo0`00000Z0?ooo`@00000:@3oool4
000000<0oooo00@000000?ooo`3oool0oooo0`00000/0?ooo`00?`3oool01@000000oooo0?ooo`3o
ool0000002P0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02L0oooo
00@000000?ooo`3oool00000:@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
02T0oooo000o0?ooo`050000003oool0oooo0?ooo`000000:03oool01@000000oooo0?ooo`3oool0
000000X0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0:03oool003l0oooo00D000000?ooo`3oool0oooo0000000X
0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0X0?ooo`00?`3oool0
1@000000oooo0?ooo`3oool0000002P0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo02P0oooo000o0?ooo`050000003oool0oooo0?ooo`000000:03oool01@000000oooo
0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0:@3oool2000002/0oooo0P00000:0?ooo`03
0000003oool0oooo02T0oooo000o0?ooo`050000003oool0oooo0?ooo`000000:03oool01@000000
oooo0?ooo`3oool0000000H0oooo0`00000/0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool01P3oool3000002d0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`040?oo
o`<00000;@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00D0oooo0`00000/0?oo
o`00?`3oool01@000000oooo0?ooo`3oool0000002P0oooo00D000000?ooo`3oool0oooo00000006
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo02`0oooo000o0?ooo`050000003oool0oooo0?ooo`000000:03oool0
1@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0:P3oool2000002/0oooo0P00
00090?ooo`030000003oool0oooo02P0oooo00D000000?ooo`3oool0oooo0000000X0?ooo`050000
003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`0Y0?ooo`050000003oool0oooo0?oo
o`000000:03oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0:`3oool0
0400oooo0`00000Z0?ooo`<00000203oool4000002X0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`070?ooo`@00000:03oool3000002X0oooo0`0000080?ooo`@00000:@3oool30000
02X0oooo0`0000080?ooo`@00000:P3oool00?l0ooooe@3oool00?l0ooooe@3oool00?l0ooooe@3o
ool00?l0ooooe@3oool00?l0ooooe@3oool00?l0ooooe@3oool00?l0ooooe@3oool00?l0ooooe@3o
ool003P0ooooo`00002C000000X0oooo000h0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0203oool002`0oooo0`0000090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool0<03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000[0?ooo`050000
003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`3o0?ooohl0oooo00<000000?ooo`3o
ool0203oool002/0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo0?l0
ooooS`3oool00`000000oooo0?ooo`080?ooo`00:`3oool01@000000oooo0?ooo`3oool0000000P0
oooo1000003o0?oooh`0oooo0`00000:0?ooo`00:`3oool01@000000oooo0?ooo`3oool0000000P0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooohD0oooo00<000000?ooo`3o
ool0203oool002/0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0o`3ooon50?ooo`030000003oool0oooo00P0oooo000[0?ooo`050000
003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0
ooooQ@3oool00`000000oooo0?ooo`080?ooo`00:`3oool01@000000oooo0?ooo`3oool0000000P0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?oooh@0oooo00<000000?ooo`3o
ool0203oool002/0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0o`3ooon30?ooo`030000003oool0oooo00P0oooo000/0?ooo`<00000
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0ooooP`3oool00`000000oooo
0?ooo`080?ooo`00>03oool3000000X0oooo00<000000?ooo`3oool0o`3ooon10?ooo`8000002P3o
ool003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?oooh40oooo00<00000
0?ooo`3oool0203oool003P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?oo
oh00oooo00<000000?ooo`3oool0203oool003P0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`3o0?ooogl0oooo00<000000?ooo`3oool0203oool003P0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`3o0?ooogh0oooo00<000000?ooo`3oool0203oool003P0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooogd0oooo00<000000?ooo`3oool0203o
ool003P0oooo0`00000@0?ooo`800000o`3oooml0?ooo`8000002P3oool003P0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`3o0?ooogX0oooo00<000000?ooo`3oool0203oool003P0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3o0?ooogT0oooo00<000000?ooo`3o
ool0203oool003P0oooo00<000000?ooo`3oool0503oool200000?l0ooooN@3oool00`000000oooo
0?ooo`080?ooo`00>03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0ooooMP3o
ool00`000000oooo0?ooo`080?ooo`00>03oool00`000000oooo0?ooo`0G0?ooo`800000o`3ooomf
0?ooo`030000003oool0oooo00P0oooo000h0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0o`3ooomc0?ooo`030000003oool0oooo00P0oooo000h0?ooo`<000006P3oool200000?l0
ooooLP3oool2000000X0oooo000h0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
o`3ooom`0?ooo`030000003oool0oooo00P0oooo000h0?ooo`030000003oool0oooo01d0oooo0P00
003o0?ooog00oooo00<000000?ooo`3oool0203oool003P0oooo00<000000?ooo`3oool07`3oool2
00000?l0ooooKP3oool00`000000oooo0?ooo`080?ooo`00>03oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo0?l0ooooJ`3oool00`000000oooo0?ooo`080?ooo`00>03oool00`000000
oooo0?ooo`0R0?ooo`800000o`3ooom[0?ooo`030000003oool0oooo00P0oooo000h0?ooo`<00000
903oool00`000000oooo0?ooo`3o0?ooofL0oooo0P00000:0?ooo`00>03oool00`000000oooo0?oo
o`0U0?ooo`800000o`3ooomX0?ooo`030000003oool0oooo00P0oooo000h0?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool0o`3ooomU0?ooo`030000003oool0oooo00P0oooo000R0?oo
o`<000000`3oool010000000oooo0?ooo`3oool3000000T0oooo00<000000?ooo`3oool0:03oool2
00000?l0ooooI@3oool00`000000oooo0?ooo`080?ooo`008@3oool01@000000oooo0?ooo`3oool0
000000T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Z0?ooo`800000o`3ooomS
0?ooo`030000003oool0oooo00P0oooo000Q0?ooo`050000003oool0oooo0?ooo`0000002P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo02`0oooo0P00003o0?ooof40oooo00<00000
0?ooo`3oool0203oool00240oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`3o0?oooeh0oooo00<00000
0?ooo`3oool0203oool00240oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0
oooo00D0oooo1000000^0?ooo`800000o`3ooomL0?ooo`<000002P3oool00240oooo00D000000?oo
o`3oool0oooo000000090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0<@3oool2
00000?l0ooooG03oool00`000000oooo0?ooo`080?ooo`008@3oool01@000000oooo0?ooo`3oool0
000000H0oooo0`0000090?ooo`030000003oool0oooo03<0oooo0P00003o0?oooeX0oooo00<00000
0?ooo`3oool0203oool00240oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0=@3oool200000?l0ooooF03oool00`000000oooo0?ooo`08
0?ooo`008@3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`08
0?ooo`008P3oool3000000P0oooo100000070?ooo`030000003oool0oooo03P0oooo0P00003o0?oo
oeD0oooo00<000000?ooo`3oool0203oool003P0oooo0`00000j0?ooo`800000o`3ooomB0?ooo`80
00002P3oool003P0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`3o0?oooe00oooo
00<000000?ooo`3oool0203oool003P0oooo00<000000?ooo`3oool0?@3oool200000?l0ooooD03o
ool00`000000oooo0?ooo`080?ooo`00>03oool00`000000oooo0?ooo`0o0?ooo`800000o`3ooom>
0?ooo`030000003oool0oooo00P0oooo000h0?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0o`3ooom;0?ooo`030000003oool0oooo00P0oooo000h0?ooo`030000003oool0oooo0480
oooo0P00003o0?oood/0oooo00<000000?ooo`3oool0203oool003P0oooo00<000000?ooo`3oool0
A03oool200000?l0ooooB@3oool00`000000oooo0?ooo`080?ooo`00>03oool3000004H0oooo00<0
00000?ooo`3oool0o`3ooom50?ooo`8000002P3oool003P0oooo00<000000?ooo`3oool0A`3oool2
00000?l0ooooAP3oool00`000000oooo0?ooo`080?ooo`00>03oool00`000000oooo0?ooo`190?oo
o`800000o`3ooom40?ooo`030000003oool0oooo00P0oooo000h0?ooo`030000003oool0oooo04/0
oooo00<000000?ooo`3oool0o`3ooom10?ooo`030000003oool0oooo00P0oooo000h0?ooo`030000
003oool0oooo04`0oooo0P00003o0?oood40oooo00<000000?ooo`3oool0203oool003P0oooo00<0
00000?ooo`3oool0CP3oool200000?l0oooo?`3oool00`000000oooo0?ooo`080?ooo`00>03oool0
0`000000oooo0?ooo`1@0?ooo`800000o`3ooolm0?ooo`030000003oool0oooo00P0oooo000h0?oo
o`<00000DP3oool00`000000oooo0?ooo`3o0?ooocT0oooo0P00000:0?ooo`00>03oool00`000000
oooo0?ooo`1C0?ooo`800000o`3ooolj0?ooo`030000003oool0oooo00P0oooo000h0?ooo`030000
003oool0oooo05D0oooo0P00003o0?ooocP0oooo00<000000?ooo`3oool0203oool003P0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`3o0?ooocD0oooo00<000000?ooo`3oool0203o
ool003P0oooo00<000000?ooo`3oool0F03oool200000?l0oooo=@3oool00`000000oooo0?ooo`08
0?ooo`00>03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0?l0oooo<P3oool00`00
0000oooo0?ooo`080?ooo`00>03oool3000005/0oooo0P00003o0?oooc40oooo0P00000:0?ooo`00
>03oool00`000000oooo0?ooo`1M0?ooo`800000o`3oool`0?ooo`030000003oool0oooo00P0oooo
000h0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0o`3oool]0?ooo`030000003o
ool0oooo00P0oooo000/0?ooo`<000002@3oool00`000000oooo0?ooo`1P0?ooo`800000o`3oool]
0?ooo`030000003oool0oooo00P0oooo000]0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0HP3oool00`000000oooo0?ooo`3o0?ooobX0oooo00<000000?ooo`3oool0203oool002d0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1S0?ooo`800000o`3ooolZ0?ooo`03
0000003oool0oooo00P0oooo000]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
I@3oool200000?l0oooo:03oool00`000000oooo0?ooo`080?ooo`00;@3oool00`000000oooo0?oo
o`080?ooo`@00000IP3oool00`000000oooo0?ooo`3o0?ooob<0oooo0`00000:0?ooo`00;@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo06P0oooo0P00003o0?ooobD0oooo00<00000
0?ooo`3oool0203oool002d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1Z0?oo
o`030000003oool0oooo0?l0oooo8P3oool00`000000oooo0?ooo`080?ooo`00;@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo06/0oooo0P00003o0?ooob80oooo00<000000?ooo`3o
ool0203oool002`0oooo0P00000:0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0
o`3ooolO0?ooo`030000003oool0oooo00P0oooo000]0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0KP3oool200000?l0oooo7`3oool00`000000oooo0?ooo`080?ooo`00>03oool3
00000700oooo00<000000?ooo`3oool0o`3ooolK0?ooo`8000002P3oool003P0oooo00<000000?oo
o`3oool0L@3oool200000?l0oooo703oool00`000000oooo0?ooo`080?ooo`00>03oool00`000000
oooo0?ooo`1c0?ooo`030000003oool0oooo0?l0oooo6@3oool00`000000oooo0?ooo`080?ooo`00
>03oool00`000000oooo0?ooo`1d0?ooo`800000o`3ooolI0?ooo`030000003oool0oooo00P0oooo
000h0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`030000003o
ool0oooo00P0oooo000h0?ooo`030000003oool0oooo07L0oooo0P00003o0?oooaH0oooo00<00000
0?ooo`3oool0203oool003P0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`3o0?oo
oa<0oooo00<000000?ooo`3oool0203oool003P0oooo0`00001j0?ooo`800000o`3ooolB0?ooo`80
00002P3oool003P0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool0203oool003P0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?oo
o`3o0?ooo`l0oooo00<000000?ooo`3oool0203oool003P0oooo00<000000?ooo`3oool0OP3oool2
00000?l0oooo3`3oool00`000000oooo0?ooo`080?ooo`00>03oool00`000000oooo0?ooo`200?oo
o`030000003oool0oooo0?l0oooo303oool00`000000oooo0?ooo`080?ooo`00>03oool00`000000
oooo0?ooo`210?ooo`800000o`3oool<0?ooo`030000003oool0oooo00P0oooo000h0?ooo`<00000
P`3oool00`000000oooo0?ooo`3o0?ooo`P0oooo0P00000:0?ooo`00>03oool00`000000oooo0?oo
o`240?ooo`800000o`3oool90?ooo`030000003oool0oooo00P0oooo000h0?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool0o`3oool60?ooo`030000003oool0oooo00P0oooo000h0?oo
o`030000003oool0oooo08L0oooo00<000000?ooo`3oool0o`3oool50?ooo`030000003oool0oooo
00P0oooo000h0?ooo`030000003oool0oooo08P0oooo0P00003o0?ooo`D0oooo00<000000?ooo`3o
ool0203oool003P0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`3o0?ooo`80oooo
00<000000?ooo`3oool0203oool003P0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?oo
o`3o0?ooo`40oooo00<000000?ooo`3oool0203oool003P0oooo0`00002<0?ooo`030000003oool0
oooo0?h0oooo0P00000:0?ooo`00>03oool00`000000oooo0?ooo`2=0?ooo`800000o`3oool00`00
0000oooo0?ooo`080?ooo`008P3oool3000000<0oooo00@000000?ooo`3oool0oooo0`0000090?oo
o`030000003oool0oooo08l0oooo00<000000?ooo`3oool0o03oool00`000000oooo0?ooo`080?oo
o`008`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0T03oool00`000000oooo0?ooo`3b0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0203oool002<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0940oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00P0oooo000S0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`2B0?ooo`800000l@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00P0oooo000S0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool4
000009<0oooo00<000000?ooo`3oool0kP3oool00`000000oooo0?ooo`040?ooo`<000002P3oool0
02<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
09D0oooo00<000000?ooo`3oool0k@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00P0oooo000S0?ooo`030000003oool0oooo00H0oooo0`0000090?ooo`030000003oool0oooo09H0
oooo00<000000?ooo`3oool0k03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0
oooo000S0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`2G0?ooo`800000j`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo
000R0?ooo`8000002@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09T0oooo00<0
00000?ooo`3oool0j03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo000S
0?ooo`030000003oool0oooo00L0oooo100000070?ooo`030000003oool0oooo09X0oooo00<00000
0?ooo`3oool0i`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo000h0?oo
o`030000003oool0oooo09/0oooo00<000000?ooo`3oool0iP3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00P0oooo000h0?ooo`<00000W03oool00`000000oooo0?ooo`3U0?ooo`03
0000003oool0oooo00H0oooo0P00000:0?ooo`00>03oool00`000000oooo0?ooo`2M0?ooo`800000
i@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo000h0?ooo`030000003o
ool0oooo09l0oooo00<000000?ooo`3oool0hP3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo000h0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0h@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo000h0?ooo`030000003oool0oooo
0:40oooo00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00P0oooo000A0?ooo`030000003oool0oooo008000008P3oool00`000000oooo0?ooo`2R0?ooo`03
0000003oool0oooo0=h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`00
403oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01l0oooo0`00002S0?ooo`80
0000gP3oool00`000000oooo0?ooo`070?ooo`8000002P3oool00100oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3o
ool0f`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo000@0?ooo`060000
003oool0oooo0000003oool000008P3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo
0=X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`004@3oool600000240
oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0203oool001H0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`2X0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`00>03oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo0=L0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`003`3oool900000200oooo00<00000
0?ooo`3oool0ZP3oool200000=L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`08
0?ooo`003P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01d0oooo0`00002/0?oo
o`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0203oool2000000X0oooo000=0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2]0?ooo`03
0000003oool0oooo0=80oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`00
>03oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`080?ooo`00403oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo0:l0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00P0oooo000>0?ooo`T000008@3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0
oooo0<l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`00403oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0/@3oool00`00
0000oooo0?ooo`3>0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool001D0
oooo00<000000?ooo`3oool0803oool300000;80oooo0P00003>0?ooo`030000003oool0oooo00P0
oooo0P00000:0?ooo`003@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0203oool000h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00P0oooo000?0?ooo`T000004`3oool5000000P0oooo00<00000
0?ooo`3oool0]P3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0203oool002`0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`2g
0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`08
0?ooo`00;@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0;P0oooo00<000000?oo
o`3oool0aP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo000^0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`350?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool002h0oooo00<000000?ooo`3oool0
1`3oool400000;T0oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`080?ooo`<00000
2P3oool002l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2k0?ooo`030000003o
ool0oooo0<80oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`00;`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool0`@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo000_0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0_@3oool200000<40oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`080?ooo`00:`3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?oo
o`3oool0_`3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0203oool002`0oooo0`0000090?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3o
ool0_@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo000h0?ooo`<00000
`@3oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo00X0oooo0P00000:0?ooo`00>03o
ool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`080?ooo`00>03oool00`000000oooo0?ooo`330?ooo`030000003oool0
oooo0;T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`00>03oool00`00
0000oooo0?ooo`340?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`080?ooo`00>03oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo0;L0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`00>03oool00`000000oooo
0?ooo`360?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`080?ooo`00>03oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo0;D0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`00>03oool300000<P0oooo00<00000
0?ooo`3oool0/`3oool00`000000oooo0?ooo`0<0?ooo`8000002P3oool003P0oooo00<000000?oo
o`3oool0b@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0203oool003P0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`2a0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool003P0oooo00<000000?ooo`3oool0
b`3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
203oool003P0oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`2_0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0203oool003P0oooo00<000000?ooo`3oool0c@3oool2
00000:h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`080?ooo`00>03oool30000
0<l0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0=0?ooo`8000002P3oool003P0
oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0203oool003P0oooo00<000000?ooo`3oool0d@3oool00`000000oooo
0?ooo`2Y0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool003P0oooo00<0
00000?ooo`3oool0dP3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0203oool003P0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`2V
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool003P0oooo00<000000?oo
o`3oool0e03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0203oool003P0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`2T0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool003P0oooo0`00003F0?ooo`030000
003oool0oooo0:<0oooo00<000000?ooo`3oool03P3oool2000000X0oooo000h0?ooo`030000003o
ool0oooo0=L0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00P0oooo000Q0?ooo`D000000P3oool010000000oooo0?ooo`3oool3000000T0oooo00<0
00000?ooo`3oool0f03oool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0203oool00280oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00P0oooo000S0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`3J0?ooo`030000003oool0oooo09h0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`00903oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0f`3oool00`000000oooo0?ooo`2M0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0203oool002@0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`050?ooo`@00000f`3oool00`000000oooo0?ooo`2K0?ooo`03
0000003oool0oooo00l0oooo0`00000:0?ooo`009@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`2J0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0203oool002D0oooo00<000000?ooo`3oool0103o
ool3000000T0oooo00<000000?ooo`3oool0gP3oool00`000000oooo0?ooo`2I0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0203oool002D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0=l0oooo00<000000?ooo`3oool0V03oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00P0oooo000Q0?ooo`050000003oool0oooo
0?ooo`0000001`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0>00oooo00<00000
0?ooo`3oool0UP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00P0oooo000R0?oo
o`<00000203oool4000000L0oooo00<000000?ooo`3oool0h@3oool00`000000oooo0?ooo`2E0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0203oool003P0oooo00<000000?ooo`3o
ool0hP3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0203oool003P0oooo0`00003S0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0
4@3oool2000000X0oooo000h0?ooo`030000003oool0oooo0>@0oooo00<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo000h0?ooo`030000003oool0
oooo0>D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00P0oooo000h0?ooo`030000003oool0oooo0>H0oooo00<000000?ooo`3oool0S`3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo000h0?ooo`030000003oool0oooo0>L0
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0
oooo000h0?ooo`030000003oool0oooo0>P0oooo00<000000?ooo`3oool0S03oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00P0oooo000h0?ooo`<00000j@3oool00`000000oooo0?oo
o`2;0?ooo`030000003oool0oooo01<0oooo0P00000:0?ooo`00>03oool00`000000oooo0?ooo`3Z
0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`08
0?ooo`00>03oool00`000000oooo0?ooo`3[0?ooo`030000003oool0oooo08P0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`080?ooo`00>03oool00`000000oooo0?ooo`3/0?ooo`03
0000003oool0oooo08L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`080?ooo`00
>03oool00`000000oooo0?ooo`3]0?ooo`800000Q`3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo00P0oooo000h0?ooo`030000003oool0oooo0>l0oooo00<000000?ooo`3oool0P`3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00P0oooo000h0?ooo`030000003oool0
oooo0?00oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00P0oooo000h0?ooo`<00000l@3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo
01D0oooo0P00000:0?ooo`00>03oool00`000000oooo0?ooo`3b0?ooo`030000003oool0oooo07l0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`080?ooo`00>03oool00`000000oooo
0?ooo`3c0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`080?ooo`00>03oool00`000000oooo0?ooo`3d0?ooo`030000003oool0oooo07d0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`080?ooo`00>03oool00`000000oooo0?ooo`3e
0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`08
0?ooo`00>03oool00`000000oooo0?ooo`3f0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`080?ooo`00>03oool300000?L0oooo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`0H0?ooo`8000002P3oool003P0oooo00<000000?ooo`3oool0
n03oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
203oool003P0oooo00<000000?ooo`3oool0n@3oool00`000000oooo0?ooo`1f0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool0203oool002/0oooo100000090?ooo`030000003oool0
oooo0?X0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo00P0oooo000_0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0n`3oool00`00
0000oooo0?ooo`1c0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0203oool002l0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3l0?ooo`030000003oool0oooo0740
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`080?ooo`00;`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0?d0oooo00<000000?ooo`3oool0L03oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00P0oooo000_0?ooo`030000003oool0oooo00H0oooo1000
003m0?ooo`800000L03oool00`000000oooo0?ooo`0I0?ooo`<000002P3oool002d0oooo0P000009
0?ooo`030000003oool0oooo0?l0oooo0@3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0203oool002h0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`3o0?ooo`80oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo00P0oooo000_0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`080?ooo`00:`3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3o
ool0o`3oool40?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`080?ooo`00;03oool3000000T0oooo00<000000?ooo`3oool0o`3oool50?ooo`030000
003oool0oooo06L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`080?ooo`00>03o
ool300000?l0oooo1P3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo01d0oooo0P00
000:0?ooo`00>03oool00`000000oooo0?ooo`3o0?ooo`L0oooo00<000000?ooo`3oool0I03oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00P0oooo000h0?ooo`030000003oool0oooo
0?l0oooo203oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool0203oool003P0oooo00<000000?ooo`3oool0o`3oool90?ooo`030000003oool0oooo0640
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`080?ooo`00>03oool00`000000oooo
0?ooo`3o0?ooo`X0oooo0P00001P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
203oool003P0oooo00<000000?ooo`3oool0o`3oool<0?ooo`030000003oool0oooo05d0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`080?ooo`00>03oool00`000000oooo0?ooo`3o
0?ooo`d0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo00P0oooo000h0?ooo`<00000o`3oool>0?ooo`030000003oool0oooo05X0oooo00<000000?oo
o`3oool0803oool2000000X0oooo000h0?ooo`030000003oool0oooo0?l0oooo3`3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool003P0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`080?ooo`00>03oool00`000000oooo0?ooo`3o0?oooa40oooo00<0
00000?ooo`3oool0E@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000h
0?ooo`030000003oool0oooo0?l0oooo4P3oool2000005D0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`080?ooo`00>03oool00`000000oooo0?ooo`3o0?oooa@0oooo00<000000?oo
o`3oool0D@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000h0?ooo`<0
0000o`3ooolE0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0903oool2000000X0
oooo000h0?ooo`030000003oool0oooo0?l0oooo5P3oool00`000000oooo0?ooo`1>0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool0203oool003P0oooo00<000000?ooo`3oool0o`3o
oolG0?ooo`800000C@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000h
0?ooo`030000003oool0oooo0?l0oooo6@3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool0203oool003P0oooo00<000000?ooo`3oool0o`3ooolJ0?oo
o`800000B03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00P0oooo000h0?ooo`03
0000003oool0oooo0?l0oooo703oool2000004D0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`080?ooo`00>03oool00`000000oooo0?ooo`3o0?oooah0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00P0oooo000h0?ooo`<00000o`3o
oolO0?ooo`800000@@3oool00`000000oooo0?ooo`0Y0?ooo`8000002P3oool003P0oooo00<00000
0?ooo`3oool0o`3ooolQ0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`080?ooo`008@3oool4000000<0oooo00@000000?ooo`3oool0oooo0`000009
0?ooo`030000003oool0oooo0?l0oooo8P3oool2000003`0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`080?ooo`009@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`080?ooo`009@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`800000=`3oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo00P0oooo000U0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00P0oooo000U0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01@3oool400000?l0oooo9`3oool200000340oooo0P00
000`0?ooo`<000002P3oool002<0oooo0P00000:0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0o`3ooolZ0?ooo`800000;P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo00P0oooo000T0?ooo`030000003oool0oooo00D0oooo0`0000090?ooo`030000003oool0oooo
0?l0oooo;03oool2000002/0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`080?oo
o`009@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0o`3oool^0?ooo`<000009P3oool2000003H0oooo00<000000?ooo`3oool0203oool00240oooo
00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0o`3ooola0?ooo`8000008`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00P0
oooo000R0?ooo`<00000203oool4000000L0oooo00<000000?ooo`3oool0o`3ooolc0?ooo`<00000
7P3oool2000003T0oooo00<000000?ooo`3oool0203oool003P0oooo00<000000?ooo`3oool0o`3o
oolf0?ooo`8000006P3oool2000003/0oooo00<000000?ooo`3oool0203oool003P0oooo0`00003o
0?ooocP0oooo1000000C0?ooo`<00000?03oool2000000X0oooo000h0?ooo`030000003oool0oooo
0?l0oooo?03oool7000000D0oooo1`0000100?ooo`030000003oool0oooo00P0oooo000h0?ooo`03
0000003oool0oooo0?l0oooo@P3oool6000004L0oooo00<000000?ooo`3oool0203oool003P0oooo
00<000000?ooo`3oool0o`3ooon?0?ooo`030000003oool0oooo00P0oooo000h0?ooo`030000003o
ool0oooo0?l0ooooS`3oool00`000000oooo0?ooo`080?ooo`00>03oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`08
0?ooo`00>03oool3000000L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00D0oooo0P00000:0?ooo`00>03ooooo000009<000002P3oool00001\
\>"],
  ImageRangeCache->{{{0, 467.375}, {288.5, 0}} -> {-0.65757, -0.715063, \
0.00994889, 0.0153804}}],

Cell[BoxData[
    \(0.6974466615079924`\)], "Output"],

Cell[BoxData[
    \(1.0000113192469362`\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.476191 6.19502 6.22536 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.2619 -0.0125 -10.7813 -17.8125 ]
[.2619 -0.0125 10.7813 0 ]
[.5 -0.0125 -5.53125 -17.8125 ]
[.5 -0.0125 5.53125 0 ]
[.7381 -0.0125 -10.7813 -17.8125 ]
[.7381 -0.0125 10.7813 0 ]
[.97619 -0.0125 -5.53125 -17.8125 ]
[.97619 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.125 -35.625 ]
[.5 -0.0125 5.125 -17.8125 ]
[-0.0125 .09417 -38.3125 -8.90625 ]
[-0.0125 .09417 0 8.90625 ]
[-0.0125 .21867 -38.3125 -8.90625 ]
[-0.0125 .21867 0 8.90625 ]
[-0.0125 .34318 -38.3125 -8.90625 ]
[-0.0125 .34318 0 8.90625 ]
[-0.0125 .46769 -38.3125 -8.90625 ]
[-0.0125 .46769 0 8.90625 ]
[-0.0125 .5922 -31.25 -8.90625 ]
[-0.0125 .5922 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -56.125 -14.7188 ]
[-0.01875 .30902 -38.3125 14.7188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.125 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .09417 m
.00625 .09417 L
s
gsave
-0.0125 .09417 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.98) show
1.000 setlinewidth
grestore
0 .21867 m
.00625 .21867 L
s
gsave
-0.0125 .21867 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.96) show
1.000 setlinewidth
grestore
0 .34318 m
.00625 .34318 L
s
gsave
-0.0125 .34318 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.94) show
1.000 setlinewidth
grestore
0 .46769 m
.00625 .46769 L
s
gsave
-0.0125 .46769 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.92) show
1.000 setlinewidth
grestore
0 .5922 m
.00625 .5922 L
s
gsave
-0.0125 .5922 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .12529 m
.00375 .12529 L
s
0 .15642 m
.00375 .15642 L
s
0 .18755 m
.00375 .18755 L
s
0 .2498 m
.00375 .2498 L
s
0 .28093 m
.00375 .28093 L
s
0 .31205 m
.00375 .31205 L
s
0 .37431 m
.00375 .37431 L
s
0 .40543 m
.00375 .40543 L
s
0 .43656 m
.00375 .43656 L
s
0 .49881 m
.00375 .49881 L
s
0 .52994 m
.00375 .52994 L
s
0 .56107 m
.00375 .56107 L
s
0 .06304 m
.00375 .06304 L
s
0 .03191 m
.00375 .03191 L
s
0 .00079 m
.00375 .00079 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -122.938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.7188 12.9063 translate
90 rotate
-75.7188 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.063 17.500 moveto
(H) show
77.625 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.875 17.500 moveto
(L) show
88.438 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .09417 m
1 .09417 L
s
.99375 .21867 m
1 .21867 L
s
.99375 .34318 m
1 .34318 L
s
.99375 .46769 m
1 .46769 L
s
.99375 .5922 m
1 .5922 L
s
.125 Mabswid
.99625 .12529 m
1 .12529 L
s
.99625 .15642 m
1 .15642 L
s
.99625 .18755 m
1 .18755 L
s
.99625 .2498 m
1 .2498 L
s
.99625 .28093 m
1 .28093 L
s
.99625 .31205 m
1 .31205 L
s
.99625 .37431 m
1 .37431 L
s
.99625 .40543 m
1 .40543 L
s
.99625 .43656 m
1 .43656 L
s
.99625 .49881 m
1 .49881 L
s
.99625 .52994 m
1 .52994 L
s
.99625 .56107 m
1 .56107 L
s
.99625 .06304 m
1 .06304 L
s
.99625 .03191 m
1 .03191 L
s
.99625 .00079 m
1 .00079 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .09417 m
1 .09417 L
s
.5 Mabswid
.02381 .60332 m
.06244 .51821 L
.10458 .44088 L
.14415 .37996 L
.18221 .33006 L
.22272 .28469 L
.26171 .24732 L
.30316 .21329 L
.34309 .18515 L
.3815 .16174 L
.42237 .14016 L
.46172 .12214 L
.49955 .10699 L
.53984 .09287 L
.57861 .08096 L
.61984 .06985 L
.65954 .06045 L
.69774 .05244 L
.73838 .04488 L
.77751 .03842 L
.81909 .03232 L
.85916 .02709 L
.89771 .02257 L
.93871 .01826 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{468.375, 289.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007D00018B000`400?l00000o`00003oo`3ooooE
0?ooo`00o`3ooooE0?ooo`00o`3ooooE0?ooo`00o`3ooooE0?ooo`00o`3ooooE0?ooo`00o`3oool7
0?ooo`H00000b03oool00?l0oooo203oool01@000000oooo0?ooo`3oool000000<P0oooo003o0?oo
o`T0oooo00<000000?ooo`3oool0b@3oool00?l0oooo2@3oool00`000000oooo0?ooo`390?ooo`00
o`3oool:0?ooo`030000003oool0oooo0<P0oooo003o0?ooo`L0oooo00D000000?ooo`3oool0oooo
000000390?ooo`00o`3oool70?ooo`H00000b03oool00?l0ooooe@3oool00?l0ooooe@3oool00?l0
ooooe@3oool00?l0ooooe@3oool00?l0ooooe@3oool00?l0ooooe@3oool00?l0ooooe@3oool00?l0
ooooe@3oool00?l0ooooe@3oool00?l0ooooe@3oool00?l0ooooe@3oool004P0oooo0`00001H0?oo
o`<000000`3oool010000000oooo0?ooo`3oool3000005L0oooo0`00001H0?ooo`<000000`3oool0
10000000oooo0?ooo`3oool3000005H0oooo1@00000:0?ooo`00A`3oool01@000000oooo0?ooo`3o
ool0000005H0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo05@0oooo
00@000000?ooo`3oool000002P3oool004L0oooo00D000000?ooo`3oool0oooo0000001F0?ooo`05
0000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo
00X0oooo00170?ooo`050000003oool0oooo0?ooo`000000EP3oool01@000000oooo0?ooo`3oool0
000000X0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`090?ooo`00A`3oool01@00
0000oooo0?ooo`3oool0000005H0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003o
ool0oooo05@0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool02@3oool004L0oooo00D000000?ooo`3oool0oooo0000
001F0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`1E0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo00P0oooo00170?ooo`050000003oool0oooo0?ooo`000000EP3oool01@000000oooo
0?ooo`3oool0000000H0oooo0`00001H0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool01P3oool3000005X0oooo00<000000?ooo`3oool0203oool004L0oooo00D000000?ooo`3oool0
oooo0000001F0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1J0?oo
o`030000003oool0oooo00P0oooo00170?ooo`050000003oool0oooo0?ooo`000000EP3oool01@00
0000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0EP3oool2000005T0oooo0P000009
0?ooo`030000003oool0oooo05D0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`00B03oool3
000005P0oooo0`0000080?ooo`@00000EP3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo00L0oooo1000001E0?ooo`<000002`3oool00?l0ooooe@3oool00?l0ooooe@3oool00?l0oooo
e@3oool00?l0ooooe@3oool00?l0ooooe@3oool00?l0ooooe@3oool00?l0ooooe@3oool00?l0oooo
e@3oool00400ooooo`00002C00000080oooo00100?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00H0oooo0@000001
0?ooo`40oooo00100?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0G03oool00`00
0000oooo0?ooo`1M0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0G@3oool00`00
0000oooo0?ooo`060?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`3o0?ooohl0
oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo0?l0ooooS`3oool100000040oooo
0@3oool00400oooo00<000000?ooo`3oool0o`3ooon?0?ooo`4000000@3oool10?ooo`00@03oool0
0`000000oooo0?ooo`3o0?ooogl0oooo200000080?ooo`4000000@3oool10?ooo`00@03oool00`00
0000oooo0?ooo`3o0?ooog<0oooo3000000@0?ooo`4000000@3oool10?ooo`00@03oool00`000000
oooo0?ooo`3o0?ooof/0oooo2000000L0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo
0?ooo`3o0?ooof<0oooo2000000T0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?oo
o`3o0?oooe/0oooo2000000/0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`3o
0?oooe@0oooo1`00000d0?ooo`4000000@3oool10?ooo`00@03oool300000?l0ooooC03oool80000
03X0oooo0P0000020?ooo`00@03oool00`000000oooo0?ooo`3o0?oood<0oooo2@0000130?ooo`40
00000@3oool10?ooo`00@03oool00`000000oooo0?ooo`3o0?oooc/0oooo2000001<0?ooo`400000
0@3oool10?ooo`00@03oool00`000000oooo0?ooo`3o0?oooc@0oooo1`00001D0?ooo`4000000@3o
ool10?ooo`00@03oool00`000000oooo0?ooo`3o0?ooobl0oooo1@00001K0?ooo`4000000@3oool1
0?ooo`00@03oool00`000000oooo0?ooo`3o0?ooobX0oooo1@00001P0?ooo`4000000@3oool10?oo
o`00@03oool00`000000oooo0?ooo`3o0?ooobD0oooo1@00001U0?ooo`4000000@3oool10?ooo`00
@03oool00`000000oooo0?ooo`3o0?oooal0oooo1P00001Z0?ooo`4000000@3oool10?ooo`00@03o
ool00`000000oooo0?ooo`3o0?oooaT0oooo1P00001`0?ooo`4000000@3oool10?ooo`00@03oool0
0`000000oooo0?ooo`3o0?oooa@0oooo1@00001f0?ooo`4000000@3oool10?ooo`00@03oool00`00
0000oooo0?ooo`3o0?ooo`l0oooo1@00001k0?ooo`4000000@3oool10?ooo`00@03oool00`000000
oooo0?ooo`3o0?ooo`X0oooo1@0000200?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo
0?ooo`3o0?ooo`H0oooo100000250?ooo`4000000@3oool10?ooo`00@03oool300000?l0oooo0P3o
ool4000008P0oooo0P0000020?ooo`00@03oool00`000000oooo0?ooo`3m0?ooo`@00000S@3oool1
00000040oooo0@3oool00400oooo00<000000?ooo`3oool0n@3oool400000940oooo0@0000010?oo
o`40oooo00100?ooo`030000003oool0oooo0?@0oooo1@00002E0?ooo`4000000@3oool10?ooo`00
@03oool00`000000oooo0?ooo`3`0?ooo`@00000VP3oool100000040oooo0@3oool00400oooo00<0
00000?ooo`3oool0k03oool4000009h0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0
oooo0>P0oooo1000002R0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`3T0?oo
o`@00000YP3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0h@3oool300000:X0
oooo0@0000010?ooo`40oooo000S0?ooo`<000000`3oool010000000oooo0?ooo`3oool2000000H0
oooo0`0000080?ooo`030000003oool0oooo0=h0oooo0`00002]0?ooo`4000000@3oool10?ooo`00
8P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0f`3oool300000;00oooo0@0000010?oo
o`40oooo000R0?ooo`050000003oool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3H0?ooo`<00000/`3oool1
00000040oooo0@3oool001P0oooo1`0000030?ooo`050000003oool0oooo0?ooo`0000001`3oool4
00000080oooo00D000000?ooo`3oool0oooo000000070?ooool00000T`0000020?ooo`008P3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0000000P0oooo00<000000?ooo`3oool0d`3oool200000;T0oooo0@0000010?ooo`40oooo
000R0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3@0?ooo`<00000^`3oool100000040
oooo0@3oool00280oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?oo
o`0000000`3oool00`000000oooo000000080?ooo`030000003oool0oooo0<d0oooo0`00002n0?oo
o`4000000@3oool10?ooo`008P3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?oo
o`3;0?ooo`800000`@3oool100000040oooo0@3oool00280oooo00D000000?ooo`3oool0oooo0000
00060?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000L0
oooo00<000000?ooo`3oool0b03oool300000<<0oooo0@0000010?ooo`40oooo000S0?ooo`<00000
203oool3000000@0oooo0`0000080?ooo`030000003oool0oooo0<D0oooo0`0000360?ooo`400000
0@3oool10?ooo`00@03oool00`000000oooo0?ooo`330?ooo`800000b@3oool100000040oooo0@3o
ool00400oooo00<000000?ooo`3oool0`03oool300000</0oooo0@0000010?ooo`40oooo00100?oo
o`030000003oool0oooo0;h0oooo0P00003>0?ooo`4000000@3oool10?ooo`00@03oool00`000000
oooo0?ooo`2k0?ooo`<00000d03oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0
^@3oool200000=<0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo0;H0oooo0`00
003E0?ooo`4000000@3oool10?ooo`00@03oool300000;@0oooo0P00003G0?ooo`8000000P3oool0
0400oooo00<000000?ooo`3oool0/P3oool200000=X0oooo0@0000010?ooo`40oooo00100?ooo`03
0000003oool0oooo0;00oooo0P00003L0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo
0?ooo`2]0?ooo`<00000gP3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0Z`3o
ool200000>40oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo0:T0oooo0P00003S
0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`2W0?ooo`800000i@3oool10000
0040oooo0@3oool00400oooo00<000000?ooo`3oool0Y@3oool200000>L0oooo0@0000010?ooo`40
oooo00100?ooo`030000003oool0oooo0:<0oooo0P00003Y0?ooo`4000000@3oool10?ooo`00@03o
ool00`000000oooo0?ooo`2Q0?ooo`800000j`3oool100000040oooo0@3oool00400oooo00<00000
0?ooo`3oool0W`3oool200000>d0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo
09d0oooo0P00003_0?ooo`4000000@3oool10?ooo`00@03oool3000009/0oooo0P00003`0?ooo`80
00000P3oool00400oooo00<000000?ooo`3oool0V@3oool200000?<0oooo0@0000010?ooo`40oooo
00100?ooo`030000003oool0oooo09L0oooo0P00003e0?ooo`4000000@3oool10?ooo`00@03oool0
0`000000oooo0?ooo`2F0?ooo`030000003oool0oooo0?D0oooo0@0000010?ooo`40oooo00100?oo
o`030000003oool0oooo09@0oooo0P00003h0?ooo`4000000@3oool10?ooo`00@03oool00`000000
oooo0?ooo`2B0?ooo`800000nP3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0
T@3oool00`000000oooo0?ooo`3j0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?oo
o`2?0?ooo`800000o@3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0S@3oool2
00000?l0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo08`0oooo00<000000?oo
o`3oool0o`3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0RP3oool200000?l0
oooo0`3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0R03oool200000?l0oooo
1@3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?oo
o`3o0?ooo`D0oooo0@0000010?ooo`40oooo00100?ooo`<00000Q@3oool200000?l0oooo1`3oool2
00000080oooo00100?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0o`3oool80?oo
o`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`220?ooo`800000o`3oool;0?ooo`40
00000@3oool10?ooo`00@03oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0?l0oooo
2`3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0P03oool00`000000oooo0?oo
o`3o0?ooo``0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo07h0oooo0P00003o
0?ooo`l0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo07d0oooo00<000000?oo
o`3oool0o`3oool?0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`1k0?ooo`80
0000o`3ooolB0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`1j0?ooo`030000
003oool0oooo0?l0oooo4P3oool100000040oooo0@3oool002<0oooo0`0000030?ooo`040000003o
ool0oooo0?ooo`8000001P3oool3000000P0oooo00<000000?ooo`3oool0N03oool200000?l0oooo
5@3oool100000040oooo0@3oool00280oooo00D000000?ooo`3oool0oooo000000080?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo07L0
oooo00<000000?ooo`3oool0o`3ooolE0?ooo`4000000@3oool10?ooo`008P3oool01@000000oooo
0?ooo`3oool0000000T0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`3o0?oooaH0oooo0@0000010?oo
o`40oooo000H0?ooo`L000000`3oool01@000000oooo0?ooo`3oool0000000L0oooo100000020?oo
o`050000003oool0oooo0?ooo`0000001`3oool4000007<0oooo0P00003o0?oooaL0oooo0`000002
0?ooo`008P3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`1c0?ooo`030000
003oool0oooo0?l0oooo6@3oool100000040oooo0@3oool00280oooo00D000000?ooo`3oool0oooo
000000060?ooo`050000003oool0oooo0?ooo`0000000P3oool200000080oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0?l0oooo6P3oool100000040
oooo0@3oool00280oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0000000000080?ooo`030000003oool0oooo0740oooo00<00000
0?ooo`3oool0o`3ooolK0?ooo`4000000@3oool10?ooo`008P3oool01@000000oooo0?ooo`3oool0
000000H0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0L03oool00`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`40oooo000R
0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1^0?ooo`800000o`3ooolO0?ooo`400000
0@3oool10?ooo`008`3oool3000000P0oooo0`0000060?ooo`8000001`3oool00`000000oooo0?oo
o`1]0?ooo`030000003oool0oooo0?l0oooo7`3oool100000040oooo0@3oool00400oooo00<00000
0?ooo`3oool0K03oool00`000000oooo0?ooo`3o0?ooob00oooo0@0000010?ooo`40oooo00100?oo
o`030000003oool0oooo06/0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`4000000@3oool10?oo
o`00@03oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0?l0oooo8P3oool100000040
oooo0@3oool00400oooo00<000000?ooo`3oool0J03oool200000?l0oooo9@3oool100000040oooo
0@3oool00400oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`3o0?ooobD0oooo0@00
00010?ooo`40oooo00100?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0o`3ooolV
0?ooo`4000000@3oool10?ooo`00@03oool3000006D0oooo00<000000?ooo`3oool0o`3ooolV0?oo
o`8000000P3oool00400oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`3o0?ooobP0
oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0
o`3ooolY0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`1R0?ooo`030000003o
ool0oooo0?l0oooo:P3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0H@3oool0
0`000000oooo0?ooo`3o0?ooob/0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo
0600oooo00<000000?ooo`3oool0o`3oool/0?ooo`4000000@3oool10?ooo`00@03oool00`000000
oooo0?ooo`1O0?ooo`030000003oool0oooo0?l0oooo;@3oool100000040oooo0@3oool00400oooo
00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3o0?ooobh0oooo0@0000010?ooo`40oooo
00100?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0o`3oool_0?ooo`4000000@3o
ool10?ooo`00@03oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0?l0oooo<03oool1
00000040oooo0@3oool00400oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`3o0?oo
oc40oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool0o`3ooolb0?ooo`4000000@3oool10?ooo`001`3oool00`000000oooo0?ooo`0f0?ooo`<00000
F@3oool00`000000oooo0?ooo`3o0?oooc80oooo0P0000020?ooo`001`3oool3000003H0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`3o0?oooc@0oooo0@0000010?ooo`40oooo0007
0?ooo`030000003oool0oooo00<00000<`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo0?l0oooo=@3oool100000040oooo0@3oool000`0oooo0P00000b0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`4000000@3oool10?ooo`001`3oool00`000000
oooo0?ooo`02000003@0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`3o0?ooocL0
oooo0@0000010?ooo`40oooo00070?ooo`<00000=P3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo0?l0oooo>03oool100000040oooo0@3oool000L0oooo00<000000?ooo`3oool00`00
000c0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0o`3oooli0?ooo`4000000@3o
ool10?ooo`00303oool200000380oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`3o
0?ooocT0oooo0@0000010?ooo`40oooo00070?ooo`030000003oool0oooo00800000=03oool00`00
0000oooo0?ooo`1B0?ooo`030000003oool0oooo0?l0oooo>P3oool100000040oooo0@3oool000L0
oooo0`00000f0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0o`3ooolk0?ooo`40
00000@3oool10?ooo`001`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0500oooo
00<000000?ooo`3oool0o`3oooll0?ooo`4000000@3oool10?ooo`001P3oool900000340oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`3o0?ooocd0oooo0@0000010?ooo`40oooo0005
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`1>
0?ooo`030000003oool0oooo0?l0oooo?P3oool100000040oooo0@3oool000@0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0]0?ooo`<00000C@3oool00`000000oooo0?ooo`3o0?oo
och0oooo0P0000020?ooo`001`3oool2000000@0oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`1<0?ooo`030000003oool0oooo0?l0oooo@03oool100000040oooo0@3oool000L0oooo
00<000000?ooo`3oool00P3oool200000380oooo00<000000?ooo`3oool0B`3oool00`000000oooo
0?ooo`3o0?oood40oooo0@0000010?ooo`40oooo00070?ooo`030000003oool0oooo0080000000<0
oooo0000003oool0<@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0oooo@@3o
ool100000040oooo0@3oool000L0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool1
0?ooo`001`3oool2000000@0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo0?l0oooo@`3oool100000040oooo0@3oool000L0oooo00<000000?ooo`3o
ool00P3oool200000380oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`3o0?oood@0
oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0
o`3ooom50?ooo`4000000@3oool10?ooo`00103oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`3o0?ooodH0oooo0@00
00010?ooo`40oooo00050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool3
000000<0oooo00@000000?ooo`3oool0oooo0P0000080?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`3o0?ooodL0oooo0@0000010?ooo`40oooo0006
0?ooo`T000004`3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0o`3o
oom70?ooo`4000000@3oool10?ooo`008P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool0o`3ooom80?ooo`4000000@3oool10?ooo`00603oool7000000<0oooo00D00000
0?ooo`3oool0oooo000000070?ooo`@0000000<0oooo000000000000100000070?ooo`@00000@P3o
ool00`000000oooo0?ooo`3o0?ooodL0oooo0`0000020?ooo`008P3oool01@000000oooo0?ooo`3o
ool0000000H0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0?l0ooooBP3oool100000040
oooo0@3oool00280oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0o`3ooom;0?ooo`4000000@3oool10?ooo`008P3oool01@000000oooo0?ooo`3oool0
000000H0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0000000P0oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`3o0?oood/0oooo0@0000010?ooo`40oooo000R
0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`000000203oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0?l0oooo
C03oool100000040oooo0@3oool00280oooo00D000000?ooo`3oool0oooo000000060?ooo`050000
003oool0oooo0?ooo`000000103oool2000000P0oooo00<000000?ooo`3oool0?`3oool00`000000
oooo0?ooo`3o0?ooodd0oooo0@0000010?ooo`40oooo000S0?ooo`<00000203oool3000000H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0?l0oooo
CP3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?oo
o`3o0?ooodl0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0o`3ooom?0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo0?l0ooooD03oool100000040oooo0@3oool00400oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`3o0?oooe40oooo0@0000010?ooo`40oooo00100?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool0o`3ooomB0?ooo`4000000@3oool10?ooo`00@03o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0?l0ooooD`3oool100000040oooo0@3o
ool00400oooo0`00000i0?ooo`030000003oool0oooo0?l0ooooDP3oool200000080oooo00100?oo
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool0o`3ooomD0?ooo`4000000@3oool10?oo
o`00@03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0?l0ooooE@3oool100000040
oooo0@3oool00400oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`3o0?oooeH0oooo
0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0o`3o
oomF0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo0?l0ooooE`3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`3o0?oooeP0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool0o`3ooomH0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo
0?ooo`0c0?ooo`030000003oool0oooo0?l0ooooF@3oool100000040oooo0@3oool00400oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`3o0?oooeX0oooo0@0000010?ooo`40oooo0010
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`4000000@3oool1
0?ooo`00@03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0?l0ooooF`3oool10000
0040oooo0@3oool00400oooo0`00000`0?ooo`030000003oool0oooo0?l0ooooF`3oool200000080
oooo00100?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0o`3ooomL0?ooo`400000
0@3oool10?ooo`00@03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0?l0ooooG@3o
ool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`3o
0?oooeh0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool0o`3ooomN0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo0?l0ooooG`3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`3o0?ooof00oooo0@0000010?ooo`40oooo00100?ooo`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool0o`3ooomP0?ooo`4000000@3oool10?ooo`00@03oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0ooooH@3oool100000040oooo0@3oool0
0400oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`3o0?ooof80oooo0@0000010?oo
o`40oooo00100?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0o`3ooomR0?ooo`40
00000@3oool10?ooo`00@03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0oooo
H`3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`3o0?ooof@0oooo0@0000010?ooo`40oooo00100?ooo`<00000:03oool00`000000oooo0?ooo`3o
0?ooof<0oooo0P0000020?ooo`00@03oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
0?l0ooooI@3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`3o0?ooofH0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0o`3ooomV0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo0?l0ooooI`3oool100000040oooo0@3oool00400oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`3o0?ooofL0oooo0@0000010?ooo`40oooo00100?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0o`3ooomX0?ooo`4000000@3oool10?oo
o`00@03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0?l0ooooJ03oool100000040
oooo0@3oool00400oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`3o0?ooofT0oooo
0@0000010?ooo`40oooo000S0?ooo`<000000`3oool010000000oooo0?ooo`3oool2000000D0oooo
1@0000070?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0o`3ooomY0?ooo`400000
0@3oool10?ooo`008P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool0o`3ooomZ0?ooo`4000000@3oool10?ooo`008P3oool01@000000oooo0?ooo`3oool0000000T0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool0o`3ooomZ0?ooo`4000000@3oool10?ooo`00603oool7000000<0oooo
00D000000?ooo`3oool0oooo000000070?ooo`@000001@3oool00`000000oooo0?ooo`060?ooo`@0
0000803oool00`000000oooo0?ooo`3o0?ooofT0oooo0`0000020?ooo`008P3oool01@000000oooo
0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`3o0?ooof`0oooo0@0000010?oo
o`40oooo000R0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0
000000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo0?l0ooooK03oool100000040oooo0@3oool00280oooo00D000000?ooo`3oool0oooo00000006
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`4000000@3oool10?ooo`008P3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3o0?ooofd0oooo
0@0000010?ooo`40oooo000R0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo
0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0o`3ooom^0?ooo`4000000@3oool10?ooo`008`3oool3000000P0
oooo0`0000040?ooo`<00000203oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0?l0
ooooKP3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`3o0?ooofl0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0o`3ooom_0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo0?l0ooooL03oool100000040oooo0@3oool00400oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`3o0?ooog40oooo0@0000010?ooo`40oooo00100?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0o`3oooma0?ooo`4000000@3oool10?ooo`00
@03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0?l0ooooLP3oool100000040oooo
0@3oool00400oooo0`00000J0?ooo`030000003oool0oooo0?l0ooooL@3oool200000080oooo0010
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0o`3ooomc0?ooo`4000000@3oool1
0?ooo`00@03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0ooooL`3oool10000
0040oooo0@3oool00400oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`3o0?ooog@0
oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
o`3ooomd0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo0?l0ooooM@3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`3o0?ooogD0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool0o`3ooomf0?ooo`4000000@3oool10?ooo`00@03oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0ooooMP3oool100000040oooo0@3oool00400oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3o0?ooogL0oooo0@0000010?ooo`40oooo
00100?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3ooomg0?ooo`4000000@3o
ool10?ooo`00@03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0ooooN03oool1
00000040oooo0@3oool00400oooo0`00000D0?ooo`030000003oool0oooo0?l0ooooM`3oool20000
0080oooo00100?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0o`3ooomi0?ooo`40
00000@3oool10?ooo`00@03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0oooo
N@3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`3o0?ooogT0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0o`3ooomj0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo0?l0ooooNP3oool100000040oooo0@3oool00400oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`3o0?ooog/0oooo0@0000010?ooo`40oooo00100?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0o`3ooomk0?ooo`4000000@3oool10?ooo`00@03o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0ooooO03oool100000040oooo0@3o
ool00400oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?ooog`0oooo0@000001
0?ooo`40oooo00100?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0o`3oooml0?oo
o`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0
ooooO@3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`3o0?ooogd0oooo0@0000010?ooo`40oooo00100?ooo`<000003P3oool00`000000oooo0?oo
o`3o0?ooogd0oooo0P0000020?ooo`00@03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0?l0ooooOP3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`3o0?ooogl0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0o`3ooomo0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooO`3oool100000040oooo0@3oool00400oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?oooh00oooo0@0000010?ooo`40oooo0010
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooon00?ooo`4000000@3oool1
0?ooo`00@03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooP@3oool10000
0040oooo0@3oool00400oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?oooh40
oooo0@0000010?ooo`40oooo000Z0?ooo`<000000`3oool010000000oooo0?ooo`3oool2000000X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?oooh80oooo0@0000010?ooo`40
oooo000Y0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooon20?ooo`4000000@3oool10?ooo`00
:@3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooPP3oool100000040oooo0@3oool001l0oooo
1`0000030?ooo`050000003oool0oooo0?ooo`0000001`3oool4000000L0oooo100000080?ooo`03
0000003oool0oooo0?l0ooooP@3oool300000080oooo000Y0?ooo`050000003oool0oooo0?ooo`00
00001P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`3o0?oooh<0oooo0@0000010?ooo`40oooo000Y0?ooo`050000003oool0oooo0?oo
o`0000001P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`3o0?oooh@0oooo0@0000010?ooo`40oooo000Y0?ooo`050000003oool0oooo
0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`3o0?oooh@0oooo0@0000010?ooo`40oooo000Y0?ooo`050000003oool0
oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`3o0?ooohD0oooo0@0000010?ooo`40oooo000Y0?ooo`050000003o
ool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`3o0?ooohD0oooo0@0000010?ooo`40oooo000Z0?ooo`<00000
203oool3000000P0oooo00<000000?ooo`3oool0o`3ooon?0?ooo`4000000@3oool10?ooo`00@03o
ool00`000000oooo0?ooo`3o0?ooohl0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`1M0?ooo`030000003oool0
oooo05`0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`060?ooo`4000000@3oool1
0?ooo`00@03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`060?ooo`4000000@3oool10?ooo`00@03ooooo000009<0
00000P3oool00001\
\>"],
  ImageRangeCache->{{{0, 467.375}, {288.5, 0}} -> {-0.389958, -1.0114, \
0.00523628, 0.000400534}}]
}, Open  ]],

Cell[BoxData[
    \(\(fs[t1_] := fsol\  /. \ t -> t1\ ;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fs[t0]\)], "Input"],

Cell[BoxData[
    \(2.063341052518239`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ 
      Find\ chi\ square\ for\ given\ H \((z)\)\ \ *) \[IndentingNewLine]\(f[
          z_] := 1/hhz[z];\)\), "\n", 
    \(\(rr[zz_] := NIntegrate[f[z], {z, 0, zz}];\)\[IndentingNewLine]\n (*\ 
      Construct\ marginalization\ coefficients\ \((see\ \ astro - 
              ph/0401556\  .. )\)\ *) \), "\[IndentingNewLine]", 
    \(Clear[chi2fa, chi2fb, chi2fc]\), "\n", 
    \(\(chi2fa = 
        Sum[\((ld[i] - 5\ Log[10, rr[zz[i]]*\((1 + zz[i])\)])\)^2/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\n", 
    \(\(chi2fb = 
        Sum[\((ld[i] - 
                5\ Log[10, rr[zz[i]]*\((1 + zz[i])\)])\)/\((sld[i]^2)\), {i, 
            1, ndat}];\)\), "\n", 
    \(\(chi2fc = 
        Sum[1/\((sld[i]^2)\), {i, 1, ndat}];\)\[IndentingNewLine]\n (*\ 
      Construct\ function\ after\ marginalization, \ 
      find\ same\ result\ as\ with\ mb\ minimization\ *) \), "\
\[IndentingNewLine]", 
    \(chi2fm = chi2fa - chi2fb^2/chi2fc\), "\[IndentingNewLine]", 
    \(dchi2q10 = chi2fm - chi2l\)}], "Input"],

Cell[BoxData[
    \(178.16382913663983`\)], "Output"],

Cell[BoxData[
    \(1.0364577015861869`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ \(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(\
--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(-\(---\)\)\)\)\)\)\)\)\)\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)*) \[IndentingNewLine]\[IndentingNewLine] \
(*\ Find\ H \((z)\)\ for\ given\ slope\ s\ of\ the\ linear\ potential . \ 
            Present\ time\  = \ \(tt\ \((corresponds\ to\ a = 1)\) . \ 
              Run\ trials\ for\ initial\ condition\ for\ field\ fi\ \((f0)\)\ \
and\ initial\ time\ ti\ until\ we\ get\ field\ energy\ enf\  = \ \(0.7\ and\ \
H \((z = 0)\)\  = 
            1\ at\ present\ time\ \(\(tt\)\(.\)\)\)\)\ *) \[IndentingNewLine]\
\[IndentingNewLine] (*\ \(--\(--\(--\(--\ \ s\)\)\)\)\  = \ \(1.2\ \ \ --\) \
\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(---\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\ *) \
\[IndentingNewLine]\[IndentingNewLine]\(Clear[aa, fi, a, aad, aadd, fidas, 
        tas, f, rr, hht, hha];\)\), "\[IndentingNewLine]", 
    \(aa = a[t]; \ fi = f[t];\), "\n", 
    \(\(aad = D[aa, t];\)\), "\n", 
    \(\(aadd = D[aa, {t, 2}];\)\), "\n", 
    \(\(fid = D[fi, t];\)\), "\n", 
    \(\(fidd = D[fi, {t, 2}];\)\), "\n", 
    \(ti = 0.000025; \ t0 = 2.25;\), "\n", 
    \(\(f0 = \(-0.706\);\)\ \), "\n", 
    \(om0m = 0.3; \ ss = 1.2;\), "\n", 
    \(\(eq1 = 
        aadd/aa\  \[Equal] \(-\ \ fid^2\)\  - \ ss\ fi\  - \ 
            om0m/\((2\ aa^3)\);\)\), "\n", 
    \(\(eq2 = 
        fidd\ \  + \ \ \ 3\ \ fid\ \((aad/aa)\)\  - \ ss \[Equal] 
          0;\)\), "\n", 
    \(\(eqb1 = f[ti] == f0;\)\), "\n", 
    \(\(eqb2 = \(f'\)[ti] == 0;\)\), "\n", 
    \(\(eqb3 = 
        a[ti] \[Equal] \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((2/3)\);\)\), "\n", 
    \(\(eqb4 = \(a'\)[
            ti] \[Equal] \((2/
                3)\)\ \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((\(-1\)/
                  3)\);\)\), "\n", 
    \(\(sol2 = 
        NDSolve[{eq1, eq2, eqb1, eqb2, eqb3, eqb4}, {aa, fi}, {t, ti, t0}, 
          MaxSteps \[Rule] 10000000];\)\), "\n", 
    \(\(asol = Part[Evaluate[a[t] /. sol2], 1];\)\), "\n", 
    \(\(fsol = Part[Evaluate[f[t] /. sol2], 1];\)\), "\n", 
    \(\(dfsol = D[fsol, t];\)\), "\[IndentingNewLine]", 
    \(\(enf = 0.5\ dfsol^2\  - \ ss\ fsol;\)\), "\[IndentingNewLine]", 
    \(\(as[t1_] := asol\  /. \ t -> t1\ ;\)\), "\[IndentingNewLine]", 
    \(\(tt = Part[FindRoot[as[t] == 1, {t, 1}], 1, 2];\)\), "\n", 
    \(\(tas[a_] := 
        Part[FindRoot[as[t] \[Equal] a, {t, 1}], 1, 2];\)\), "\n", 
    \(\(hht[t1_] := D[asol, t]/asol\  /. \ t -> t1\ ;\)\), "\n", 
    \(\(hha[a_] := hht[tas[a]];\)\), "\[IndentingNewLine]", 
    \(\(hhz[z_] := hha[1/\((z + 1)\)];\)\), "\[IndentingNewLine]", 
    \(enf\  /. \ t \[Rule] tt\), "\[IndentingNewLine]", 
    \(hhz[0]\), "\[IndentingNewLine]", 
    \(\(enf = 0.5\ dfsol^2\  - \ ss\ fsol;\)\), "\n", 
    \(\(ppf = 0.5\ dfsol^2\  + \ ss\ fsol;\)\), "\n", 
    \(\(wft[t1_] := ppf/enf\  /. \ t -> t1\ ;\)\ \), "\n", 
    \(\(wfa[a_] := wft[tas[a]];\)\), "\n", 
    \(\(wfz[z_] := wfa[1/\((z + 1)\)];\)\), "\n", 
    \(\(plw12q = 
        Plot[wfz[z], {z, 0, 2}, Frame \[Rule] True, PlotRange \[Rule] All, 
          FrameLabel \[Rule] {"\<z\>", "\<w(z)\>"}];\)\)}], "Input"],

Cell[BoxData[
    \(0.7012341120028767`\)], "Output"],

Cell[BoxData[
    \(1.0019035069922555`\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.476191 4.35747 4.3859 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.2619 -0.0125 -10.7813 -17.8125 ]
[.2619 -0.0125 10.7813 0 ]
[.5 -0.0125 -5.53125 -17.8125 ]
[.5 -0.0125 5.53125 0 ]
[.7381 -0.0125 -10.7813 -17.8125 ]
[.7381 -0.0125 10.7813 0 ]
[.97619 -0.0125 -5.53125 -17.8125 ]
[.97619 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.125 -35.625 ]
[.5 -0.0125 5.125 -17.8125 ]
[-0.0125 .05929 -38.3125 -8.90625 ]
[-0.0125 .05929 0 8.90625 ]
[-0.0125 .14701 -38.3125 -8.90625 ]
[-0.0125 .14701 0 8.90625 ]
[-0.0125 .23472 -38.3125 -8.90625 ]
[-0.0125 .23472 0 8.90625 ]
[-0.0125 .32244 -38.3125 -8.90625 ]
[-0.0125 .32244 0 8.90625 ]
[-0.0125 .41016 -31.25 -8.90625 ]
[-0.0125 .41016 0 8.90625 ]
[-0.0125 .49788 -38.3125 -8.90625 ]
[-0.0125 .49788 0 8.90625 ]
[-0.0125 .5856 -38.3125 -8.90625 ]
[-0.0125 .5856 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -56.125 -14.7188 ]
[-0.01875 .30902 -38.3125 14.7188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.125 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .05929 m
.00625 .05929 L
s
gsave
-0.0125 .05929 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.98) show
1.000 setlinewidth
grestore
0 .14701 m
.00625 .14701 L
s
gsave
-0.0125 .14701 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.96) show
1.000 setlinewidth
grestore
0 .23472 m
.00625 .23472 L
s
gsave
-0.0125 .23472 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.94) show
1.000 setlinewidth
grestore
0 .32244 m
.00625 .32244 L
s
gsave
-0.0125 .32244 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.92) show
1.000 setlinewidth
grestore
0 .41016 m
.00625 .41016 L
s
gsave
-0.0125 .41016 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
1.000 setlinewidth
grestore
0 .49788 m
.00625 .49788 L
s
gsave
-0.0125 .49788 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.88) show
1.000 setlinewidth
grestore
0 .5856 m
.00625 .5856 L
s
gsave
-0.0125 .5856 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.86) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .08122 m
.00375 .08122 L
s
0 .10315 m
.00375 .10315 L
s
0 .12508 m
.00375 .12508 L
s
0 .16894 m
.00375 .16894 L
s
0 .19087 m
.00375 .19087 L
s
0 .2128 m
.00375 .2128 L
s
0 .25665 m
.00375 .25665 L
s
0 .27858 m
.00375 .27858 L
s
0 .30051 m
.00375 .30051 L
s
0 .34437 m
.00375 .34437 L
s
0 .3663 m
.00375 .3663 L
s
0 .38823 m
.00375 .38823 L
s
0 .43209 m
.00375 .43209 L
s
0 .45402 m
.00375 .45402 L
s
0 .47595 m
.00375 .47595 L
s
0 .51981 m
.00375 .51981 L
s
0 .54174 m
.00375 .54174 L
s
0 .56367 m
.00375 .56367 L
s
0 .03736 m
.00375 .03736 L
s
0 .01543 m
.00375 .01543 L
s
0 .60753 m
.00375 .60753 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -122.938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.7188 12.9063 translate
90 rotate
-75.7188 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.063 17.500 moveto
(H) show
77.625 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.875 17.500 moveto
(L) show
88.438 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .05929 m
1 .05929 L
s
.99375 .14701 m
1 .14701 L
s
.99375 .23472 m
1 .23472 L
s
.99375 .32244 m
1 .32244 L
s
.99375 .41016 m
1 .41016 L
s
.99375 .49788 m
1 .49788 L
s
.99375 .5856 m
1 .5856 L
s
.125 Mabswid
.99625 .08122 m
1 .08122 L
s
.99625 .10315 m
1 .10315 L
s
.99625 .12508 m
1 .12508 L
s
.99625 .16894 m
1 .16894 L
s
.99625 .19087 m
1 .19087 L
s
.99625 .2128 m
1 .2128 L
s
.99625 .25665 m
1 .25665 L
s
.99625 .27858 m
1 .27858 L
s
.99625 .30051 m
1 .30051 L
s
.99625 .34437 m
1 .34437 L
s
.99625 .3663 m
1 .3663 L
s
.99625 .38823 m
1 .38823 L
s
.99625 .43209 m
1 .43209 L
s
.99625 .45402 m
1 .45402 L
s
.99625 .47595 m
1 .47595 L
s
.99625 .51981 m
1 .51981 L
s
.99625 .54174 m
1 .54174 L
s
.99625 .56367 m
1 .56367 L
s
.99625 .03736 m
1 .03736 L
s
.99625 .01543 m
1 .01543 L
s
.99625 .60753 m
1 .60753 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .60332 m
.06244 .51254 L
.10458 .43237 L
.14415 .37052 L
.18221 .3206 L
.22272 .27571 L
.26171 .23904 L
.30316 .20585 L
.34309 .17855 L
.3815 .1559 L
.42237 .13508 L
.46172 .11773 L
.49955 .10317 L
.53984 .08961 L
.57861 .07819 L
.61984 .06753 L
.65954 .05852 L
.69774 .05084 L
.73838 .0436 L
.77751 .03742 L
.81909 .03157 L
.85916 .02656 L
.89771 .02224 L
.93871 .01811 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{522.625, 323},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008:0001@b000`400?l00000o`00003oo`3ooooo
0?ooo``0oooo003o0?ooool0oooo303oool00?l0ooooo`3oool<0?ooo`00o`3ooooo0?ooo``0oooo
003o0?ooool0oooo303oool00?l0ooooo`3oool<0?ooo`00o`3ooolR0?ooo`H00000h`3oool00?l0
oooo8`3oool01@000000oooo0?ooo`3oool000000><0oooo003o0?ooob@0oooo00<000000?ooo`3o
ool0i03oool00?l0oooo903oool00`000000oooo0?ooo`3T0?ooo`00o`3ooolU0?ooo`030000003o
ool0oooo0><0oooo003o0?ooob80oooo00D000000?ooo`3oool0oooo0000003T0?ooo`00o`3ooolR
0?ooo`H00000h`3oool00?l0ooooo`3oool<0?ooo`00o`3ooooo0?ooo``0oooo003o0?ooool0oooo
303oool00?l0ooooo`3oool<0?ooo`00o`3ooooo0?ooo``0oooo003o0?ooool0oooo303oool00?l0
ooooo`3oool<0?ooo`00o`3ooooo0?ooo``0oooo003o0?ooool0oooo303oool00?l0ooooo`3oool<
0?ooo`00o`3ooooo0?ooo``0oooo001;0?ooo`<00000I03oool3000000<0oooo00@000000?ooo`3o
ool0oooo0`00001T0?ooo`<00000I03oool3000000<0oooo00@000000?ooo`3oool0oooo0`00001S
0?ooo`D000002`3oool004X0oooo00D000000?ooo`3oool0oooo0000001R0?ooo`050000003oool0
oooo0?ooo`0000002@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo06@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`1Q0?ooo`040000003oool0oooo000000/0oooo
001:0?ooo`050000003oool0oooo0?ooo`000000HP3oool01@000000oooo0?ooo`3oool0000000X0
oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0;0?ooo`00BP3oool01@000000oooo
0?ooo`3oool000000680oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo
0640oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0680oooo00<000000?ooo`3oool02P3oool004X0oooo00D000000?ooo`3oool0oooo0000001R0?oo
o`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0
oooo06@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0
oooo00X0oooo001:0?ooo`050000003oool0oooo0?ooo`000000HP3oool01@000000oooo0?ooo`3o
ool0000000T0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`1T0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`090?ooo`00BP3oool0
1@000000oooo0?ooo`3oool000000680oooo00D000000?ooo`3oool0oooo000000060?ooo`<00000
I@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00H0oooo0`00001W0?ooo`030000
003oool0oooo00T0oooo001:0?ooo`050000003oool0oooo0?ooo`000000HP3oool01@000000oooo
0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`1T0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`090?ooo`00
BP3oool01@000000oooo0?ooo`3oool000000680oooo00D000000?ooo`3oool0oooo000000070?oo
o`030000003oool0oooo06<0oooo0P00001U0?ooo`8000002@3oool00`000000oooo0?ooo`1R0?oo
o`050000003oool0oooo0?ooo`0000002`3oool004/0oooo0`00001T0?ooo`<00000203oool40000
06<0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`070?ooo`@00000HP3oool30000
00`0oooo003o0?ooool0oooo303oool00?l0ooooo`3oool<0?ooo`00o`3ooooo0?ooo``0oooo003o
0?ooool0oooo303oool00?l0ooooo`3oool<0?ooo`00o`3ooooo0?ooo``0oooo003o0?ooool0oooo
303oool00?l0ooooo`3oool<0?ooo`00@@3ooooo00000<T000000@3oool00440oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0203oool100000040oooo00110?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo0@0000010?ooo`00
@@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0
JP3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0
203oool100000040oooo00110?ooo`030000003oool0oooo0?l0ooooa@3oool100000040oooo0011
0?ooo`030000003oool0oooo0?l0ooooa@3oool100000040oooo00110?ooo`030000003oool0oooo
0?l0oooo]P3oool5000000X0oooo0@0000010?ooo`00@@3oool300000?l0oooo[P3oool8000000d0
oooo0`0000010?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooojD0oooo2@00000G0?ooo`400000
0@3oool00440oooo00<000000?ooo`3oool0o`3ooonK0?ooo`X00000803oool100000040oooo0011
0?ooo`030000003oool0oooo0?l0ooooTP3oool9000002X0oooo0@0000010?ooo`00@@3oool00`00
0000oooo0?ooo`3o0?ooohX0oooo2000000c0?ooo`4000000@3oool00440oooo00<000000?ooo`3o
ool0o`3ooon10?ooo`T00000>`3oool100000040oooo00110?ooo`030000003oool0oooo0?l0oooo
M`3oool:000004@0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooog00oooo1`00
001>0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0o`3ooomZ0?ooo`H00000E@3oool1
00000040oooo00110?ooo`030000003oool0oooo0?l0ooooI03oool6000005/0oooo0@0000010?oo
o`00@@3oool300000?l0ooooGP3oool6000005l0oooo0`0000010?ooo`00@@3oool00`000000oooo
0?ooo`3o0?oooeP0oooo1P00001W0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0o`3o
oomB0?ooo`H00000K@3oool100000040oooo00110?ooo`030000003oool0oooo0?l0ooooB`3oool7
000007<0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooodD0oooo1P00001j0?oo
o`4000000@3oool00440oooo00<000000?ooo`3oool0o`3ooolo0?ooo`H00000P03oool100000040
oooo000S0?ooo`<000000`3oool010000000oooo0?ooo`3oool2000000H0oooo0`0000090?ooo`03
0000003oool0oooo0?l0oooo>@3oool6000008H0oooo0@0000010?ooo`008P3oool01@000000oooo
0?ooo`3oool0000000P0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00P0oooo00<000000?ooo`3oool0o`3ooolc0?ooo`H00000S03oool100000040oooo000R0?ooo`05
0000003oool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooobd0oooo1P00002B0?ooo`4000000@3oool0
01T0oooo1`0000020?ooo`050000003oool0oooo0?ooo`0000001`3oool400000080oooo00D00000
0?ooo`3oool0oooo000000080?ooo`030000003oool0oooo0?l0oooo:03oool5000009P0oooo0@00
00010?ooo`008P3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0000000T0oooo1000003o0?ooob<0oooo1000002J0?ooo`@00000
0@3oool00280oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo7`3oool500000:40
oooo0@0000010?ooo`008P3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool0o`3ooolK0?oo
o`@00000YP3oool100000040oooo000R0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@00
0000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003o
ool0oooo0?l0oooo5`3oool400000:X0oooo0@0000010?ooo`008P3oool01@000000oooo0?ooo`3o
ool0000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`00
0000203oool00`000000oooo0?ooo`3o0?oooa<0oooo1000002^0?ooo`4000000@3oool002<0oooo
0`0000080?ooo`<00000103oool3000000T0oooo00<000000?ooo`3oool0o`3oool?0?ooo`@00000
/P3oool100000040oooo00110?ooo`030000003oool0oooo0?l0oooo2`3oool400000;H0oooo0@00
00010?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo1000002j0?ooo`4000000@3oool0
0440oooo00<000000?ooo`3oool0o`3oool40?ooo`<00000_P3oool100000040oooo00110?ooo`03
0000003oool0oooo0?l0oooo0@3oool300000<40oooo0@0000010?ooo`00@@3oool300000?d0oooo
0`0000320?ooo`<000000@3oool00440oooo00<000000?ooo`3oool0n`3oool200000<L0oooo0@00
00010?ooo`00@@3oool00`000000oooo0?ooo`3h0?ooo`<00000b@3oool100000040oooo00110?oo
o`030000003oool0oooo0?D0oooo0`00003<0?ooo`4000000@3oool00440oooo00<000000?ooo`3o
ool0lP3oool300000<l0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`3_0?ooo`<00000
dP3oool100000040oooo00110?ooo`030000003oool0oooo0>`0oooo0`00003E0?ooo`4000000@3o
ool00440oooo00<000000?ooo`3oool0j03oool400000=P0oooo0@0000010?ooo`00@@3oool00`00
0000oooo0?ooo`3U0?ooo`<00000g03oool100000040oooo00110?ooo`030000003oool0oooo0>80
oooo0`00003O0?ooo`4000000@3oool00440oooo0`00003O0?ooo`<00000h03oool300000040oooo
00110?ooo`030000003oool0oooo0=`0oooo0`00003U0?ooo`4000000@3oool00440oooo00<00000
0?ooo`3oool0f@3oool300000>P0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`3G0?oo
o`800000j`3oool100000040oooo00110?ooo`030000003oool0oooo0=@0oooo0`00003]0?ooo`40
00000@3oool00440oooo00<000000?ooo`3oool0d@3oool300000?00oooo0@0000010?ooo`00@@3o
ool00`000000oooo0?ooo`3>0?ooo`<00000l`3oool100000040oooo00110?ooo`030000003oool0
oooo0<`0oooo0P00003f0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0bP3oool20000
0?P0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`380?ooo`800000nP3oool100000040
oooo00110?ooo`<00000a@3oool300000?X0oooo0`0000010?ooo`00@@3oool00`000000oooo0?oo
o`330?ooo`800000o`3oool100000040oooo00110?ooo`030000003oool0oooo0<40oooo0P00003o
0?ooo`80oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`2o0?ooo`800000o`3oool40?oo
o`4000000@3oool00440oooo00<000000?ooo`3oool0_@3oool200000?l0oooo1P3oool100000040
oooo00110?ooo`030000003oool0oooo0;/0oooo0P00003o0?ooo`P0oooo0@0000010?ooo`008`3o
ool3000000<0oooo00@000000?ooo`3oool0oooo0P0000060?ooo`<000002@3oool00`000000oooo
0?ooo`2i0?ooo`800000o`3oool:0?ooo`4000000@3oool00280oooo00D000000?ooo`3oool0oooo
000000080?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000080?ooo`03
0000003oool0oooo0;L0oooo0P00003o0?ooo``0oooo0@0000010?ooo`008P3oool01@000000oooo
0?ooo`3oool0000000T0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0]@3oool200000?l0oooo3P3oool100000040oooo000I0?ooo`L0
00000P3oool01@000000oooo0?ooo`3oool0000000L0oooo100000020?ooo`050000003oool0oooo
0?ooo`000000203oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo0?l0oooo3P3oool1
00000040oooo000R0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3o
ool000000080oooo00D000000?ooo`3oool0oooo000000080?ooo`@00000/@3oool200000?l0oooo
3P3oool400000040oooo000R0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo
0?ooo`3oool000000080oooo0P0000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0/03oool200000?l0oooo4`3oool100000040oooo000R0?ooo`050000003oool0oooo0?ooo`00
00001P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`00000000002@3oool0
0`000000oooo0?ooo`2^0?ooo`800000o`3ooolE0?ooo`4000000@3oool00280oooo00D000000?oo
o`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0:`0oooo0P00003o0?oooaL0oooo0@0000010?ooo`008P3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`3o0?oooaL0oooo
0@0000010?ooo`008`3oool3000000P0oooo0`0000060?ooo`800000203oool00`000000oooo0?oo
o`2Y0?ooo`800000o`3ooolJ0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0Y`3oool2
00000?l0oooo703oool100000040oooo00110?ooo`030000003oool0oooo0:D0oooo0P00003o0?oo
oah0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`2S0?ooo`800000o`3ooolP0?ooo`40
00000@3oool00440oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`3o0?ooob00oooo
0@0000010?ooo`00@@3oool300000:00oooo0P00003o0?ooob40oooo0`0000010?ooo`00@@3oool0
0`000000oooo0?ooo`2N0?ooo`800000o`3ooolU0?ooo`4000000@3oool00440oooo00<000000?oo
o`3oool0W03oool200000?l0oooo9`3oool100000040oooo00110?ooo`030000003oool0oooo09X0
oooo0P00003o0?ooobT0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`2I0?ooo`030000
003oool0oooo0?l0oooo:@3oool100000040oooo00110?ooo`030000003oool0oooo09L0oooo0P00
003o0?ooob`0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0
oooo0?l0oooo;03oool100000040oooo00110?ooo`030000003oool0oooo09@0oooo0P00003o0?oo
obl0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0?l0
oooo;`3oool100000040oooo00110?ooo`<00000T@3oool200000?l0oooo<03oool300000040oooo
00110?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0o`3ooolb0?ooo`4000000@3o
ool00440oooo00<000000?ooo`3oool0SP3oool200000?l0oooo=@3oool100000040oooo00110?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool0o`3ooole0?ooo`4000000@3oool00440
oooo00<000000?ooo`3oool0R`3oool200000?l0oooo>03oool100000040oooo00110?ooo`030000
003oool0oooo08X0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`4000000@3oool00440oooo00<0
00000?ooo`3oool0R03oool200000?l0oooo>`3oool100000040oooo00110?ooo`030000003oool0
oooo08L0oooo00<000000?ooo`3oool0o`3ooolk0?ooo`4000000@3oool00440oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`3o0?oooc`0oooo0@0000010?ooo`00@@3oool00`000000
oooo0?ooo`240?ooo`800000o`3ooolo0?ooo`4000000@3oool00440oooo0`0000230?ooo`030000
003oool0oooo0?l0oooo?@3oool300000040oooo00110?ooo`030000003oool0oooo0880oooo00<0
00000?ooo`3oool0o`3ooom00?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0P@3oool0
0`000000oooo0?ooo`3o0?oood40oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`1o0?oo
o`800000o`3ooom40?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0OP3oool00`000000
oooo0?ooo`3o0?oood@0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`1m0?ooo`030000
003oool0oooo0?l0ooooA@3oool100000040oooo00110?ooo`030000003oool0oooo07/0oooo0P00
003o0?ooodP0oooo0@0000010?ooo`008`3oool3000000<0oooo00@000000?ooo`3oool0oooo0P00
00080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?oo
o`3o0?ooodP0oooo0@0000010?ooo`008P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`3oool0o`3ooom90?ooo`4000000@3oool00280oooo00D000000?ooo`3oool0oooo0000
00090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`1h0?ooo`030000003oool0oooo0?l0ooooBP3oool100000040oooo000I0?ooo`L000000P3oool0
1@000000oooo0?ooo`3oool0000000L0oooo100000000`3oool0000000000004000000P0oooo1000
001e0?ooo`800000o`3ooom:0?ooo`@000000@3oool00280oooo00D000000?ooo`3oool0oooo0000
00060?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`3o0?ooodd0oooo0@0000010?ooo`00
8P3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`3o
0?ooodh0oooo0@0000010?ooo`008P3oool01@000000oooo0?ooo`3oool0000000H0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool0L`3o
ool00`000000oooo0?ooo`3o0?ooodl0oooo0@0000010?ooo`008P3oool01@000000oooo0?ooo`3o
ool0000000H0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0000000T0oooo
00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`3o0?oooe00oooo0@0000010?ooo`008P3o
ool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000040?ooo`80
00002@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0ooooD@3oool100000040
oooo000S0?ooo`<00000203oool3000000H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`1`0?ooo`030000003oool0oooo0?l0ooooDP3oool100000040oooo00110?ooo`030000003o
ool0oooo06l0oooo00<000000?ooo`3oool0o`3ooomC0?ooo`4000000@3oool00440oooo00<00000
0?ooo`3oool0KP3oool00`000000oooo0?ooo`3o0?oooe@0oooo0@0000010?ooo`00@@3oool00`00
0000oooo0?ooo`1]0?ooo`030000003oool0oooo0?l0ooooE@3oool100000040oooo00110?ooo`<0
0000K03oool00`000000oooo0?ooo`3o0?oooe@0oooo0`0000010?ooo`00@@3oool00`000000oooo
0?ooo`1[0?ooo`030000003oool0oooo0?l0ooooE`3oool100000040oooo00110?ooo`030000003o
ool0oooo06X0oooo00<000000?ooo`3oool0o`3ooomH0?ooo`4000000@3oool00440oooo00<00000
0?ooo`3oool0J@3oool00`000000oooo0?ooo`3o0?oooeT0oooo0@0000010?ooo`00@@3oool00`00
0000oooo0?ooo`1X0?ooo`030000003oool0oooo0?l0ooooFP3oool100000040oooo00110?ooo`03
0000003oool0oooo06L0oooo00<000000?ooo`3oool0o`3ooomK0?ooo`4000000@3oool00440oooo
00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`3o0?oooe`0oooo0@0000010?ooo`00@@3o
ool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0?l0ooooG@3oool100000040oooo0011
0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`4000000@3oool0
0440oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`3o0?oooel0oooo0@0000010?oo
o`00@@3oool300000680oooo00<000000?ooo`3oool0o`3ooomN0?ooo`<000000@3oool00440oooo
00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`3o0?ooof40oooo0@0000010?ooo`001`3o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0o`3o
oomR0?ooo`4000000@3oool000L0oooo0`00000g0?ooo`030000003oool0oooo05l0oooo00<00000
0?ooo`3oool0o`3ooomS0?ooo`4000000@3oool000L0oooo00<000000?ooo`3oool00`00000d0?oo
o`030000003oool0oooo05h0oooo00<000000?ooo`3oool0o`3ooomT0?ooo`4000000@3oool000`0
oooo0P00000c0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0o`3ooomU0?ooo`40
00000@3oool000L0oooo00<000000?ooo`3oool00P00000e0?ooo`030000003oool0oooo05`0oooo
00<000000?ooo`3oool0o`3ooomV0?ooo`4000000@3oool000L0oooo0`00000g0?ooo`030000003o
ool0oooo05/0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`4000000@3oool000L0oooo00<00000
0?ooo`3oool00`00000d0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0o`3ooomX
0?ooo`4000000@3oool000`0oooo0P00000c0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0o`3ooomY0?ooo`4000000@3oool000L0oooo00<000000?ooo`3oool00P00000e0?ooo`<0
0000F@3oool00`000000oooo0?ooo`3o0?ooofL0oooo0`0000010?ooo`001`3oool3000003L0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3o0?ooofX0oooo0@0000010?ooo`001`3o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0o`3o
oom[0?ooo`4000000@3oool000H0oooo2@00000b0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool0o`3ooom/0?ooo`4000000@3oool000D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0o`3ooom]0?oo
o`4000000@3oool000@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo05@0oooo00<000000?ooo`3oool0o`3ooom^0?ooo`4000000@3oool00440oooo
00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`3o0?ooofl0oooo0@0000010?ooo`001`3o
ool2000000@0oooo00<000000?ooo`3oool04`3oool3000000<0oooo00@000000?ooo`3oool0oooo
0P0000050?ooo`D00000203oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0?l0oooo
L03oool100000040oooo00070?ooo`030000003oool0oooo0080oooo0P00000D0?ooo`050000003o
ool0oooo0?ooo`000000203oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000P0
oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`3o0?ooog40oooo0@0000010?ooo`00
1`3oool00`000000oooo0?ooo`02000000030?ooo`000000oooo01<0oooo00D000000?ooo`3oool0
oooo000000090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`1@0?ooo`030000003oool0oooo0?l0ooooLP3oool100000040oooo00070?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool02@3oool700000080oooo00D000000?ooo`3oool0
oooo000000070?ooo`@000001@3oool00`000000oooo0?ooo`070?ooo`@00000CP3oool00`000000
oooo0?ooo`3o0?ooog00oooo100000010?ooo`001`3oool2000000@0oooo00<000000?ooo`3oool0
4P3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000050?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`3o0?oo
og<0oooo0@0000010?ooo`001`3oool00`000000oooo0?ooo`020?ooo`800000503oool01@000000
oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`3o0?ooog@0oooo0@000001
0?ooo`00103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00D000000?oo
o`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0o`3ooome0?ooo`4000000@3o
ool000D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0
oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0?l0ooooMP3oool100000040oooo
00060?ooo`T000004`3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0
oooo000000020?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`1<0?oo
o`030000003oool0oooo0?l0ooooMP3oool100000040oooo000S0?ooo`<00000203oool3000000@0
oooo0`0000090?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0o`3ooomg0?ooo`40
00000@3oool00440oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`3o0?ooogP0oooo
0@0000010?ooo`00@@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0?l0ooooN@3o
ool100000040oooo00110?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0o`3ooomi
0?ooo`4000000@3oool00440oooo0`0000180?ooo`030000003oool0oooo0?l0ooooN03oool30000
0040oooo00110?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0o`3ooomk0?ooo`40
00000@3oool00440oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`3o0?ooog`0oooo
0@0000010?ooo`00@@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0?l0ooooO03o
ool100000040oooo00110?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0o`3ooomm
0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`3o0?oo
ogh0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0?l0
ooooO`3oool100000040oooo00110?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0
o`3ooomo0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`3o0?oooh00oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo0?l0ooooP@3oool100000040oooo00110?ooo`<00000@03oool00`000000oooo0?ooo`3o0?oo
oh00oooo0`0000010?ooo`00@@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0?l0
ooooPP3oool100000040oooo00110?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0
o`3ooon30?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?oo
o`3o0?oooh@0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo0?l0ooooQ03oool100000040oooo00110?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool0o`3ooon50?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0?03oool00`000000
oooo0?ooo`3o0?ooohH0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo0?l0ooooQP3oool100000040oooo00110?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool0o`3ooon70?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`3o0?ooohP0oooo0@0000010?ooo`00@@3oool3000003X0oooo00<000000?oo
o`3oool0o`3ooon60?ooo`<000000@3oool00440oooo00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`3o0?ooohT0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo0?l0ooooR@3oool100000040oooo00110?ooo`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool0o`3ooon:0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`3o0?oooh/0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo0?l0ooooR`3oool100000040oooo000Z0?ooo`<000000`3oool010000000
oooo0?ooo`3oool2000000/0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`3o0?oo
oh`0oooo0@0000010?ooo`00:@3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0?l0ooooS@3oool10000
0040oooo000Y0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo03D0oooo00<000000?ooo`3oool0o`3ooon=0?ooo`4000000@3oool00200
oooo1`0000020?ooo`050000003oool0oooo0?ooo`0000001`3oool4000000P0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`3o0?ooohh0oooo0@0000010?ooo`00:@3oool01@000000
oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000080?ooo`@00000<P3oool0
0`000000oooo0?ooo`3o0?oooh`0oooo100000010?ooo`00:@3oool01@000000oooo0?ooo`3oool0
000000H0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo03<0oooo00<0
00000?ooo`3oool0o`3ooon?0?ooo`4000000@3oool002T0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo0?l0ooooT03oool100000040oooo000Y0?ooo`050000003oool0oooo0?ooo`000000
1P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`3o0?oooi40oooo0@0000010?ooo`00:@3oool01@000000oooo0?ooo`3oool0000000H0
oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool0o`3ooonA0?ooo`4000000@3oool002X0oooo0`0000080?ooo`<000002@3oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo0?l0ooooTP3oool100000040oooo00110?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool0o`3ooonB0?ooo`4000000@3oool00440oooo00<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`3o0?oooi<0oooo0@0000010?ooo`00@@3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0?l0ooooU03oool100000040oooo00110?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool0o`3ooonD0?ooo`4000000@3oool00440
oooo0`00000]0?ooo`030000003oool0oooo0?l0ooooT`3oool300000040oooo00110?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool0o`3ooonF0?ooo`4000000@3oool00440oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`3o0?oooiH0oooo0@0000010?ooo`00@@3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0ooooU`3oool100000040oooo00110?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool0o`3ooonG0?ooo`4000000@3oool00440
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`3o0?oooiP0oooo0@0000010?ooo`00
@@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0?l0ooooV03oool100000040oooo
00110?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3ooonI0?ooo`4000000@3o
ool00440oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?oooiT0oooo0@000001
0?ooo`00@@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0?l0ooooVP3oool10000
0040oooo00110?ooo`<00000:03oool00`000000oooo0?ooo`3o0?oooiP0oooo0`0000010?ooo`00
@@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0?l0ooooV`3oool100000040oooo
00110?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0o`3ooonK0?ooo`4000000@3o
ool00440oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3o0?oooi`0oooo0@000001
0?ooo`00@@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0?l0ooooW03oool10000
0040oooo00110?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0o`3ooonM0?ooo`40
00000@3oool00440oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3o0?oooid0oooo
0@0000010?ooo`00@@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0?l0ooooWP3o
ool100000040oooo00110?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0o`3ooonN
0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`3o0?oo
oil0oooo0@0000010?ooo`00@@3oool3000002<0oooo00<000000?ooo`3oool0o`3ooonM0?ooo`<0
00000@3oool00440oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3o0?oooj00oooo
0@0000010?ooo`00@@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0?l0ooooX03o
ool100000040oooo00110?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0o`3ooonQ
0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3o0?oo
oj40oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0?l0
ooooXP3oool100000040oooo000S0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`<00000
103oool3000000T0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`3o0?oooj80oooo
0@0000010?ooo`008P3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0
oooo000000020?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo0?l0ooooX`3oool100000040oooo000R0?ooo`050000003oool0oooo0?oo
o`0000001P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000
00080?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0o`3ooonS0?ooo`4000000@3o
ool001T0oooo1`0000020?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0o`3ooonT0?ooo`4000000@3oool00280oooo00D000000?ooo`3oool0
oooo000000070?ooo`030000003oool0000000@0oooo00<000000?ooo`0000002@3oool4000001d0
oooo00<000000?ooo`3oool0o`3ooonQ0?ooo`@000000@3oool00280oooo00D000000?ooo`3oool0
oooo000000080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo0?l0ooooY@3oool100000040oooo000R0?ooo`050000
003oool0oooo0?ooo`0000001`3oool00`000000oooo000000040?ooo`030000003oool0000000T0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3o0?ooojD0oooo0@0000010?ooo`00
8P3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000020?oo
o`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo0?l0ooooYP3oool100000040oooo000R0?ooo`050000003oool0oooo0?ooo`0000001P3oool0
1@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000080?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool0o`3ooonV0?ooo`4000000@3oool002<0oooo0`00
00080?ooo`<00000103oool3000000T0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`3o0?ooojL0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo0?l0ooooY`3oool100000040oooo00110?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool0o`3ooonX0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`3o0?ooojP0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo0?l0ooooZ@3oool100000040oooo00110?ooo`<000006@3oool00`000000oooo0?oo
o`3o0?ooojL0oooo0`0000010?ooo`00@@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo0?l0ooooZP3oool100000040oooo00110?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0o`3ooonZ0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`3o0?oooj/0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo0?l0ooooZ`3oool100000040oooo00110?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0o`3ooon/0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`3o0?oooj`0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo0?l0oooo[03oool100000040oooo00110?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0o`3ooon]0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`3o0?ooojd0oooo0@0000010?ooo`00@@3oool3000001@0oooo00<0
00000?ooo`3oool0o`3ooon/0?ooo`<000000@3oool00440oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`3o0?ooojh0oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo0?l0oooo[`3oool100000040oooo00110?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0o`3ooon_0?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`3o0?ooojl0oooo0@0000010?ooo`00@@3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0?l0oooo/03oool100000040oooo00110?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0o`3ooon`0?ooo`4000000@3oool00440oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`3o0?oook40oooo0@0000010?ooo`00@@3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0oooo/@3oool100000040oooo00110?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0o`3ooonb0?ooo`4000000@3oool00440oooo0`00
000@0?ooo`030000003oool0oooo0?l0oooo/03oool300000040oooo00110?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0o`3ooonc0?ooo`4000000@3oool00440oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`3o0?oook<0oooo0@0000010?ooo`00@@3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0oooo/`3oool100000040oooo00110?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooond0?ooo`4000000@3oool00440oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?oook@0oooo0@0000010?ooo`008`3oool3
000000<0oooo00<000000?ooo`3oool00P3oool3000000@0oooo0`0000090?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0o`3ooone0?ooo`4000000@3oool00280oooo00D000000?oo
o`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?oo
o`3oool0000000P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?oookD0oooo
0@0000010?ooo`008P3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0
oooo000000020?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0?l0oooo]P3oool100000040oooo000I0?ooo`L000000P3oool01@000000
oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`000000203oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo]P3o
ool100000040oooo000R0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0000
00030?ooo`050000003oool0oooo0?ooo`000000203oool4000000/0oooo00<000000?ooo`3oool0
o`3ooonc0?ooo`@000000@3oool00280oooo00D000000?ooo`3oool0oooo000000080?ooo`030000
003oool0oooo0080oooo0P0000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`3o0?oookL0oooo0@0000010?ooo`008P3oool01@000000oooo0?oo
o`3oool0000000L0oooo00<000000?ooo`0000000`3oool010000000oooo0000000000090?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooong0?ooo`4000000@3oool00280oooo
00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooonh0?oo
o`4000000@3oool00280oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0o`3ooonh0?ooo`4000000@3oool002<0oooo0`0000080?ooo`<000001P3oool20000
00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?oookT0oooo0@0000010?oo
o`00@@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo^@3oool100000040
oooo00110?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooonj0?ooo`400000
0@3oool00440oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?oookX0oooo0@00
00010?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooolD0oooo0@0000010?ooo`00@@3oool30000
0?l0oooo``3oool300000040oooo00110?ooo`030000003oool0oooo0?l0ooooa@3oool100000040
oooo00110?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0J@3oool00`000000oooo
0?ooo`1Z0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0J@3oool00`000000oooo
0?ooo`080?ooo`4000000@3oool00440oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool100000040oooo0011
0?ooool00000b@0000010?ooo`00\
\>"],
  ImageRangeCache->{{{0, 521.625}, {322, 0}} -> {-0.355084, -1.01425, \
0.00462374, 0.000502015}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ 
      Find\ chi\ square\ for\ given\ H \((z)\)\ \ *) \[IndentingNewLine]\(f[
          z_] := 1/hhz[z];\)\), "\n", 
    \(\(rr[zz_] := NIntegrate[f[z], {z, 0, zz}];\)\[IndentingNewLine]\n (*\ 
      Construct\ marginalization\ coefficients\ \((see\ astro - 
              ph/0401556\  .. )\)\ *) \), "\[IndentingNewLine]", 
    \(Clear[chi2fa, chi2fb, chi2fc]\), "\n", 
    \(\(chi2fa = 
        Sum[\((ld[i] - 5\ Log[10, rr[zz[i]]*\((1 + zz[i])\)])\)^2/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\n", 
    \(\(chi2fb = 
        Sum[\((ld[i] - 
                5\ Log[10, rr[zz[i]]*\((1 + zz[i])\)])\)/\((sld[i]^2)\), {i, 
            1, ndat}];\)\), "\n", 
    \(\(chi2fc = 
        Sum[1/\((sld[i]^2)\), {i, 1, ndat}];\)\[IndentingNewLine]\n (*\ 
      Construct\ function\ after\ marginalization, \ 
      find\ same\ result\ as\ with\ mb\ minimization\ *) \), "\
\[IndentingNewLine]", 
    \(chi2fm = chi2fa - chi2fb^2/chi2fc\), "\[IndentingNewLine]", 
    \(dchi2q12 = chi2fm - chi2l\)}], "Input"],

Cell[BoxData[
    \(178.8143373746425`\)], "Output"],

Cell[BoxData[
    \(1.6869659395888448`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ \(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(\
--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(-\(---\)\)\)\)\)\)\)\)\)\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)*) \[IndentingNewLine]\[IndentingNewLine] \
(*\ Find\ H \((z)\)\ for\ given\ slope\ s\ of\ the\ linear\ potential . \ 
            Present\ time\  = \ \(tt\ \((corresponds\ to\ a = 1)\) . \ 
              Run\ trials\ for\ initial\ condition\ for\ field\ fi\ \((f0)\)\ \
and\ initial\ time\ ti\ until\ we\ get\ field\ energy\ enf\  = \ \(0.7\ and\ \
H \((z = 0)\)\  = 
            1\ at\ present\ time\ \(\(tt\)\(.\)\)\)\)\ *) \[IndentingNewLine]\
\[IndentingNewLine] (*\ \(--\(--\(--\(--\ \ s\)\)\)\)\  = \ \(1.5\ \ \ --\) \
\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(---\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\ *) \
\[IndentingNewLine]\[IndentingNewLine]\(Clear[aa, fi, a, aad, aadd, fidas, 
        tas, f, rr, hht, hha];\)\), "\[IndentingNewLine]", 
    \(aa = a[t]; \ fi = f[t];\), "\n", 
    \(\(aad = D[aa, t];\)\), "\n", 
    \(\(aadd = D[aa, {t, 2}];\)\), "\n", 
    \(\(fid = D[fi, t];\)\), "\n", 
    \(\(fidd = D[fi, {t, 2}];\)\), "\n", 
    \(ti = 0.000025; \ t0 = 2.25;\), "\n", 
    \(\(f0 = \(-0.617\);\)\ \), "\n", 
    \(om0m = 0.3; \ ss = 1.5;\), "\n", 
    \(\(eq1 = 
        aadd/aa\  \[Equal] \(-\ \ fid^2\)\  - \ ss\ fi\  - \ 
            om0m/\((2\ aa^3)\);\)\), "\n", 
    \(\(eq2 = 
        fidd\ \  + \ \ \ 3\ \ fid\ \((aad/aa)\)\  - \ ss \[Equal] 
          0;\)\), "\n", 
    \(\(eqb1 = f[ti] == f0;\)\), "\n", 
    \(\(eqb2 = \(f'\)[ti] == 0;\)\), "\n", 
    \(\(eqb3 = 
        a[ti] \[Equal] \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((2/3)\);\)\), "\n", 
    \(\(eqb4 = \(a'\)[
            ti] \[Equal] \((2/
                3)\)\ \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((\(-1\)/
                  3)\);\)\), "\n", 
    \(\(sol2 = 
        NDSolve[{eq1, eq2, eqb1, eqb2, eqb3, eqb4}, {aa, fi}, {t, ti, t0}, 
          MaxSteps \[Rule] 10000000];\)\), "\n", 
    \(\(asol = Part[Evaluate[a[t] /. sol2], 1];\)\), "\n", 
    \(\(fsol = Part[Evaluate[f[t] /. sol2], 1];\)\), "\n", 
    \(\(dfsol = D[fsol, t];\)\), "\[IndentingNewLine]", 
    \(\(enf = 0.5\ dfsol^2\  - \ ss\ fsol;\)\), "\[IndentingNewLine]", 
    \(\(as[t1_] := asol\  /. \ t -> t1\ ;\)\), "\[IndentingNewLine]", 
    \(\(tt = Part[FindRoot[as[t] == 1, {t, 1}], 1, 2];\)\), "\n", 
    \(\(tas[a_] := 
        Part[FindRoot[as[t] \[Equal] a, {t, 1}], 1, 2];\)\), "\n", 
    \(\(hht[t1_] := D[asol, t]/asol\  /. \ t -> t1\ ;\)\), "\n", 
    \(\(hha[a_] := hht[tas[a]];\)\), "\[IndentingNewLine]", 
    \(\(hhz[z_] := hha[1/\((z + 1)\)];\)\), "\[IndentingNewLine]", 
    \(enf\  /. \ t \[Rule] tt\), "\[IndentingNewLine]", 
    \(hhz[0]\), "\[IndentingNewLine]", 
    \(\(enf = 0.5\ dfsol^2\  - \ ss\ fsol;\)\), "\n", 
    \(\(ppf = 0.5\ dfsol^2\  + \ ss\ fsol;\)\), "\n", 
    \(\(wft[t1_] := ppf/enf\  /. \ t -> t1\ ;\)\ \), "\n", 
    \(\(wfa[a_] := wft[tas[a]];\)\), "\n", 
    \(\(wfz[z_] := wfa[1/\((z + 1)\)];\)\), "\n", 
    \(\(plw15q = 
        Plot[wfz[z], {z, 0, 2}, Frame \[Rule] True, PlotRange \[Rule] All, 
          FrameLabel \[Rule] {"\<z\>", "\<w(z)\>"}];\)\)}], "Input"],

Cell[BoxData[
    \(0.7014426459293387`\)], "Output"],

Cell[BoxData[
    \(1.0020078367949998`\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.476191 2.81454 2.83975 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.2619 -0.0125 -10.7813 -17.8125 ]
[.2619 -0.0125 10.7813 0 ]
[.5 -0.0125 -5.53125 -17.8125 ]
[.5 -0.0125 5.53125 0 ]
[.7381 -0.0125 -10.7813 -17.8125 ]
[.7381 -0.0125 10.7813 0 ]
[.97619 -0.0125 -5.53125 -17.8125 ]
[.97619 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.125 -35.625 ]
[.5 -0.0125 5.125 -17.8125 ]
[-0.0125 .11678 -38.3125 -8.90625 ]
[-0.0125 .11678 0 8.90625 ]
[-0.0125 .25877 -31.25 -8.90625 ]
[-0.0125 .25877 0 8.90625 ]
[-0.0125 .40075 -38.3125 -8.90625 ]
[-0.0125 .40075 0 8.90625 ]
[-0.0125 .54274 -31.25 -8.90625 ]
[-0.0125 .54274 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -56.125 -14.7188 ]
[-0.01875 .30902 -38.3125 14.7188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.125 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11678 m
.00625 .11678 L
s
gsave
-0.0125 .11678 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
1.000 setlinewidth
grestore
0 .25877 m
.00625 .25877 L
s
gsave
-0.0125 .25877 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
1.000 setlinewidth
grestore
0 .40075 m
.00625 .40075 L
s
gsave
-0.0125 .40075 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.85) show
1.000 setlinewidth
grestore
0 .54274 m
.00625 .54274 L
s
gsave
-0.0125 .54274 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .14518 m
.00375 .14518 L
s
0 .17357 m
.00375 .17357 L
s
0 .20197 m
.00375 .20197 L
s
0 .23037 m
.00375 .23037 L
s
0 .28716 m
.00375 .28716 L
s
0 .31556 m
.00375 .31556 L
s
0 .34396 m
.00375 .34396 L
s
0 .37236 m
.00375 .37236 L
s
0 .42915 m
.00375 .42915 L
s
0 .45755 m
.00375 .45755 L
s
0 .48595 m
.00375 .48595 L
s
0 .51434 m
.00375 .51434 L
s
0 .08838 m
.00375 .08838 L
s
0 .05998 m
.00375 .05998 L
s
0 .03159 m
.00375 .03159 L
s
0 .00319 m
.00375 .00319 L
s
0 .57114 m
.00375 .57114 L
s
0 .59954 m
.00375 .59954 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -122.938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.7188 12.9063 translate
90 rotate
-75.7188 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.063 17.500 moveto
(H) show
77.625 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.875 17.500 moveto
(L) show
88.438 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .11678 m
1 .11678 L
s
.99375 .25877 m
1 .25877 L
s
.99375 .40075 m
1 .40075 L
s
.99375 .54274 m
1 .54274 L
s
.125 Mabswid
.99625 .14518 m
1 .14518 L
s
.99625 .17357 m
1 .17357 L
s
.99625 .20197 m
1 .20197 L
s
.99625 .23037 m
1 .23037 L
s
.99625 .28716 m
1 .28716 L
s
.99625 .31556 m
1 .31556 L
s
.99625 .34396 m
1 .34396 L
s
.99625 .37236 m
1 .37236 L
s
.99625 .42915 m
1 .42915 L
s
.99625 .45755 m
1 .45755 L
s
.99625 .48595 m
1 .48595 L
s
.99625 .51434 m
1 .51434 L
s
.99625 .08838 m
1 .08838 L
s
.99625 .05998 m
1 .05998 L
s
.99625 .03159 m
1 .03159 L
s
.99625 .00319 m
1 .00319 L
s
.99625 .57114 m
1 .57114 L
s
.99625 .59954 m
1 .59954 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .11678 m
1 .11678 L
s
.5 Mabswid
.02381 .60332 m
.06244 .50234 L
.10458 .41735 L
.14415 .35408 L
.18221 .30428 L
.22272 .26032 L
.26171 .22493 L
.30316 .19323 L
.34309 .16737 L
.3815 .14604 L
.42237 .12652 L
.46172 .11031 L
.49955 .09673 L
.53984 .08412 L
.57861 .07351 L
.61984 .06362 L
.65954 .05526 L
.69774 .04815 L
.73838 .04145 L
.77751 .03572 L
.81909 .03031 L
.85916 .02567 L
.89771 .02167 L
.93871 .01786 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{583, 360.313},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000970001J2000`400?l00000o`00003oo`3ooooo
0?ooodT0oooo003o0?ooool0ooooB@3oool00?l0ooooo`3ooom90?ooo`00o`3ooooo0?ooodT0oooo
003o0?ooool0ooooB@3oool00?l0oooo@@3oool600000?l0oooo0P3oool00?l0oooo@P3oool01@00
0000oooo0?ooo`3oool000000?l0oooo0P3oool00?l0oooo@`3oool00`000000oooo0?ooo`3o0?oo
o`<0oooo003o0?oood<0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3ooom40?ooo`030000
003oool0oooo0?l0oooo0P3oool00?l0oooo@@3oool01@000000oooo0?ooo`3oool000000?l0oooo
0`3oool00?l0oooo@@3oool600000?l0oooo0P3oool00?l0ooooo`3ooom90?ooo`00o`3ooooo0?oo
odT0oooo003o0?ooool0ooooB@3oool00?l0ooooo`3ooom90?ooo`00o`3ooooo0?ooodT0oooo003o
0?ooool0ooooB@3oool00?l0ooooo`3ooom90?ooo`00o`3ooooo0?ooodT0oooo003o0?ooool0oooo
B@3oool00?l0ooooo`3ooom90?ooo`00o`3ooooo0?ooodT0oooo001=0?ooo`<00000LP3oool30000
00<0oooo00@000000?ooo`3oool0oooo0`00001c0?ooo`<00000LP3oool3000000<0oooo00@00000
0?ooo`3oool0oooo0`00001a0?ooo`D000003@3oool004`0oooo00D000000?ooo`3oool0oooo0000
001`0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`1a0?ooo`030000
003oool0oooo0780oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1_0?ooo`040000
003oool0oooo000000d0oooo001<0?ooo`050000003oool0oooo0?ooo`000000L03oool01@000000
oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`1b0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0=0?oo
o`00C03oool01@000000oooo0?ooo`3oool000000700oooo00D000000?ooo`3oool0oooo0000000:
0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0303oool004`0oooo00D000000?oo
o`3oool0oooo0000001`0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?oo
o`1`0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`1`0?ooo`030000003oool0oooo00`0oooo001<0?ooo`050000003oool0oooo0?ooo`000000L03o
ool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0L@3oool00`000000oooo
0?ooo`1b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0LP3oool00`000000oooo
0?ooo`0;0?ooo`00C03oool01@000000oooo0?ooo`3oool000000700oooo00D000000?ooo`3oool0
oooo000000060?ooo`<00000M03oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo00H0
oooo0`00001e0?ooo`030000003oool0oooo00/0oooo001<0?ooo`050000003oool0oooo0?ooo`00
0000L03oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`1b0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0M@3oool00`00
0000oooo0?ooo`0;0?ooo`00C03oool01@000000oooo0?ooo`3oool000000700oooo00D000000?oo
o`3oool0oooo000000070?ooo`030000003oool0oooo0780oooo0P00001c0?ooo`8000002@3oool0
0`000000oooo0?ooo`1`0?ooo`050000003oool0oooo0?ooo`0000003@3oool004d0oooo0`00001b
0?ooo`<00000203oool400000780oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`07
0?ooo`@00000L03oool3000000h0oooo003o0?ooool0ooooB@3oool00?l0ooooo`3ooom90?ooo`00
o`3ooooo0?ooodT0oooo003o0?ooool0ooooB@3oool00?l0ooooo`3ooom90?ooo`00o`3ooooo0?oo
odT0oooo003o0?ooool0ooooB@3oool00?l0ooooo`3ooom90?ooo`00o`3ooooo0?ooodT0oooo0013
0?ooool00000o`00000400000080oooo00130?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00T0oooo0@0000010?oo
o`40oooo00130?ooo`<000002@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool01`3oool300000080oooo00130?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo07P0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`090?ooo`4000000@3oool10?ooo`00@`3o
ool00`000000oooo0?ooo`3o0?ooool0oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0
oooo0?l0ooooo`3oool100000040oooo0@3oool004<0oooo00<000000?ooo`3oool0o`3ooooo0?oo
o`4000000@3oool10?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooool0oooo0@0000010?ooo`40
oooo00130?ooo`030000003oool0oooo0?l0oooojP3oool:000000/0oooo0@0000010?ooo`40oooo
00130?ooo`030000003oool0oooo0?l0oooof`3oool?000001D0oooo0@0000010?ooo`40oooo0013
0?ooo`030000003oool0oooo0?l0ooood03oool;000002@0oooo0@0000010?ooo`40oooo00130?oo
o`030000003oool0oooo0?l0ooooaP3oool:000002l0oooo0@0000010?ooo`40oooo00130?ooo`03
0000003oool0oooo0?l0oooo_03oool:000003T0oooo0@0000010?ooo`40oooo00130?ooo`030000
003oool0oooo0?l0oooo]03oool8000004<0oooo0@0000010?ooo`40oooo00130?ooo`030000003o
ool0oooo0?l0oooo[@3oool7000004/0oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0
oooo0?l0ooooYP3oool700000580oooo0@0000010?ooo`40oooo00130?ooo`<00000o`3ooonO0?oo
o`L00000E`3oool300000080oooo00130?ooo`030000003oool0oooo0?l0ooooV03oool700000600
oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo0?l0ooooT@3oool7000006L0oooo
0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo0?l0ooooRP3oool7000006h0oooo0@00
00010?ooo`40oooo00130?ooo`030000003oool0oooo0?l0ooooQ03oool6000007D0oooo0@000001
0?ooo`40oooo00130?ooo`030000003oool0oooo0?l0ooooO@3oool7000007/0oooo0@0000010?oo
o`40oooo00130?ooo`030000003oool0oooo0?l0ooooMP3oool700000880oooo0@0000010?ooo`40
oooo00130?ooo`030000003oool0oooo0?l0ooooK`3oool7000008T0oooo0@0000010?ooo`40oooo
00130?ooo`030000003oool0oooo0?l0ooooJ03oool700000900oooo0@0000010?ooo`40oooo0013
0?ooo`030000003oool0oooo0?l0ooooHP3oool6000009L0oooo0@0000010?ooo`40oooo00130?oo
o`030000003oool0oooo0?l0ooooG@3oool5000009d0oooo0@0000010?ooo`40oooo00130?ooo`03
0000003oool0oooo0?l0ooooF03oool500000:80oooo0@0000010?ooo`40oooo00130?ooo`030000
003oool0oooo0?l0ooooD`3oool500000:L0oooo0@0000010?ooo`40oooo00130?ooo`030000003o
ool0oooo0?l0ooooCP3oool500000:`0oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0
oooo0?l0ooooB@3oool500000;40oooo0@0000010?ooo`40oooo00130?ooo`<00000o`3ooom40?oo
o`D00000]03oool300000080oooo00130?ooo`030000003oool0oooo0?l0oooo?`3oool500000;/0
oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo0?l0oooo>P3oool500000<00oooo
0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo0?l0oooo=P3oool400000<D0oooo0@00
00010?ooo`40oooo00130?ooo`030000003oool0oooo0?l0oooo<P3oool400000<T0oooo0@000001
0?ooo`40oooo00130?ooo`030000003oool0oooo0?l0oooo;P3oool400000<d0oooo0@0000010?oo
o`40oooo00130?ooo`030000003oool0oooo0?l0oooo:P3oool400000=40oooo0@0000010?ooo`40
oooo00130?ooo`030000003oool0oooo0?l0oooo9P3oool400000=D0oooo0@0000010?ooo`40oooo
00130?ooo`030000003oool0oooo0?l0oooo8P3oool400000=T0oooo0@0000010?ooo`40oooo0013
0?ooo`030000003oool0oooo0?l0oooo7P3oool400000=d0oooo0@0000010?ooo`40oooo00130?oo
o`030000003oool0oooo0?l0oooo6P3oool400000>40oooo0@0000010?ooo`40oooo00130?ooo`03
0000003oool0oooo0?l0oooo5P3oool400000>D0oooo0@0000010?ooo`40oooo00130?ooo`030000
003oool0oooo0?l0oooo4P3oool400000>T0oooo0@0000010?ooo`40oooo00130?ooo`030000003o
ool0oooo0?l0oooo3`3oool300000>d0oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0
oooo0?l0oooo303oool300000?00oooo0@0000010?ooo`40oooo00130?ooo`<00000o`3oool90?oo
o`<00000l@3oool300000080oooo00130?ooo`030000003oool0oooo0?l0oooo1P3oool300000?H0
oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo0?l0oooo0`3oool300000?T0oooo
0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo0?l0oooo0`00003l0?ooo`4000000@3o
ool10?ooo`00@`3oool00`000000oooo0?ooo`3l0?ooo`<00000o`3oool100000040oooo0@3oool0
04<0oooo00<000000?ooo`3oool0n@3oool300000?l0oooo0`3oool100000040oooo0@3oool004<0
oooo00<000000?ooo`3oool0m`3oool200000?l0oooo1P3oool100000040oooo0@3oool004<0oooo
00<000000?ooo`3oool0m03oool300000?l0oooo203oool100000040oooo0@3oool004<0oooo00<0
00000?ooo`3oool0l@3oool300000?l0oooo2`3oool100000040oooo0@3oool004<0oooo00<00000
0?ooo`3oool0k`3oool200000?l0oooo3P3oool100000040oooo0@3oool004<0oooo00<000000?oo
o`3oool0k03oool300000?l0oooo403oool100000040oooo0@3oool002@0oooo0`0000030?ooo`04
0000003oool0oooo0?ooo`8000001@3oool3000000/0oooo00<000000?ooo`3oool0j@3oool30000
0?l0oooo4`3oool100000040oooo0@3oool002<0oooo00D000000?ooo`3oool0oooo000000080?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3W0?oo
o`800000o`3ooolF0?ooo`4000000@3oool10?ooo`008`3oool01@000000oooo0?ooo`3oool00000
00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0>@0oooo0`00003o0?oooaP0oooo0@0000010?ooo`40oooo000I0?ooo`L000000`3oool01@000000
oooo0?ooo`3oool0000000L0oooo100000060?ooo`030000003oool0oooo00L0ooooo`00003o0000
00@000000P3oool002<0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo
0?ooo`0000001P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0=l0oooo0P00003o
0?oooah0oooo0@0000010?ooo`40oooo000S0?ooo`050000003oool0oooo0?ooo`0000001P3oool0
1@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`3L0?ooo`<00000o`3ooolP0?ooo`4000000@3oool10?ooo`008`3oool01@000000oooo0?ooo`3o
ool0000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`<000002`3oool00`000000oooo
0?ooo`3I0?ooo`<00000o`3ooolS0?ooo`4000000@3oool10?ooo`008`3oool01@000000oooo0?oo
o`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0e`3oool200000?l0oooo9P3oool100000040oooo0@3oool002<0oooo
00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0=@0oooo0`00003o0?ooobP0oooo0@0000010?oo
o`40oooo000T0?ooo`<00000203oool3000000@0oooo100000090?ooo`030000003oool0oooo0=80
oooo0P00003o0?ooob/0oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo0=00oooo
0P00003o0?ooobd0oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo0<h0oooo0P00
003o0?ooobl0oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo0<`0oooo0P00003o
0?oooc40oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo0<X0oooo0P00003o0?oo
oc<0oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo0<P0oooo0P00003o0?ooocD0
oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo0<H0oooo0P00003o0?ooocL0oooo
0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo0<@0oooo0P00003o0?ooocT0oooo0@00
00010?ooo`40oooo00130?ooo`030000003oool0oooo0<80oooo0P00003o0?oooc/0oooo0@000001
0?ooo`40oooo00130?ooo`<00000`03oool200000?l0oooo>`3oool300000080oooo00130?ooo`03
0000003oool0oooo0;h0oooo0P00003o0?ooocl0oooo0@0000010?ooo`40oooo00130?ooo`030000
003oool0oooo0;`0oooo0P00003o0?oood40oooo0@0000010?ooo`40oooo00130?ooo`030000003o
ool0oooo0;X0oooo0P00003o0?oood<0oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0
oooo0;T0oooo00<000000?ooo`3oool0o`3ooom30?ooo`4000000@3oool10?ooo`00@`3oool00`00
0000oooo0?ooo`2g0?ooo`800000o`3ooom60?ooo`4000000@3oool10?ooo`00@`3oool00`000000
oooo0?ooo`2e0?ooo`800000o`3ooom80?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo
0?ooo`2d0?ooo`030000003oool0oooo0?l0ooooB03oool100000040oooo0@3oool004<0oooo00<0
00000?ooo`3oool0/P3oool200000?l0ooooB`3oool100000040oooo0@3oool004<0oooo00<00000
0?ooo`3oool0/03oool200000?l0ooooC@3oool100000040oooo0@3oool004<0oooo00<000000?oo
o`3oool0[P3oool200000?l0ooooC`3oool100000040oooo0@3oool004<0oooo00<000000?ooo`3o
ool0[@3oool00`000000oooo0?ooo`3o0?ooodl0oooo0@0000010?ooo`40oooo00130?ooo`030000
003oool0oooo0:/0oooo0P00003o0?oooe80oooo0@0000010?ooo`40oooo00130?ooo`030000003o
ool0oooo0:T0oooo0P00003o0?oooe@0oooo0@0000010?ooo`40oooo00130?ooo`<00000Z03oool0
0`000000oooo0?ooo`3o0?oooe80oooo0`0000020?ooo`00@`3oool00`000000oooo0?ooo`2V0?oo
o`800000o`3ooomG0?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo0?ooo`2U0?ooo`03
0000003oool0oooo0?l0ooooE`3oool100000040oooo0@3oool004<0oooo00<000000?ooo`3oool0
X`3oool200000?l0ooooFP3oool100000040oooo0@3oool004<0oooo00<000000?ooo`3oool0X@3o
ool200000?l0ooooG03oool100000040oooo0@3oool004<0oooo00<000000?ooo`3oool0X03oool0
0`000000oooo0?ooo`3o0?oooe`0oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo
09h0oooo0P00003o0?oooel0oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo09d0
oooo00<000000?ooo`3oool0o`3ooomO0?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo
0?ooo`2K0?ooo`800000o`3ooomR0?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo0?oo
o`2I0?ooo`800000o`3ooomT0?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo0?ooo`2H
0?ooo`030000003oool0oooo0?l0ooooI03oool100000040oooo0@3oool004<0oooo00<000000?oo
o`3oool0U`3oool00`000000oooo0?ooo`3o0?ooofD0oooo0@0000010?ooo`40oooo00130?ooo`03
0000003oool0oooo09D0oooo0P00003o0?ooofP0oooo0@0000010?ooo`40oooo00130?ooo`030000
003oool0oooo09@0oooo00<000000?ooo`3oool0o`3ooomX0?ooo`4000000@3oool10?ooo`00@`3o
ool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0?l0ooooJ@3oool100000040oooo0@3o
ool004<0oooo0`00002B0?ooo`030000003oool0oooo0?l0ooooJ03oool300000080oooo00130?oo
o`030000003oool0oooo0900oooo0P00003o0?ooofd0oooo0@0000010?ooo`40oooo00130?ooo`03
0000003oool0oooo08l0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`4000000@3oool10?ooo`00
@`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0?l0ooooKP3oool100000040oooo
0@3oool004<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`3o0?ooofl0oooo0@00
00010?ooo`40oooo00130?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0o`3ooom`
0?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo0?ooo`2:0?ooo`800000o`3ooomc0?oo
o`4000000@3oool10?ooo`00@`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0?l0
ooooL`3oool100000040oooo0@3oool004<0oooo00<000000?ooo`3oool0R03oool00`000000oooo
0?ooo`3o0?ooog@0oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo08L0oooo00<0
00000?ooo`3oool0o`3ooome0?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo0?ooo`25
0?ooo`800000o`3ooomh0?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo0?ooo`240?oo
o`030000003oool0oooo0?l0ooooN03oool100000040oooo0@3oool004<0oooo00<000000?ooo`3o
ool0P`3oool00`000000oooo0?ooo`3o0?ooogT0oooo0@0000010?ooo`40oooo00130?ooo`030000
003oool0oooo0880oooo00<000000?ooo`3oool0o`3ooomj0?ooo`4000000@3oool10?ooo`00@`3o
ool300000840oooo00<000000?ooo`3oool0o`3ooomi0?ooo`<000000P3oool004<0oooo00<00000
0?ooo`3oool0P03oool00`000000oooo0?ooo`3o0?ooog`0oooo0@0000010?ooo`40oooo00130?oo
o`030000003oool0oooo07l0oooo00<000000?ooo`3oool0o`3ooomm0?ooo`4000000@3oool10?oo
o`00@`3oool00`000000oooo0?ooo`1m0?ooo`800000o`3ooon00?ooo`4000000@3oool10?ooo`00
@`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0?l0ooooP03oool100000040oooo
0@3oool004<0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`3o0?oooh40oooo0@00
00010?ooo`40oooo00130?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0o`3ooon2
0?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo
0?l0ooooP`3oool100000040oooo0@3oool004<0oooo00<000000?ooo`3oool0N03oool00`000000
oooo0?ooo`3o0?oooh@0oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo07L0oooo
00<000000?ooo`3oool0o`3ooon50?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo0?l0ooooQP3oool100000040oooo0@3oool002/0oooo0`000003
0?ooo`040000003oool0oooo0?ooo`800000303oool00`000000oooo0?ooo`1e0?ooo`030000003o
ool0oooo0?l0ooooQ`3oool100000040oooo0@3oool002X0oooo00D000000?ooo`3oool0oooo0000
00080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0L`3oool200000?l0ooooRP3o
ool100000040oooo0@3oool002X0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`3o0?ooohX0oooo0@00
00010?ooo`40oooo000P0?ooo`L000000`3oool01@000000oooo0?ooo`3oool0000000L0oooo1000
00090?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0o`3ooon;0?ooo`4000000@3o
ool10?ooo`00:P3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo
000000090?ooo`@00000K`3oool00`000000oooo0?ooo`3o0?ooohT0oooo100000020?ooo`00:P3o
ool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000090?ooo`03
0000003oool0oooo06l0oooo00<000000?ooo`3oool0o`3ooon=0?ooo`4000000@3oool10?ooo`00
:P3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000090?oo
o`030000003oool0oooo06h0oooo00<000000?ooo`3oool0o`3ooon>0?ooo`4000000@3oool10?oo
o`00:P3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo00000009
0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0o`3ooon?0?ooo`4000000@3oool1
0?ooo`00:P3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo0000
00090?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0o`3ooon@0?ooo`4000000@3o
ool10?ooo`00:`3oool3000000P0oooo0`00000:0?ooo`030000003oool0oooo06/0oooo00<00000
0?ooo`3oool0o`3ooonA0?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo0?ooo`1Z0?oo
o`030000003oool0oooo0?l0ooooTP3oool100000040oooo0@3oool004<0oooo00<000000?ooo`3o
ool0J@3oool00`000000oooo0?ooo`3o0?oooi<0oooo0@0000010?ooo`40oooo00130?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool0o`3ooonD0?ooo`4000000@3oool10?ooo`00@`3o
ool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo0@3o
ool004<0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`3o0?oooiH0oooo0@000001
0?ooo`40oooo00130?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0o`3ooonG0?oo
o`4000000@3oool10?ooo`00@`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0?l0
ooooV03oool100000040oooo0@3oool004<0oooo00<000000?ooo`3oool0I03oool00`000000oooo
0?ooo`3o0?oooiP0oooo0@0000010?ooo`40oooo00070?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0H`3oool00`000000oooo0?ooo`3o0?oooiT0oooo0@0000010?ooo`40oooo0007
0?ooo`<00000>@3oool300000680oooo00<000000?ooo`3oool0o`3ooonH0?ooo`<000000P3oool0
00L0oooo00<000000?ooo`3oool00`00000f0?ooo`030000003oool0oooo0640oooo00<000000?oo
o`3oool0o`3ooonK0?ooo`4000000@3oool10?ooo`00303oool2000003D0oooo00<000000?ooo`3o
ool0H03oool00`000000oooo0?ooo`3o0?oooi`0oooo0@0000010?ooo`40oooo00070?ooo`030000
003oool0oooo00800000=`3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0?l0oooo
W@3oool100000040oooo0@3oool000L0oooo0`00000i0?ooo`030000003oool0oooo05h0oooo00<0
00000?ooo`3oool0o`3ooonN0?ooo`4000000@3oool10?ooo`001`3oool00`000000oooo0?ooo`03
000003H0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`3o0?oooil0oooo0@000001
0?ooo`40oooo000<0?ooo`800000=@3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo
0?l0ooooX03oool100000040oooo0@3oool000L0oooo00<000000?ooo`3oool00P00000g0?ooo`03
0000003oool0oooo05/0oooo00<000000?ooo`3oool0o`3ooonQ0?ooo`4000000@3oool10?ooo`00
1`3oool3000003T0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`3o0?oooj80oooo
0@0000010?ooo`40oooo00070?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0F@3o
ool00`000000oooo0?ooo`3o0?oooj<0oooo0@0000010?ooo`40oooo00060?ooo`T00000=03oool0
0`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0?l0ooooX`3oool100000040oooo0@3oool0
00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool0o`3ooonT0?ooo`4000000@3oool10?ooo`00103oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`3o0?ooojD0oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool0o`3ooonV0?ooo`4000000@3oool10?ooo`001`3oool2000000@0oooo00<0
00000?ooo`3oool0<`3oool3000005H0oooo00<000000?ooo`3oool0o`3ooonT0?ooo`<000000P3o
ool000L0oooo00<000000?ooo`3oool00P3oool2000003D0oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`3o0?ooojL0oooo0@0000010?ooo`40oooo00070?ooo`030000003oool0oooo
0080000000<0oooo0000003oool0=03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo
0?l0ooooZ03oool100000040oooo0@3oool000L0oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`0c0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0o`3ooonY0?ooo`40
00000@3oool10?ooo`001`3oool2000000@0oooo00<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`1C0?ooo`030000003oool0oooo0?l0ooooZ@3oool100000040oooo0@3oool000L0oooo00<0
00000?ooo`3oool00P3oool2000003D0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`3o0?ooojX0oooo0@0000010?ooo`40oooo00040?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0?l0ooooZ`3oool1
00000040oooo0@3oool000D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo0500oooo00<000000?ooo`3oool0o`3ooon/0?ooo`4000000@3oool10?oo
o`001P3oool9000003@0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`3o0?oooj`0
oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0
o`3ooon]0?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo0?ooo`1>0?ooo`030000003o
ool0oooo0?l0oooo[P3oool100000040oooo0@3oool004<0oooo00<000000?ooo`3oool0CP3oool0
0`000000oooo0?ooo`3o0?ooojh0oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo
04d0oooo00<000000?ooo`3oool0o`3ooon_0?ooo`4000000@3oool10?ooo`00@`3oool00`000000
oooo0?ooo`1<0?ooo`030000003oool0oooo0?l0oooo/03oool100000040oooo0@3oool004<0oooo
00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?oook40oooo0@0000010?ooo`40oooo
00130?ooo`<00000B`3oool00`000000oooo0?ooo`3o0?ooojl0oooo0`0000020?ooo`00@`3oool0
0`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0?l0oooo/P3oool100000040oooo0@3oool0
04<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3o0?oook<0oooo0@0000010?oo
o`40oooo00130?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0o`3ooond0?ooo`40
00000@3oool10?ooo`00@`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0?l0oooo
]03oool100000040oooo0@3oool004<0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`3o0?oookD0oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0o`3ooonf0?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo0?l0oooo]P3oool100000040oooo0@3oool004<0oooo00<000000?ooo`3o
ool0A@3oool00`000000oooo0?ooo`3o0?oookL0oooo0@0000010?ooo`40oooo00130?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool0o`3ooonh0?ooo`4000000@3oool10?ooo`00@`3o
ool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0?l0oooo^03oool100000040oooo0@3o
ool004<0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`3o0?oookT0oooo0@000001
0?ooo`40oooo00130?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0o`3ooonj0?oo
o`4000000@3oool10?ooo`00@`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0?l0
oooo^P3oool100000040oooo0@3oool004<0oooo0`0000110?ooo`030000003oool0oooo0?l0oooo
^@3oool300000080oooo00130?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0o`3o
oonl0?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo0?l0oooo_03oool100000040oooo0@3oool004<0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`3o0?oookd0oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`3oool0o`3ooonn0?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo0?l0oooo_P3oool100000040oooo0@3oool004<0oooo00<0
00000?ooo`3oool0?@3oool00`000000oooo0?ooo`3o0?oookl0oooo0@0000010?ooo`40oooo0013
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0o`3oooo00?ooo`4000000@3oool1
0?ooo`00@`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0?l0oooo`03oool10000
0040oooo0@3oool004<0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?oool40
oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
o`3oooo10?ooo`4000000@3oool10?ooo`00903oool3000000<0oooo00<000000?ooo`3oool00P3o
ool3000000<0oooo0`00000;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0o`3o
ooo20?ooo`4000000@3oool10?ooo`008`3oool01@000000oooo0?ooo`3oool0000000H0oooo00D0
00000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`3o0?oool<0oooo0@0000010?ooo`40oooo000S0?ooo`050000003o
ool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0?l0oooo``3oool100000040
oooo0@3oool001T0oooo1`0000030?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000
oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo0?l0ooooa03oool100000040oooo0@3oool002<0oooo00D000000?ooo`3o
ool0oooo000000070?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool01`3oool40000
03H0oooo00<000000?ooo`3oool0o`3oooo20?ooo`@000000P3oool002<0oooo00D000000?ooo`3o
ool0oooo000000080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo0?l0ooooa@3oool100000040oooo0@3oool002<0
oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0000000<0oooo0`00000;0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0o`3oooo60?ooo`4000000@3oool10?oo
o`008`3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`3o
0?ooolL0oooo0@0000010?ooo`40oooo000S0?ooo`050000003oool0oooo0?ooo`0000001P3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0e0?ooo`030000003oool0oooo0?l0ooooa`3oool100000040oooo0@3oool002@0oooo0`000008
0?ooo`<00000103oool4000000T0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`3o
0?ooolP0oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo03<0oooo00<000000?oo
o`3oool0o`3oooo90?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo0?l0oooob@3oool100000040oooo0@3oool004<0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`3o0?ooolX0oooo0@0000010?ooo`40oooo00130?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool0o`3oooo:0?ooo`4000000@3oool10?ooo`00@`3oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0?l0oooob`3oool100000040oooo0@3oool0
04<0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`3o0?oool/0oooo0@0000010?oo
o`40oooo00130?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0o`3oooo<0?ooo`40
00000@3oool10?ooo`00@`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0?l0oooo
c03oool100000040oooo0@3oool004<0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`3o0?ooold0oooo0@0000010?ooo`40oooo00130?ooo`<00000;`3oool00`000000oooo0?ooo`3o
0?oool/0oooo0`0000020?ooo`00@`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
0?l0oooocP3oool100000040oooo0@3oool004<0oooo00<000000?ooo`3oool0;P3oool00`000000
oooo0?ooo`3o0?ooolh0oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool0o`3oooo?0?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo0?l0ooooc`3oool100000040oooo0@3oool004<0oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`3o0?ooom00oooo0@0000010?ooo`40oooo00130?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0o`3oooo@0?ooo`4000000@3oool10?oo
o`00@`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0ooood@3oool100000040
oooo0@3oool004<0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`3o0?ooom40oooo
0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0o`3o
oooB0?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo0?l0oooodP3oool100000040oooo0@3oool004<0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`3o0?ooom<0oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0o`3ooooC0?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo0?l0ooooe03oool100000040oooo0@3oool004<0oooo0`00
000X0?ooo`030000003oool0oooo0?l0oooodP3oool300000080oooo00130?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool0o`3ooooE0?ooo`4000000@3oool10?ooo`00@`3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo0?l0ooooe@3oool100000040oooo0@3oool004<0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3o0?ooomD0oooo0@0000010?ooo`40
oooo00130?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0o`3ooooF0?ooo`400000
0@3oool10?ooo`00@`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0?l0ooooeP3o
ool100000040oooo0@3oool004<0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3o
0?ooomL0oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool0o`3ooooG0?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo0?l0oooof03oool100000040oooo0@3oool004<0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`3o0?ooomP0oooo0@0000010?ooo`40oooo00130?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0o`3ooooI0?ooo`4000000@3oool10?ooo`00@`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0?l0oooof@3oool100000040oooo0@3oool0
04<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3o0?ooomX0oooo0@0000010?oo
o`40oooo00130?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0o`3ooooJ0?ooo`40
00000@3oool10?ooo`00@`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0oooo
f`3oool100000040oooo0@3oool004<0oooo0`00000Q0?ooo`030000003oool0oooo0?l0oooof@3o
ool300000080oooo00130?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0o`3ooooL
0?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
0?l0oooog03oool100000040oooo0@3oool004<0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`3o0?ooomd0oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool0o`3ooooM0?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo0?l0oooogP3oool100000040oooo0@3oool004<0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`3o0?ooomh0oooo0@0000010?ooo`40oooo00130?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0o`3ooooO0?ooo`4000000@3oool10?oo
o`00@`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0?l0oooog`3oool100000040
oooo0@3oool004<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3o0?oooml0oooo
0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0o`3o
oooP0?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo0?l0ooooh03oool100000040oooo0@3oool004<0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`3o0?ooon40oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0o`3ooooQ0?ooo`4000000@3oool10?ooo`00@`3oool3000001/0oooo
00<000000?ooo`3oool0o`3ooooO0?ooo`<000000P3oool004<0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`3o0?ooon80oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0o`3ooooR0?ooo`4000000@3oool10?ooo`00@`3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo0?l0oooohP3oool100000040oooo0@3oool004<0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3o0?ooon<0oooo0@0000010?ooo`40
oooo00130?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0o`3ooooS0?ooo`400000
0@3oool10?ooo`00@`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0?l0ooooi03o
ool100000040oooo0@3oool004<0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`3o
0?ooon@0oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0o`3ooooT0?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo0?l0ooooi@3oool100000040oooo0@3oool004<0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`3o0?ooonD0oooo0@0000010?ooo`40oooo000[0?ooo`<000000`3o
ool00`000000oooo0?ooo`020?ooo`<000002P3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo0?l0ooooiP3oool100000040oooo0@3oool002X0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo0?l0ooooiP3oool100000040oooo0@3oool002X0oooo00D000000?ooo`3oool0oooo
000000060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo0?l0ooooiP3oool100000040oooo0@3oool00200oooo1`0000030?ooo`050000
003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`3o0?ooonL0oooo0@0000010?ooo`40oooo000Z0?ooo`05
0000003oool0oooo0?ooo`0000001`3oool00`000000oooo0000000:0?ooo`@00000503oool00`00
0000oooo0?ooo`3o0?ooon@0oooo100000020?ooo`00:P3oool01@000000oooo0?ooo`3oool00000
00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
0?l0ooooi`3oool100000040oooo0@3oool002X0oooo00D000000?ooo`3oool0oooo000000070?oo
o`030000003oool0000000X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3o0?oo
onP0oooo0@0000010?ooo`40oooo000Z0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@00
0000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3o
0?ooonP0oooo0@0000010?ooo`40oooo000Z0?ooo`050000003oool0oooo0?ooo`0000001P3oool0
1@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`3o0?ooonT0oooo0@0000010?ooo`40oooo000[0?ooo`<00000203oool3000000X0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`3o0?ooonT0oooo0@0000010?ooo`40oooo00130?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0o`3ooooY0?ooo`4000000@3oool10?oo
o`00@`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0oooojP3oool100000040
oooo0@3oool004<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3o0?ooonX0oooo
0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0o`3o
ooo[0?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0?l0ooooj`3oool100000040oooo0@3oool004<0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`3o0?ooon/0oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0o`3oooo/0?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0?l0ooook03oool100000040oooo0@3oool004<0oooo0`00
000@0?ooo`030000003oool0oooo0?l0oooojP3oool300000080oooo00130?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0o`3oooo]0?ooo`4000000@3oool10?ooo`00@`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooook@3oool100000040oooo0@3oool004<0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?ooonh0oooo0@0000010?ooo`40
oooo00130?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3oooo^0?ooo`400000
0@3oool10?ooo`00@`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0ooookP3o
ool100000040oooo0@3oool004<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o
0?ooonl0oooo0@0000010?ooo`40oooo00130?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0o`3oooo_0?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo0?l0ooool03oool100000040oooo0@3oool004<0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`3o0?oooo00oooo0@0000010?ooo`40oooo00130?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0o`3oooo`0?ooo`4000000@3oool10?ooo`00@`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooool@3oool100000040oooo0@3oool0
04<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?oooo40oooo0@0000010?oo
o`40oooo00130?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooooa0?ooo`40
00000@3oool10?ooo`00@`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0oooo
lP3oool100000040oooo0@3oool004<0oooo0`00000:0?ooo`030000003oool0oooo0?l0ooool03o
ool300000080oooo00130?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooooc
0?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0?l0ooool`3oool100000040oooo0@3oool004<0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`40
00000@3oool10?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooool0oooo0@0000010?ooo`40oooo
00130?ooo`030000003oool0oooo0?l0ooooo`3oool100000040oooo0@3oool004<0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo07L0oooo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo00T0oooo0@000001
0?ooo`40oooo00130?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0M`3oool00`00
0000oooo0?ooo`1g0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0M`3oool00`00
0000oooo0?ooo`090?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`090?ooo`40
00000@3oool10?ooo`00@`3ooooo00000?l00000100000020?ooo`00\
\>"],
  ImageRangeCache->{{{0, 582}, {359.313, 0}} -> {-0.324638, -1.01996, \
0.00409075, 0.000685968}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ 
      Find\ chi\ square\ for\ given\ H \((z)\)\ \ *) \[IndentingNewLine]\(f[
          z_] := 1/hhz[z];\)\), "\n", 
    \(\(rr[zz_] := NIntegrate[f[z], {z, 0, zz}];\)\[IndentingNewLine]\n (*\ 
      Construct\ marginalization\ coefficients\ \((see\ \ astro - 
              ph/0401556\  .. )\)\ *) \), "\[IndentingNewLine]", 
    \(Clear[chi2fa, chi2fb, chi2fc]\), "\n", 
    \(\(chi2fa = 
        Sum[\((ld[i] - 5\ Log[10, rr[zz[i]]*\((1 + zz[i])\)])\)^2/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\n", 
    \(\(chi2fb = 
        Sum[\((ld[i] - 
                5\ Log[10, rr[zz[i]]*\((1 + zz[i])\)])\)/\((sld[i]^2)\), {i, 
            1, ndat}];\)\), "\n", 
    \(\(chi2fc = 
        Sum[1/\((sld[i]^2)\), {i, 1, ndat}];\)\[IndentingNewLine]\n (*\ 
      Construct\ function\ after\ marginalization, \ 
      find\ same\ result\ as\ with\ mb\ minimization\ *) \), "\
\[IndentingNewLine]", 
    \(chi2fm = chi2fa - chi2fb^2/chi2fc\), "\[IndentingNewLine]", 
    \(dchi2q15 = chi2fm - chi2l\)}], "Input"],

Cell[BoxData[
    \(180.38770070672035`\)], "Output"],

Cell[BoxData[
    \(3.2603292716667056`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ \(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(\
--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(-\(---\)\)\)\)\)\)\)\)\)\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)*) \[IndentingNewLine]\[IndentingNewLine] \
(*\ Find\ H \((z)\)\ for\ given\ slope\ s\ of\ the\ linear\ potential . \ 
            Present\ time\  = \ \(tt\ \((corresponds\ to\ a = 1)\) . \ 
              Run\ trials\ for\ initial\ condition\ for\ field\ fi\ \((f0)\)\ \
and\ initial\ time\ ti\ until\ we\ get\ field\ energy\ enf\  = \ \(0.7\ and\ \
H \((z = 0)\)\  = 
            1\ at\ present\ time\ \(\(tt\)\(.\)\)\)\)\ *) \[IndentingNewLine]\
\[IndentingNewLine] (*\ \(--\(--\(--\(--\ \ s\)\)\)\)\  = \ \(2\ \ \ --\) \(\
--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(---\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\ *) \
\[IndentingNewLine]\[IndentingNewLine]\(Clear[aa, fi, a, aad, aadd, fidas, 
        tas, f, rr, hht, hha];\)\), "\[IndentingNewLine]", 
    \(aa = a[t]; \ fi = f[t];\), "\n", 
    \(\(aad = D[aa, t];\)\), "\n", 
    \(\(aadd = D[aa, {t, 2}];\)\), "\n", 
    \(\(fid = D[fi, t];\)\), "\n", 
    \(\(fidd = D[fi, {t, 2}];\)\), "\n", 
    \(ti = 0.000025; \ t0 = 2.25;\), "\n", 
    \(\(f0 = \(-0.543\);\)\ \), "\n", 
    \(om0m = 0.3; \ ss = 2;\), "\n", 
    \(\(eq1 = 
        aadd/aa\  \[Equal] \(-\ \ fid^2\)\  - \ ss\ fi\  - \ 
            om0m/\((2\ aa^3)\);\)\), "\n", 
    \(\(eq2 = 
        fidd\ \  + \ \ \ 3\ \ fid\ \((aad/aa)\)\  - \ ss \[Equal] 
          0;\)\), "\n", 
    \(\(eqb1 = f[ti] == f0;\)\), "\n", 
    \(\(eqb2 = \(f'\)[ti] == 0;\)\), "\n", 
    \(\(eqb3 = 
        a[ti] \[Equal] \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((2/3)\);\)\), "\n", 
    \(\(eqb4 = \(a'\)[
            ti] \[Equal] \((2/
                3)\)\ \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((\(-1\)/
                  3)\);\)\), "\n", 
    \(\(sol2 = 
        NDSolve[{eq1, eq2, eqb1, eqb2, eqb3, eqb4}, {aa, fi}, {t, ti, t0}, 
          MaxSteps \[Rule] 10000000];\)\), "\n", 
    \(\(asol = Part[Evaluate[a[t] /. sol2], 1];\)\), "\n", 
    \(\(fsol = Part[Evaluate[f[t] /. sol2], 1];\)\), "\n", 
    \(\(dfsol = D[fsol, t];\)\), "\[IndentingNewLine]", 
    \(\(enf = 0.5\ dfsol^2\  - \ ss\ fsol;\)\), "\[IndentingNewLine]", 
    \(\(as[t1_] := asol\  /. \ t -> t1\ ;\)\), "\[IndentingNewLine]", 
    \(\(tt = Part[FindRoot[as[t] == 1, {t, 1}], 1, 2];\)\), "\n", 
    \(\(tas[a_] := 
        Part[FindRoot[as[t] \[Equal] a, {t, 1}], 1, 2];\)\), "\n", 
    \(\(hht[t1_] := D[asol, t]/asol\  /. \ t -> t1\ ;\)\), "\n", 
    \(\(hha[a_] := hht[tas[a]];\)\), "\[IndentingNewLine]", 
    \(\(hhz[z_] := hha[1/\((z + 1)\)];\)\), "\[IndentingNewLine]", 
    \(enf\  /. \ t \[Rule] tt\), "\[IndentingNewLine]", 
    \(hhz[0]\), "\[IndentingNewLine]", 
    \(\(enf = 0.5\ dfsol^2\  - \ ss\ fsol;\)\), "\n", 
    \(\(ppf = 0.5\ dfsol^2\  + \ ss\ fsol;\)\), "\n", 
    \(\(wft[t1_] := ppf/enf\  /. \ t -> t1\ ;\)\ \), "\n", 
    \(\(wfa[a_] := wft[tas[a]];\)\), "\n", 
    \(\(wfz[z_] := wfa[1/\((z + 1)\)];\)\), "\n", 
    \(\(plw20q = 
        Plot[wfz[z], {z, 0, 2}, Frame \[Rule] True, PlotRange \[Rule] All, 
          FrameLabel \[Rule] {"\<z\>", "\<w(z)\>"}];\)\)}], "Input"],

Cell[BoxData[
    \(0.7012996072665285`\)], "Output"],

Cell[BoxData[
    \(1.0019365764555734`\)], "Output"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(plw20q\)\" is similar \
to existing symbol \"\!\(plw02q\)\"."\)], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.476191 1.61546 1.63548 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.2619 -0.0125 -10.7813 -17.8125 ]
[.2619 -0.0125 10.7813 0 ]
[.5 -0.0125 -5.53125 -17.8125 ]
[.5 -0.0125 5.53125 0 ]
[.7381 -0.0125 -10.7813 -17.8125 ]
[.7381 -0.0125 10.7813 0 ]
[.97619 -0.0125 -5.53125 -17.8125 ]
[.97619 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.125 -35.625 ]
[.5 -0.0125 5.125 -17.8125 ]
[-0.0125 .06176 -38.3125 -8.90625 ]
[-0.0125 .06176 0 8.90625 ]
[-0.0125 .14353 -31.25 -8.90625 ]
[-0.0125 .14353 0 8.90625 ]
[-0.0125 .2253 -38.3125 -8.90625 ]
[-0.0125 .2253 0 8.90625 ]
[-0.0125 .30708 -31.25 -8.90625 ]
[-0.0125 .30708 0 8.90625 ]
[-0.0125 .38885 -38.3125 -8.90625 ]
[-0.0125 .38885 0 8.90625 ]
[-0.0125 .47063 -31.25 -8.90625 ]
[-0.0125 .47063 0 8.90625 ]
[-0.0125 .5524 -38.3125 -8.90625 ]
[-0.0125 .5524 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -56.125 -14.7188 ]
[-0.01875 .30902 -38.3125 14.7188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.125 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .06176 m
.00625 .06176 L
s
gsave
-0.0125 .06176 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
1.000 setlinewidth
grestore
0 .14353 m
.00625 .14353 L
s
gsave
-0.0125 .14353 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
1.000 setlinewidth
grestore
0 .2253 m
.00625 .2253 L
s
gsave
-0.0125 .2253 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.85) show
1.000 setlinewidth
grestore
0 .30708 m
.00625 .30708 L
s
gsave
-0.0125 .30708 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .38885 m
.00625 .38885 L
s
gsave
-0.0125 .38885 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .47063 m
.00625 .47063 L
s
gsave
-0.0125 .47063 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
1.000 setlinewidth
grestore
0 .5524 m
.00625 .5524 L
s
gsave
-0.0125 .5524 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.65) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .07811 m
.00375 .07811 L
s
0 .09447 m
.00375 .09447 L
s
0 .11082 m
.00375 .11082 L
s
0 .12718 m
.00375 .12718 L
s
0 .15989 m
.00375 .15989 L
s
0 .17624 m
.00375 .17624 L
s
0 .19259 m
.00375 .19259 L
s
0 .20895 m
.00375 .20895 L
s
0 .24166 m
.00375 .24166 L
s
0 .25801 m
.00375 .25801 L
s
0 .27437 m
.00375 .27437 L
s
0 .29072 m
.00375 .29072 L
s
0 .32343 m
.00375 .32343 L
s
0 .33979 m
.00375 .33979 L
s
0 .35614 m
.00375 .35614 L
s
0 .3725 m
.00375 .3725 L
s
0 .40521 m
.00375 .40521 L
s
0 .42156 m
.00375 .42156 L
s
0 .43792 m
.00375 .43792 L
s
0 .45427 m
.00375 .45427 L
s
0 .48698 m
.00375 .48698 L
s
0 .50334 m
.00375 .50334 L
s
0 .51969 m
.00375 .51969 L
s
0 .53605 m
.00375 .53605 L
s
0 .0454 m
.00375 .0454 L
s
0 .02905 m
.00375 .02905 L
s
0 .01269 m
.00375 .01269 L
s
0 .56876 m
.00375 .56876 L
s
0 .58511 m
.00375 .58511 L
s
0 .60147 m
.00375 .60147 L
s
0 .61782 m
.00375 .61782 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -122.938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.7188 12.9063 translate
90 rotate
-75.7188 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.063 17.500 moveto
(H) show
77.625 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.875 17.500 moveto
(L) show
88.438 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06176 m
1 .06176 L
s
.99375 .14353 m
1 .14353 L
s
.99375 .2253 m
1 .2253 L
s
.99375 .30708 m
1 .30708 L
s
.99375 .38885 m
1 .38885 L
s
.99375 .47063 m
1 .47063 L
s
.99375 .5524 m
1 .5524 L
s
.125 Mabswid
.99625 .07811 m
1 .07811 L
s
.99625 .09447 m
1 .09447 L
s
.99625 .11082 m
1 .11082 L
s
.99625 .12718 m
1 .12718 L
s
.99625 .15989 m
1 .15989 L
s
.99625 .17624 m
1 .17624 L
s
.99625 .19259 m
1 .19259 L
s
.99625 .20895 m
1 .20895 L
s
.99625 .24166 m
1 .24166 L
s
.99625 .25801 m
1 .25801 L
s
.99625 .27437 m
1 .27437 L
s
.99625 .29072 m
1 .29072 L
s
.99625 .32343 m
1 .32343 L
s
.99625 .33979 m
1 .33979 L
s
.99625 .35614 m
1 .35614 L
s
.99625 .3725 m
1 .3725 L
s
.99625 .40521 m
1 .40521 L
s
.99625 .42156 m
1 .42156 L
s
.99625 .43792 m
1 .43792 L
s
.99625 .45427 m
1 .45427 L
s
.99625 .48698 m
1 .48698 L
s
.99625 .50334 m
1 .50334 L
s
.99625 .51969 m
1 .51969 L
s
.99625 .53605 m
1 .53605 L
s
.99625 .0454 m
1 .0454 L
s
.99625 .02905 m
1 .02905 L
s
.99625 .01269 m
1 .01269 L
s
.99625 .56876 m
1 .56876 L
s
.99625 .58511 m
1 .58511 L
s
.99625 .60147 m
1 .60147 L
s
.99625 .61782 m
1 .61782 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .60332 m
.06244 .48263 L
.10458 .38954 L
.14415 .32451 L
.18221 .27549 L
.22272 .23362 L
.26171 .20072 L
.30316 .1718 L
.34309 .14852 L
.3815 .1295 L
.42237 .11223 L
.46172 .09797 L
.49955 .08607 L
.53984 .07505 L
.57861 .0658 L
.61984 .05719 L
.65954 .04992 L
.69774 .04374 L
.73838 .03792 L
.77751 .03295 L
.81909 .02825 L
.85916 .02423 L
.89771 .02076 L
.93871 .01744 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{584.875, 361.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000980001JB000`400?l00000o`00003oo`3ooooo
0?ooodX0oooo003o0?ooool0ooooBP3oool00?l0ooooo`3ooom:0?ooo`00o`3ooooo0?ooodX0oooo
003o0?ooool0ooooBP3oool00?l0oooo@P3oool600000?l0oooo0P3oool00?l0oooo@`3oool01@00
0000oooo0?ooo`3oool000000?l0oooo0P3oool00?l0ooooA03oool00`000000oooo0?ooo`3o0?oo
o`<0oooo003o0?oood@0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3ooom50?ooo`030000
003oool0oooo0?l0oooo0P3oool00?l0oooo@P3oool01@000000oooo0?ooo`3oool000000?l0oooo
0`3oool00?l0oooo@P3oool600000?l0oooo0P3oool00?l0ooooo`3ooom:0?ooo`00o`3ooooo0?oo
odX0oooo003o0?ooool0ooooBP3oool00?l0ooooo`3ooom:0?ooo`00o`3ooooo0?ooodX0oooo003o
0?ooool0ooooBP3oool00?l0ooooo`3ooom:0?ooo`00o`3ooooo0?ooodX0oooo003o0?ooool0oooo
BP3oool00?l0ooooo`3ooom:0?ooo`00o`3ooooo0?ooodX0oooo001=0?ooo`<00000L`3oool30000
00<0oooo00@000000?ooo`3oool0oooo0`00001c0?ooo`<00000LP3oool3000000<0oooo00@00000
0?ooo`3oool0oooo0`00001b0?ooo`D00000303oool004`0oooo00D000000?ooo`3oool0oooo0000
001a0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`1a0?ooo`030000
003oool0oooo0780oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1`0?ooo`040000
003oool0oooo000000`0oooo001<0?ooo`050000003oool0oooo0?ooo`000000L@3oool01@000000
oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`1b0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0<0?oo
o`00C03oool01@000000oooo0?ooo`3oool000000740oooo00D000000?ooo`3oool0oooo0000000:
0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool02`3oool004`0oooo00D000000?oo
o`3oool0oooo0000001a0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?oo
o`1`0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`1a0?ooo`030000003oool0oooo00/0oooo001<0?ooo`050000003oool0oooo0?ooo`000000L@3o
ool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0L@3oool00`000000oooo
0?ooo`1b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0L`3oool00`000000oooo
0?ooo`0:0?ooo`00C03oool01@000000oooo0?ooo`3oool000000740oooo00D000000?ooo`3oool0
oooo000000060?ooo`<00000M03oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo00H0
oooo0`00001f0?ooo`030000003oool0oooo00X0oooo001<0?ooo`050000003oool0oooo0?ooo`00
0000L@3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`1b0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0MP3oool00`00
0000oooo0?ooo`0:0?ooo`00C03oool01@000000oooo0?ooo`3oool000000740oooo00D000000?oo
o`3oool0oooo000000070?ooo`030000003oool0oooo0780oooo0P00001c0?ooo`8000002@3oool0
0`000000oooo0?ooo`1a0?ooo`050000003oool0oooo0?ooo`000000303oool004d0oooo0`00001c
0?ooo`<00000203oool400000780oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`07
0?ooo`@00000L@3oool3000000d0oooo003o0?ooool0ooooBP3oool00?l0ooooo`3ooom:0?ooo`00
o`3ooooo0?ooodX0oooo003o0?ooool0ooooBP3oool00?l0ooooo`3ooom:0?ooo`00o`3ooooo0?oo
odX0oooo003o0?ooool0ooooBP3oool00?l0ooooo`3ooom:0?ooo`00o`3ooooo0?ooodX0oooo0013
0?ooool00000o`00000600000040oooo00130?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00T0oooo0@0000010?oo
o`00@`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`090?ooo`4000000@3oool004<0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00T0oooo0@0000010?ooo`00@`3o
ool00`000000oooo0?ooo`3o0?ooool0oooo0P3oool100000040oooo00130?ooo`030000003oool0
oooo0?l0ooooo`3oool20?ooo`4000000@3oool004<0oooo00<000000?ooo`3oool0o`3ooooo0?oo
o`80oooo0@0000010?ooo`00@`3oool300000?l0ooooo`3oool300000040oooo00130?ooo`030000
003oool0oooo0?l0ooook03oool:000000/0oooo0@0000010?ooo`00@`3oool00`000000oooo0?oo
o`3o0?ooom`0oooo4000000E0?ooo`4000000@3oool004<0oooo00<000000?ooo`3oool0o`3ooooB
0?ooo`X000009@3oool100000040oooo00130?ooo`030000003oool0oooo0?l0oooob03oool:0000
02l0oooo0@0000010?ooo`00@`3oool00`000000oooo0?ooo`3o0?oookh0oooo2P00000i0?ooo`40
00000@3oool004<0oooo00<000000?ooo`3oool0o`3ooond0?ooo`X00000@`3oool100000040oooo
00130?ooo`030000003oool0oooo0?l0ooooZP3oool:000004d0oooo0@0000010?ooo`00@`3oool3
00000?l0ooooW`3oool;000005D0oooo0`0000010?ooo`00@`3oool00`000000oooo0?ooo`3o0?oo
oi@0oooo2`00001R0?ooo`4000000@3oool004<0oooo00<000000?ooo`3oool0o`3ooon;0?ooo`T0
0000K@3oool100000040oooo00130?ooo`030000003oool0oooo0?l0ooooQ@3oool6000007H0oooo
0@0000010?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooogh0oooo1`00001l0?ooo`4000000@3o
ool004<0oooo00<000000?ooo`3oool0o`3ooomg0?ooo`L00000P`3oool100000040oooo00130?oo
o`030000003oool0oooo0?l0ooooL03oool7000008X0oooo0@0000010?ooo`00@`3oool00`000000
oooo0?ooo`3o0?ooofT0oooo1`00002A0?ooo`4000000@3oool004<0oooo0`00003o0?ooof80oooo
1`00002F0?ooo`<000000@3oool004<0oooo00<000000?ooo`3oool0o`3ooomL0?ooo`H00000W`3o
ool100000040oooo00130?ooo`030000003oool0oooo0?l0ooooE@3oool700000:D0oooo0@000001
0?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooodl0oooo1P00002/0?ooo`4000000@3oool004<0
oooo00<000000?ooo`3oool0o`3ooom:0?ooo`D00000/P3oool100000040oooo000T0?ooo`<00000
0`3oool010000000oooo0?ooo`3oool2000000D0oooo0`00000;0?ooo`030000003oool0oooo0?l0
ooooA@3oool500000;L0oooo0@0000010?ooo`008`3oool01@000000oooo0?ooo`3oool0000000P0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0
oooo@03oool500000;`0oooo0@0000010?ooo`008`3oool01@000000oooo0?ooo`3oool0000000T0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0
oooo>`3oool500000<40oooo0@0000010?ooo`006@3oool7000000<0oooo00D000000?ooo`3oool0
oooo000000070?ooo`@000001P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0
oooo=P3oool500000<H0oooo0@0000010?ooo`008`3oool01@000000oooo0?ooo`3oool0000000H0
oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00L0oooo1000003o0?oo
obl0oooo1P0000380?ooo`@000000@3oool002<0oooo00D000000?ooo`3oool0oooo000000060?oo
o`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0?l0oooo:`3oool500000=40oooo0@0000010?ooo`008`3oool01@000000oooo0?ooo`3oool0
000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`<000002`3oool00`000000oooo0?oo
o`3o0?ooobL0oooo1000003F0?ooo`4000000@3oool002<0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo0?l0oooo8`3oool400000=X0oooo0@0000010?ooo`008`3oool01@000000oooo0?oo
o`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0o`3ooolO0?ooo`@00000gP3oool100000040oooo000T0?ooo`<00000
203oool3000000@0oooo100000090?ooo`030000003oool0oooo0?l0oooo6`3oool400000>80oooo
0@0000010?ooo`00@`3oool00`000000oooo0?ooo`3o0?oooaL0oooo1000003V0?ooo`4000000@3o
ool004<0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`D00000jP3oool100000040oooo00130?oo
o`<00000o`3oool>0?ooo`@00000k@3oool300000040oooo00130?ooo`030000003oool0oooo0?l0
oooo2P3oool400000?<0oooo0@0000010?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooo`H0oooo
1000003g0?ooo`4000000@3oool004<0oooo00<000000?ooo`3oool0o`3oool20?ooo`@00000n`3o
ool100000040oooo00130?ooo`030000003oool0oooo0?d0oooo1000003o0?ooo`4000000@3oool0
04<0oooo00<000000?ooo`3oool0nP3oool300000?l0oooo103oool100000040oooo00130?ooo`03
0000003oool0oooo0?P0oooo0P00003o0?ooo`L0oooo0@0000010?ooo`00@`3oool00`000000oooo
0?ooo`3e0?ooo`<00000o`3oool90?ooo`4000000@3oool004<0oooo00<000000?ooo`3oool0lP3o
ool300000?l0oooo303oool100000040oooo00130?ooo`<00000l03oool200000?l0oooo3@3oool3
00000040oooo00130?ooo`030000003oool0oooo0>d0oooo0`00003o0?oooa40oooo0@0000010?oo
o`00@`3oool00`000000oooo0?ooo`3Z0?ooo`<00000o`3ooolD0?ooo`4000000@3oool004<0oooo
00<000000?ooo`3oool0i`3oool300000?l0oooo5`3oool100000040oooo00130?ooo`030000003o
ool0oooo0>@0oooo0`00003o0?oooaX0oooo0@0000010?ooo`00@`3oool00`000000oooo0?ooo`3Q
0?ooo`<00000o`3ooolM0?ooo`4000000@3oool004<0oooo00<000000?ooo`3oool0gP3oool30000
0?l0oooo803oool100000040oooo00130?ooo`030000003oool0oooo0=/0oooo0`00003o0?ooob<0
oooo0@0000010?ooo`00@`3oool300000=P0oooo0`00003o0?ooob@0oooo0`0000010?ooo`00@`3o
ool00`000000oooo0?ooo`3E0?ooo`<00000o`3ooolY0?ooo`4000000@3oool004<0oooo00<00000
0?ooo`3oool0d`3oool200000?l0oooo;03oool100000040oooo00130?ooo`030000003oool0oooo
0=40oooo0P00003o0?ooobh0oooo0@0000010?ooo`00@`3oool00`000000oooo0?ooo`3>0?ooo`<0
0000o`3oool`0?ooo`4000000@3oool004<0oooo00<000000?ooo`3oool0c03oool200000?l0oooo
<`3oool100000040oooo00130?ooo`030000003oool0oooo0<X0oooo0P00003o0?ooocD0oooo0@00
00010?ooo`00@`3oool00`000000oooo0?ooo`370?ooo`<00000o`3ooolg0?ooo`4000000@3oool0
04<0oooo00<000000?ooo`3oool0a@3oool200000?l0oooo>P3oool100000040oooo00130?ooo`<0
0000``3oool200000?l0oooo>P3oool300000040oooo00130?ooo`030000003oool0oooo0<40oooo
0P00003o0?oooch0oooo0@0000010?ooo`00@`3oool00`000000oooo0?ooo`2o0?ooo`800000o`3o
oom00?ooo`4000000@3oool004<0oooo00<000000?ooo`3oool0_@3oool200000?l0oooo@P3oool1
00000040oooo000[0?ooo`<000000`3oool010000000oooo0?ooo`3oool2000000`0oooo00<00000
0?ooo`3oool0^`3oool200000?l0ooooA03oool100000040oooo000Z0?ooo`050000003oool0oooo
0?ooo`000000203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0;T0oooo0P00003o
0?ooodH0oooo0@0000010?ooo`00:P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`2g0?ooo`800000o`3ooom80?ooo`4000000@3oool0
0200oooo1`0000030?ooo`050000003oool0oooo0?ooo`0000001`3oool4000000T0oooo00<00000
0?ooo`3oool0]@3oool200000?l0ooooBP3oool100000040oooo000Z0?ooo`050000003oool0oooo
0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000T0oooo1000002b0?ooo`800000o`3o
oom90?ooo`@000000@3oool002X0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003o
ool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`2a0?ooo`800000o`3ooom>0?ooo`400000
0@3oool002X0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`00
00002@3oool00`000000oooo0?ooo`2_0?ooo`800000o`3ooom@0?ooo`4000000@3oool002X0oooo
00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`00
0000oooo0?ooo`2]0?ooo`800000o`3ooomB0?ooo`4000000@3oool002X0oooo00D000000?ooo`3o
ool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`2[
0?ooo`800000o`3ooomD0?ooo`4000000@3oool002/0oooo0`0000080?ooo`<000002P3oool00`00
0000oooo0?ooo`2Y0?ooo`800000o`3ooomF0?ooo`4000000@3oool004<0oooo00<000000?ooo`3o
ool0Z03oool00`000000oooo0?ooo`3o0?oooeH0oooo0@0000010?ooo`00@`3oool00`000000oooo
0?ooo`2V0?ooo`800000o`3ooomI0?ooo`4000000@3oool004<0oooo0`00002T0?ooo`800000o`3o
oomI0?ooo`<000000@3oool004<0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`3o
0?oooe/0oooo0@0000010?ooo`00@`3oool00`000000oooo0?ooo`2Q0?ooo`800000o`3ooomN0?oo
o`4000000@3oool004<0oooo00<000000?ooo`3oool0W`3oool200000?l0ooooH03oool100000040
oooo00130?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0o`3ooomP0?ooo`400000
0@3oool004<0oooo00<000000?ooo`3oool0W03oool200000?l0ooooH`3oool100000040oooo0013
0?ooo`030000003oool0oooo09X0oooo0P00003o0?ooofD0oooo0@0000010?ooo`00@`3oool00`00
0000oooo0?ooo`2I0?ooo`030000003oool0oooo0?l0ooooI@3oool100000040oooo00130?ooo`03
0000003oool0oooo09L0oooo0P00003o0?ooofP0oooo0@0000010?ooo`00@`3oool3000009H0oooo
00<000000?ooo`3oool0o`3ooomV0?ooo`<000000@3oool004<0oooo00<000000?ooo`3oool0U03o
ool200000?l0ooooJ`3oool100000040oooo00130?ooo`030000003oool0oooo0980oooo0P00003o
0?ooofd0oooo0@0000010?ooo`00@`3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo
0?l0ooooK@3oool100000040oooo00130?ooo`030000003oool0oooo08l0oooo0P00003o0?ooog00
oooo0@0000010?ooo`00@`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0?l0oooo
L03oool100000040oooo00130?ooo`030000003oool0oooo08`0oooo0P00003o0?ooog<0oooo0@00
00010?ooo`00@`3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo0?l0ooooL`3oool1
00000040oooo00130?ooo`<00000R@3oool200000?l0ooooM03oool300000040oooo00130?ooo`03
0000003oool0oooo08L0oooo0P00003o0?ooogP0oooo0@0000010?ooo`00@`3oool00`000000oooo
0?ooo`260?ooo`030000003oool0oooo0?l0ooooN03oool100000040oooo00130?ooo`030000003o
ool0oooo08@0oooo0P00003o0?ooog/0oooo0@0000010?ooo`00@`3oool00`000000oooo0?ooo`23
0?ooo`030000003oool0oooo0?l0ooooN`3oool100000040oooo00130?ooo`030000003oool0oooo
0880oooo00<000000?ooo`3oool0o`3oooml0?ooo`4000000@3oool004<0oooo00<000000?ooo`3o
ool0P@3oool00`000000oooo0?ooo`3o0?ooogd0oooo0@0000010?ooo`00@`3oool00`000000oooo
0?ooo`1o0?ooo`800000o`3ooon00?ooo`4000000@3oool004<0oooo00<000000?ooo`3oool0OP3o
ool00`000000oooo0?ooo`3o0?oooh00oooo0@0000010?ooo`00@`3oool3000007d0oooo00<00000
0?ooo`3oool0o`3ooomo0?ooo`<000000@3oool004<0oooo00<000000?ooo`3oool0O03oool00`00
0000oooo0?ooo`3o0?oooh80oooo0@0000010?ooo`00@`3oool00`000000oooo0?ooo`1k0?ooo`03
0000003oool0oooo0?l0ooooP`3oool100000040oooo00130?ooo`030000003oool0oooo07X0oooo
00<000000?ooo`3oool0o`3ooon40?ooo`4000000@3oool004<0oooo00<000000?ooo`3oool0N03o
ool200000?l0ooooQ`3oool100000040oooo000T0?ooo`<000000`3oool00`000000oooo0?ooo`02
0?ooo`<000000`3oool3000000/0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`3o
0?ooohL0oooo0@0000010?ooo`008`3oool01@000000oooo0?ooo`3oool0000000H0oooo00D00000
0?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0MP3o
ool00`000000oooo0?ooo`3o0?ooohP0oooo0@0000010?ooo`008`3oool01@000000oooo0?ooo`3o
ool0000000H0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`3o0?ooohT0oooo0@0000010?ooo`006@3o
ool7000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`00
00001P3oool00`000000oooo0?ooo`070?ooo`@00000L`3oool00`000000oooo0?ooo`3o0?ooohL0
oooo100000010?ooo`008`3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`00
00001`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0780oooo0P00003o0?ooohd0
oooo0@0000010?ooo`008`3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0740oooo00<000000?ooo`3o
ool0o`3ooon=0?ooo`4000000@3oool002<0oooo00D000000?ooo`3oool0oooo000000070?ooo`03
0000003oool0000000<0oooo0`00000;0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3o
ool0o`3ooon>0?ooo`4000000@3oool002<0oooo00D000000?ooo`3oool0oooo000000060?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
06l0oooo00<000000?ooo`3oool0o`3ooon?0?ooo`4000000@3oool002<0oooo00D000000?ooo`3o
ool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0o`3ooon@0?ooo`4000000@3oool0
02@0oooo0`0000080?ooo`<00000103oool4000000T0oooo00<000000?ooo`3oool0K@3oool00`00
0000oooo0?ooo`3o0?oooi40oooo0@0000010?ooo`00@`3oool00`000000oooo0?ooo`1/0?ooo`03
0000003oool0oooo0?l0ooooTP3oool100000040oooo00130?ooo`030000003oool0oooo06/0oooo
00<000000?ooo`3oool0o`3ooonC0?ooo`4000000@3oool004<0oooo0`00001Z0?ooo`030000003o
ool0oooo0?l0ooooTP3oool300000040oooo00130?ooo`030000003oool0oooo06X0oooo00<00000
0?ooo`3oool0o`3ooonD0?ooo`4000000@3oool004<0oooo00<000000?ooo`3oool0J@3oool00`00
0000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`00@`3oool00`000000oooo0?ooo`1X0?ooo`03
0000003oool0oooo0?l0ooooUP3oool100000040oooo00130?ooo`030000003oool0oooo06L0oooo
00<000000?ooo`3oool0o`3ooonG0?ooo`4000000@3oool004<0oooo00<000000?ooo`3oool0IP3o
ool00`000000oooo0?ooo`3o0?oooiP0oooo0@0000010?ooo`00@`3oool00`000000oooo0?ooo`1U
0?ooo`030000003oool0oooo0?l0ooooV@3oool100000040oooo00130?ooo`030000003oool0oooo
06@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`4000000@3oool004<0oooo0`00001S0?ooo`03
0000003oool0oooo0?l0ooooV@3oool300000040oooo00130?ooo`030000003oool0oooo0680oooo
00<000000?ooo`3oool0o`3ooonL0?ooo`4000000@3oool004<0oooo00<000000?ooo`3oool0H@3o
ool00`000000oooo0?ooo`3o0?oooid0oooo0@0000010?ooo`00@`3oool00`000000oooo0?ooo`1P
0?ooo`030000003oool0oooo0?l0ooooWP3oool100000040oooo00130?ooo`030000003oool0oooo
0600oooo00<000000?ooo`3oool0o`3ooonN0?ooo`4000000@3oool004<0oooo00<000000?ooo`3o
ool0G`3oool00`000000oooo0?ooo`3o0?oooil0oooo0@0000010?ooo`00@`3oool00`000000oooo
0?ooo`1N0?ooo`030000003oool0oooo0?l0ooooX03oool100000040oooo00130?ooo`030000003o
ool0oooo05d0oooo00<000000?ooo`3oool0o`3ooonQ0?ooo`4000000@3oool004<0oooo0`00001L
0?ooo`030000003oool0oooo0?l0ooooX03oool300000040oooo00130?ooo`030000003oool0oooo
05/0oooo00<000000?ooo`3oool0o`3ooonS0?ooo`4000000@3oool004<0oooo00<000000?ooo`3o
ool0FP3oool00`000000oooo0?ooo`3o0?oooj@0oooo0@0000010?ooo`00@`3oool00`000000oooo
0?ooo`1I0?ooo`030000003oool0oooo0?l0ooooY@3oool100000040oooo00130?ooo`030000003o
ool0oooo05T0oooo00<000000?ooo`3oool0o`3ooonU0?ooo`4000000@3oool004<0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`3o0?ooojH0oooo0@0000010?ooo`00@`3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo0?l0ooooY`3oool100000040oooo00070?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`3o0?ooojP0
oooo0@0000010?ooo`001`3oool3000003T0oooo00<000000?ooo`3oool0E@3oool00`000000oooo
0?ooo`3o0?ooojT0oooo0@0000010?ooo`001`3oool00`000000oooo0?ooo`03000003H0oooo0`00
001E0?ooo`030000003oool0oooo0?l0ooooY`3oool300000040oooo000<0?ooo`800000=@3oool0
0`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0?l0ooooZP3oool100000040oooo00070?oo
o`030000003oool0oooo00800000=`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
0?l0ooooZ`3oool100000040oooo00070?ooo`<00000>@3oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo0?l0oooo[03oool100000040oooo00070?ooo`030000003oool0oooo00<00000
=P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0?l0oooo[@3oool100000040oooo
000<0?ooo`8000007@3oool3000000<0oooo00<000000?ooo`3oool00P3oool3000000X0oooo00<0
00000?ooo`3oool0D@3oool00`000000oooo0?ooo`3o0?ooojd0oooo0@0000010?ooo`001`3oool0
0`000000oooo0?ooo`02000001h0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003o
ool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0?l0oooo
[P3oool100000040oooo00070?ooo`<00000803oool01@000000oooo0?ooo`3oool0000000H0oooo
00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool0o`3ooon_0?ooo`4000000@3oool000L0oooo00<000000?ooo`3oool05P3oool7000000<0oooo
00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000002@3oool40000
04d0oooo00<000000?ooo`3oool0o`3ooon]0?ooo`@000000@3oool000H0oooo2@00000K0?ooo`05
0000003oool0oooo0?ooo`0000001`3oool00`000000oooo0000000:0?ooo`030000003oool0oooo
04d0oooo00<000000?ooo`3oool0o`3ooona0?ooo`4000000@3oool000D0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0H0?ooo`050000003oool0oooo0?ooo`000000203oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0o`3ooona0?oo
o`4000000@3oool000@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0G0?ooo`05
0000003oool0oooo0?ooo`0000001`3oool00`000000oooo0000000:0?ooo`030000003oool0oooo
04`0oooo00<000000?ooo`3oool0o`3ooonb0?ooo`4000000@3oool000L0oooo0P0000040?ooo`03
0000003oool0oooo01X0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo
0?ooo`0000002@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0oooo/`3oool1
00000040oooo00070?ooo`030000003oool0oooo0080oooo0P00000L0?ooo`050000003oool0oooo
0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0BP3o
ool00`000000oooo0?ooo`3o0?oook@0oooo0@0000010?ooo`001`3oool00`000000oooo0?ooo`02
000000030?ooo`000000oooo01`0oooo0`0000080?ooo`<000002P3oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo0?l0oooo]@3oool100000040oooo00070?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
0?l0oooo]@3oool100000040oooo00070?ooo`800000103oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool0o`3ooonf0?ooo`4000000@3oool000L0oooo
00<000000?ooo`3oool00P3oool2000003D0oooo0`0000170?ooo`030000003oool0oooo0?l0oooo
]@3oool300000040oooo00040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0<03o
ool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0?l0oooo^03oool100000040oooo0005
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`16
0?ooo`030000003oool0oooo0?l0oooo^03oool100000040oooo00060?ooo`T00000=03oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo0?l0oooo^@3oool100000040oooo00130?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool0o`3oooni0?ooo`4000000@3oool004<0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`3o0?oookX0oooo0@0000010?ooo`00@`3o
ool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0?l0oooo^`3oool100000040oooo0013
0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0o`3ooonk0?ooo`4000000@3oool0
04<0oooo0`0000120?ooo`030000003oool0oooo0?l0oooo^P3oool300000040oooo00130?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool0o`3ooonl0?ooo`4000000@3oool004<0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3o0?oookd0oooo0@0000010?ooo`00@`3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0?l0oooo_@3oool100000040oooo0013
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0o`3ooonn0?ooo`4000000@3oool0
04<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`3o0?oookl0oooo0@0000010?oo
o`00@`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0?l0oooo_`3oool100000040
oooo00130?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0o`3oooo00?ooo`400000
0@3oool004<0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`3o0?oool00oooo0@00
00010?ooo`00@`3oool3000003d0oooo00<000000?ooo`3oool0o`3ooono0?ooo`<000000@3oool0
04<0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`3o0?oool80oooo0@0000010?oo
o`00@`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0?l0oooo`P3oool100000040
oooo00130?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3oooo30?ooo`400000
0@3oool004<0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?oool<0oooo0@00
00010?ooo`00@`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0?l0ooooa03oool1
00000040oooo00130?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0o`3oooo50?oo
o`4000000@3oool004<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`3o0?ooolD0
oooo0@0000010?ooo`00@`3oool3000003P0oooo00<000000?ooo`3oool0o`3oooo40?ooo`<00000
0@3oool004<0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`3o0?ooolH0oooo0@00
00010?ooo`00@`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0?l0ooooa`3oool1
00000040oooo00130?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0o`3oooo70?oo
o`4000000@3oool004<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`3o0?ooolP0
oooo0@0000010?ooo`00903oool3000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`<000002`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0?l0oooo
b@3oool100000040oooo000S0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0=@3oool00`000000oooo
0?ooo`3o0?ooolT0oooo0@0000010?ooo`008`3oool01@000000oooo0?ooo`3oool0000000P0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool0o`3oooo:0?ooo`4000000@3oool001T0oooo1`0000030?ooo`050000003o
ool0oooo0?ooo`000000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo
1000000c0?ooo`030000003oool0oooo0?l0ooooa`3oool400000040oooo000S0?ooo`050000003o
ool0oooo0?ooo`000000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`3o0?oool/0oooo0@0000010?ooo`008`3o
ool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0o`3oooo;0?ooo`400000
0@3oool002<0oooo00D000000?ooo`3oool0oooo000000090?ooo`040000003oool0oooo0?ooo`<0
00002`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0?l0ooooc03oool100000040
oooo000S0?ooo`050000003oool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3oool00000
00d0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`3o0?oool`0oooo0@0000010?oo
o`008`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`3o
0?ooold0oooo0@0000010?ooo`00903oool3000000L0oooo1@0000030?ooo`@000002@3oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo0?l0ooooc@3oool100000040oooo00130?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool0o`3oooo>0?ooo`4000000@3oool004<0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`3o0?ooolh0oooo0@0000010?ooo`00@`3o
ool3000002l0oooo00<000000?ooo`3oool0o`3oooo=0?ooo`<000000@3oool004<0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`3o0?oooll0oooo0@0000010?ooo`00@`3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo0?l0ooood03oool100000040oooo00130?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool0o`3oooo@0?ooo`4000000@3oool004<0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`3o0?ooom40oooo0@0000010?ooo`00@`3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0ooood@3oool100000040oooo0013
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0o`3ooooA0?ooo`4000000@3oool0
04<0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`3o0?ooom80oooo0@0000010?oo
o`00@`3oool3000002`0oooo00<000000?ooo`3oool0o`3oooo@0?ooo`<000000@3oool004<0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`3o0?ooom<0oooo0@0000010?ooo`00@`3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0ooood`3oool100000040oooo0013
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0o`3ooooD0?ooo`4000000@3oool0
04<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`3o0?ooom@0oooo0@0000010?oo
o`00@`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0ooooe@3oool100000040
oooo00130?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3ooooE0?ooo`400000
0@3oool004<0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`3o0?ooomH0oooo0@00
00010?ooo`00@`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0?l0ooooeP3oool1
00000040oooo00130?ooo`<00000:03oool00`000000oooo0?ooo`3o0?ooom@0oooo0`0000010?oo
o`00@`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0?l0ooooe`3oool100000040
oooo00130?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0o`3ooooG0?ooo`400000
0@3oool004<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3o0?ooomP0oooo0@00
00010?ooo`00@`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0?l0oooof03oool1
00000040oooo00130?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0o`3ooooI0?oo
o`4000000@3oool004<0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3o0?ooomT0
oooo0@0000010?ooo`00@`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0?l0oooo
fP3oool100000040oooo00130?ooo`<00000903oool00`000000oooo0?ooo`3o0?ooomP0oooo0`00
00010?ooo`00@`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0?l0oooof`3oool1
00000040oooo00130?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0o`3ooooK0?oo
o`4000000@3oool004<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3o0?ooom`0
oooo0@0000010?ooo`00@`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0?l0oooo
g03oool100000040oooo000[0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3o0?ooom`0oooo0@00
00010?ooo`00:P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0oooog@3oool100000040oooo000Z
0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool0o`3ooooM0?ooo`4000000@3oool00200oooo1`000003
0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool0o`3ooooN0?ooo`4000000@3oool002X0oooo00D00000
0?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00T0oooo1000000O0?ooo`030000003o
ool0oooo0?l0oooof`3oool400000040oooo000Z0?ooo`050000003oool0oooo0?ooo`0000002@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0o`3o
oooO0?ooo`4000000@3oool002X0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3o0?oooml0oooo0@00
00010?ooo`00:P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0?l0ooooh03oool100000040oooo000Z
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3o0?ooon00oooo0@00
00010?ooo`00:`3oool3000000L0oooo1@0000090?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool0o`3ooooQ0?ooo`4000000@3oool004<0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`3o0?ooon40oooo0@0000010?ooo`00@`3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo0?l0ooooh@3oool100000040oooo00130?ooo`<00000703oool00`000000oooo
0?ooo`3o0?ooon00oooo0`0000010?ooo`00@`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0?l0oooohP3oool100000040oooo00130?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0o`3ooooR0?ooo`4000000@3oool004<0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`3o0?ooon<0oooo0@0000010?ooo`00@`3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo0?l0ooooh`3oool100000040oooo00130?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0o`3ooooS0?ooo`4000000@3oool004<0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`3o0?ooon@0oooo0@0000010?ooo`00@`3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo0?l0ooooi03oool100000040oooo00130?ooo`<000006P3oool00`00
0000oooo0?ooo`3o0?ooon80oooo0`0000010?ooo`00@`3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo0?l0ooooi@3oool100000040oooo00130?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0o`3ooooU0?ooo`4000000@3oool004<0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`3o0?ooonD0oooo0@0000010?ooo`00@`3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo0?l0ooooiP3oool100000040oooo00130?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0o`3ooooV0?ooo`4000000@3oool004<0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`3o0?ooonH0oooo0@0000010?ooo`00@`3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo0?l0ooooiP3oool100000040oooo00130?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0o`3ooooW0?ooo`4000000@3oool004<0oooo0`00000G
0?ooo`030000003oool0oooo0?l0ooooi@3oool300000040oooo00130?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0o`3ooooW0?ooo`4000000@3oool004<0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`3o0?ooonP0oooo0@0000010?ooo`00@`3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo0?l0ooooj03oool100000040oooo00130?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0o`3ooooX0?ooo`4000000@3oool004<0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`3o0?ooonT0oooo0@0000010?ooo`00@`3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0ooooj@3oool100000040oooo00130?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3ooooY0?ooo`4000000@3oool004<0oooo
0`00000D0?ooo`030000003oool0oooo0?l0ooooj03oool300000040oooo00130?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0o`3ooooZ0?ooo`4000000@3oool004<0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`3o0?ooonX0oooo0@0000010?ooo`00@`3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0ooooj`3oool100000040oooo00130?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0o`3oooo[0?ooo`4000000@3oool002@0oooo
0`0000030?ooo`030000003oool0oooo0080oooo0`0000030?ooo`<000002`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo0?l0ooooj`3oool100000040oooo000S0?ooo`050000003o
ool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0ooook03oool100000040
oooo000S0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool00000
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
0?l0ooook03oool100000040oooo000I0?ooo`L000000`3oool01@000000oooo0?ooo`3oool00000
00H0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`3o0?ooon`0oooo0@0000010?ooo`008`3oool01@00
0000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003o
ool0oooo00L0oooo1000000@0?ooo`030000003oool0oooo0?l0oooojP3oool400000040oooo000S
0?ooo`050000003oool0oooo0?ooo`0000001P3oool200000080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0o`3o
ooo]0?ooo`4000000@3oool002<0oooo00D000000?ooo`3oool0oooo000000060?ooo`040000003o
ool00000000000<0oooo0`00000;0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
o`3oooo]0?ooo`4000000@3oool002<0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0?l0ooookP3oool100000040oooo000S0?ooo`050000003oool0oooo0?ooo`000000
203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`3o0?ooonh0oooo0@0000010?ooo`00903oool3000000X0oooo0P00
00030?ooo`@000002@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0ooookP3o
ool100000040oooo00130?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3oooo_
0?ooo`4000000@3oool004<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?oo
onl0oooo0@0000010?ooo`00@`3oool3000000l0oooo00<000000?ooo`3oool0o`3oooo]0?ooo`<0
00000@3oool004<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?oooo00oooo
0@0000010?ooo`00@`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0ooool03o
ool100000040oooo00130?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3oooo`
0?ooo`4000000@3oool004<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?oo
oo00oooo0@0000010?ooo`00@`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0
ooool@3oool100000040oooo00130?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
o`3ooooa0?ooo`4000000@3oool004<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`3o0?oooo40oooo0@0000010?ooo`00@`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0?l0oooolP3oool100000040oooo00130?ooo`<00000303oool00`000000oooo0?ooo`3o0?oo
oo00oooo0`0000010?ooo`00@`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0
oooolP3oool100000040oooo00130?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
o`3ooooc0?ooo`4000000@3oool004<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`3o0?oooo<0oooo0@0000010?ooo`00@`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo0?l0ooool`3oool100000040oooo00130?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0o`3ooood0?ooo`4000000@3oool004<0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`3o0?oooo@0oooo0@0000010?ooo`00@`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0?l0oooom03oool100000040oooo00130?ooo`<000002@3oool00`000000oooo0?oo
o`3o0?oooo<0oooo0`0000010?ooo`00@`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0?l0oooom@3oool100000040oooo00130?ooo`030000003oool0oooo0?l0ooooo`3oool20?oo
o`4000000@3oool004<0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`80oooo0@0000010?ooo`00
@`3oool00`000000oooo0?ooo`3o0?ooool0oooo0P3oool100000040oooo00130?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1g0?ooo`030000003o
ool0oooo07P0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`090?ooo`4000000@3o
ool004<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo07L0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo00T0oooo0@0000010?ooo`00@`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`090?ooo`4000000@3oool004<0
ooooo`00003o000000H000000@3oool00001\
\>"],
  ImageRangeCache->{{{0, 583.875}, {360.5, 0}} -> {-0.323689, -1.03768, \
0.0040758, 0.00118672}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ 
      Find\ chi\ square\ for\ given\ H \((z)\)\ \ *) \[IndentingNewLine]\(f[
          z_] := 1/hhz[z];\)\), "\n", 
    \(\(rr[zz_] := NIntegrate[f[z], {z, 0, zz}];\)\[IndentingNewLine]\n (*\ 
      Construct\ marginalization\ coefficients\ \((see\ astro - 
              ph/0401556\  .. )\)\ *) \), "\[IndentingNewLine]", 
    \(Clear[chi2fa, chi2fb, chi2fc]\), "\n", 
    \(\(chi2fa = 
        Sum[\((ld[i] - 5\ Log[10, rr[zz[i]]*\((1 + zz[i])\)])\)^2/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\n", 
    \(\(chi2fb = 
        Sum[\((ld[i] - 
                5\ Log[10, rr[zz[i]]*\((1 + zz[i])\)])\)/\((sld[i]^2)\), {i, 
            1, ndat}];\)\), "\n", 
    \(\(chi2fc = 
        Sum[1/\((sld[i]^2)\), {i, 1, ndat}];\)\[IndentingNewLine]\n (*\ 
      Construct\ function\ after\ marginalization, \ 
      find\ same\ result\ as\ with\ mb\ minimization\ *) \), "\
\[IndentingNewLine]", 
    \(chi2fm = chi2fa - chi2fb^2/chi2fc\), "\[IndentingNewLine]", 
    \(dchi2q20 = chi2fm - chi2l\)}], "Input"],

Cell[BoxData[
    \(184.90357184875757`\)], "Output"],

Cell[BoxData[
    \(7.7762004137039185`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ \(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(\
--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(-\(---\)\)\)\)\)\)\)\)\)\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)*) \[IndentingNewLine]\[IndentingNewLine] \
(*\ Find\ H \((z)\)\ for\ given\ slope\ s\ of\ the\ linear\ potential . \ 
            Present\ time\  = \ \(tt\ \((corresponds\ to\ a = 1)\) . \ 
              Run\ trials\ for\ initial\ condition\ for\ field\ fi\ \((f0)\)\ \
and\ initial\ time\ ti\ until\ we\ get\ field\ energy\ enf\  = \ \(0.7\ and\ \
H \((z = 0)\)\  = 
            1\ at\ present\ time\ \(\(tt\)\(.\)\)\)\)\ *) \[IndentingNewLine]\
\[IndentingNewLine] (*\ \(--\(--\(--\(--\ \ s\)\)\)\)\  = \ \(2.5\ \ \ --\) \
\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(---\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\ *) \
\[IndentingNewLine]\[IndentingNewLine]\(Clear[aa, fi, a, aad, aadd, fidas, 
        tas, f, rr, hht, hha];\)\), "\[IndentingNewLine]", 
    \(aa = a[t]; \ fi = f[t];\), "\n", 
    \(\(aad = D[aa, t];\)\), "\n", 
    \(\(aadd = D[aa, {t, 2}];\)\), "\n", 
    \(\(fid = D[fi, t];\)\), "\n", 
    \(\(fidd = D[fi, {t, 2}];\)\), "\n", 
    \(ti = 0.000025; \ t0 = 1.5;\), "\n", 
    \(\(f0 = \(-0.512\);\)\ \), "\n", 
    \(om0m = 0.3; \ ss = 2.5;\), "\n", 
    \(\(eq1 = 
        aadd/aa\  \[Equal] \(-\ \ fid^2\)\  - \ ss\ fi\  - \ 
            om0m/\((2\ aa^3)\);\)\), "\n", 
    \(\(eq2 = 
        fidd\ \  + \ \ \ 3\ \ fid\ \((aad/aa)\)\  - \ ss \[Equal] 
          0;\)\), "\n", 
    \(\(eqb1 = f[ti] == f0;\)\), "\n", 
    \(\(eqb2 = \(f'\)[ti] == 0;\)\), "\n", 
    \(\(eqb3 = 
        a[ti] \[Equal] \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((2/3)\);\)\), "\n", 
    \(\(eqb4 = \(a'\)[
            ti] \[Equal] \((2/
                3)\)\ \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((\(-1\)/
                  3)\);\)\), "\n", 
    \(\(sol2 = 
        NDSolve[{eq1, eq2, eqb1, eqb2, eqb3, eqb4}, {aa, fi}, {t, ti, t0}, 
          MaxSteps \[Rule] 10000000];\)\), "\n", 
    \(\(asol = Part[Evaluate[a[t] /. sol2], 1];\)\), "\n", 
    \(\(fsol = Part[Evaluate[f[t] /. sol2], 1];\)\), "\n", 
    \(\(dfsol = D[fsol, t];\)\), "\[IndentingNewLine]", 
    \(\(enf = 0.5\ dfsol^2\  - \ ss\ fsol;\)\), "\[IndentingNewLine]", 
    \(\(as[t1_] := asol\  /. \ t -> t1\ ;\)\), "\[IndentingNewLine]", 
    \(\(tt = Part[FindRoot[as[t] == 1, {t, 1}], 1, 2];\)\), "\n", 
    \(\(tas[a_] := 
        Part[FindRoot[as[t] \[Equal] a, {t, 1}], 1, 2];\)\), "\n", 
    \(\(hht[t1_] := D[asol, t]/asol\  /. \ t -> t1\ ;\)\), "\n", 
    \(\(hha[a_] := hht[tas[a]];\)\), "\[IndentingNewLine]", 
    \(\(hhz[z_] := hha[1/\((z + 1)\)];\)\), "\[IndentingNewLine]", 
    \(enf\  /. \ t \[Rule] tt\), "\[IndentingNewLine]", 
    \(hhz[0]\), "\[IndentingNewLine]", 
    \(\(enf = 0.5\ dfsol^2\  - \ ss\ fsol;\)\), "\n", 
    \(\(ppf = 0.5\ dfsol^2\  + \ ss\ fsol;\)\), "\n", 
    \(\(wft[t1_] := ppf/enf\  /. \ t -> t1\ ;\)\ \), "\n", 
    \(\(wfa[a_] := wft[tas[a]];\)\), "\n", 
    \(\(wfz[z_] := wfa[1/\((z + 1)\)];\)\), "\n", 
    \(\(plw25q = 
        Plot[wfz[z], {z, 0, 2}, Frame \[Rule] True, PlotRange \[Rule] All, 
          FrameLabel \[Rule] {"\<z\>", "\<w(z)\>"}];\)\)}], "Input"],

Cell[BoxData[
    \(0.7023957146664535`\)], "Output"],

Cell[BoxData[
    \(1.0024815218714327`\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.476191 1.06482 1.08036 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.2619 -0.0125 -10.7813 -17.8125 ]
[.2619 -0.0125 10.7813 0 ]
[.5 -0.0125 -5.53125 -17.8125 ]
[.5 -0.0125 5.53125 0 ]
[.7381 -0.0125 -10.7813 -17.8125 ]
[.7381 -0.0125 10.7813 0 ]
[.97619 -0.0125 -5.53125 -17.8125 ]
[.97619 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.125 -35.625 ]
[.5 -0.0125 5.125 -17.8125 ]
[-0.0125 .0925 -31.25 -8.90625 ]
[-0.0125 .0925 0 8.90625 ]
[-0.0125 .20053 -31.25 -8.90625 ]
[-0.0125 .20053 0 8.90625 ]
[-0.0125 .30857 -31.25 -8.90625 ]
[-0.0125 .30857 0 8.90625 ]
[-0.0125 .4166 -31.25 -8.90625 ]
[-0.0125 .4166 0 8.90625 ]
[-0.0125 .52464 -31.25 -8.90625 ]
[-0.0125 .52464 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -49.0625 -14.7188 ]
[-0.01875 .30902 -31.25 14.7188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.125 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0925 m
.00625 .0925 L
s
gsave
-0.0125 .0925 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
1.000 setlinewidth
grestore
0 .20053 m
.00625 .20053 L
s
gsave
-0.0125 .20053 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .30857 m
.00625 .30857 L
s
gsave
-0.0125 .30857 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
1.000 setlinewidth
grestore
0 .4166 m
.00625 .4166 L
s
gsave
-0.0125 .4166 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .52464 m
.00625 .52464 L
s
gsave
-0.0125 .52464 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .1141 m
.00375 .1141 L
s
0 .13571 m
.00375 .13571 L
s
0 .15732 m
.00375 .15732 L
s
0 .17892 m
.00375 .17892 L
s
0 .22214 m
.00375 .22214 L
s
0 .24375 m
.00375 .24375 L
s
0 .26535 m
.00375 .26535 L
s
0 .28696 m
.00375 .28696 L
s
0 .33018 m
.00375 .33018 L
s
0 .35178 m
.00375 .35178 L
s
0 .37339 m
.00375 .37339 L
s
0 .395 m
.00375 .395 L
s
0 .43821 m
.00375 .43821 L
s
0 .45982 m
.00375 .45982 L
s
0 .48143 m
.00375 .48143 L
s
0 .50303 m
.00375 .50303 L
s
0 .07089 m
.00375 .07089 L
s
0 .04928 m
.00375 .04928 L
s
0 .02767 m
.00375 .02767 L
s
0 .00607 m
.00375 .00607 L
s
0 .54625 m
.00375 .54625 L
s
0 .56786 m
.00375 .56786 L
s
0 .58946 m
.00375 .58946 L
s
0 .61107 m
.00375 .61107 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -115.875 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.7188 12.9063 translate
90 rotate
-75.7188 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.063 17.500 moveto
(H) show
77.625 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.875 17.500 moveto
(L) show
88.438 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0925 m
1 .0925 L
s
.99375 .20053 m
1 .20053 L
s
.99375 .30857 m
1 .30857 L
s
.99375 .4166 m
1 .4166 L
s
.99375 .52464 m
1 .52464 L
s
.125 Mabswid
.99625 .1141 m
1 .1141 L
s
.99625 .13571 m
1 .13571 L
s
.99625 .15732 m
1 .15732 L
s
.99625 .17892 m
1 .17892 L
s
.99625 .22214 m
1 .22214 L
s
.99625 .24375 m
1 .24375 L
s
.99625 .26535 m
1 .26535 L
s
.99625 .28696 m
1 .28696 L
s
.99625 .33018 m
1 .33018 L
s
.99625 .35178 m
1 .35178 L
s
.99625 .37339 m
1 .37339 L
s
.99625 .395 m
1 .395 L
s
.99625 .43821 m
1 .43821 L
s
.99625 .45982 m
1 .45982 L
s
.99625 .48143 m
1 .48143 L
s
.99625 .50303 m
1 .50303 L
s
.99625 .07089 m
1 .07089 L
s
.99625 .04928 m
1 .04928 L
s
.99625 .02767 m
1 .02767 L
s
.99625 .00607 m
1 .00607 L
s
.99625 .54625 m
1 .54625 L
s
.99625 .56786 m
1 .56786 L
s
.99625 .58946 m
1 .58946 L
s
.99625 .61107 m
1 .61107 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .0925 m
1 .0925 L
s
.5 Mabswid
.02381 .60332 m
.04262 .5258 L
.06244 .46116 L
.08426 .40427 L
.10458 .36098 L
.14264 .29742 L
.18163 .2484 L
.22307 .20811 L
.263 .17731 L
.30142 .15309 L
.34228 .13173 L
.38164 .11449 L
.41947 .10038 L
.45976 .0875 L
.49853 .07683 L
.53975 .06701 L
.57946 .0588 L
.61766 .05188 L
.6583 .0454 L
.69743 .03991 L
.73901 .03475 L
.77908 .03036 L
.81763 .02659 L
.85863 .02301 L
.89812 .01992 L
.93609 .01726 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.063, 338.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008T0001DR000`400?l00000o`00003oo`3ooooo
0?ooobH0oooo003o0?ooool0oooo9P3oool00?l0ooooo`3ooolV0?ooo`00o`3ooooo0?ooobH0oooo
003o0?ooool0oooo9P3oool00?l0oooo;03oool600000?<0oooo003o0?ooobd0oooo00D000000?oo
o`3oool0oooo0000003c0?ooo`00o`3oool^0?ooo`030000003oool0oooo0?@0oooo003o0?ooobh0
oooo00<000000?ooo`3oool0m03oool00?l0oooo;`3oool00`000000oooo0?ooo`3c0?ooo`00o`3o
ool/0?ooo`050000003oool0oooo0?ooo`000000m03oool00?l0oooo;03oool600000?<0oooo003o
0?ooool0oooo9P3oool00?l0ooooo`3ooolV0?ooo`00o`3ooooo0?ooobH0oooo003o0?ooool0oooo
9P3oool00?l0ooooo`3ooolV0?ooo`00o`3ooooo0?ooobH0oooo003o0?ooool0oooo9P3oool00?l0
ooooo`3ooolV0?ooo`00o`3ooooo0?ooobH0oooo003o0?ooool0oooo9P3oool00?l0ooooo`3ooolV
0?ooo`00B03oool3000006X0oooo0`0000030?ooo`040000003oool0oooo0?ooo`<00000JP3oool3
000006X0oooo0`0000030?ooo`040000003oool0oooo0?ooo`<00000JP3oool5000000l0oooo0017
0?ooo`050000003oool0oooo0?ooo`000000J03oool01@000000oooo0?ooo`3oool0000000T0oooo
00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0J03oool010000000oooo0?ooo`00000?0?ooo`00A`3oool01@000000oooo
0?ooo`3oool0000006P0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo
06L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
06P0oooo00<000000?ooo`3oool03`3oool004L0oooo00D000000?ooo`3oool0oooo0000001X0?oo
o`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0
oooo06X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0
oooo00h0oooo00170?ooo`050000003oool0oooo0?ooo`000000J03oool01@000000oooo0?ooo`3o
ool0000000X0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`1Z0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0>0?ooo`00A`3oool0
1@000000oooo0?ooo`3oool0000006P0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo06/0oooo00<000000?ooo`3oool03@3oool004L0oooo00D000000?ooo`3oool0oooo
0000001X0?ooo`050000003oool0oooo0?ooo`0000001P3oool3000006/0oooo00<000000?ooo`3o
ool0JP3oool00`000000oooo0?ooo`060?ooo`<00000KP3oool00`000000oooo0?ooo`0=0?ooo`00
A`3oool01@000000oooo0?ooo`3oool0000006P0oooo00D000000?ooo`3oool0oooo000000060?oo
o`030000003oool0oooo06/0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo06h0oooo00<000000?ooo`3oool03@3oool004L0oooo00D000000?ooo`3o
ool0oooo0000001X0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`1Y
0?ooo`800000J`3oool2000000T0oooo00<000000?ooo`3oool0J@3oool01@000000oooo0?ooo`3o
ool0000000l0oooo00180?ooo`<00000JP3oool3000000P0oooo1000001Y0?ooo`030000003oool0
oooo06X0oooo00<000000?ooo`3oool01`3oool4000006T0oooo0`00000@0?ooo`00o`3ooooo0?oo
obH0oooo003o0?ooool0oooo9P3oool00?l0ooooo`3ooolV0?ooo`00o`3ooooo0?ooobH0oooo003o
0?ooool0oooo9P3oool00?l0ooooo`3ooolV0?ooo`00o`3ooooo0?ooobH0oooo003o0?ooool0oooo
9P3oool003h0ooooo`00003R000000D0oooo000n0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool00`3oool003h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?oo
o`00?P3oool3000000T0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1_0?ooo`03
0000003oool0oooo06l0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`070?ooo`<0
00001@3oool003h0oooo00<000000?ooo`3oool0o`3ooooN0?ooo`030000003oool0oooo00<0oooo
000n0?ooo`030000003oool0oooo0?l0oooogP3oool00`000000oooo0?ooo`030?ooo`00?P3oool0
0`000000oooo0?ooo`3o0?ooomh0oooo00<000000?ooo`3oool00`3oool003h0oooo00<000000?oo
o`3oool0o`3oooo>0?ooo`D000002`3oool00`000000oooo0?ooo`030?ooo`00?P3oool00`000000
oooo0?ooo`3o0?oool@0oooo2P00000@0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000
003oool0oooo0?l0oooo]`3oool=000001X0oooo00<000000?ooo`3oool00`3oool003h0oooo00<0
00000?ooo`3oool0o`3ooonT0?oooa<000009`3oool00`000000oooo0?ooo`030?ooo`00?P3oool0
0`000000oooo0?ooo`3o0?oooiH0oooo3P00000j0?ooo`030000003oool0oooo00<0oooo000n0?oo
o`030000003oool0oooo0?l0ooooS03oool:000004P0oooo00<000000?ooo`3oool00`3oool003h0
oooo00<000000?ooo`3oool0o`3ooon20?ooo`X00000DP3oool00`000000oooo0?ooo`030?ooo`00
?P3oool300000?l0ooooN@3oool9000005X0oooo0`0000050?ooo`00?P3oool00`000000oooo0?oo
o`3o0?ooog00oooo2@00001U0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0
oooo0?l0ooooIP3oool:000006h0oooo00<000000?ooo`3oool00`3oool003h0oooo00<000000?oo
o`3oool0o`3ooomM0?ooo`T00000N03oool00`000000oooo0?ooo`030?ooo`00?P3oool00`000000
oooo0?ooo`3o0?oooe<0oooo2P0000210?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000
003oool0oooo0?l0ooooBP3oool9000008/0oooo00<000000?ooo`3oool00`3oool003h0oooo00<0
00000?ooo`3oool0o`3ooom40?ooo`H00000U03oool00`000000oooo0?ooo`030?ooo`00?P3oool0
0`000000oooo0?ooo`3o0?oooch0oooo1P00002J0?ooo`030000003oool0oooo00<0oooo000n0?oo
o`030000003oool0oooo0?l0oooo=`3oool700000:00oooo00<000000?ooo`3oool00`3oool003h0
oooo00<000000?ooo`3oool0o`3ooola0?ooo`H00000Y`3oool00`000000oooo0?ooo`030?ooo`00
?P3oool300000?l0oooo:P3oool700000:/0oooo0`0000050?ooo`00?P3oool00`000000oooo0?oo
o`3o0?ooob@0oooo1P00002d0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0
oooo0?l0oooo803oool400000;X0oooo00<000000?ooo`3oool00`3oool003h0oooo00<000000?oo
o`3oool0o`3ooolK0?ooo`D00000_P3oool00`000000oooo0?ooo`030?ooo`00?P3oool00`000000
oooo0?ooo`3o0?oooaL0oooo100000330?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000
003oool0oooo0?l0oooo4@3oool600000<L0oooo00<000000?ooo`3oool00`3oool003h0oooo00<0
00000?ooo`3oool0o`3oool;0?ooo`H00000c@3oool00`000000oooo0?ooo`030?ooo`00?P3oool0
0`000000oooo0?ooo`3o0?ooo`D0oooo1P00003C0?ooo`030000003oool0oooo00<0oooo000n0?oo
o`030000003oool0oooo0?l0oooo1@00003I0?ooo`030000003oool0oooo00<0oooo000n0?ooo`03
0000003oool0oooo0?/0oooo1000003N0?ooo`030000003oool0oooo00<0oooo000n0?ooo`<00000
m`3oool400000>00oooo0`0000050?ooo`00?P3oool00`000000oooo0?ooo`3c0?ooo`@00000iP3o
ool00`000000oooo0?ooo`030?ooo`00?P3oool00`000000oooo0?ooo`3_0?ooo`@00000jP3oool0
0`000000oooo0?ooo`030?ooo`00?P3oool00`000000oooo0?ooo`3[0?ooo`@00000kP3oool00`00
0000oooo0?ooo`030?ooo`00?P3oool00`000000oooo0?ooo`3W0?ooo`@00000lP3oool00`000000
oooo0?ooo`030?ooo`00?P3oool00`000000oooo0?ooo`3T0?ooo`<00000mP3oool00`000000oooo
0?ooo`030?ooo`00?P3oool00`000000oooo0?ooo`3P0?ooo`@00000n@3oool00`000000oooo0?oo
o`030?ooo`009`3oool3000000<0oooo00@000000?ooo`3oool0oooo0P00000;0?ooo`030000003o
ool0oooo0=`0oooo1000003m0?ooo`030000003oool0oooo00<0oooo000V0?ooo`050000003oool0
oooo0?ooo`000000203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0=T0oooo0`00
003o0?ooo`80oooo00<000000?ooo`3oool00`3oool002H0oooo00D000000?ooo`3oool0oooo0000
00090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0eP3oool300000?l0oooo1@3o
ool00`000000oooo0?ooo`030?ooo`00703oool7000000<0oooo00D000000?ooo`3oool0oooo0000
00070?ooo`@00000203oool00`000000oooo0?ooo`3B0?ooo`@00000o`3oool80?ooo`030000003o
ool0oooo00<0oooo000V0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?oo
o`3oool0000000P0ooooo`00003R000000D0oooo000V0?ooo`050000003oool0oooo0?ooo`000000
1P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0c03oool300000?l0
oooo3`3oool00`000000oooo0?ooo`030?ooo`009P3oool01@000000oooo0?ooo`3oool0000000H0
oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo0<P0oooo1000003o0?oo
oa80oooo00<000000?ooo`3oool00`3oool002H0oooo00D000000?ooo`3oool0oooo000000060?oo
o`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`350?ooo`<00000o`3ooolF
0?ooo`030000003oool0oooo00<0oooo000V0?ooo`050000003oool0oooo0?ooo`0000001P3oool0
1@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0``3oool200000?l0oooo6@3o
ool00`000000oooo0?ooo`030?ooo`009`3oool3000000P0oooo0`0000090?ooo`030000003oool0
oooo0<00oooo0`00003o0?oooa/0oooo00<000000?ooo`3oool00`3oool003h0oooo00<000000?oo
o`3oool0_P3oool200000?l0oooo7P3oool00`000000oooo0?ooo`030?ooo`00?P3oool00`000000
oooo0?ooo`2k0?ooo`<00000o`3ooolP0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000
003oool0oooo0;P0oooo0`00003o0?ooob<0oooo00<000000?ooo`3oool00`3oool003h0oooo00<0
00000?ooo`3oool0]P3oool200000?l0oooo9P3oool00`000000oooo0?ooo`030?ooo`00?P3oool3
00000;<0oooo0`00003o0?ooobH0oooo0`0000050?ooo`00?P3oool00`000000oooo0?ooo`2a0?oo
o`800000o`3oool[0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo0:l0
oooo0P00003o0?ooobd0oooo00<000000?ooo`3oool00`3oool003h0oooo00<000000?ooo`3oool0
[03oool300000?l0oooo;`3oool00`000000oooo0?ooo`030?ooo`00?P3oool00`000000oooo0?oo
o`2Z0?ooo`800000o`3ooolb0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0
oooo0:L0oooo0`00003o0?oooc@0oooo00<000000?ooo`3oool00`3oool003h0oooo00<000000?oo
o`3oool0Y@3oool200000?l0oooo=`3oool00`000000oooo0?ooo`030?ooo`00?P3oool00`000000
oooo0?ooo`2S0?ooo`800000o`3oooli0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000
003oool0oooo0:40oooo0P00003o0?oooc/0oooo00<000000?ooo`3oool00`3oool003h0oooo00<0
00000?ooo`3oool0W`3oool200000?l0oooo?@3oool00`000000oooo0?ooo`030?ooo`00?P3oool3
000009d0oooo0P00003o0?ooocd0oooo0`0000050?ooo`00?P3oool00`000000oooo0?ooo`2K0?oo
o`800000o`3ooom10?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo09X0
oooo00<000000?ooo`3oool0o`3ooom10?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000
003oool0oooo09P0oooo0P00003o0?oood@0oooo00<000000?ooo`3oool00`3oool003h0oooo00<0
00000?ooo`3oool0UP3oool200000?l0ooooAP3oool00`000000oooo0?ooo`030?ooo`00?P3oool0
0`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0?l0ooooAP3oool00`000000oooo0?ooo`03
0?ooo`00?P3oool00`000000oooo0?ooo`2C0?ooo`800000o`3ooom90?ooo`030000003oool0oooo
00<0oooo000n0?ooo`030000003oool0oooo0940oooo0P00003o0?oood/0oooo00<000000?ooo`3o
ool00`3oool003h0oooo00<000000?ooo`3oool0S`3oool200000?l0ooooC@3oool00`000000oooo
0?ooo`030?ooo`00?P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0?l0ooooC@3o
ool00`000000oooo0?ooo`030?ooo`00?P3oool00`000000oooo0?ooo`2<0?ooo`800000o`3ooom@
0?ooo`030000003oool0oooo00<0oooo000n0?ooo`<00000RP3oool200000?l0ooooD03oool30000
00D0oooo000n0?ooo`030000003oool0oooo08P0oooo0P00003o0?oooe@0oooo00<000000?ooo`3o
ool00`3oool003h0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`3o0?oooe@0oooo
00<000000?ooo`3oool00`3oool003h0oooo00<000000?ooo`3oool0Q@3oool200000?l0ooooE`3o
ool00`000000oooo0?ooo`030?ooo`00?P3oool00`000000oooo0?ooo`230?ooo`800000o`3ooomI
0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo0880oooo00<000000?oo
o`3oool0o`3ooomI0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo0800
oooo0P00003o0?oooe`0oooo00<000000?ooo`3oool00`3oool003h0oooo00<000000?ooo`3oool0
OP3oool200000?l0ooooGP3oool00`000000oooo0?ooo`030?ooo`00?P3oool00`000000oooo0?oo
o`1l0?ooo`800000o`3ooomP0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0
oooo07/0oooo00<000000?ooo`3oool0o`3ooomP0?ooo`030000003oool0oooo00<0oooo000n0?oo
o`<00000NP3oool00`000000oooo0?ooo`3o0?oooel0oooo0`0000050?ooo`00?P3oool00`000000
oooo0?ooo`1h0?ooo`800000o`3ooomT0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool0o`3ooomT0?ooo`030000003oool0oooo00<0oooo
000n0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0o`3ooomU0?ooo`030000003o
ool0oooo00<0oooo000n0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0o`3ooomV
0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo07<0oooo0P00003o0?oo
ofT0oooo00<000000?ooo`3oool00`3oool003h0oooo00<000000?ooo`3oool0LP3oool00`000000
oooo0?ooo`3o0?ooofT0oooo00<000000?ooo`3oool00`3oool002L0oooo0`0000030?ooo`030000
003oool0oooo0080oooo0`0000090?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0
o`3ooomZ0?ooo`030000003oool0oooo00<0oooo000V0?ooo`050000003oool0oooo0?ooo`000000
1P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0K`3oool200000?l0
ooooK@3oool00`000000oooo0?ooo`030?ooo`009P3oool01@000000oooo0?ooo`3oool0000000H0
oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo06h0oooo00<000000?oo
o`3oool0o`3ooom]0?ooo`030000003oool0oooo00<0oooo000L0?ooo`L000000`3oool01@000000
oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000080?ooo`@00000K03oool0
0`000000oooo0?ooo`3o0?ooof/0oooo100000050?ooo`009P3oool01@000000oooo0?ooo`3oool0
000000L0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0
oooo0?l0ooooK`3oool00`000000oooo0?ooo`030?ooo`009P3oool01@000000oooo0?ooo`3oool0
000000P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1Z0?ooo`800000o`3ooomb
0?ooo`030000003oool0oooo00<0oooo000V0?ooo`050000003oool0oooo0?ooo`0000001`3oool0
0`000000oooo000000090?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0o`3ooomb
0?ooo`030000003oool0oooo00<0oooo000V0?ooo`050000003oool0oooo0?ooo`0000001P3oool0
1@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?oo
o`3o0?ooog<0oooo00<000000?ooo`3oool00`3oool002H0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`1W0?ooo`030000
003oool0oooo0?l0ooooM03oool00`000000oooo0?ooo`030?ooo`009`3oool3000000P0oooo0`00
00090?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0o`3ooome0?ooo`030000003o
ool0oooo00<0oooo000n0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0o`3ooomf
0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo06@0oooo00<000000?oo
o`3oool0o`3ooomg0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo06<0
oooo00<000000?ooo`3oool0o`3ooomh0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000
003oool0oooo0680oooo00<000000?ooo`3oool0o`3ooomi0?ooo`030000003oool0oooo00<0oooo
000n0?ooo`<00000H@3oool00`000000oooo0?ooo`3o0?ooogP0oooo0`0000050?ooo`00?P3oool0
0`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0?l0ooooN`3oool00`000000oooo0?ooo`03
0?ooo`00?P3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0?l0ooooO03oool00`00
0000oooo0?ooo`030?ooo`00?P3oool00`000000oooo0?ooo`1M0?ooo`800000o`3ooomo0?ooo`03
0000003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0
o`3ooomo0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo05/0oooo00<0
00000?ooo`3oool0o`3ooon00?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0
oooo05X0oooo00<000000?ooo`3oool0o`3ooon10?ooo`030000003oool0oooo00<0oooo000n0?oo
o`030000003oool0oooo05T0oooo00<000000?ooo`3oool0o`3ooon20?ooo`030000003oool0oooo
00<0oooo000n0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0o`3ooon30?ooo`03
0000003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
o`3ooon40?ooo`030000003oool0oooo00<0oooo000n0?ooo`<00000EP3oool00`000000oooo0?oo
o`3o0?oooh<0oooo0`0000050?ooo`00?P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0
oooo0?l0ooooQP3oool00`000000oooo0?ooo`030?ooo`00?P3oool00`000000oooo0?ooo`1D0?oo
o`030000003oool0oooo0?l0ooooQ`3oool00`000000oooo0?ooo`030?ooo`00?P3oool00`000000
oooo0?ooo`1C0?ooo`030000003oool0oooo0?l0ooooR03oool00`000000oooo0?ooo`030?ooo`00
?P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0?l0ooooR@3oool00`000000oooo
0?ooo`030?ooo`00?P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0?l0ooooR@3o
ool00`000000oooo0?ooo`030?ooo`00?P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0
oooo0?l0ooooRP3oool00`000000oooo0?ooo`030?ooo`00?P3oool00`000000oooo0?ooo`1@0?oo
o`030000003oool0oooo0?l0ooooR`3oool00`000000oooo0?ooo`030?ooo`00?P3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo0?l0ooooS03oool00`000000oooo0?ooo`030?ooo`00
?P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0?l0ooooS03oool00`000000oooo
0?ooo`030?ooo`00?P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0?l0ooooS@3o
ool00`000000oooo0?ooo`030?ooo`00?P3oool3000004d0oooo00<000000?ooo`3oool0o`3ooon<
0?ooo`<000001@3oool003h0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?oo
ohl0oooo00<000000?ooo`3oool00`3oool003h0oooo00<000000?ooo`3oool0C03oool00`000000
oooo0?ooo`3o0?ooohl0oooo00<000000?ooo`3oool00`3oool003h0oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`3o0?oooi00oooo00<000000?ooo`3oool00`3oool003h0oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0?ooo`3o0?oooi40oooo00<000000?ooo`3oool00`3o
ool003h0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3o0?oooi80oooo00<00000
0?ooo`3oool00`3oool003h0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3o0?oo
oi80oooo00<000000?ooo`3oool00`3oool003h0oooo00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`3o0?oooi<0oooo00<000000?ooo`3oool00`3oool003h0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`3o0?oooi@0oooo00<000000?ooo`3oool00`3oool000/0oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0?l0ooooU@3o
ool00`000000oooo0?ooo`030?ooo`002`3oool300000300oooo0`0000160?ooo`030000003oool0
oooo0?l0ooooT`3oool3000000D0oooo000;0?ooo`030000003oool0oooo00<00000;@3oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo0?l0ooooUP3oool00`000000oooo0?ooo`030?oo
o`00403oool2000002`0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`3o0?oooiL0
oooo00<000000?ooo`3oool00`3oool000/0oooo00<000000?ooo`3oool00P00000^0?ooo`030000
003oool0oooo04<0oooo00<000000?ooo`3oool0o`3ooonH0?ooo`030000003oool0oooo00<0oooo
000;0?ooo`<00000<03oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0?l0ooooV03o
ool00`000000oooo0?ooo`030?ooo`002`3oool00`000000oooo0?ooo`03000002d0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`3o0?oooiT0oooo00<000000?ooo`3oool00`3oool0
0100oooo0P00000/0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`030000003oool0oooo00<0oooo000;0?ooo`030000003oool0oooo008000005`3oool3000000<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`030000003oool0oooo00<0oooo000;0?ooo`<00000
603oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo0?l0ooooV`3oool00`000000oooo0?ooo`030?ooo`00
2`3oool00`000000oooo0?ooo`0H0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0o`3ooonK0?ooo`03
0000003oool0oooo00<0oooo000:0?ooo`T000002@3oool7000000<0oooo00D000000?ooo`3oool0
oooo000000080?ooo`030000003oool0oooo00P0oooo1000000n0?ooo`030000003oool0oooo0?l0
ooooV@3oool4000000D0oooo00090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
403oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0n0?ooo`030000003oool0oooo0?l0ooooW@3oool00`000000oooo0?ooo`030?ooo`00
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0
oooo000000090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0?P3oool00`000000
oooo0?ooo`3o0?oooid0oooo00<000000?ooo`3oool00`3oool000/0oooo0P0000040?ooo`030000
003oool0oooo0180oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`3o0?oooih0oooo00<000000?ooo`3o
ool00`3oool000/0oooo00<000000?ooo`3oool00P3oool2000001@0oooo00D000000?ooo`3oool0
oooo000000090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`3o0?oooih0oooo00<000000?ooo`3oool00`3oool000/0oooo00<000000?ooo`3oool0
0P0000000`3oool000000?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0?03oool00`000000
oooo0?ooo`3o0?oooil0oooo00<000000?ooo`3oool00`3oool000/0oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`0C0?ooo`<000001`3oool5000000P0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`3o0?oooj00oooo00<000000?ooo`3oool00`3oool000/0oooo0P00
00040?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`3o0?oooj00oooo00<000000?ooo`3oool00`3oool000/0oooo00<000000?ooo`3oool00P3oool2
000002`0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`3o0?oooj40oooo00<00000
0?ooo`3oool00`3oool003h0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`3o0?oo
oj40oooo00<000000?ooo`3oool00`3oool000P0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0o`3ooonR0?ooo`03
0000003oool0oooo00<0oooo00090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
:03oool3000003P0oooo00<000000?ooo`3oool0o`3ooonQ0?ooo`<000001@3oool000X0oooo2@00
000[0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0o`3ooonS0?ooo`030000003o
ool0oooo00<0oooo000n0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0o`3ooonT
0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0o`3ooonT0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool0o`3ooonU0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000
003oool0oooo03D0oooo00<000000?ooo`3oool0o`3ooonV0?ooo`030000003oool0oooo00<0oooo
000n0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0o`3ooonV0?ooo`030000003o
ool0oooo00<0oooo000n0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0o`3ooonW
0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0o`3ooonW0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool0o`3ooonX0?ooo`030000003oool0oooo00<0oooo000n0?ooo`<00000
<P3oool00`000000oooo0?ooo`3o0?ooojL0oooo0`0000050?ooo`00?P3oool00`000000oooo0?oo
o`0b0?ooo`030000003oool0oooo0?l0ooooZ@3oool00`000000oooo0?ooo`030?ooo`00?P3oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0?l0ooooZP3oool00`000000oooo0?ooo`03
0?ooo`00?P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0?l0ooooZP3oool00`00
0000oooo0?ooo`030?ooo`00?P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0?l0
ooooZ`3oool00`000000oooo0?ooo`030?ooo`00?P3oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo0?l0ooooZ`3oool00`000000oooo0?ooo`030?ooo`00?P3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo0?l0oooo[03oool00`000000oooo0?ooo`030?ooo`00?P3oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0?l0oooo[03oool00`000000oooo0?ooo`03
0?ooo`00?P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0?l0oooo[@3oool00`00
0000oooo0?ooo`030?ooo`00?P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0?l0
oooo[@3oool00`000000oooo0?ooo`030?ooo`00?P3oool3000002d0oooo00<000000?ooo`3oool0
o`3ooon/0?ooo`<000001@3oool003h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`3o0?ooojh0oooo00<000000?ooo`3oool00`3oool003h0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`3o0?ooojl0oooo00<000000?ooo`3oool00`3oool003h0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`3o0?ooojl0oooo00<000000?ooo`3oool00`3oool003h0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`3o0?oook00oooo00<000000?ooo`3o
ool00`3oool003h0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`3o0?oook00oooo
00<000000?ooo`3oool00`3oool003h0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`3o0?oook40oooo00<000000?ooo`3oool00`3oool003h0oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`3o0?oook40oooo00<000000?ooo`3oool00`3oool003h0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`3o0?oook80oooo00<000000?ooo`3oool00`3oool003h0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?oook80oooo00<000000?ooo`3o
ool00`3oool003h0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`3o0?oook<0oooo
00<000000?ooo`3oool00`3oool003h0oooo0`00000X0?ooo`030000003oool0oooo0?l0oooo/@3o
ool3000000D0oooo000n0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0o`3ooond
0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool0o`3ooond0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0o`3ooone0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0o`3ooone0?ooo`030000003oool0oooo00<0oooo
000n0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0o`3ooone0?ooo`030000003o
ool0oooo00<0oooo000W0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`<000002@3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0?l0oooo]P3oool00`000000oooo0?ooo`03
0?ooo`009P3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo0000
00080?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0o`3ooonf0?ooo`030000003o
ool0oooo00<0oooo000V0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?oo
o`3oool0000000P0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`3o0?oookL0oooo
00<000000?ooo`3oool00`3oool001`0oooo1`0000030?ooo`050000003oool0oooo0?ooo`000000
1P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`3o0?oookL0oooo00<000000?ooo`3oool00`3oool002H0oooo00D000000?ooo`3oool0
oooo000000060?ooo`050000003oool0oooo0?ooo`000000203oool4000002<0oooo00<000000?oo
o`3oool0o`3ooond0?ooo`@000001@3oool002H0oooo00D000000?ooo`3oool0oooo000000060?oo
o`8000000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool0o`3ooonh0?ooo`030000003oool0oooo00<0oooo000V0?ooo`050000003oool0oooo0?oo
o`0000001P3oool010000000oooo0000000000090?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0o`3ooonh0?ooo`030000003oool0oooo00<0oooo000V0?ooo`050000003oool0oooo
0?ooo`0000001`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool0o`3oooni0?ooo`030000003oool0oooo00<0oooo000V0?ooo`050000003oool0oooo
0?ooo`000000203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool0o`3oooni0?ooo`030000003oool0oooo00<0oooo000W0?ooo`<000002P3oool20000
00P0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3o0?oookT0oooo00<000000?oo
o`3oool00`3oool003h0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3o0?oookX0
oooo00<000000?ooo`3oool00`3oool003h0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`3o0?oookX0oooo00<000000?ooo`3oool00`3oool003h0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`3o0?oook/0oooo00<000000?ooo`3oool00`3oool003h0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`3o0?oook/0oooo00<000000?ooo`3oool00`3oool0
03h0oooo0`00000O0?ooo`030000003oool0oooo0?l0oooo^P3oool3000000D0oooo000n0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0o`3ooonl0?ooo`030000003oool0oooo00<0
oooo000n0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0o`3ooonl0?ooo`030000
003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0o`3o
oonm0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0o`3ooonm0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0o`3ooonn0?ooo`030000003oool0oooo00<0oooo000n0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0o`3ooonn0?ooo`030000003oool0oooo00<0
oooo000n0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0o`3ooonn0?ooo`030000
003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0o`3o
oono0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0o`3ooono0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0o`3oooo00?ooo`030000003oool0oooo00<0oooo000n0?ooo`<0
00006`3oool00`000000oooo0?ooo`3o0?oookh0oooo0`0000050?ooo`00?P3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo0?l0oooo`03oool00`000000oooo0?ooo`030?ooo`00?P3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0?l0oooo`@3oool00`000000oooo0?oo
o`030?ooo`00?P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0?l0oooo`@3oool0
0`000000oooo0?ooo`030?ooo`00?P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
0?l0oooo`@3oool00`000000oooo0?ooo`030?ooo`00?P3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo0?l0oooo`@3oool00`000000oooo0?ooo`030?ooo`00?P3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo0?l0oooo`P3oool00`000000oooo0?ooo`030?ooo`00?P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0oooo`P3oool00`000000oooo0?oo
o`030?ooo`00?P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0oooo`P3oool0
0`000000oooo0?ooo`030?ooo`00?P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
0?l0oooo``3oool00`000000oooo0?ooo`030?ooo`00?P3oool3000001P0oooo00<000000?ooo`3o
ool0o`3oooo10?ooo`<000001@3oool003h0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`3o0?oool<0oooo00<000000?ooo`3oool00`3oool003h0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`3o0?oool<0oooo00<000000?ooo`3oool00`3oool003h0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`3o0?oool@0oooo00<000000?ooo`3oool00`3oool0
03h0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`3o0?oool@0oooo00<000000?oo
o`3oool00`3oool003h0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`3o0?oool@0
oooo00<000000?ooo`3oool00`3oool003h0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`3o0?ooolD0oooo00<000000?ooo`3oool00`3oool003h0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`3o0?ooolD0oooo00<000000?ooo`3oool00`3oool003h0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`3o0?ooolD0oooo00<000000?ooo`3oool00`3oool0
03h0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3o0?ooolH0oooo00<000000?oo
o`3oool00`3oool003h0oooo0`00000E0?ooo`030000003oool0oooo0?l0ooooa03oool3000000D0
oooo000n0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3oooo60?ooo`030000
003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3o
ooo60?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0o`3oooo70?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0o`3oooo70?ooo`030000003oool0oooo00<0oooo000n0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0o`3oooo70?ooo`030000003oool0oooo00<0
oooo000n0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0o`3oooo80?ooo`030000
003oool0oooo00<0oooo000W0?ooo`<000000`3oool010000000oooo0?ooo`3oool3000000X0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3o0?ooolP0oooo00<000000?ooo`3oool0
0`3oool002H0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3o0?ooolP0oooo00<000000?ooo`3oool0
0`3oool002H0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3o0?ooolP0oooo00<000000?ooo`3oool0
0`3oool001`0oooo1`0000030?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0o`3oooo90?ooo`030000
003oool0oooo00<0oooo000V0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo
0?ooo`060?ooo`@000004@3oool00`000000oooo0?ooo`3o0?ooolH0oooo100000050?ooo`009P3o
ool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo0?l0oooob@3oool00`000000oooo0?ooo`030?ooo`009P3o
ool01@000000oooo0?ooo`3oool0000000H0oooo0`00000:0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0o`3oooo90?ooo`030000003oool0oooo00<0oooo000V0?ooo`050000003o
ool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0o`3oooo:0?ooo`030000003oool0oooo00<0oooo000V0?ooo`050000003o
ool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0o`3oooo:0?ooo`030000003oool0oooo00<0oooo000W0?ooo`<00000203o
ool4000000P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?ooolX0oooo00<0
00000?ooo`3oool00`3oool003h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3o
0?ooolX0oooo00<000000?ooo`3oool00`3oool003h0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`3o0?oool/0oooo00<000000?ooo`3oool00`3oool003h0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`3o0?oool/0oooo00<000000?ooo`3oool00`3oool003h0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?oool/0oooo00<000000?ooo`3oool0
0`3oool003h0oooo0`00000@0?ooo`030000003oool0oooo0?l0oooob@3oool3000000D0oooo000n
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3oooo<0?ooo`030000003oool0
oooo00<0oooo000n0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3oooo<0?oo
o`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0o`3oooo<0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0o`3oooo<0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0o`3oooo=0?ooo`030000003oool0oooo00<0oooo000n
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3oooo=0?ooo`030000003oool0
oooo00<0oooo000n0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3oooo=0?oo
o`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0o`3oooo=0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0o`3oooo>0?ooo`030000003oool0oooo00<0oooo000n0?ooo`<000003@3o
ool00`000000oooo0?ooo`3o0?oool`0oooo0`0000050?ooo`00?P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo0?l0oooocP3oool00`000000oooo0?ooo`030?ooo`00?P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0oooocP3oool00`000000oooo0?ooo`030?oo
o`00?P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000
oooo0?ooo`030?ooo`00?P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo
c`3oool00`000000oooo0?ooo`030?ooo`00?P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`030?ooo`00?P3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`030?ooo`00?P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooood03oool00`000000oooo0?ooo`030?oo
o`00?P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooood03oool00`000000
oooo0?ooo`030?ooo`00?P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo
d03oool00`000000oooo0?ooo`030?ooo`00?P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0?l0ooood03oool00`000000oooo0?ooo`030?ooo`00?P3oool3000000X0oooo00<00000
0?ooo`3oool0o`3oooo?0?ooo`<000001@3oool003h0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`3o0?ooom40oooo00<000000?ooo`3oool00`3oool003h0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`3o0?ooom40oooo00<000000?ooo`3oool00`3oool003h0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?ooom40oooo00<000000?ooo`3oool0
0`3oool003h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooom80oooo00<0
00000?ooo`3oool00`3oool003h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o
0?ooom80oooo00<000000?ooo`3oool00`3oool003h0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`3o0?ooom80oooo00<000000?ooo`3oool00`3oool003h0oooo00<000000?ooo`3o
ool0o`3ooooN0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo0?l0oooo
gP3oool00`000000oooo0?ooo`030?ooo`00?P3oool00`000000oooo0?ooo`3o0?ooomh0oooo00<0
00000?ooo`3oool00`3oool003h0oooo0`00003o0?ooom`0oooo0`0000050?ooo`00?P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0K`3oool00`00
0000oooo0?ooo`1_0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`030?ooo`00?P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0
oooo000n0?ooool00000hP0000050?ooo`00\
\>"],
  ImageRangeCache->{{{0, 547.063}, {337.75, 0}} -> {-0.325735, -1.06601, \
0.00438271, 0.00193177}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ 
      Find\ chi\ square\ for\ given\ H \((z)\)\ \ *) \[IndentingNewLine]\(f[
          z_] := 1/hhz[z];\)\), "\n", 
    \(\(rr[zz_] := NIntegrate[f[z], {z, 0, zz}];\)\[IndentingNewLine]\n (*\ 
      Construct\ marginalization\ coefficients\ \((see\ astro - 
              ph/0401556\  .. )\)\ *) \), "\[IndentingNewLine]", 
    \(Clear[chi2fa, chi2fb, chi2fc]\), "\n", 
    \(\(chi2fa = 
        Sum[\((ld[i] - 5\ Log[10, rr[zz[i]]*\((1 + zz[i])\)])\)^2/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\n", 
    \(\(chi2fb = 
        Sum[\((ld[i] - 
                5\ Log[10, rr[zz[i]]*\((1 + zz[i])\)])\)/\((sld[i]^2)\), {i, 
            1, ndat}];\)\), "\n", 
    \(\(chi2fc = 
        Sum[1/\((sld[i]^2)\), {i, 1, ndat}];\)\[IndentingNewLine]\n (*\ 
      Construct\ function\ after\ marginalization, \ 
      find\ same\ result\ as\ with\ mb\ minimization\ *) \), "\
\[IndentingNewLine]", 
    \(chi2fm = chi2fa - chi2fb^2/chi2fc\), "\[IndentingNewLine]", 
    \(dchi2q25 = chi2fm - chi2l\)}], "Input"],

Cell[BoxData[
    \(192.14065699465573`\)], "Output"],

Cell[BoxData[
    \(15.013285559602082`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ \(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(\
--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(-\(---\)\)\)\)\)\)\)\)\)\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)*) \[IndentingNewLine]\[IndentingNewLine] \
(*\ Find\ H \((z)\)\ for\ given\ slope\ s\ of\ the\ linear\ potential . \ 
            Present\ time\  = \ \(tt\ \((corresponds\ to\ a = 1)\) . \ 
              Run\ trials\ for\ initial\ condition\ for\ field\ fi\ \((f0)\)\ \
and\ initial\ time\ ti\ until\ we\ get\ field\ energy\ enf\  = \ \(0.7\ and\ \
H \((z = 0)\)\  = 
            1\ at\ present\ time\ \(\(tt\)\(.\)\)\)\)\ *) \[IndentingNewLine]\
\[IndentingNewLine] (*\ \(--\(--\(--\(--\ \ s\)\)\)\)\  = \ \(3\ \ \ --\) \(\
--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(---\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\ *) \
\[IndentingNewLine]\[IndentingNewLine]\(Clear[aa, fi, a, aad, aadd, fidas, 
        tas, f, rr, hht, hha];\)\), "\[IndentingNewLine]", 
    \(aa = a[t]; \ fi = f[t];\), "\n", 
    \(\(aad = D[aa, t];\)\), "\n", 
    \(\(aadd = D[aa, {t, 2}];\)\), "\n", 
    \(\(fid = D[fi, t];\)\), "\n", 
    \(\(fidd = D[fi, {t, 2}];\)\), "\n", 
    \(ti = 0.000025; \ t0 = 1.5;\), "\n", 
    \(\(f0 = \(-0.5\);\)\ \), "\n", 
    \(om0m = 0.3; \ ss = 3;\), "\n", 
    \(\(eq1 = 
        aadd/aa\  \[Equal] \(-\ \ fid^2\)\  - \ ss\ fi\  - \ 
            om0m/\((2\ aa^3)\);\)\), "\n", 
    \(\(eq2 = 
        fidd\ \  + \ \ \ 3\ \ fid\ \((aad/aa)\)\  - \ ss \[Equal] 
          0;\)\), "\n", 
    \(\(eqb1 = f[ti] == f0;\)\), "\n", 
    \(\(eqb2 = \(f'\)[ti] == 0;\)\), "\n", 
    \(\(eqb3 = 
        a[ti] \[Equal] \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((2/3)\);\)\), "\n", 
    \(\(eqb4 = \(a'\)[
            ti] \[Equal] \((2/
                3)\)\ \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((\(-1\)/
                  3)\);\)\), "\n", 
    \(\(sol2 = 
        NDSolve[{eq1, eq2, eqb1, eqb2, eqb3, eqb4}, {aa, fi}, {t, ti, t0}, 
          MaxSteps \[Rule] 10000000];\)\), "\n", 
    \(\(asol = Part[Evaluate[a[t] /. sol2], 1];\)\), "\n", 
    \(\(fsol = Part[Evaluate[f[t] /. sol2], 1];\)\), "\n", 
    \(\(dfsol = D[fsol, t];\)\), "\[IndentingNewLine]", 
    \(\(enf = 0.5\ dfsol^2\  - \ ss\ fsol;\)\), "\[IndentingNewLine]", 
    \(\(as[t1_] := asol\  /. \ t -> t1\ ;\)\), "\[IndentingNewLine]", 
    \(\(tt = Part[FindRoot[as[t] == 1, {t, 1}], 1, 2];\)\), "\n", 
    \(\(tas[a_] := 
        Part[FindRoot[as[t] \[Equal] a, {t, 1}], 1, 2];\)\), "\n", 
    \(\(hht[t1_] := D[asol, t]/asol\  /. \ t -> t1\ ;\)\), "\n", 
    \(\(hha[a_] := hht[tas[a]];\)\), "\[IndentingNewLine]", 
    \(\(hhz[z_] := hha[1/\((z + 1)\)];\)\), "\[IndentingNewLine]", 
    \(enf\  /. \ t \[Rule] tt\), "\[IndentingNewLine]", 
    \(hhz[0]\), "\[IndentingNewLine]", 
    \(\(enf = 0.5\ dfsol^2\  - \ ss\ fsol;\)\), "\n", 
    \(\(ppf = 0.5\ dfsol^2\  + \ ss\ fsol;\)\), "\n", 
    \(\(wft[t1_] := ppf/enf\  /. \ t -> t1\ ;\)\ \), "\n", 
    \(\(wfa[a_] := wft[tas[a]];\)\), "\n", 
    \(\(wfz[z_] := wfa[1/\((z + 1)\)];\)\), "\n", 
    \(\(plw30q = 
        Plot[wfz[z], {z, 0, 2}, Frame \[Rule] True, PlotRange \[Rule] All, 
          FrameLabel \[Rule] {"\<z\>", "\<w(z)\>"}];\)\)}], "Input"],

Cell[BoxData[
    \(0.7026398872106371`\)], "Output"],

Cell[BoxData[
    \(1.00260353453523`\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.476191 0.764124 0.775918 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.2619 -0.0125 -10.7813 -17.8125 ]
[.2619 -0.0125 10.7813 0 ]
[.5 -0.0125 -5.53125 -17.8125 ]
[.5 -0.0125 5.53125 0 ]
[.7381 -0.0125 -10.7813 -17.8125 ]
[.7381 -0.0125 10.7813 0 ]
[.97619 -0.0125 -5.53125 -17.8125 ]
[.97619 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.125 -35.625 ]
[.5 -0.0125 5.125 -17.8125 ]
[-0.0125 .0658 -31.25 -8.90625 ]
[-0.0125 .0658 0 8.90625 ]
[-0.0125 .14339 -31.25 -8.90625 ]
[-0.0125 .14339 0 8.90625 ]
[-0.0125 .22098 -31.25 -8.90625 ]
[-0.0125 .22098 0 8.90625 ]
[-0.0125 .29857 -31.25 -8.90625 ]
[-0.0125 .29857 0 8.90625 ]
[-0.0125 .37617 -31.25 -8.90625 ]
[-0.0125 .37617 0 8.90625 ]
[-0.0125 .45376 -31.25 -8.90625 ]
[-0.0125 .45376 0 8.90625 ]
[-0.0125 .53135 -31.25 -8.90625 ]
[-0.0125 .53135 0 8.90625 ]
[-0.0125 .60894 -31.25 -8.90625 ]
[-0.0125 .60894 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -49.0625 -14.7188 ]
[-0.01875 .30902 -31.25 14.7188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.125 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0658 m
.00625 .0658 L
s
gsave
-0.0125 .0658 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
1.000 setlinewidth
grestore
0 .14339 m
.00625 .14339 L
s
gsave
-0.0125 .14339 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .22098 m
.00625 .22098 L
s
gsave
-0.0125 .22098 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
1.000 setlinewidth
grestore
0 .29857 m
.00625 .29857 L
s
gsave
-0.0125 .29857 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .37617 m
.00625 .37617 L
s
gsave
-0.0125 .37617 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .45376 m
.00625 .45376 L
s
gsave
-0.0125 .45376 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .53135 m
.00625 .53135 L
s
gsave
-0.0125 .53135 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
1.000 setlinewidth
grestore
0 .60894 m
.00625 .60894 L
s
gsave
-0.0125 .60894 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .08132 m
.00375 .08132 L
s
0 .09683 m
.00375 .09683 L
s
0 .11235 m
.00375 .11235 L
s
0 .12787 m
.00375 .12787 L
s
0 .15891 m
.00375 .15891 L
s
0 .17443 m
.00375 .17443 L
s
0 .18994 m
.00375 .18994 L
s
0 .20546 m
.00375 .20546 L
s
0 .2365 m
.00375 .2365 L
s
0 .25202 m
.00375 .25202 L
s
0 .26754 m
.00375 .26754 L
s
0 .28305 m
.00375 .28305 L
s
0 .31409 m
.00375 .31409 L
s
0 .32961 m
.00375 .32961 L
s
0 .34513 m
.00375 .34513 L
s
0 .36065 m
.00375 .36065 L
s
0 .39168 m
.00375 .39168 L
s
0 .4072 m
.00375 .4072 L
s
0 .42272 m
.00375 .42272 L
s
0 .43824 m
.00375 .43824 L
s
0 .46928 m
.00375 .46928 L
s
0 .48479 m
.00375 .48479 L
s
0 .50031 m
.00375 .50031 L
s
0 .51583 m
.00375 .51583 L
s
0 .54687 m
.00375 .54687 L
s
0 .56239 m
.00375 .56239 L
s
0 .5779 m
.00375 .5779 L
s
0 .59342 m
.00375 .59342 L
s
0 .05028 m
.00375 .05028 L
s
0 .03476 m
.00375 .03476 L
s
0 .01924 m
.00375 .01924 L
s
0 .00372 m
.00375 .00372 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -115.875 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.7188 12.9063 translate
90 rotate
-75.7188 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.063 17.500 moveto
(H) show
77.625 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.875 17.500 moveto
(L) show
88.438 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0658 m
1 .0658 L
s
.99375 .14339 m
1 .14339 L
s
.99375 .22098 m
1 .22098 L
s
.99375 .29857 m
1 .29857 L
s
.99375 .37617 m
1 .37617 L
s
.99375 .45376 m
1 .45376 L
s
.99375 .53135 m
1 .53135 L
s
.99375 .60894 m
1 .60894 L
s
.125 Mabswid
.99625 .08132 m
1 .08132 L
s
.99625 .09683 m
1 .09683 L
s
.99625 .11235 m
1 .11235 L
s
.99625 .12787 m
1 .12787 L
s
.99625 .15891 m
1 .15891 L
s
.99625 .17443 m
1 .17443 L
s
.99625 .18994 m
1 .18994 L
s
.99625 .20546 m
1 .20546 L
s
.99625 .2365 m
1 .2365 L
s
.99625 .25202 m
1 .25202 L
s
.99625 .26754 m
1 .26754 L
s
.99625 .28305 m
1 .28305 L
s
.99625 .31409 m
1 .31409 L
s
.99625 .32961 m
1 .32961 L
s
.99625 .34513 m
1 .34513 L
s
.99625 .36065 m
1 .36065 L
s
.99625 .39168 m
1 .39168 L
s
.99625 .4072 m
1 .4072 L
s
.99625 .42272 m
1 .42272 L
s
.99625 .43824 m
1 .43824 L
s
.99625 .46928 m
1 .46928 L
s
.99625 .48479 m
1 .48479 L
s
.99625 .50031 m
1 .50031 L
s
.99625 .51583 m
1 .51583 L
s
.99625 .54687 m
1 .54687 L
s
.99625 .56239 m
1 .56239 L
s
.99625 .5779 m
1 .5779 L
s
.99625 .59342 m
1 .59342 L
s
.99625 .05028 m
1 .05028 L
s
.99625 .03476 m
1 .03476 L
s
.99625 .01924 m
1 .01924 L
s
.99625 .00372 m
1 .00372 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .0658 m
1 .0658 L
s
.5 Mabswid
.02381 .60332 m
.04262 .51149 L
.06244 .43894 L
.08255 .38215 L
.10458 .33316 L
.14509 .26651 L
.18408 .22044 L
.22553 .18356 L
.26546 .15591 L
.30387 .13444 L
.34474 .11569 L
.38409 .10068 L
.42192 .08844 L
.46221 .07731 L
.50098 .06811 L
.54221 .05965 L
.58192 .05259 L
.62011 .04663 L
.66075 .04106 L
.69988 .03633 L
.74147 .03189 L
.78153 .0281 L
.82008 .02485 L
.86109 .02176 L
.90057 .01909 L
.93855 .01679 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{687.75, 425.063},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:_0001ZB000`400?l00000o`00003oo`3ooooo
0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo
003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooomc0?ooo`H00000o`3ooolh0?oo
o`00o`3ooomd0?ooo`050000003oool0oooo0?ooo`000000o`3ooolh0?ooo`00o`3ooome0?ooo`03
0000003oool0oooo0?l0oooo>@3oool00?l0ooooM@3oool00`000000oooo0?ooo`3o0?ooocT0oooo
003o0?ooogH0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`00o`3ooomc0?ooo`050000003oool0
oooo0?ooo`000000o`3oooli0?ooo`00o`3ooomc0?ooo`H00000o`3ooolh0?ooo`00o`3ooooo0?oo
ok40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o
0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo
/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00540
oooo0`0000290?ooo`<000000`3oool010000000oooo0?ooo`3oool3000008X0oooo0`0000290?oo
o`<000000`3oool010000000oooo0?ooo`3oool3000008P0oooo1@00000E0?ooo`00D03oool01@00
0000oooo0?ooo`3oool0000008L0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003o
ool0oooo08P0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo08H0oooo00@000000?ooo`3oool000005@3oool00500oooo00D000000?ooo`3oool0oooo
000000270?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`270?ooo`03
0000003oool0oooo08T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo01D0oooo001@0?ooo`050000003oool0oooo0?ooo`000000Q`3oool01@000000
oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`290?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0D0?oo
o`00D03oool01@000000oooo0?ooo`3oool0000008L0oooo00D000000?ooo`3oool0oooo0000000:
0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0503oool00500oooo00D000000?oo
o`3oool0oooo000000270?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?oo
o`280?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`290?ooo`030000003oool0oooo01<0oooo001@0?ooo`050000003oool0oooo0?ooo`000000Q`3o
ool01@000000oooo0?ooo`3oool0000000H0oooo0`00002;0?ooo`030000003oool0oooo08T0oooo
00<000000?ooo`3oool01P3oool3000008`0oooo00<000000?ooo`3oool04`3oool00500oooo00D0
00000?ooo`3oool0oooo000000270?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000
oooo0?ooo`2;0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`2<0?ooo`030000003oool0oooo01<0oooo001@0?ooo`050000003oool0oooo0?ooo`00
0000Q`3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0R@3oool20000
08X0oooo0P0000090?ooo`030000003oool0oooo08L0oooo00D000000?ooo`3oool0oooo0000000E
0?ooo`00D@3oool3000008T0oooo0`0000080?ooo`@00000R@3oool00`000000oooo0?ooo`290?oo
o`030000003oool0oooo00L0oooo100000270?ooo`<000005P3oool00?l0ooooo`3ooona0?ooo`00
o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oo
ok40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00o`3ooooo0?oook40oooo003o
0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00A03ooooo00000?l00000I@0000080?ooo`00
A03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00140?ooo`<000002`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool02@3o
ool3000000P0oooo00140?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00H0oooo00140?ooo`030000003oool0oooo0?l0ooooo`3ooomQ0?ooo`030000003oool0oooo00H0
oooo00140?ooo`030000003oool0oooo0?l0ooooo`3ooomQ0?ooo`030000003oool0oooo00H0oooo
00140?ooo`030000003oool0oooo0?l0ooooo`3ooomQ0?ooo`030000003oool0oooo00H0oooo0014
0?ooo`030000003oool0oooo0?l0ooooo`3ooomQ0?ooo`030000003oool0oooo00H0oooo00140?oo
o`030000003oool0oooo0?l0ooooo`3ooom80?ooo``000003@3oool00`000000oooo0?ooo`060?oo
o`00A03oool00`000000oooo0?ooo`3o0?ooool0oooo<@3ooolG000001T0oooo00<000000?ooo`3o
ool01P3oool004@0oooo0`00003o0?ooool0oooo803ooolA000002h0oooo0`0000080?ooo`00A03o
ool00`000000oooo0?ooo`3o0?ooool0oooo503oool<00000440oooo00<000000?ooo`3oool01P3o
ool004@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`L0oooo3@00001=0?ooo`030000003oool0
oooo00H0oooo00140?ooo`030000003oool0oooo0?l0oooonP3oool<000005X0oooo00<000000?oo
o`3oool01P3oool004@0oooo00<000000?ooo`3oool0o`3oooo^0?ooo``00000IP3oool00`000000
oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`3o0?ooon80oooo3000001b0?ooo`030000
003oool0oooo00H0oooo00140?ooo`030000003oool0oooo0?l0ooooeP3oool<000007h0oooo00<0
00000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0o`3oooo:0?ooo``00000RP3oool0
0`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`3o0?oookl0oooo2`00002F0?oo
o`030000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo0?l0oooo]`3oool800000:40
oooo00<000000?ooo`3oool01P3oool004@0oooo0`00003o0?ooojh0oooo2@00002W0?ooo`<00000
203oool004@0oooo00<000000?ooo`3oool0o`3ooonV0?ooo`P00000/P3oool00`000000oooo0?oo
o`060?ooo`00A03oool00`000000oooo0?ooo`3o0?oooih0oooo2000002j0?ooo`030000003oool0
oooo00H0oooo00140?ooo`030000003oool0oooo0?l0ooooUP3oool800000<80oooo00<000000?oo
o`3oool01P3oool004@0oooo00<000000?ooo`3oool0o`3ooon=0?ooo`T00000bP3oool00`000000
oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`3o0?ooohD0oooo2000003C0?ooo`030000
003oool0oooo00H0oooo00140?ooo`030000003oool0oooo0?l0ooooO@3oool800000=/0oooo00<0
00000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0o`3ooomf0?ooo`L00000h`3oool0
0`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`3o0?ooog00oooo1P00003Z0?oo
o`030000003oool0oooo00H0oooo00140?ooo`<00000o`3ooomZ0?ooo`H00000kP3oool3000000P0
oooo00140?ooo`030000003oool0oooo0?l0ooooI03oool600000?H0oooo00<000000?ooo`3oool0
1P3oool004@0oooo00<000000?ooo`3oool0o`3ooomO0?ooo`D00000o03oool00`000000oooo0?oo
o`060?ooo`00A03oool00`000000oooo0?ooo`3o0?oooeT0oooo1P00003o0?ooo`80oooo00<00000
0?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0o`3ooomC0?ooo`H00000o`3oool80?oo
o`030000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo0?l0ooooC@3oool600000?l0
oooo3P3oool00`000000oooo0?ooo`060?ooo`00:`3oool3000000<0oooo00@000000?ooo`3oool0
oooo0P00000=0?ooo`030000003oool0oooo0?l0ooooA`3oool600000?l0oooo503oool00`000000
oooo0?ooo`060?ooo`00:P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`3o0?oood80oooo1@00003o0?oooaX0oooo00<000000?ooo`3o
ool01P3oool002X0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0o`3ooolm0?ooo`D00000o`3ooolO0?ooo`030000003oool0oooo00H0
oooo000P0?ooo`L000000`3oool01@000000oooo0?ooo`3oool0000000L0oooo1000000:0?ooo`03
0000003oool0oooo0?l0oooo>03oool500000?l0oooo903oool00`000000oooo0?ooo`060?ooo`00
:P3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo0000000:0?oo
ool00000o`00001U000000P0oooo000Z0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@00
0000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0o`3oool_0?ooo`@00000o`3oool^
0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`050000003oool0oooo0?ooo`0000001P3oool0
1@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0o`3oool[0?ooo`@00000o`3o
oolb0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`050000003oool0oooo0?ooo`0000001P3o
ool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`@00000
o`3ooolf0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`050000003oool0oooo0?ooo`000000
1P3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`@0
0000o`3ooolj0?ooo`030000003oool0oooo00H0oooo000[0?ooo`<00000203oool3000000/0oooo
00<000000?ooo`3oool0o`3ooolO0?ooo`@00000o`3oooln0?ooo`030000003oool0oooo00H0oooo
00140?ooo`030000003oool0oooo0?l0oooo6`3oool400000?l0oooo@P3oool00`000000oooo0?oo
o`060?ooo`00A03oool00`000000oooo0?ooo`3o0?oooaL0oooo1000003o0?ooodH0oooo00<00000
0?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`@00000o`3ooom:0?oo
o`030000003oool0oooo00H0oooo00140?ooo`<00000o`3oool@0?ooo`<00000o`3ooom<0?ooo`<0
0000203oool004@0oooo00<000000?ooo`3oool0o`3oool<0?ooo`@00000o`3ooomA0?ooo`030000
003oool0oooo00H0oooo00140?ooo`030000003oool0oooo0?l0oooo203oool400000?l0ooooE@3o
ool00`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`3o0?ooo`D0oooo0`00003o
0?oooeT0oooo00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0o`3oool10?oo
o`@00000o`3ooomL0?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo0?d0
oooo0`00003o0?ooof00oooo00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0
nP3oool300000?l0ooooH`3oool00`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?oo
o`3f0?ooo`@00000o`3ooomV0?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003oool0
oooo0?<0oooo0`00003o0?ooofX0oooo00<000000?ooo`3oool01P3oool004@0oooo00<000000?oo
o`3oool0l03oool300000?l0ooooK@3oool00`000000oooo0?ooo`060?ooo`00A03oool300000>`0
oooo1000003o0?ooofh0oooo0`0000080?ooo`00A03oool00`000000oooo0?ooo`3Y0?ooo`<00000
o`3ooomd0?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo0>H0oooo0`00
003o0?ooogL0oooo00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0i03oool2
00000?l0ooooNP3oool00`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`3Q0?oo
o`<00000o`3oooml0?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo0=h0
oooo0`00003o0?ooogl0oooo00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0
g03oool200000?l0ooooPP3oool00`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?oo
o`3I0?ooo`<00000o`3ooon40?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003oool0
oooo0=H0oooo0`00003o0?ooohL0oooo00<000000?ooo`3oool01P3oool004@0oooo0`00003D0?oo
o`800000o`3ooon80?ooo`<00000203oool004@0oooo00<000000?ooo`3oool0d@3oool300000?l0
ooooS03oool00`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`3>0?ooo`<00000
o`3ooon?0?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo0<`0oooo0P00
003o0?oooi80oooo00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0bP3oool2
00000?l0ooooU03oool00`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`380?oo
o`800000o`3ooonF0?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo0<H0
oooo0P00003o0?oooiP0oooo00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0
a03oool200000?l0ooooVP3oool00`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?oo
o`320?ooo`800000o`3ooonL0?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003oool0
oooo0<00oooo0P00003o0?oooih0oooo00<000000?ooo`3oool01P3oool004@0oooo0`00002n0?oo
o`800000o`3ooonN0?ooo`<00000203oool004@0oooo00<000000?ooo`3oool0_03oool200000?l0
ooooXP3oool00`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`2j0?ooo`800000
o`3ooonT0?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo0;P0oooo0P00
003o0?ooojH0oooo00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0]P3oool2
00000?l0ooooZ03oool00`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`2d0?oo
o`800000o`3ooonZ0?ooo`030000003oool0oooo00H0oooo000[0?ooo`<000000`3oool00`000000
oooo0?ooo`020?ooo`<000002`3oool00`000000oooo0?ooo`2b0?ooo`800000o`3ooon/0?ooo`03
0000003oool0oooo00H0oooo000Z0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000
oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0/03oool200000?l0oooo[P3oool00`00
0000oooo0?ooo`060?ooo`00:P3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?oo
o`3oool0oooo0000000:0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0o`3ooon^
0?ooo`030000003oool0oooo00H0oooo000P0?ooo`L000000`3oool01@000000oooo0?ooo`3oool0
000000H0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D00000Z`3oool200000?l0oooo[P3o
ool4000000P0oooo000Z0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0000
000;0?ooo`030000003oool0oooo0:/0oooo0P00003o0?oook<0oooo00<000000?ooo`3oool01P3o
ool002X0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0Z@3oool200000?l0oooo]@3oool00`000000oooo0?ooo`060?ooo`00:P3oool0
1@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`0000002`3oool00`000000oooo0?oo
o`2W0?ooo`800000o`3ooong0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`050000003oool0
oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0
YP3oool00`000000oooo0?ooo`3o0?oookL0oooo00<000000?ooo`3oool01P3oool002X0oooo00D0
00000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000
oooo0?ooo`2T0?ooo`800000o`3ooonj0?ooo`030000003oool0oooo00H0oooo000[0?ooo`<00000
203oool3000000/0oooo00<000000?ooo`3oool0XP3oool200000?l0oooo_03oool00`000000oooo
0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`2P0?ooo`800000o`3ooonn0?ooo`030000003o
ool0oooo00H0oooo00140?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0o`3ooonn
0?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo09d0oooo0P00003o0?oo
ol40oooo00<000000?ooo`3oool01P3oool004@0oooo0`00002L0?ooo`030000003oool0oooo0?l0
oooo_`3oool3000000P0oooo00140?ooo`030000003oool0oooo09X0oooo0P00003o0?oool@0oooo
00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?oo
o`3o0?oool@0oooo00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0U`3oool2
00000?l0ooooa`3oool00`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`2F0?oo
o`030000003oool0oooo0?l0ooooa`3oool00`000000oooo0?ooo`060?ooo`00A03oool00`000000
oooo0?ooo`2D0?ooo`800000o`3oooo:0?ooo`030000003oool0oooo00H0oooo00140?ooo`030000
003oool0oooo09<0oooo00<000000?ooo`3oool0o`3oooo:0?ooo`030000003oool0oooo00H0oooo
00140?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0o`3oooo;0?ooo`030000003o
ool0oooo00H0oooo00140?ooo`030000003oool0oooo0900oooo0P00003o0?ooolh0oooo00<00000
0?ooo`3oool01P3oool004@0oooo0`00002?0?ooo`030000003oool0oooo0?l0ooooc03oool30000
00P0oooo00140?ooo`030000003oool0oooo08d0oooo0P00003o0?ooom40oooo00<000000?ooo`3o
ool01P3oool004@0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3o0?ooom40oooo
00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0RP3oool200000?l0ooooe03o
ool00`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`290?ooo`030000003oool0
oooo0?l0ooooe03oool00`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`270?oo
o`800000o`3ooooG0?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo08H0
oooo00<000000?ooo`3oool0o`3ooooG0?ooo`030000003oool0oooo00H0oooo00140?ooo`030000
003oool0oooo08D0oooo00<000000?ooo`3oool0o`3ooooH0?ooo`030000003oool0oooo00H0oooo
00140?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0o`3ooooI0?ooo`030000003o
ool0oooo00H0oooo00140?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0o`3ooooJ
0?ooo`030000003oool0oooo00H0oooo00140?ooo`<00000P@3oool200000?l0oooof`3oool30000
00P0oooo00140?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0o`3ooooM0?ooo`03
0000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0
o`3ooooN0?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo07h0oooo00<0
00000?ooo`3oool0o`3ooooO0?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003oool0
oooo07d0oooo00<000000?ooo`3oool0o`3ooooP0?ooo`030000003oool0oooo00H0oooo00140?oo
o`030000003oool0oooo07`0oooo00<000000?ooo`3oool0o`3ooooQ0?ooo`030000003oool0oooo
00H0oooo00140?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0o`3ooooR0?ooo`03
0000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo07T0oooo0P00003o0?ooonD0oooo
00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`3o0?ooonD0oooo00<000000?ooo`3oool01P3oool004@0oooo0`00001g0?ooo`030000003oool0
oooo0?l0ooooi03oool3000000P0oooo00140?ooo`030000003oool0oooo07H0oooo00<000000?oo
o`3oool0o`3ooooW0?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo07D0
oooo00<000000?ooo`3oool0o`3ooooX0?ooo`030000003oool0oooo00H0oooo00140?ooo`030000
003oool0oooo07@0oooo00<000000?ooo`3oool0o`3ooooY0?ooo`030000003oool0oooo00H0oooo
00140?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0o`3ooooZ0?ooo`030000003o
ool0oooo00H0oooo00140?ooo`030000003oool0oooo0740oooo0P00003o0?ooond0oooo00<00000
0?ooo`3oool01P3oool002/0oooo0`0000030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0?l0ooook@3oool00`00
0000oooo0?ooo`060?ooo`00:P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0?l0ooookP3oool00`00
0000oooo0?ooo`060?ooo`00:P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo0?l0ooook`3oool00`00
0000oooo0?ooo`060?ooo`00803oool7000000<0oooo00D000000?ooo`3oool0oooo000000080?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`3o0?oo
oo00oooo00<000000?ooo`3oool01P3oool002X0oooo00D000000?ooo`3oool0oooo000000080?oo
o`030000003oool0oooo00X0oooo1@00001Z0?ooo`030000003oool0oooo0?l0ooookP3oool40000
00P0oooo000Z0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo06/0oooo00<000000?ooo`3oool0o`3oooob0?ooo`030000003oool0oooo
00H0oooo000Z0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo06X0oooo00<000000?ooo`3oool0o`3ooooc0?ooo`030000003oool0oooo
00H0oooo000Z0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo06X0oooo00<000000?ooo`3oool0o`3ooooc0?ooo`030000003oool0oooo
00H0oooo000Z0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`3o0?oo
oo@0oooo00<000000?ooo`3oool01P3oool002/0oooo0`0000070?ooo`D000002P3oool00`000000
oooo0?ooo`1X0?ooo`030000003oool0oooo0?l0oooom@3oool00`000000oooo0?ooo`060?ooo`00
A03oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0?l0oooomP3oool00`000000oooo
0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0?l0oooom`3o
ool00`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0
oooo0?l0oooon03oool00`000000oooo0?ooo`060?ooo`00A03oool3000006@0oooo00<000000?oo
o`3oool0o`3oooog0?ooo`<00000203oool004@0oooo00<000000?ooo`3oool0I03oool00`000000
oooo0?ooo`3o0?ooooT0oooo00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0
H`3oool00`000000oooo0?ooo`3o0?ooooX0oooo00<000000?ooo`3oool01P3oool004@0oooo00<0
00000?ooo`3oool0HP3oool00`000000oooo0?ooo`3o0?oooo/0oooo00<000000?ooo`3oool01P3o
ool004@0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`3o0?oooo`0oooo00<00000
0?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`3o0?oo
ood0oooo00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0G`3oool00`000000
oooo0?ooo`3o0?ooooh0oooo00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0
GP3oool00`000000oooo0?ooo`3o0?ooool0oooo00<000000?ooo`3oool01P3oool004@0oooo00<0
00000?ooo`3oool0GP3oool00`000000oooo0?ooo`3o0?ooool0oooo00<000000?ooo`3oool01P3o
ool004@0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`3o0?ooool0oooo0@3oool0
0`000000oooo0?ooo`060?ooo`00A03oool3000005`0oooo00<000000?ooo`3oool0o`3ooooo0?oo
o`<00000203oool004@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`3o0?ooool0
oooo0`3oool00`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`1J0?ooo`030000
003oool0oooo0?l0ooooo`3oool40?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003o
ool0oooo05T0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`D0oooo00<000000?ooo`3oool01P3o
ool004@0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3o0?ooool0oooo1P3oool0
0`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
0?l0ooooo`3oool60?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool0o`3ooooo0?ooo`L0oooo00<000000?ooo`3oool01P3oool004@0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`3o0?ooool0oooo203oool00`000000oooo
0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0?l0ooooo`3o
ool90?ooo`030000003oool0oooo00H0oooo00140?ooo`<00000E03oool00`000000oooo0?ooo`3o
0?ooool0oooo203oool3000000P0oooo00140?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool0o`3ooooo0?ooo`X0oooo00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3o
ool0D`3oool00`000000oooo0?ooo`3o0?ooool0oooo2`3oool00`000000oooo0?ooo`060?ooo`00
A03oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0?l0ooooo`3oool;0?ooo`030000
003oool0oooo00H0oooo00140?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0o`3o
oooo0?ooo``0oooo00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0D@3oool0
0`000000oooo0?ooo`3o0?ooool0oooo3@3oool00`000000oooo0?ooo`060?ooo`00A03oool00`00
0000oooo0?ooo`1A0?ooo`030000003oool0oooo0?l0ooooo`3oool=0?ooo`030000003oool0oooo
00H0oooo00140?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0o`3ooooo0?ooo`h0
oooo00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0D03oool00`000000oooo
0?ooo`3o0?ooool0oooo3P3oool00`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo0?l0ooooo`3oool?0?ooo`030000003oool0oooo00H0oooo0014
0?ooo`<00000C`3oool00`000000oooo0?ooo`3o0?ooool0oooo3@3oool3000000P0oooo00140?oo
o`030000003oool0oooo04h0oooo00<000000?ooo`3oool0o`3ooooo0?oooa00oooo00<000000?oo
o`3oool01P3oool004@0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3o0?ooool0
oooo4@3oool00`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`1=0?ooo`030000
003oool0oooo0?l0ooooo`3ooolA0?ooo`030000003oool0oooo00H0oooo000>0?ooo`030000003o
ool0oooo03<0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?ooool0oooo4P3o
ool00`000000oooo0?ooo`060?ooo`003P3oool3000001X0oooo0`0000030?ooo`030000003oool0
oooo0080oooo0`00000;0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0o`3ooooo
0?oooa80oooo00<000000?ooo`3oool01P3oool000h0oooo00<000000?ooo`3oool00`00000F0?oo
o`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000X0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?ooool0oooo4`3oool00`000000oooo0?oo
o`060?ooo`004`3oool2000001D0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003o
ool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0?l0oooo
o`3ooolD0?ooo`030000003oool0oooo00H0oooo000>0?ooo`030000003oool0oooo008000003@3o
ool7000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`00
00002P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0?l0ooooo`3ooolD0?ooo`03
0000003oool0oooo00H0oooo000>0?ooo`<000006@3oool01@000000oooo0?ooo`3oool0000000H0
oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D00000A`3oool00`000000oooo0?ooo`3o0?oo
ool0oooo4P3oool4000000P0oooo000>0?ooo`030000003oool0oooo00<000005P3oool01@000000
oooo0?ooo`3oool0000000H0oooo0P0000020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0B@3oool00`000000oooo0?ooo`3o0?ooool0oooo5@3oool00`000000oooo0?ooo`060?oo
o`004`3oool2000001D0oooo00D000000?ooo`3oool0oooo000000060?ooo`040000003oool00000
000000/0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool0
0`000000oooo0?ooo`060?ooo`003P3oool00`000000oooo0?ooo`02000001L0oooo00D000000?oo
o`3oool0oooo000000070?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`3o0?ooool0oooo5P3oool00`000000oooo0?ooo`060?ooo`003P3oool30000
01T0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0A`3oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool00`000000oooo0?ooo`06
0?ooo`003P3oool00`000000oooo0?ooo`0J0?ooo`<000002P3oool2000000X0oooo00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`3o0?ooool0oooo603oool00`000000oooo0?ooo`060?oo
o`003@3oool9000002h0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`3o0?ooool0
oooo603oool00`000000oooo0?ooo`060?ooo`00303oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`3o0?ooool0oooo
6@3oool00`000000oooo0?ooo`060?ooo`002`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`3o0?ooool0oooo6@3o
ool00`000000oooo0?ooo`060?ooo`003P3oool2000000@0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo0?l0ooooo`3ooolJ0?ooo`030000003oool0
oooo00H0oooo000>0?ooo`030000003oool0oooo0080oooo0P00000_0?ooo`<00000@`3oool00`00
0000oooo0?ooo`3o0?ooool0oooo6@3oool3000000P0oooo000>0?ooo`030000003oool0oooo0080
000000<0oooo0000003oool0;P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0?l0
ooooo`3ooolK0?ooo`030000003oool0oooo00H0oooo000>0?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0?l0oooo
o`3ooolL0?ooo`030000003oool0oooo00H0oooo000>0?ooo`800000103oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0o`3ooooo0?oooa`0oooo00<0
00000?ooo`3oool01P3oool000h0oooo00<000000?ooo`3oool00P3oool2000002l0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`3o0?ooool0oooo7@3oool00`000000oooo0?ooo`06
0?ooo`00A03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0?l0ooooo`3ooolM0?oo
o`030000003oool0oooo00H0oooo000;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0?l0ooooo`3ooolN0?ooo`03
0000003oool0oooo00H0oooo000<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0?l0ooooo`3ooolO0?ooo`030000
003oool0oooo00H0oooo000=0?ooo`T00000;P3oool00`000000oooo0?ooo`0o0?ooo`030000003o
ool0oooo0?l0ooooo`3ooolO0?ooo`030000003oool0oooo00H0oooo00140?ooo`<00000?P3oool0
0`000000oooo0?ooo`3o0?ooool0oooo7P3oool3000000P0oooo00140?ooo`030000003oool0oooo
03h0oooo00<000000?ooo`3oool0o`3ooooo0?ooob00oooo00<000000?ooo`3oool01P3oool004@0
oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool00`000000
oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0?l0oooo
o`3ooolQ0?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooob80oooo00<000000?ooo`3oool01P3oool004@0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`3o0?ooool0oooo8P3oool00`000000oooo0?ooo`06
0?ooo`00A03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0ooooo`3ooolS0?oo
o`030000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooob<0oooo00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0
>P3oool00`000000oooo0?ooo`3o0?ooool0oooo903oool00`000000oooo0?ooo`060?ooo`00A03o
ool3000003X0oooo00<000000?ooo`3oool0o`3ooooo0?ooob80oooo0`0000080?ooo`00A03oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0?l0ooooo`3ooolU0?ooo`030000003oool0
oooo00H0oooo00140?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0o`3ooooo0?oo
obD0oooo00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`3o0?ooool0oooo9P3oool00`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo0?l0ooooo`3ooolV0?ooo`030000003oool0oooo00H0oooo
00140?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0o`3ooooo0?ooobL0oooo00<0
00000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`3o
0?ooool0oooo9`3oool00`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo0?l0ooooo`3ooolX0?ooo`030000003oool0oooo00H0oooo00140?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool0o`3ooooo0?ooobP0oooo00<000000?ooo`3o
ool01P3oool004@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`3o0?ooool0oooo
:03oool00`000000oooo0?ooo`060?ooo`00A03oool3000003D0oooo00<000000?ooo`3oool0o`3o
oooo0?ooobL0oooo0`0000080?ooo`00A03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo0?l0ooooo`3ooolY0?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0o`3ooooo0?ooobX0oooo00<000000?ooo`3oool01P3oool004@0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`3o0?ooool0oooo:P3oool00`000000
oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0?l0oooo
o`3oool[0?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo03<0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooob/0oooo00<000000?ooo`3oool01P3oool002/0oooo0`000003
0?ooo`040000003oool0oooo0?ooo`<00000303oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo0?l0ooooo`3oool/0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`050000003oool0
oooo0?ooo`0000002@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0380oooo00<0
00000?ooo`3oool0o`3ooooo0?ooob`0oooo00<000000?ooo`3oool01P3oool002X0oooo00D00000
0?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0<@3o
ool00`000000oooo0?ooo`3o0?ooool0oooo;@3oool00`000000oooo0?ooo`060?ooo`00803oool7
000000<0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00P0oooo1@00
000_0?ooo`030000003oool0oooo0?l0ooooo`3ooolZ0?ooo`@00000203oool002X0oooo00D00000
0?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0<03o
ool00`000000oooo0?ooo`3o0?ooool0oooo;P3oool00`000000oooo0?ooo`060?ooo`00:P3oool0
1@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo0?l0ooooo`3oool^0?ooo`030000003oool0oooo00H0oooo000Z
0?ooo`050000003oool0oooo0?ooo`0000001P3oool3000000`0oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`3o0?ooool0oooo;`3oool00`000000oooo0?ooo`060?ooo`00:P3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo0?l0ooooo`3oool_0?ooo`030000003oool0oooo00H0oooo000Z
0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool0o`3ooooo0?ooobl0oooo00<000000?ooo`3oool01P3o
ool002/0oooo0`0000080?ooo`@000002P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo0?l0ooooo`3oool`0?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool0o`3ooooo0?oooc00oooo00<000000?ooo`3oool01P3oool004@0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`3o0?ooool0oooo<03oool00`000000
oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0oooo
o`3ooola0?ooo`030000003oool0oooo00H0oooo00140?ooo`<00000;@3oool00`000000oooo0?oo
o`3o0?ooool0oooo;`3oool3000000P0oooo00140?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooc40oooo00<000000?ooo`3oool01P3oool004@0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`3o0?ooool0oooo<P3oool00`000000oooo0?ooo`060?oo
o`00A03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0?l0ooooo`3ooolb0?ooo`03
0000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
o`3ooooo0?oooc80oooo00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`3o0?ooool0oooo<`3oool00`000000oooo0?ooo`060?ooo`00A03oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0ooooo`3ooolc0?ooo`030000003oool0
oooo00H0oooo00140?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oc<0oooo00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`3o0?ooool0oooo=03oool00`000000oooo0?ooo`060?ooo`00A03oool3000002X0oooo
00<000000?ooo`3oool0o`3ooooo0?oooc80oooo0`0000080?ooo`00A03oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo0?l0ooooo`3ooold0?ooo`030000003oool0oooo00H0oooo0014
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3ooooo0?ooocD0oooo00<00000
0?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?oo
ool0oooo=@3oool00`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo0?l0ooooo`3ooolf0?ooo`030000003oool0oooo00H0oooo00140?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool0o`3ooooo0?ooocH0oooo00<000000?ooo`3oool0
1P3oool004@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`3o0?ooool0oooo=P3o
ool00`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo0?l0ooooo`3ooolg0?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool0o`3ooooo0?ooocL0oooo00<000000?ooo`3oool01P3oool004@0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3o0?ooool0oooo=`3oool00`000000
oooo0?ooo`060?ooo`00A03oool3000002H0oooo00<000000?ooo`3oool0o`3ooooo0?ooocH0oooo
0`0000080?ooo`00A03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0?l0ooooo`3o
oolh0?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooocP0oooo00<000000?ooo`3oool01P3oool004@0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`3o0?ooool0oooo>@3oool00`000000oooo0?ooo`060?oo
o`00A03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0?l0ooooo`3oooli0?ooo`03
0000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
o`3ooooo0?ooocT0oooo00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000oooo0?ooo`060?ooo`00A03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003oool0
oooo00H0oooo00140?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ocX0oooo00<000000?ooo`3oool01P3oool004@0oooo0`00000S0?ooo`030000003oool0oooo0?l0
ooooo`3oooli0?ooo`<00000203oool004@0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`3o0?ooool0oooo>`3oool00`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo0?l0ooooo`3ooolk0?ooo`030000003oool0oooo00H0oooo0014
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0o`3ooooo0?oooc`0oooo00<00000
0?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3o0?oo
ool0oooo?03oool00`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo0?l0ooooo`3oooll0?ooo`030000003oool0oooo00H0oooo000[0?ooo`<00000
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`3o0?ooool0oooo?03oool00`000000oooo0?ooo`060?ooo`00:P3o
ool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo0?l0ooooo`3ooolm0?ooo`030000003oool0oooo00H0oooo
000Z0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool0o`3ooooo0?ooocd0oooo00<000000?ooo`3oool0
1P3oool00200oooo1`0000030?ooo`050000003oool0oooo0?ooo`0000001@3oool6000000X0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3o0?ooool0oooo?@3oool00`000000oooo
0?ooo`060?ooo`00:P3oool01@000000oooo0?ooo`3oool0000000D0oooo00D000000?ooo`3oool0
oooo0000000;0?ooo`D000007`3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool4000000P0
oooo000Z0?ooo`050000003oool0oooo0?ooo`0000001P3oool010000000oooo0?ooo`00000;0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0o`3ooooo0?oooch0oooo00<000000?oo
o`3oool01P3oool002X0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool00000
00/0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`3o0?ooool0oooo?P3oool00`00
0000oooo0?ooo`060?ooo`00:P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?oo
o`0000002`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0?l0ooooo`3oooln0?oo
o`030000003oool0oooo00H0oooo000Z0?ooo`050000003oool0oooo0?ooo`000000203oool20000
00/0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3o0?ooool0oooo?`3oool00`00
0000oooo0?ooo`060?ooo`00:`3oool3000000X0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0ooooo`3ooolo0?ooo`030000003oool0oooo00H0
oooo00140?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0o`3ooooo0?ooocl0oooo
00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`3o0?ooool0oooo?`3oool00`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo0?l0ooooo`3ooom00?ooo`030000003oool0oooo00H0oooo00140?oo
o`<000007P3oool00`000000oooo0?ooo`3o0?ooool0oooo?P3oool3000000P0oooo00140?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0o`3ooooo0?oood00oooo00<000000?ooo`3o
ool01P3oool004@0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3o0?ooool0oooo
@03oool00`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo0?l0ooooo`3ooom10?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0o`3ooooo0?oood40oooo00<000000?ooo`3oool01P3oool0
04@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3o0?ooool0oooo@@3oool00`00
0000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0?l0
ooooo`3ooom20?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0o`3ooooo0?oood80oooo00<000000?ooo`3oool01P3oool004@0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`3o0?ooool0oooo@P3oool00`000000oooo0?oo
o`060?ooo`00A03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0?l0ooooo`3ooom2
0?ooo`030000003oool0oooo00H0oooo00140?ooo`<000006`3oool00`000000oooo0?ooo`3o0?oo
ool0oooo@@3oool3000000P0oooo00140?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0o`3ooooo0?oood<0oooo00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`3o0?ooool0oooo@`3oool00`000000oooo0?ooo`060?ooo`00A03o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0?l0ooooo`3ooom30?ooo`030000003o
ool0oooo00H0oooo00140?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0o`3ooooo
0?oood@0oooo00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`3o0?ooool0ooooA03oool00`000000oooo0?ooo`060?ooo`00A03oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo0?l0ooooo`3ooom40?ooo`030000003oool0oooo00H0
oooo00140?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0o`3ooooo0?ooodD0oooo
00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`3o0?ooool0ooooA@3oool00`000000oooo0?ooo`060?ooo`00A03oool3000001T0oooo00<00000
0?ooo`3oool0o`3ooooo0?oood<0oooo0`0000080?ooo`00A03oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo0?l0ooooo`3ooom50?ooo`030000003oool0oooo00H0oooo00140?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3ooooo0?ooodH0oooo00<000000?ooo`3o
ool01P3oool004@0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`3o0?ooool0oooo
AP3oool00`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo0?l0ooooo`3ooom60?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0o`3ooooo0?ooodH0oooo00<000000?ooo`3oool01P3oool0
04@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`3o0?ooool0ooooA`3oool00`00
0000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0?l0
ooooo`3ooom70?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0o`3ooooo0?ooodL0oooo00<000000?ooo`3oool01P3oool004@0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`3o0?ooool0ooooA`3oool00`000000oooo0?oo
o`060?ooo`00A03oool3000001H0oooo00<000000?ooo`3oool0o`3ooooo0?ooodH0oooo0`000008
0?ooo`00A03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0ooooo`3ooom80?oo
o`030000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooodP0oooo00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`3o0?ooool0ooooB03oool00`000000oooo0?ooo`060?ooo`00A03o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0ooooo`3ooom90?ooo`030000003o
ool0oooo00H0oooo00140?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3ooooo
0?ooodT0oooo00<000000?ooo`3oool01P3oool002/0oooo0`0000030?ooo`040000003oool0oooo
0?ooo`@000002`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0ooooo`3ooom9
0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`050000003oool0oooo0?ooo`0000002P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3ooooo
0?ooodT0oooo00<000000?ooo`3oool01P3oool002X0oooo00D000000?ooo`3oool0oooo0000000:
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3o
0?ooool0ooooB@3oool00`000000oooo0?ooo`060?ooo`00803oool7000000<0oooo00D000000?oo
o`3oool0oooo0000000:0?ooo`030000003oool0oooo00P0oooo1@00000B0?ooo`030000003oool0
oooo0?l0ooooo`3ooom70?ooo`@00000203oool002X0oooo00D000000?ooo`3oool0oooo0000000:
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3o
0?ooool0ooooBP3oool00`000000oooo0?ooo`060?ooo`00:P3oool01@000000oooo0?ooo`3oool0
000000P0oooo0P00000;0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0o`3ooooo
0?ooodX0oooo00<000000?ooo`3oool01P3oool002X0oooo00D000000?ooo`3oool0oooo00000009
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3o
0?ooool0ooooBP3oool00`000000oooo0?ooo`060?ooo`00:P3oool01@000000oooo0?ooo`3oool0
000000X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo0?l0ooooo`3ooom:0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`050000003oool0oooo
0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`3o0?ooool0ooooB`3oool00`000000oooo0?ooo`060?ooo`00:`3oool3
000000P0oooo0`00000;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0o`3ooooo
0?oood/0oooo00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`3o0?ooool0ooooB`3oool00`000000oooo0?ooo`060?ooo`00A03oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0ooooo`3ooom;0?ooo`030000003oool0oooo00H0
oooo00140?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0o`3ooooo0?oood`0oooo
00<000000?ooo`3oool01P3oool004@0oooo0`00000B0?ooo`030000003oool0oooo0?l0ooooo`3o
oom:0?ooo`<00000203oool004@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3o
0?ooool0ooooC03oool00`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo0?l0ooooo`3ooom<0?ooo`030000003oool0oooo00H0oooo00140?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0o`3ooooo0?oood`0oooo00<000000?ooo`3o
ool01P3oool004@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?ooool0oooo
C@3oool00`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo0?l0ooooo`3ooom=0?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0o`3ooooo0?ooodd0oooo00<000000?ooo`3oool01P3oool0
04@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?ooool0ooooC@3oool00`00
0000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0
ooooo`3ooom=0?ooo`030000003oool0oooo00H0oooo00140?ooo`<00000403oool00`000000oooo
0?ooo`3o0?ooool0ooooC03oool3000000P0oooo00140?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0o`3ooooo0?ooodh0oooo00<000000?ooo`3oool01P3oool004@0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`3o0?ooool0ooooCP3oool00`000000oooo0?ooo`06
0?ooo`00A03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0ooooo`3ooom>0?oo
o`030000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?ooo`060?ooo`00A03o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooo`3ooom?0?ooo`030000003o
ool0oooo00H0oooo00140?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooooo
0?ooodl0oooo00<000000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?ooo`060?ooo`00A03oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0ooooo`3ooom@0?ooo`030000003oool0oooo00H0
oooo00140?ooo`<000003P3oool00`000000oooo0?ooo`3o0?ooool0ooooCP3oool3000000P0oooo
00140?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooooo0?oooe00oooo00<0
00000?ooo`3oool01P3oool004@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3o
0?ooool0ooooD03oool00`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0?l0ooooo`3ooom@0?ooo`030000003oool0oooo00H0oooo00140?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3o
ool01P3oool004@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?ooool0oooo
D@3oool00`000000oooo0?ooo`060?ooo`00A03oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool01P3oool0
04@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooool0ooooDP3oool00`00
0000oooo0?ooo`060?ooo`00A03oool3000000`0oooo00<000000?ooo`3oool0o`3ooooo0?oooe00
oooo0`0000080?ooo`00A03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo
o`3ooomB0?ooo`030000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooe80oooo00<000000?ooo`3oool01P3oool004@0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooool0ooooDP3oool00`000000oooo0?ooo`06
0?ooo`00A03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooo`3ooomC0?oo
o`030000003oool0oooo00H0oooo00140?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooe<0oooo00<000000?ooo`3oool01P3oool002/0oooo0`0000030?ooo`040000
003oool0oooo0?ooo`D000002P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0
ooooo`3ooomC0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`050000003oool0oooo0?ooo`00
00001`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0?l0ooooo`3ooomQ0?oo
o`030000003oool0oooo00H0oooo000Z0?ooo`050000003oool0oooo0?ooo`000000203oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooo`3ooomQ0?ooo`030000003oool0oooo
00H0oooo000P0?ooo`L000000`3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`3o0?ooool0ooooH@3oool00`000000oooo0?ooo`060?oo
o`00:P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool02@3oool50000
0?l0ooooo`3ooomL0?ooo`@00000203oool002X0oooo00D000000?ooo`3oool0oooo0000000:0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool002X0oooo00D000000?ooo`3o
ool0oooo0000000:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool002X0
oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`060?ooo`00:P3oool01@000000oooo0?ooo`3oool00000
00H0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool01P3oool002/0oooo0`0000080?ooo`<000002`3ooooo00000?l00000I@0000080?oo
o`00o`3ooooo0?oook40oooo003o0?ooool0oooo/@3oool00?l0ooooo`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 686.75}, {424.063, 0}} -> {-0.284536, -1.07609, \
0.00343855, 0.00211028}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ 
      Find\ chi\ square\ for\ given\ H \((z)\)\ \ *) \[IndentingNewLine]\(f[
          z_] := 1/hhz[z];\)\), "\n", 
    \(\(rr[zz_] := NIntegrate[f[z], {z, 0, zz}];\)\[IndentingNewLine]\n (*\ 
      Construct\ marginalization\ coefficients\ \((see\ \ astro - 
              ph/0401556\  .. )\)\ *) \), "\[IndentingNewLine]", 
    \(Clear[chi2fa, chi2fb, chi2fc]\), "\n", 
    \(\(chi2fa = 
        Sum[\((ld[i] - 5\ Log[10, rr[zz[i]]*\((1 + zz[i])\)])\)^2/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\n", 
    \(\(chi2fb = 
        Sum[\((ld[i] - 
                5\ Log[10, rr[zz[i]]*\((1 + zz[i])\)])\)/\((sld[i]^2)\), {i, 
            1, ndat}];\)\), "\n", 
    \(\(chi2fc = 
        Sum[1/\((sld[i]^2)\), {i, 1, ndat}];\)\[IndentingNewLine]\n (*\ 
      Construct\ function\ after\ marginalization, \ 
      find\ same\ result\ as\ with\ mb\ minimization\ *) \), "\
\[IndentingNewLine]", 
    \(chi2fm = chi2fa - chi2fb^2/chi2fc\), "\[IndentingNewLine]", 
    \(dchi2q30 = chi2fm - chi2l\)}], "Input"],

Cell[BoxData[
    \(202.41744463331997`\)], "Output"],

Cell[BoxData[
    \(25.290073198266327`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ \ Construct\ Plot\ for\ chi^2\ vs\ the\ slope\ ss\ \ \ *) \)\(\
\n\)\(chi2alq = 
      Table[{{0, 0}, {0.1, dchi2q01}, {0.2, dchi2q02}, {0.5, 
            dchi2q05}, {0.75, dchi2q075}, {1, dchi2q10}, {1.2, 
            dchi2q12}, {1.5, dchi2q15}, {2, dchi2q20}, {2.5, dchi2q25}, {3, 
            dchi2q30}}]\)\)\)], "Input"],

Cell[BoxData[
    \({{0, 0}, {0.1`, 0.006240717135369778`}, {0.2`, 
        0.021065798588097095`}, {0.5`, 0.1747115021571517`}, {0.75`, 
        0.4710142631083727`}, {1, 1.0364577015861869`}, {1.2`, 
        1.6869659395888448`}, {1.5`, 3.2603292716667056`}, {2, 
        7.7762004137039185`}, {2.5`, 15.013285559602082`}, {3, 
        25.290073198266327`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(plch2q = 
      ListPlot[chi2alq, PlotJoined \[Rule] True, Frame \[Rule] True, 
        PlotRange \[Rule] All, 
        FrameLabel \[Rule] {"\<s\>", \
\*"\"\<\!\(\[CapitalDelta]\[Chi]\^2\)\>\""}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0147151 0.0232741 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.18254 -0.0125 -10.7813 -17.8125 ]
[.18254 -0.0125 10.7813 0 ]
[.34127 -0.0125 -5.53125 -17.8125 ]
[.34127 -0.0125 5.53125 0 ]
[.5 -0.0125 -10.7813 -17.8125 ]
[.5 -0.0125 10.7813 0 ]
[.65873 -0.0125 -5.53125 -17.8125 ]
[.65873 -0.0125 5.53125 0 ]
[.81746 -0.0125 -10.7813 -17.8125 ]
[.81746 -0.0125 10.7813 0 ]
[.97619 -0.0125 -5.53125 -17.8125 ]
[.97619 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -4.75 -35.625 ]
[.5 -0.0125 4.75 -17.8125 ]
[-0.0125 .01472 -11.0625 -8.90625 ]
[-0.0125 .01472 0 8.90625 ]
[-0.0125 .13109 -11.0625 -8.90625 ]
[-0.0125 .13109 0 8.90625 ]
[-0.0125 .24746 -18.125 -8.90625 ]
[-0.0125 .24746 0 8.90625 ]
[-0.0125 .36383 -18.125 -8.90625 ]
[-0.0125 .36383 0 8.90625 ]
[-0.0125 .4802 -18.125 -8.90625 ]
[-0.0125 .4802 0 8.90625 ]
[-0.0125 .59657 -18.125 -8.90625 ]
[-0.0125 .59657 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -35.9375 -13.0938 ]
[-0.01875 .30902 -18.125 13.0938 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -65.75 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
68.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -72.0625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13109 m
.00625 .13109 L
s
gsave
-0.0125 .13109 -72.0625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .24746 m
.00625 .24746 L
s
gsave
-0.0125 .24746 -79.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .36383 m
.00625 .36383 L
s
gsave
-0.0125 .36383 -79.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
0 .4802 m
.00625 .4802 L
s
gsave
-0.0125 .4802 -79.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .59657 m
.00625 .59657 L
s
gsave
-0.0125 .59657 -79.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03799 m
.00375 .03799 L
s
0 .06126 m
.00375 .06126 L
s
0 .08454 m
.00375 .08454 L
s
0 .10781 m
.00375 .10781 L
s
0 .15436 m
.00375 .15436 L
s
0 .17763 m
.00375 .17763 L
s
0 .20091 m
.00375 .20091 L
s
0 .22418 m
.00375 .22418 L
s
0 .27073 m
.00375 .27073 L
s
0 .294 m
.00375 .294 L
s
0 .31728 m
.00375 .31728 L
s
0 .34055 m
.00375 .34055 L
s
0 .3871 m
.00375 .3871 L
s
0 .41037 m
.00375 .41037 L
s
0 .43365 m
.00375 .43365 L
s
0 .45692 m
.00375 .45692 L
s
0 .50347 m
.00375 .50347 L
s
0 .52675 m
.00375 .52675 L
s
0 .55002 m
.00375 .55002 L
s
0 .57329 m
.00375 .57329 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -101.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
74.0938 12.9063 translate
90 rotate
-74.0938 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Dc) show
79.688 11.875 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
85.188 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13109 m
1 .13109 L
s
.99375 .24746 m
1 .24746 L
s
.99375 .36383 m
1 .36383 L
s
.99375 .4802 m
1 .4802 L
s
.99375 .59657 m
1 .59657 L
s
.125 Mabswid
.99625 .03799 m
1 .03799 L
s
.99625 .06126 m
1 .06126 L
s
.99625 .08454 m
1 .08454 L
s
.99625 .10781 m
1 .10781 L
s
.99625 .15436 m
1 .15436 L
s
.99625 .17763 m
1 .17763 L
s
.99625 .20091 m
1 .20091 L
s
.99625 .22418 m
1 .22418 L
s
.99625 .27073 m
1 .27073 L
s
.99625 .294 m
1 .294 L
s
.99625 .31728 m
1 .31728 L
s
.99625 .34055 m
1 .34055 L
s
.99625 .3871 m
1 .3871 L
s
.99625 .41037 m
1 .41037 L
s
.99625 .43365 m
1 .43365 L
s
.99625 .45692 m
1 .45692 L
s
.99625 .50347 m
1 .50347 L
s
.99625 .52675 m
1 .52675 L
s
.99625 .55002 m
1 .55002 L
s
.99625 .57329 m
1 .57329 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.05556 .01486 L
.0873 .01521 L
.18254 .01878 L
.2619 .02568 L
.34127 .03884 L
.40476 .05398 L
.5 .0906 L
.65873 .1957 L
.81746 .36414 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{777.063, 480.25},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<90001h2000`400?l00000o`00003oo`3ooooo
0?ooool0oooo303oool00?l0ooooo`3ooooo0?ooo``0oooo003o0?ooool0ooooo`3oool<0?ooo`00
o`3ooooo0?ooool0oooo303oool00?l0ooooo`3ooooo0?ooo``0oooo003o0?ooool0ooooo`3oool<
0?ooo`00o`3ooonK0?ooo`<00000o`3ooom]0?ooo`00o`3ooonK0?ooo`040000003oool0oooo0000
0?l0ooooK03oool00?l0ooooWP3oool00`000000oooo0?ooo`3o0?ooofX0oooo003o0?oooi`0oooo
0P00003o0?ooofd0oooo003o0?oooi/0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`00o`3ooonK
0?ooo`040000003oool0oooo00000?l0ooooK03oool00?l0ooooW03oool300000?l0ooooK03oool0
0?l0ooooo`3ooooo0?ooo``0oooo003o0?ooool0ooooo`3oool<0?ooo`00o`3ooooo0?ooool0oooo
303oool00?l0ooooo`3ooooo0?ooo``0oooo003o0?ooool0ooooo`3oool<0?ooo`00o`3ooooo0?oo
ool0oooo303oool00?l0ooooo`3ooooo0?ooo``0oooo003o0?ooool0ooooo`3oool<0?ooo`00o`3o
oooo0?ooool0oooo303oool00?l0ooooo`3ooooo0?ooo``0oooo001;0?ooo`<00000J03oool30000
00<0oooo00@000000?ooo`3oool0oooo0`00001X0?ooo`<00000I`3oool3000000<0oooo00@00000
0?ooo`3oool0oooo0`00001W0?ooo`D00000IP3oool500000080oooo00@000000?ooo`3oool0oooo
0`00001W0?ooo`@00000703oool004X0oooo00D000000?ooo`3oool0oooo0000001V0?ooo`050000
003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo06L0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1U0?ooo`040000003oool0oooo0000
06L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0
oooo01T0oooo001:0?ooo`050000003oool0oooo0?ooo`000000IP3oool01@000000oooo0?ooo`3o
ool0000000X0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`1W0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`1X0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0I0?ooo`00BP3oool0
1@000000oooo0?ooo`3oool0000006H0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000
003oool0oooo06D0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo06H0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo06L0oooo00<000000?ooo`3oool06@3oool004X0oooo00D000000?ooo`3oool0oooo
0000001V0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1U0?ooo`03
0000003oool0oooo06L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1V0?ooo`03
0000003oool0oooo06P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1W0?ooo`03
0000003oool0oooo01T0oooo001:0?ooo`050000003oool0oooo0?ooo`000000IP3oool01@000000
oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`1W0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`1X0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0IP3oool2000001`0oooo001:0?ooo`05
0000003oool0oooo0?ooo`000000IP3oool01@000000oooo0?ooo`3oool0000000H0oooo0`00001Y
0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool01P3oool3000006/0oooo00<00000
0?ooo`3oool0J03oool00`000000oooo0?ooo`040?ooo`<00000JP3oool00`000000oooo0?ooo`0J
0?ooo`00BP3oool01@000000oooo0?ooo`3oool0000006H0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool06@3oool004X0oooo00D00000
0?ooo`3oool0oooo0000001V0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo
0?ooo`1W0?ooo`800000J03oool2000000T0oooo00<000000?ooo`3oool0IP3oool01@000000oooo
0?ooo`3oool0000006H0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo
06H0oooo00D000000?ooo`3oool0oooo0000000K0?ooo`00B`3oool3000006P0oooo0`0000080?oo
o`@00000I`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00L0oooo1000001V0?oo
o`<00000J03oool3000000P0oooo1000001V0?ooo`<00000703oool00?l0ooooo`3ooooo0?ooo``0
oooo003o0?ooool0ooooo`3oool<0?ooo`00o`3ooooo0?ooool0oooo303oool00?l0ooooo`3ooooo
0?ooo``0oooo003o0?ooool0ooooo`3oool<0?ooo`00o`3ooooo0?ooool0oooo303oool00?l0oooo
o`3ooooo0?ooo``0oooo003o0?ooool0ooooo`3oool<0?ooo`00o`3ooooo0?ooool0oooo303oool0
0?l0ooooo`3ooooo0?ooo``0oooo003o0?ooool0ooooo`3oool<0?ooo`00o`3ooooo0?ooool0oooo
303oool003`0ooooo`00003o00000<<00000303oool003`0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0K03oool00`000000
oooo0?ooo`1]0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0K03oool00`000000
oooo0?ooo`1]0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02P3oool003`0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo06`0oooo
00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo06`0oooo
00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00X0oooo
000l0?ooo`030000003oool0oooo0?l0ooooo`3ooono0?ooo`030000003oool0oooo00X0oooo000/
0?ooo`<000003@3oool00`000000oooo0?ooo`3o0?ooool0oooo_`3oool00`000000oooo0?ooo`0:
0?ooo`00:`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0o`3ooooo
0?oookl0oooo00<000000?ooo`3oool02P3oool002/0oooo00D000000?ooo`3oool0oooo0000000<
0?ooo`030000003oool0oooo0?l0ooooo`3ooono0?ooo`030000003oool0oooo00X0oooo000[0?oo
o`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`3o0?ooool0oooo_`3oool0
0`000000oooo0?ooo`0:0?ooo`00:`3oool01@000000oooo0?ooo`3oool0000000`0oooo1P00000;
0?ooocT00000o`3ooooo0?ooog<0oooo1P00000<0?ooo`00:`3oool01@000000oooo0?ooo`3oool0
000000`0oooo00<000000?ooo`3oool0A`3ooolF00000?l0ooooo`3ooomR0?ooo`030000003oool0
oooo00X0oooo000[0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`1M
0?oooaH00000o`3ooooo0?oood`0oooo00<000000?ooo`3oool02P3oool002/0oooo00D000000?oo
o`3oool0oooo0000000<0?ooo`030000003oool0oooo07<0oooo4@00003o0?ooool0oooo>`3oool0
0`000000oooo0?ooo`0:0?ooo`00:`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<00000
0?ooo`3oool0Q03oool;00000?l0ooooo`3oool`0?ooo`030000003oool0oooo00X0oooo000/0?oo
o`<000003@3oool00`000000oooo0?ooo`2?0?ooo`/00000o`3ooooo0?ooobD0oooo00<000000?oo
o`3oool02P3oool003`0oooo00<000000?ooo`3oool0VP3oool<00000?l0ooooo`3ooolI0?ooo`03
0000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0:H0oooo2`00003o0?ooool0oooo
3P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`2a0?ooo`T00000o`3o
oooo0?ooo`D0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0^P3oool6
00000?l0oooooP3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`300?oo
o`H00000o`3ooooh0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0<H0
oooo1P00003o0?oooo80oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0
c03oool600000?l0ooook03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?oo
o`3B0?ooo`H00000o`3ooooV0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0
oooo0=P0oooo1P00003o0?ooon00oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?oo
o`3oool0gP3oool600000?l0oooofP3oool00`000000oooo0?ooo`0:0?ooo`00?03oool400000><0
oooo1P00003o0?ooom40oooo1000000<0?ooo`00?03oool00`000000oooo0?ooo`3Z0?ooo`H00000
o`3oooo>0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?00oooo1000
003o0?ooolX0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0m03oool4
00000?l0ooooaP3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3h0?oo
o`@00000o`3oooo20?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?`0
oooo1000003o0?oookh0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0
o`3oool10?ooo`@00000o`3ooonj0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003o
ool0oooo0?l0oooo1@3oool400000?l0oooo]P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool0
0`000000oooo0?ooo`3o0?ooo`T0oooo1000003o0?oook80oooo00<000000?ooo`3oool02P3oool0
03`0oooo00<000000?ooo`3oool0o`3oool=0?ooo`@00000o`3ooon^0?ooo`030000003oool0oooo
00X0oooo000l0?ooo`030000003oool0oooo0?l0oooo4@3oool400000?l0ooooZP3oool00`000000
oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oooaD0oooo1000003o0?ooojH0oooo
00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`@00000o`3o
oonR0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0oooo7@3oool3
00000?l0ooooW`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oo
ob00oooo0P00003o0?oooid0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3o
ool0o`3ooolR0?ooo`<00000o`3ooonJ0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000
003oool0oooo0?l0oooo9@3oool300000?l0ooooU`3oool00`000000oooo0?ooo`0:0?ooo`00?03o
ool400000?l0oooo9`3oool200000?l0ooooTP3oool4000000`0oooo000l0?ooo`030000003oool0
oooo0?l0oooo:P3oool300000?l0ooooTP3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`00
0000oooo0?ooo`3o0?ooobd0oooo0`00003o0?ooohl0oooo00<000000?ooo`3oool02P3oool003`0
oooo00<000000?ooo`3oool0o`3oool`0?ooo`800000o`3ooon=0?ooo`030000003oool0oooo00X0
oooo000l0?ooo`030000003oool0oooo0?l0oooo<P3oool300000?l0ooooRP3oool00`000000oooo
0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooocD0oooo0`00003o0?ooohL0oooo00<0
00000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`800000o`3ooon5
0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0oooo>P3oool30000
0?l0ooooPP3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooocd0
oooo0`00003o0?ooogl0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0
o`3ooom00?ooo`800000o`3ooomm0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003o
ool0oooo0?l0oooo@P3oool300000?l0ooooNP3oool00`000000oooo0?ooo`0:0?ooo`00?03oool0
0`000000oooo0?ooo`3o0?ooodD0oooo0`00003o0?ooogL0oooo00<000000?ooo`3oool02P3oool0
03`0oooo00<000000?ooo`3oool0o`3ooom80?ooo`800000o`3ooome0?ooo`030000003oool0oooo
00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooBP3oool300000?l0ooooLP3oool00`000000
oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooodd0oooo0`00003o0?ooofl0oooo
00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooom@0?ooo`800000o`3o
oom]0?ooo`030000003oool0oooo00X0oooo000l0?ooo`@00000o`3ooomA0?ooo`<00000o`3ooomW
0?ooo`@00000303oool003`0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`<00000o`3ooomW0?oo
o`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooF03oool200000?l0
ooooI@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oooeX0oooo
0`00003o0?ooof80oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3o
oomM0?ooo`800000o`3ooomP0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0
oooo0?l0ooooG`3oool200000?l0ooooGP3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`00
0000oooo0?ooo`3o0?ooof40oooo00<000000?ooo`3oool0o`3ooomK0?ooo`030000003oool0oooo
00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooHP3oool200000?l0ooooF`3oool00`000000
oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooof@0oooo00<000000?ooo`3oool0
o`3ooomH0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooI@3o
ool200000?l0ooooF03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o
0?ooofL0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo00X0oooo000l0?oo
o`030000003oool0oooo0?l0ooooJ03oool200000?l0ooooE@3oool00`000000oooo0?ooo`0:0?oo
o`00?03oool00`000000oooo0?ooo`3o0?ooofX0oooo00<000000?ooo`3oool0o`3ooomB0?ooo`03
0000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooJ`3oool200000?l0oooo
DP3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooofd0oooo00<0
00000?ooo`3oool0o`3ooom?0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0
oooo0?l0ooooKP3oool200000?l0ooooC`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`00
0000oooo0?ooo`3o0?ooog00oooo00<000000?ooo`3oool0o`3ooom<0?ooo`030000003oool0oooo
00X0oooo000l0?ooo`@00000o`3ooom`0?ooo`800000o`3ooom90?ooo`@00000303oool003`0oooo
00<000000?ooo`3oool0o`3ooomc0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo
0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooog@0oooo0P00003o0?ooodT0oooo00<0
00000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooomf0?ooo`030000003oool0
oooo0?l0ooooAP3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oo
ogL0oooo0P00003o0?ooodH0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3o
ool0o`3ooomi0?ooo`030000003oool0oooo0?l0oooo@`3oool00`000000oooo0?ooo`0:0?ooo`00
?03oool00`000000oooo0?ooo`3o0?ooogX0oooo0P00003o0?oood<0oooo00<000000?ooo`3oool0
2P3oool003`0oooo00<000000?ooo`3oool0o`3oooml0?ooo`800000o`3ooom10?ooo`030000003o
ool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooOP3oool00`000000oooo0?ooo`3o
0?oooch0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooomo0?oo
o`800000o`3oooln0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0
ooooP@3oool00`000000oooo0?ooo`3o0?oooc/0oooo00<000000?ooo`3oool02P3oool003`0oooo
00<000000?ooo`3oool0o`3ooon20?ooo`800000o`3ooolk0?ooo`030000003oool0oooo00X0oooo
000[0?ooo`<000003P3oool00`000000oooo0?ooo`3o0?oooh@0oooo00<000000?ooo`3oool0o`3o
oolh0?ooo`030000003oool0oooo00X0oooo000^0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0o`3ooon50?ooo`800000o`3ooolh0?ooo`030000003oool0oooo00X0oooo000_0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooon70?ooo`030000003oool0oooo
0?l0oooo=@3oool00`000000oooo0?ooo`0:0?ooo`00;`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0?l0ooooR03oool200000?l0oooo=@3oool00`000000oooo0?ooo`0:0?ooo`00
;`3oool00`000000oooo0?ooo`0:0?ooo`H00000o`3ooon70?ooo`030000003oool0oooo0?l0oooo
;@3oool6000000`0oooo000^0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3o
oon;0?ooo`800000o`3ooolb0?ooo`030000003oool0oooo00X0oooo000[0?ooo`<000003P3oool0
0`000000oooo0?ooo`3o0?ooohd0oooo00<000000?ooo`3oool0o`3oool_0?ooo`030000003oool0
oooo00X0oooo000[0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooon>0?oo
o`800000o`3oool_0?ooo`030000003oool0oooo00X0oooo000/0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0o`3ooon@0?ooo`030000003oool0oooo0?l0oooo;03oool00`000000
oooo0?ooo`0:0?ooo`00;03oool4000000`0oooo00<000000?ooo`3oool0o`3ooonA0?ooo`800000
o`3oool/0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooT`3o
ool00`000000oooo0?ooo`3o0?ooobT0oooo00<000000?ooo`3oool02P3oool003`0oooo00<00000
0?ooo`3oool0o`3ooonD0?ooo`800000o`3ooolY0?ooo`030000003oool0oooo00X0oooo000l0?oo
o`030000003oool0oooo0?l0ooooUP3oool00`000000oooo0?ooo`3o0?ooobH0oooo00<000000?oo
o`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooonG0?ooo`800000o`3ooolV0?ooo`03
0000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooV@3oool00`000000oooo
0?ooo`3o0?ooob<0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`800000o`3ooolS0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0
oooo0?l0ooooW03oool00`000000oooo0?ooo`3o0?ooob00oooo00<000000?ooo`3oool02P3oool0
03`0oooo00<000000?ooo`3oool0o`3ooonM0?ooo`800000o`3ooolP0?ooo`030000003oool0oooo
00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooW`3oool00`000000oooo0?ooo`3o0?oooad0
oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooonP0?ooo`800000
o`3ooolM0?ooo`030000003oool0oooo00X0oooo000l0?ooo`@00000o`3ooonQ0?ooo`030000003o
ool0oooo0?l0oooo5`3oool4000000`0oooo000l0?ooo`030000003oool0oooo0?l0ooooX`3oool2
00000?l0oooo6P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oo
ojD0oooo00<000000?ooo`3oool0o`3ooolG0?ooo`030000003oool0oooo00X0oooo000l0?ooo`03
0000003oool0oooo0?l0ooooYP3oool200000?l0oooo5`3oool00`000000oooo0?ooo`0:0?ooo`00
?03oool00`000000oooo0?ooo`3o0?ooojP0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`030000
003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooZ@3oool200000?l0oooo503o
ool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oooj/0oooo00<00000
0?ooo`3oool0o`3ooolA0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo
0?l0oooo[03oool200000?l0oooo4@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000
oooo0?ooo`3o0?ooojh0oooo00<000000?ooo`3oool0o`3oool>0?ooo`030000003oool0oooo00X0
oooo000l0?ooo`030000003oool0oooo0?l0oooo[`3oool200000?l0oooo3P3oool00`000000oooo
0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oook40oooo00<000000?ooo`3oool0o`3o
ool;0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0oooo/P3oool2
00000?l0oooo2`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oo
ok@0oooo0P00003o0?ooo`T0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3o
ool0o`3ooonf0?ooo`030000003oool0oooo0?l0oooo1P3oool00`000000oooo0?ooo`0:0?ooo`00
?03oool00`000000oooo0?ooo`3o0?oookL0oooo0P00003o0?ooo`H0oooo00<000000?ooo`3oool0
2P3oool003`0oooo00<000000?ooo`3oool0o`3oooni0?ooo`030000003oool0oooo0?l0oooo0`3o
ool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oookX0oooo0P00003o
0?ooo`<0oooo00<000000?ooo`3oool02P3oool003`0oooo1000003o0?oook/0oooo00<000000?oo
o`3oool0o03oool4000000`0oooo000l0?ooo`030000003oool0oooo0?l0oooo_@3oool200000?l0
oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooono0?ooo`030000
003oool0oooo0?`0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3o
ooo00?ooo`800000o03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o
0?oool80oooo00<000000?ooo`3oool0n@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`00
0000oooo0?ooo`3o0?oool<0oooo0P00003i0?ooo`030000003oool0oooo00X0oooo000l0?ooo`03
0000003oool0oooo0?l0ooooa@3oool00`000000oooo0?ooo`3f0?ooo`030000003oool0oooo00X0
oooo000l0?ooo`030000003oool0oooo0?l0ooooaP3oool200000?H0oooo00<000000?ooo`3oool0
2P3oool003`0oooo00<000000?ooo`3oool0o`3oooo80?ooo`030000003oool0oooo0?<0oooo00<0
00000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3oooo90?ooo`800000l`3oool0
0`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oool/0oooo00<000000?oo
o`3oool0l03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oool`0
oooo0P00003`0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0oooo
cP3oool00`000000oooo0?ooo`3]0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003o
ool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo00X0oooo000l
0?ooo`030000003oool0oooo0?l0ooood03oool00`000000oooo0?ooo`3[0?ooo`030000003oool0
oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooood@3oool00`000000oooo0?ooo`3Z0?oo
o`030000003oool0oooo00X0oooo000l0?ooo`@00000o`3ooooA0?ooo`030000003oool0oooo0>H0
oooo1000000<0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooom<0oooo00<000000?ooo`3oool0
j03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooom@0oooo00<0
00000?ooo`3oool0i`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o
0?ooomD0oooo00<000000?ooo`3oool0iP3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`00
0000oooo0?ooo`3o0?ooomD0oooo00<000000?ooo`3oool0iP3oool00`000000oooo0?ooo`0:0?oo
o`00?03oool00`000000oooo0?ooo`3o0?ooomH0oooo00<000000?ooo`3oool0i@3oool00`000000
oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooomL0oooo00<000000?ooo`3oool0
i03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooomP0oooo00<0
00000?ooo`3oool0h`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o
0?ooomT0oooo00<000000?ooo`3oool0hP3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`00
0000oooo0?ooo`3o0?ooomX0oooo00<000000?ooo`3oool0h@3oool00`000000oooo0?ooo`0:0?oo
o`00?03oool00`000000oooo0?ooo`3o0?ooom/0oooo00<000000?ooo`3oool0h03oool00`000000
oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooom`0oooo00<000000?ooo`3oool0
g`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooomd0oooo00<0
00000?ooo`3oool0gP3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o
0?ooomh0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`00
0000oooo0?ooo`3o0?oooml0oooo00<000000?ooo`3oool0g03oool00`000000oooo0?ooo`0:0?oo
o`00?03oool00`000000oooo0?ooo`3o0?ooon00oooo00<000000?ooo`3oool0f`3oool00`000000
oooo0?ooo`0:0?ooo`00?03oool400000?l0ooooh03oool00`000000oooo0?ooo`3G0?ooo`@00000
303oool003`0oooo00<000000?ooo`3oool0o`3ooooR0?ooo`030000003oool0oooo0=T0oooo00<0
00000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooS0?ooo`030000003oool0
oooo0=P0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooS0?oo
o`030000003oool0oooo0=P0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3o
ool0o`3ooooT0?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool02P3oool003`0oooo
00<000000?ooo`3oool0o`3ooooU0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool0
2P3oool003`0oooo00<000000?ooo`3oool0o`3ooooV0?ooo`030000003oool0oooo0=D0oooo00<0
00000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooW0?ooo`030000003oool0
oooo0=@0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooX0?oo
o`030000003oool0oooo0=<0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3o
ool0o`3ooooY0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool02P3oool003`0oooo
00<000000?ooo`3oool0o`3ooooZ0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool0
2P3oool003`0oooo00<000000?ooo`3oool0o`3oooo[0?ooo`030000003oool0oooo0=00oooo00<0
00000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3oooo/0?ooo`030000003oool0
oooo0<l0oooo00<000000?ooo`3oool02P3oool002D0oooo0`0000040?ooo`<000003@3oool00`00
0000oooo0?ooo`3o0?ooond0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0:0?oo
o`009P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000303oool00`00
0000oooo0?ooo`3o0?ooonh0oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0:0?oo
o`009P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000303oool00`00
0000oooo0?ooo`3o0?ooonl0oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`0:0?oo
o`009P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000303oool00`00
0000oooo0?ooo`3o0?oooo00oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?oo
o`009P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000303oool60000
0?l0ooookP3oool00`000000oooo0?ooo`350?ooo`H00000303oool002H0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0o`3ooooa0?oo
o`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool002H0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0o`3oooob0?oo
o`030000003oool0oooo0<T0oooo00<000000?ooo`3oool02P3oool002H0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0o`3ooooc0?oo
o`030000003oool0oooo0<P0oooo00<000000?ooo`3oool02P3oool002D0oooo0P0000040?ooo`05
0000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`3o0?oooo@0oooo00<000000?oo
o`3oool0a`3oool00`000000oooo0?ooo`0:0?ooo`009P3oool00`000000oooo0?ooo`030?ooo`<0
00003@3oool00`000000oooo0?ooo`3o0?ooooD0oooo00<000000?ooo`3oool0aP3oool00`000000
oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooooH0oooo00<000000?ooo`3oool0
a@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooooL0oooo00<0
00000?ooo`3oool0a03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o
0?ooooP0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`00
0000oooo0?ooo`3o0?ooooT0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0:0?oo
o`00?03oool00`000000oooo0?ooo`3o0?ooooX0oooo00<000000?ooo`3oool0`@3oool00`000000
oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oooo/0oooo00<000000?ooo`3oool0
`03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oooo`0oooo00<0
00000?ooo`3oool0_`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o
0?ooood0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`00
0000oooo0?ooo`3o0?ooooh0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0:0?oo
o`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo00<000000?ooo`3oool0_03oool00`000000
oooo0?ooo`0:0?ooo`00?03oool400000?l0oooooP3oool00`000000oooo0?ooo`2i0?ooo`@00000
303oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`40oooo00<000000?ooo`3oool0^`3o
ool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo0P3oool0
0`000000oooo0?ooo`2j0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo
0?l0ooooo`3oool30?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool02P3oool003`0
oooo00<000000?ooo`3oool0o`3ooooo0?ooo`@0oooo00<000000?ooo`3oool0^03oool00`000000
oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo1@3oool00`000000oooo
0?ooo`2g0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3o
ool60?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool02P3oool003`0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooo`L0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0:
0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo203oool00`000000oooo0?ooo`2d0?oo
o`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3oool90?ooo`03
0000003oool0oooo0;<0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0
o`3ooooo0?ooo`X0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0:0?ooo`00?03o
ool00`000000oooo0?ooo`3o0?ooool0oooo2`3oool00`000000oooo0?ooo`2a0?ooo`030000003o
ool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3oool<0?ooo`030000003oool0
oooo0;00oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oo
o`d0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000
oooo0?ooo`3o0?ooool0oooo3@3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo00X0
oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3oool>0?ooo`030000003oool0oooo0:h0oooo
00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`l0oooo00<0
00000?ooo`3oool0[@3oool00`000000oooo0?ooo`0:0?ooo`00603oool00`000000oooo0?ooo`0Q
0?ooo`@00000o`3ooooo0?ooo`l0oooo00<000000?ooo`3oool0Z@3oool4000000`0oooo000E0?oo
o`@000008`3oool00`000000oooo0?ooo`3o0?ooool0oooo4@3oool00`000000oooo0?ooo`2[0?oo
o`030000003oool0oooo00X0oooo000C0?ooo`8000000`3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo0?l0ooooo`3ooolB0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3o
ool02P3oool00100oooo0`0000050?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
o`3ooooo0?oooa<0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0:0?ooo`003`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0o`3o
oooo0?oooa@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0:0?ooo`00403oool3
000000D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3o0?ooool0oooo5@3oool0
0`000000oooo0?ooo`2W0?ooo`030000003oool0oooo00X0oooo000C0?ooo`8000000`3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`030000003oool0oooo
0:H0oooo00<000000?ooo`3oool02P3oool001D0oooo1000000S0?ooo`030000003oool0oooo0?l0
ooooo`3ooolG0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool02P3oool001P0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3o0?ooool0oooo603oool00`000000oooo
0?ooo`2T0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooaT0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?oo
o`0:0?ooo`006@3oool200000240oooo00<000000?ooo`3oool0o`3ooooo0?oooaX0oooo00<00000
0?ooo`3oool0XP3oool00`000000oooo0?ooo`0:0?ooo`004P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool0o`3ooooo0?oooa/0oooo00<000000?oo
o`3oool0X@3oool00`000000oooo0?ooo`0:0?ooo`004P3oool300000080oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`3o0?ooool0oooo6`3oool00`000000oooo0?ooo`2Q0?ooo`03
0000003oool0oooo00X0oooo000E0?ooo`L00000803oool00`000000oooo0?ooo`3o0?ooool0oooo
703oool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo00X0oooo000E0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3o0?ooool0oooo7@3o
ool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo00X0oooo000D0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3o0?ooool0oooo7P3oool0
0`000000oooo0?ooo`2N0?ooo`030000003oool0oooo00X0oooo000C0?ooo`030000003oool0oooo
02H0oooo1000003o0?ooool0oooo7P3oool00`000000oooo0?ooo`2J0?ooo`@00000303oool000`0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0?l0
ooooo`3ooolP0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool02P3oool000`0oooo
00<000000?ooo`3oool00P3oool2000002T0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo
00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0:0?ooo`00303oool01`000000oooo0?oo
o`3oool000000?ooo`000000:@3oool00`000000oooo0?ooo`3o0?ooool0oooo8P3oool00`000000
oooo0?ooo`2J0?ooo`030000003oool0oooo00X0oooo000=0?ooo`<0000000<0oooo000000000000
:@3oool00`000000oooo0?ooo`3o0?ooool0oooo8`3oool00`000000oooo0?ooo`2I0?ooo`030000
003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooolT0?ooo`030000003o
ool0oooo09P0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo
0?ooobD0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`00
0000oooo0?ooo`3o0?ooool0oooo9P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo
00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooolW0?ooo`030000003oool0oooo09D0
oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooobP0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?oo
o`3o0?ooool0oooo:@3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo00X0oooo000l
0?ooo`030000003oool0oooo0?l0ooooo`3ooolY0?ooo`030000003oool0oooo09<0oooo00<00000
0?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooobX0oooo00<000000?oo
o`3oool0TP3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0
oooo:`3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000
003oool0oooo0?l0ooooo`3oool/0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0
2P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooobd0oooo00<000000?ooo`3oool0S`3o
ool00`000000oooo0?ooo`0:0?ooo`00?03oool400000?l0ooooo`3oool]0?ooo`030000003oool0
oooo08/0oooo1000000<0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo;`3oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0
ooooo`3oool`0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool003`0oooo
00<000000?ooo`3oool0o`3ooooo0?oooc40oooo00<000000?ooo`3oool0R`3oool00`000000oooo
0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo<P3oool00`000000oooo0?oo
o`2:0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooolc
0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?oo
o`3oool0o`3ooooo0?oooc@0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0:0?oo
o`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo=@3oool00`000000oooo0?ooo`270?ooo`03
0000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooolf0?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3o
oooo0?ooocL0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool0
0`000000oooo0?ooo`3o0?ooool0oooo=`3oool00`000000oooo0?ooo`250?ooo`030000003oool0
oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooolh0?ooo`030000003oool0oooo
08@0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooocT0
oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0:0?ooo`009@3oool3000000<0oooo
0`00000>0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003oool0oooo0880oooo
00<000000?ooo`3oool02P3oool002H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0?l0ooooo`3ooolk0?ooo`030000003oool0oooo0840oooo00<0
00000?ooo`3oool02P3oool002H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0?l0ooooo`3oooll0?ooo`030000003oool0oooo0800oooo00<00000
0?ooo`3oool02P3oool002H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo0?l0ooooo`3ooolm0?ooo`030000003oool0oooo07l0oooo00<000000?oo
o`3oool02P3oool002H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`H0
0000o`3ooooo0?oooc/0oooo00<000000?ooo`3oool0N@3oool6000000`0oooo000V0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?ooool0oooo
?`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00X0oooo000V0?ooo`030000003o
ool0oooo0080oooo0`00000>0?ooo`030000003oool0oooo0?l0ooooo`3ooolo0?ooo`030000003o
ool0oooo07d0oooo00<000000?ooo`3oool02P3oool002H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0ooooo`3ooom00?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool02P3oool002D0oooo0P0000050?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0o`3ooooo0?oood40oooo00<000000?ooo`3oool0N`3oool00`00
0000oooo0?ooo`0:0?ooo`009P3oool00`000000oooo0?ooo`030?ooo`@00000303oool00`000000
oooo0?ooo`3o0?ooool0oooo@@3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo00X0
oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooom20?ooo`030000003oool0oooo07X0oooo
00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oood<0oooo00<0
00000?ooo`3oool0N@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o
0?ooool0oooo@`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00X0oooo000l0?oo
o`030000003oool0oooo0?l0ooooo`3ooom40?ooo`030000003oool0oooo07P0oooo00<000000?oo
o`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooodD0oooo00<000000?ooo`3o
ool0M`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo
A@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003o
ool0oooo0?l0ooooo`3ooom60?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool02P3o
ool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooodL0oooo00<000000?ooo`3oool0M@3oool0
0`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooA`3oool00`00
0000oooo0?ooo`1e0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0
ooooo`3ooom80?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool02P3oool003`0oooo
1000003o0?ooool0ooooB03oool00`000000oooo0?ooo`1`0?ooo`@00000303oool003`0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooodT0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?oo
o`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooBP3oool00`000000oooo0?ooo`1b
0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooom;0?oo
o`030000003oool0oooo0740oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3o
ool0o`3ooooo0?oood/0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0:0?ooo`00
?03oool00`000000oooo0?ooo`3o0?ooool0ooooC03oool00`000000oooo0?ooo`1`0?ooo`030000
003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooom=0?ooo`030000003o
ool0oooo06l0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo
0?ooodd0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`00
0000oooo0?ooo`3o0?ooool0ooooCP3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo
00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooom?0?ooo`030000003oool0oooo06d0
oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooodl0oooo
00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?oo
o`3o0?ooool0ooooD03oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo00X0oooo000l
0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo06/0oooo00<00000
0?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?oo
o`3oool0J`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0
ooooDP3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000
003oool0oooo0?l0ooooo`3ooomC0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0
2P3oool003`0oooo1000003o0?ooool0ooooDP3oool00`000000oooo0?ooo`1V0?ooo`@00000303o
ool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo00<000000?ooo`3oool0J03oool0
0`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooE@3oool00`00
0000oooo0?ooo`1W0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0
ooooo`3ooomE0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool02P3oool003`0oooo
00<000000?ooo`3oool0o`3ooooo0?oooeH0oooo00<000000?ooo`3oool0IP3oool00`000000oooo
0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooE`3oool00`000000oooo0?oo
o`1U0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomG
0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?oo
o`3oool0o`3ooooo0?oooeP0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0:0?oo
o`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooF@3oool00`000000oooo0?ooo`1S0?ooo`03
0000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomI0?ooo`030000
003oool0oooo06<0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3o
oooo0?oooeX0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0:0?ooo`00?03oool0
0`000000oooo0?ooo`3o0?ooool0ooooF`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0
oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomK0?ooo`030000003oool0oooo
0640oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooe`0
oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo
0?ooo`3o0?ooool0ooooG@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00X0oooo
000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`030000003oool0oooo05l0oooo00<0
00000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooeh0oooo00<00000
0?ooo`3oool0GP3oool00`000000oooo0?ooo`0:0?ooo`00?03oool400000?l0ooooo`3ooomN0?oo
o`030000003oool0oooo05X0oooo1000000<0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0
ooooG`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000
003oool0oooo0?l0ooooo`3ooomP0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0
2P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooof40oooo00<000000?ooo`3oool0F`3o
ool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooH@3oool0
0`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo
0?l0ooooo`3ooomR0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool02P3oool003`0
oooo00<000000?ooo`3oool0o`3ooooo0?ooof<0oooo00<000000?ooo`3oool0F@3oool00`000000
oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooH`3oool00`000000oooo
0?ooo`1I0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3o
oomT0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool02P3oool003`0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooofD0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0:
0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooI@3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomV0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0
o`3ooooo0?ooofL0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0:0?ooo`00?03o
ool00`000000oooo0?ooo`3o0?ooool0ooooI`3oool00`000000oooo0?ooo`1E0?ooo`030000003o
ool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomX0?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ofT0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool400000?l0
ooooo`3ooomX0?ooo`030000003oool0oooo0500oooo1000000<0?ooo`00?03oool00`000000oooo
0?ooo`3o0?ooool0ooooJP3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo00X0oooo
000l0?ooo`030000003oool0oooo0?l0ooooo`3ooom[0?ooo`030000003oool0oooo0540oooo00<0
00000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooof/0oooo00<00000
0?ooo`3oool0D@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oo
ool0ooooK03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo00X0oooo000l0?ooo`03
0000003oool0oooo0?l0ooooo`3ooom]0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooofd0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooKP3o
ool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0
oooo0?l0ooooo`3ooom_0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool02P3oool0
03`0oooo00<000000?ooo`3oool0o`3ooooo0?ooofl0oooo00<000000?ooo`3oool0C@3oool00`00
0000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooL03oool00`000000
oooo0?ooo`1<0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0oooo
o`3oooma0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool02P3oool003`0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooog40oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?oo
o`0:0?ooo`00903oool5000000<0oooo0`00000=0?ooo`030000003oool0oooo0?l0ooooo`3ooomb
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool02P3oool002D0oooo00@000000?oo
o`3oool000000P3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0o`3o
oooo0?ooog<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0:0?ooo`009P3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?oo
o`3o0?ooool0ooooL`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00X0oooo000W
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0?l0ooooo`3ooomd0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool02P3o
ool002L0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00X0oooo1P00
003o0?ooool0ooooLP3oool00`000000oooo0?ooo`120?ooo`H00000303oool002P0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooo`3o
oome0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool02P3oool002P0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooo`3o
oomf0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool02P3oool002P0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooo`3o
oomg0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool02P3oool002@0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo
0?ooo`3o0?ooool0ooooM`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00X0oooo
000U0?ooo`<00000103oool3000000d0oooo00<000000?ooo`3oool0o`3ooooo0?ooogP0oooo00<0
00000?ooo`3oool0A03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o
0?ooool0ooooN@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00X0oooo000l0?oo
o`030000003oool0oooo0?l0ooooo`3ooomi0?ooo`030000003oool0oooo04<0oooo00<000000?oo
o`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooogX0oooo00<000000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo
N`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003o
ool0oooo0?l0ooooo`3ooomk0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool02P3o
ool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooog`0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooO@3oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0
ooooo`3ooomm0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool02P3oool003`0oooo
00<000000?ooo`3oool0o`3ooooo0?ooogh0oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooO`3oool00`000000oooo0?oo
o`0m0?ooo`030000003oool0oooo00X0oooo000l0?ooo`@00000o`3ooooo0?ooogh0oooo00<00000
0?ooo`3oool0>P3oool4000000`0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooon00?oo
o`030000003oool0oooo03`0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooh40oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0:0?ooo`00
?03oool00`000000oooo0?ooo`3o0?ooool0ooooP@3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooon20?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo
0?oooh<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`00
0000oooo0?ooo`3o0?ooool0ooooP`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooon40?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooohD0oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?oo
o`3o0?ooool0ooooQ@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00X0oooo000l
0?ooo`030000003oool0oooo0?l0ooooo`3ooon60?ooo`030000003oool0oooo03H0oooo00<00000
0?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooohL0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0
ooooQ`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000
003oool0oooo0?l0ooooo`3ooon80?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
2P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooohT0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooR@3oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00X0oooo000l0?ooo`@00000o`3ooooo0?oo
ohT0oooo00<000000?ooo`3oool0;`3oool4000000`0oooo000l0?ooo`030000003oool0oooo0?l0
ooooo`3ooon;0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool003`0oooo
00<000000?ooo`3oool0o`3ooooo0?oooh/0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooS03oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooon=
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?oo
o`3oool0o`3ooooo0?ooohd0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?oo
o`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooSP3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooon?0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3o
oooo0?ooohl0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool0
0`000000oooo0?ooo`3o0?ooool0ooooT03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonA0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooi40
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo
0?ooo`3o0?ooool0ooooTP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00X0oooo
000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonC0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooi<0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oo
ool0ooooU03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00X0oooo000l0?ooo`03
0000003oool0oooo0?l0ooooo`3ooonE0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool02P3oool003`0oooo1000003o0?ooool0ooooU03oool00`000000oooo0?ooo`0T0?ooo`@00000
303oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooiH0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooU`3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo
0?l0ooooo`3ooonG0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool02P3oool003`0
oooo00<000000?ooo`3oool0o`3ooooo0?oooiP0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooV@3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3o
oonI0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool02P3oool003`0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooiX0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0:
0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooV`3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonK0?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0
o`3ooooo0?oooi`0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0:0?ooo`00?03o
ool00`000000oooo0?ooo`3o0?ooool0ooooW@3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonM0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oih0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000
oooo0?ooo`3o0?ooool0ooooW`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00X0
oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonO0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool02P3oool003`0oooo1000003o0?ooool0ooooW`3oool00`000000oooo0?oo
o`0I0?ooo`@00000303oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooj40oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oo
ool0ooooX@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00X0oooo000l0?ooo`03
0000003oool0oooo0?l0ooooo`3ooonR0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooj<0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooX`3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0
oooo0?l0ooooo`3ooonT0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool02P3oool0
03`0oooo00<000000?ooo`3oool0o`3ooooo0?ooojD0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooY@3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0oooo
o`3ooonV0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02P3oool003`0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooojL0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooY`3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonX0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool02P3oool002@0oooo1@0000020?ooo`<0
00003P3oool00`000000oooo0?ooo`3o0?ooool0ooooZ@3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00X0oooo000U0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`3o0?ooool0ooooZ@3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00X0oooo000V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`3o0?ooool0ooooZP3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00X0oooo000W0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3o
ool600000?l0ooooo`3ooonX0?ooo`030000003oool0oooo00`0oooo1P00000<0?ooo`009`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooooo
0?oooj/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`00:03oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oj`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0:0?ooo`00:03oool00`000000
oooo0?ooo`03000000h0oooo00<000000?ooo`3oool0o`3ooooo0?ooojd0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0:0?ooo`00:03oool010000000oooo0?ooo`00000@0?ooo`03
0000003oool0oooo0?l0ooooo`3ooon]0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool02P3oool002@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0o`3ooooo0?ooojh0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0:0?ooo`009@3oool3000000@0oooo1000000<0?ooo`030000003oool0oooo0?l0oooo
o`3ooono0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3o
oono0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooono
0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooono0?oo
o`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooono0?ooo`03
0000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
K@3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0
K@3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1]0?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1]0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`00?03ooooo00000?l0
0000``00000<0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 776.063}, {479.25, 0}} -> {-0.346987, -3.34505, \
0.00447719, 0.0610691}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(pldchiq = 
      Show[plch2q, 
        Graphics[{\[IndentingNewLine]{Dashing[{0.01, 0.01}], 
              Line[{{0, 1}, {0.95, 1}}]}, \[IndentingNewLine]{Dashing[{0.01, 
                  0.01}], 
              Line[{{0.95, 1}, {0.95, 
                    0}}]}, \[IndentingNewLine]{Dashing[{0.01, 0.01}], 
              Line[{{0, 4}, {1.59, 4}}]}, \[IndentingNewLine]{Dashing[{0.01, 
                  0.01}], 
              Line[{{1.59, 4}, {1.59, 
                    0}}]}, \[IndentingNewLine]{Dashing[{0.01, 0.01}], 
              Line[{{0, 6.63}, {1.87, 
                    6.63}}]}, \[IndentingNewLine]{Dashing[{0.01, 0.01}], 
              Line[{{1.87, 6.63}, {1.87, 
                    0}}]}\[IndentingNewLine]}], \[IndentingNewLine]Epilog \
\[Rule] {Text["\<68.3%\>", {1.07, 0.4}], Text["\<95.4%\>", {1.7, 2}], 
            Text["\<99.0%\>", {1.97, 0.52}], 
            Text["\<Quintessence Models\>", {1, 
                17}]}\[IndentingNewLine]]\)\(\[IndentingNewLine]\)\( (*\ \(\(\
--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--Fig\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\) . \ \(\(\(\(\(\(\(\(\(\(\(\(\(\(\(\(\(1\ \
--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)\)\(-\)\ \
\ *) \)\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0147151 0.0232741 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.18254 -0.0125 -10.7813 -17.8125 ]
[.18254 -0.0125 10.7813 0 ]
[.34127 -0.0125 -5.53125 -17.8125 ]
[.34127 -0.0125 5.53125 0 ]
[.5 -0.0125 -10.7813 -17.8125 ]
[.5 -0.0125 10.7813 0 ]
[.65873 -0.0125 -5.53125 -17.8125 ]
[.65873 -0.0125 5.53125 0 ]
[.81746 -0.0125 -10.7813 -17.8125 ]
[.81746 -0.0125 10.7813 0 ]
[.97619 -0.0125 -5.53125 -17.8125 ]
[.97619 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -4.75 -35.625 ]
[.5 -0.0125 4.75 -17.8125 ]
[-0.0125 .01472 -11.0625 -8.90625 ]
[-0.0125 .01472 0 8.90625 ]
[-0.0125 .13109 -11.0625 -8.90625 ]
[-0.0125 .13109 0 8.90625 ]
[-0.0125 .24746 -18.125 -8.90625 ]
[-0.0125 .24746 0 8.90625 ]
[-0.0125 .36383 -18.125 -8.90625 ]
[-0.0125 .36383 0 8.90625 ]
[-0.0125 .4802 -18.125 -8.90625 ]
[-0.0125 .4802 0 8.90625 ]
[-0.0125 .59657 -18.125 -8.90625 ]
[-0.0125 .59657 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -35.9375 -13.0938 ]
[-0.01875 .30902 -18.125 13.0938 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.36349 .02402 -20.125 -8.90625 ]
[.36349 .02402 20.125 8.90625 ]
[.56349 .06126 -20.125 -8.90625 ]
[.56349 .06126 20.125 8.90625 ]
[.64921 .02682 -20.125 -8.90625 ]
[.64921 .02682 20.125 8.90625 ]
[.34127 .41037 -62.4375 -8.90625 ]
[.34127 .41037 62.4375 8.90625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -65.75 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
68.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -72.0625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13109 m
.00625 .13109 L
s
gsave
-0.0125 .13109 -72.0625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .24746 m
.00625 .24746 L
s
gsave
-0.0125 .24746 -79.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .36383 m
.00625 .36383 L
s
gsave
-0.0125 .36383 -79.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
0 .4802 m
.00625 .4802 L
s
gsave
-0.0125 .4802 -79.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .59657 m
.00625 .59657 L
s
gsave
-0.0125 .59657 -79.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03799 m
.00375 .03799 L
s
0 .06126 m
.00375 .06126 L
s
0 .08454 m
.00375 .08454 L
s
0 .10781 m
.00375 .10781 L
s
0 .15436 m
.00375 .15436 L
s
0 .17763 m
.00375 .17763 L
s
0 .20091 m
.00375 .20091 L
s
0 .22418 m
.00375 .22418 L
s
0 .27073 m
.00375 .27073 L
s
0 .294 m
.00375 .294 L
s
0 .31728 m
.00375 .31728 L
s
0 .34055 m
.00375 .34055 L
s
0 .3871 m
.00375 .3871 L
s
0 .41037 m
.00375 .41037 L
s
0 .43365 m
.00375 .43365 L
s
0 .45692 m
.00375 .45692 L
s
0 .50347 m
.00375 .50347 L
s
0 .52675 m
.00375 .52675 L
s
0 .55002 m
.00375 .55002 L
s
0 .57329 m
.00375 .57329 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -101.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
74.0938 12.9063 translate
90 rotate
-74.0938 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Dc) show
79.688 11.875 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
85.188 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13109 m
1 .13109 L
s
.99375 .24746 m
1 .24746 L
s
.99375 .36383 m
1 .36383 L
s
.99375 .4802 m
1 .4802 L
s
.99375 .59657 m
1 .59657 L
s
.125 Mabswid
.99625 .03799 m
1 .03799 L
s
.99625 .06126 m
1 .06126 L
s
.99625 .08454 m
1 .08454 L
s
.99625 .10781 m
1 .10781 L
s
.99625 .15436 m
1 .15436 L
s
.99625 .17763 m
1 .17763 L
s
.99625 .20091 m
1 .20091 L
s
.99625 .22418 m
1 .22418 L
s
.99625 .27073 m
1 .27073 L
s
.99625 .294 m
1 .294 L
s
.99625 .31728 m
1 .31728 L
s
.99625 .34055 m
1 .34055 L
s
.99625 .3871 m
1 .3871 L
s
.99625 .41037 m
1 .41037 L
s
.99625 .43365 m
1 .43365 L
s
.99625 .45692 m
1 .45692 L
s
.99625 .50347 m
1 .50347 L
s
.99625 .52675 m
1 .52675 L
s
.99625 .55002 m
1 .55002 L
s
.99625 .57329 m
1 .57329 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.05556 .01486 L
.0873 .01521 L
.18254 .01878 L
.2619 .02568 L
.34127 .03884 L
.40476 .05398 L
.5 .0906 L
.65873 .1957 L
.81746 .36414 L
.97619 .60332 L
s
[ .01 .01 ] 0 setdash
.02381 .03799 m
.3254 .03799 L
s
.3254 .03799 m
.3254 .01472 L
s
.02381 .10781 m
.52857 .10781 L
s
.52857 .10781 m
.52857 .01472 L
s
.02381 .16902 m
.61746 .16902 L
s
.61746 .16902 m
.61746 .01472 L
s
gsave
.36349 .02402 -81.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(68.3) show
87.625 17.500 moveto
(%) show
99.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.56349 .06126 -81.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(95.4) show
87.625 17.500 moveto
(%) show
99.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.64921 .02682 -81.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(99.0) show
87.625 17.500 moveto
(%) show
99.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.34127 .41037 -123.438 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Quintessence) show
141.563 17.500 moveto
(Models) show
183.875 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{773.188, 477.875},
  ImageMargins->{{43, 0}, {0, 34.625}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<50001gB000`400?l00000o`00003oo`3ooooo
0?ooool0oooo203oool00?l0ooooo`3ooooo0?ooo`P0oooo003o0?ooool0ooooo`3oool80?ooo`00
o`3ooooo0?ooool0oooo203oool00?l0ooooo`3ooooo0?ooo`P0oooo003o0?oooiT0oooo0`00003o
0?ooof/0oooo003o0?oooiT0oooo00@000000?ooo`3oool00000o`3ooomZ0?ooo`00o`3ooonL0?oo
o`030000003oool0oooo0?l0ooooJ03oool00?l0ooooVP3oool200000?l0ooooJ`3oool00?l0oooo
V@3oool00`000000oooo0?ooo`3o0?ooof/0oooo003o0?oooiT0oooo00@000000?ooo`3oool00000
o`3ooomZ0?ooo`00o`3ooonJ0?ooo`<00000o`3ooomZ0?ooo`00o`3ooooo0?ooool0oooo203oool0
0?l0ooooo`3ooooo0?ooo`P0oooo003o0?ooool0ooooo`3oool80?ooo`00o`3ooooo0?ooool0oooo
203oool00?l0ooooo`3ooooo0?ooo`P0oooo003o0?ooool0ooooo`3oool80?ooo`00o`3ooooo0?oo
ool0oooo203oool00?l0ooooo`3ooooo0?ooo`P0oooo003o0?ooool0ooooo`3oool80?ooo`00o`3o
oooo0?ooool0oooo203oool00?l0ooooo`3ooooo0?ooo`P0oooo001;0?ooo`<00000I`3oool30000
00<0oooo00@000000?ooo`3oool0oooo0`00001W0?ooo`<00000I`3oool3000000<0oooo00@00000
0?ooo`3oool0oooo0`00001W0?ooo`D00000I03oool500000080oooo00@000000?ooo`3oool0oooo
0`00001W0?ooo`@00000703oool004X0oooo00D000000?ooo`3oool0oooo0000001U0?ooo`050000
003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo06L0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1U0?ooo`040000003oool0oooo0000
06D0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0
oooo01T0oooo001:0?ooo`050000003oool0oooo0?ooo`000000I@3oool01@000000oooo0?ooo`3o
ool0000000X0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`1W0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`1V0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0I0?ooo`00BP3oool0
1@000000oooo0?ooo`3oool0000006D0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000
003oool0oooo06@0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo06H0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo06L0oooo00<000000?ooo`3oool06@3oool004X0oooo00D000000?ooo`3oool0oooo
0000001U0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1T0?ooo`03
0000003oool0oooo06L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1V0?ooo`03
0000003oool0oooo06H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1W0?ooo`03
0000003oool0oooo01T0oooo001:0?ooo`050000003oool0oooo0?ooo`000000I@3oool01@000000
oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`1W0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`1V0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0IP3oool2000001`0oooo001:0?ooo`05
0000003oool0oooo0?ooo`000000I@3oool01@000000oooo0?ooo`3oool0000000H0oooo0`00001X
0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool01P3oool3000006/0oooo00<00000
0?ooo`3oool0IP3oool00`000000oooo0?ooo`040?ooo`<00000JP3oool00`000000oooo0?ooo`0J
0?ooo`00BP3oool01@000000oooo0?ooo`3oool0000006D0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool06@3oool004X0oooo00D00000
0?ooo`3oool0oooo0000001U0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo
0?ooo`1V0?ooo`800000J03oool2000000T0oooo00<000000?ooo`3oool0IP3oool01@000000oooo
0?ooo`3oool0000006@0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo
06H0oooo00D000000?ooo`3oool0oooo0000000K0?ooo`00B`3oool3000006L0oooo0`0000080?oo
o`@00000IP3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00L0oooo1000001V0?oo
o`<00000IP3oool3000000P0oooo1000001V0?ooo`<00000703oool00?l0ooooo`3ooooo0?ooo`P0
oooo003o0?ooool0ooooo`3oool80?ooo`00o`3ooooo0?ooool0oooo203oool00?l0ooooo`3ooooo
0?ooo`P0oooo003o0?ooool0ooooo`3oool80?ooo`00o`3ooooo0?ooool0oooo203oool00?l0oooo
o`3ooooo0?ooo`P0oooo003o0?ooool0ooooo`3oool80?ooo`00o`3ooooo0?ooool0oooo203oool0
0?l0ooooo`3ooooo0?ooo`P0oooo003o0?ooool0ooooo`3oool80?ooo`00?03ooooo00000?l00000
_`00000<0?ooo`00?03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo06`0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1/0?ooo`03
0000003oool0oooo06`0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1/0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0
o`3ooooo0?oook/0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3o
oooo0?oook/0oooo00<000000?ooo`3oool02P3oool002`0oooo0`00000=0?ooo`030000003oool0
oooo0?l0ooooo`3ooonk0?ooo`030000003oool0oooo00X0oooo000[0?ooo`050000003oool0oooo
0?ooo`000000303oool00`000000oooo0?ooo`3o0?ooool0oooo^`3oool00`000000oooo0?ooo`0:
0?ooo`00:`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0o`3ooooo
0?oook/0oooo00<000000?ooo`3oool02P3oool002/0oooo00D000000?ooo`3oool0oooo0000000<
0?ooo`H000002`3ooolQ00000;80oooo00<000000?ooo`3oool0o`3ooooB0?ooo`D00000303oool0
02/0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo02l0oooo7000002F
0?ooo`030000003oool0oooo0?l0ooooeP3oool00`000000oooo0?ooo`0:0?ooo`00:`3oool01@00
0000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0B`3ooolR000007@0oooo00<00000
0?ooo`3oool0o`3ooooF0?ooo`030000003oool0oooo00X0oooo000[0?ooo`050000003oool0oooo
0?ooo`000000303oool00`000000oooo0?ooo`1]0?oooaH00000GP3oool00`000000oooo0?ooo`07
0?ooo`<00000103oool3000000<0oooo00@000000?ooo`3oool0oooo100000040?ooo`030000003o
ool0oooo00<0oooo0P00001S0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3o
ool:0?ooo`030000003oool0oooo00X0oooo000[0?ooo`050000003oool0oooo0?ooo`000000303o
ool00`000000oooo0?ooo`230?ooo`/00000G03oool01@000000oooo0?ooo`3oool000000080oooo
00D000000?ooo`3oool0oooo0000000:0?ooo`050000003oool0oooo0?ooo`000000103oool01000
0000oooo0?ooo`00001R0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3oool:
0?ooo`030000003oool0oooo00X0oooo000[0?ooo`050000003oool0oooo0?ooo`000000303oool0
0`000000oooo0?ooo`2>0?ooo`/00000D@3oool01@000000oooo0?ooo`3oool000000080oooo00D0
00000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`020?ooo`8000001@3oool2000000D0oooo00<000000?ooo`3oool00P3oool3000000@0
oooo00<000000?ooo`3oool00`3oool200000>D0oooo00<000000?ooo`3oool02P3oool002`0oooo
0`00000=0?ooo`030000003oool0oooo09T0oooo2`0000160?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`00003T0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0:@0oooo2`00
000k0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0000000;0?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P00001S0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`3R0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo
0:l0oooo2@00000b0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00P0oooo0P0000030?ooo`8000000P3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool00`3oool4000000<0oooo100000060?ooo`050000003oool0oooo
0?ooo`0000001@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0>80oooo00<0
00000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0^03oool6000002`0oooo00@00000
0?ooo`0000000000103oool00`000000oooo0000000:0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000IP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool0
1@000000oooo0?ooo`3oool0000000D0oooo00@000000?ooo`3oool0oooo0P00003U0?ooo`030000
003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0;h0oooo1P00000M0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000X0oooo
00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000006D0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000P3o
ool00`000000oooo0?ooo`3W0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0
oooo0<@0oooo1P00000G0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00L000000?ooo`3oool0oooo0000003oool000000080
oooo00D000000?ooo`3oool0oooo0000002X0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00L000000?ooo`3oool0oooo0000003oool000000080
oooo00@000000?ooo`3oool00000j03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000
oooo0?ooo`3:0?ooo`H000004@3oool00`000000oooo0?ooo`090?ooo`8000000`3oool3000000P0
oooo0`0000030?ooo`8000001@3oool00`000000oooo0?ooo`2U0?ooo`050000003oool0oooo0?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000000H0oooo00L000000?ooo`3oool0oooo0000
003oool000000080oooo00D000000?ooo`3oool0oooo0000003W0?ooo`030000003oool0oooo00X0
oooo000l0?ooo`030000003oool0oooo0=00oooo1`00000:0?ooo`030000003oool0oooo0<h0oooo
00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000>L0oooo
00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0e`3oool6000000@0oooo00<0
00000?ooo`3oool0c`3oool3000000@0oooo0`0000080?ooo`<000000`3oool2000000D0oooo00<0
00000?ooo`3oool0i03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3M
0?ooo`H00000o`3ooooG0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo
0>40oooo00<000000?ooo`0000001@00003o0?ooom40oooo00<000000?ooo`3oool02P3oool003`0
oooo1000000=0?ooo`P000001P3oool8000000H0oooo200000060?ooo`P000001P3oool8000000H0
oooo200000060?ooo`P000001P3oool8000000H0oooo200000060?ooo`P000001P3oool8000000H0
oooo200000060?ooo`P000001P3oool8000000H0oooo200000060?ooo`8000001`3oool500000840
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?ooo`L0oooo1000000<0?ooo`00
?03oool00`000000oooo0?ooo`3^0?ooo`@00000O@3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?oo
o`3b0?ooo`@00000N@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0oooo2P3o
ool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3f0?ooo`@00000M@3oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`0:
0?ooo`00?03oool00`000000oooo0?ooo`3j0?ooo`@00000L@3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000
oooo0?ooo`3n0?ooo`@00000K@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0
oooo2P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooo`<0oooo
1000001Y0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000
003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0oooo1`3oool4000006D0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool02P3o
ool003`0oooo00<000000?ooo`3oool0o`3oool;0?ooo`@00000o`3ooon/0?ooo`030000003oool0
oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0oooo3`3oool400000?l0ooooZ03oool00`00
0000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oooa<0oooo1000003o0?oooj@0
oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooolG0?ooo`@00000
o`3ooonP0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0oooo6`3o
ool3000005T0oooo0P0000050?ooo`<00000103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool200000?l0oooo8P3oool00`000000oooo0?oo
o`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oooah0oooo0P00001I0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000o`3ooolQ0?ooo`030000003oool0oooo00X0oooo000l
0?ooo`030000003oool0oooo0?l0oooo803oool3000004d0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`3o0?ooo`X0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooolS
0?ooo`<00000BP3oool00`000000oooo0?ooo`050?ooo`@000001P3oool00`000000oooo0?ooo`03
0?ooo`H000001@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00X0oooo000l0?ooo`@00000o`3ooolU
0?ooo`800000B03oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000001P3o
ool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000001P3oool010000000oooo
0?ooo`3oool2000001D0oooo00<000000?ooo`3oool0o`3oool70?ooo`@00000303oool003`0oooo
00<000000?ooo`3oool0o`3ooolX0?ooo`<00000A@3oool00`000000oooo0?ooo`040?ooo`050000
003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo0000
00<0oooo0P0000020?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0o`3oool:0?oo
o`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0oooo:`3oool300000480
oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000080oooo0`0000090?oo
o`030000003oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`00
0000oooo0?ooo`3o0?ooobh0oooo0P0000100?ooo`030000003oool0oooo00@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`0000000P3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3o
ool:0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0oooo<03oool3
000003d0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`3oool02@3oool200000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`0:0?ooo`00?03o
ool00`000000oooo0?ooo`3o0?oooc<0oooo0`00000j0?ooo`030000003oool0oooo00D0oooo0`00
00040?ooo`@000002@3oool010000000oooo0?ooo`3oool2000000D0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool02P3oool003`0oooo00<0
00000?ooo`3oool0o`3ooolf0?ooo`800000o`3ooon30?ooo`030000003oool0oooo00X0oooo000l
0?ooo`030000003oool0oooo0?l0oooo>03oool300000?l0ooooP03oool00`000000oooo0?ooo`0:
0?ooo`00?03oool00`000000oooo0?ooo`3o0?oooc/0oooo0`00003o0?ooogd0oooo00<000000?oo
o`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3oooln0?ooo`800000o`3ooomk0?ooo`03
0000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0oooo@03oool300000?l0oooo
N03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oood<0oooo0`00
003o0?ooogD0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooom6
0?ooo`800000:03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0oooo2P3oool0
0`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooodP0oooo0`00000U0?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo
00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooB`3oool300000280oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool02P3oool003`0oooo
00<000000?ooo`3oool0o`3ooom>0?ooo`800000803oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool400000?l0ooooC`3o
ool3000001d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?ooo`L0oooo1000
000<0?ooo`00?03oool00`000000oooo0?ooo`3o0?oooe<0oooo0`00000J0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00X0oooo000l0?oo
o`030000003oool0oooo0?l0ooooEP3oool2000001P0oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3o
ool0o`3ooomH0?ooo`<000005@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0
oooo2P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oooe/0oooo
0P00003o0?oooeh0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3o
oomM0?ooo`800000o`3ooomL0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0
oooo0?l0ooooG`3oool00`000000oooo0?ooo`3o0?oooeT0oooo00<000000?ooo`3oool02P3oool0
03`0oooo00<000000?ooo`3oool0o`3ooomP0?ooo`800000o`3ooomI0?ooo`030000003oool0oooo
00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooHP3oool00`000000oooo0?ooo`3o0?oooeH0
oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooomS0?ooo`800000
o`3ooomF0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooI@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3o
ool:0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooIP3oool2
000000P0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<00000
0?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooomX0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?oo
o`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooomY0?ooo`8000001@3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`0:0?ooo`00
?03oool00`000000oooo0?ooo`3o0?ooof/0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`0:0?ooo`00?03o
ool00`000000oooo0?ooo`3o0?ooof`0oooo0P0000020?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00X0oooo000l0?ooo`@000003@3oool8
000000H0oooo200000060?ooo`P000001P3oool8000000H0oooo200000060?ooo`P000001P3oool8
000000H0oooo200000060?ooo`P000001P3oool8000000H0oooo200000060?ooo`P000001P3oool8
000000H0oooo200000060?ooo`P000001P3oool8000000H0oooo200000060?ooo`P000001P3oool8
000000H0oooo200000060?ooo`P000001P3oool8000000H0oooo200000060?ooo`P000001P3oool8
000000H0oooo1000000m0?ooo`030000003oool0oooo0?l0oooo1`3oool4000000`0oooo000l0?oo
o`030000003oool0oooo0?l0ooooK`3oool2000003d0oooo00<000000?ooo`3oool0o`3oool:0?oo
o`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooL@3oool00`000000
oooo0?ooo`3o0?ooodL0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0
o`3ooomb0?ooo`800000o`3ooom70?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003o
ool0oooo0?l0ooooM03oool00`000000oooo0?ooo`3o0?oood@0oooo00<000000?ooo`3oool02P3o
ool003`0oooo00<000000?ooo`3oool0o`3ooome0?ooo`800000o`3ooom40?ooo`030000003oool0
oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooM`3oool00`000000oooo0?ooo`3o0?oo
od40oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooomh0?ooo`80
0000o`3ooom10?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0oooo
NP3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo
0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooog/0oooo0P00000a0?ooo`030000003o
ool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o
0?ooogd0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<00000
0?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooomn0?ooo`800000;P3oool00`00
0000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3o
ool0o`3ooon00?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0o`3oool:0?ooo`03
0000003oool0oooo00X0oooo000[0?ooo`<000003P3oool00`000000oooo0?ooo`3o0?oooh40oooo
0P00000[0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`0:0?ooo`00;P3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooP`3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`0:0?ooo`00;`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooQ03oool2000002P0oooo00<00000
0?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00X0oooo000_0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo0?l0oooo<P3oool00`00
0000oooo0?ooo`0:0?ooo`00;`3oool00`000000oooo0?ooo`0:0?ooo`H00000o`3ooon40?ooo`80
0000o`3oool^0?ooo`D00000303oool002h0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`3o0?ooohT0oooo00<000000?ooo`3oool0o`3oool_0?ooo`030000003oool0oooo00X0oooo
000[0?ooo`<000003P3oool00`000000oooo0?ooo`3o0?ooohX0oooo0P00003o0?ooobl0oooo00<0
00000?ooo`3oool02P3oool002/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3o
0?oooh`0oooo00<000000?ooo`3oool0o`3oool/0?ooo`030000003oool0oooo00X0oooo000/0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooon=0?ooo`800000o`3oool/0?oo
o`030000003oool0oooo00X0oooo000/0?ooo`@00000303oool00`000000oooo0?ooo`3o0?ooohl0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3o
ool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooon@0?ooo`800000703oool00`000000oooo
0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3o
oonB0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003o
ool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooT`3oool2000001T0oooo00<00000
0?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo
0?l0ooooU@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0oooo2P3oool00`00
0000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oooiH0oooo0P00000F0?ooo`03
0000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo
0?ooo`3o0?oooiP0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3o0?ooo`X0oooo
00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooonI0?ooo`8000004`3o
ool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool02P3oool003`0oooo00<00000
0?ooo`3oool0o`3ooonK0?ooo`030000003oool0oooo0?l0oooo7@3oool00`000000oooo0?ooo`0:
0?ooo`00?03oool00`000000oooo0?ooo`3o0?oooi`0oooo0P00003o0?oooad0oooo00<000000?oo
o`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooonN0?ooo`030000003oool0oooo0?l0
oooo6P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool400000?l0ooooWP3oool200000?l0oooo
5`3oool4000000`0oooo000l0?ooo`030000003oool0oooo0?l0ooooX@3oool00`000000oooo0?oo
o`3o0?oooaL0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooonR
0?ooo`800000o`3ooolG0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo
0?l0ooooY03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0oooo2P3oool00`00
0000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooojD0oooo0P0000070?ooo`03
0000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo
0?ooo`3o0?ooojL0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooo`X0oooo
00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooonX0?ooo`800000103o
ool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool02P3oool003`0oooo00<00000
0?ooo`3oool0o`3ooonZ0?ooo`050000003oool0oooo0?ooo`000000o`3oool<0?ooo`030000003o
ool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooZ`3oool2000000030?ooo`000000
oooo0?l0oooo2`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oo
ojd0oooo0P00003o0?ooo``0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3o
ool03P3oool8000000H0oooo200000060?ooo`P000001P3oool8000000H0oooo200000060?ooo`P0
00001P3oool8000000H0oooo200000060?ooo`P000001P3oool8000000H0oooo200000060?ooo`P0
00001P3oool8000000H0oooo200000060?ooo`P000001P3oool8000000H0oooo200000060?ooo`P0
00001P3oool8000000H0oooo200000060?ooo`P000001P3oool8000000H0oooo200000060?ooo`P0
00001P3oool8000000H0oooo200000060?ooo`P000001P3oool8000000H0oooo200000060?ooo`P0
000000<0oooo000000000000o`3oool;0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000
003oool0oooo0?l0oooo/03oool00`000000oooo0?ooo`3o0?ooo`P0oooo00<000000?ooo`3oool0
2P3oool003`0oooo00<000000?ooo`3oool0o`3ooona0?ooo`800000o`3oool80?ooo`030000003o
ool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0oooo/`3oool00`000000oooo0?ooo`3o
0?ooo`D0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooond0?oo
o`800000o`3oool50?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0
oooo]P3oool00`000000oooo0?ooo`3o0?ooo`80oooo00<000000?ooo`3oool02P3oool003`0oooo
1000003o0?oookH0oooo0P00003n0?ooo`@00000303oool003`0oooo00<000000?ooo`3oool0o`3o
ooni0?ooo`030000003oool0oooo0?h0oooo00<000000?ooo`3oool02P3oool003`0oooo00<00000
0?ooo`3oool0o`3ooonj0?ooo`800000oP3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`00
0000oooo0?ooo`3o0?oook`0oooo00<000000?ooo`3oool0n`3oool00`000000oooo0?ooo`0:0?oo
o`00?03oool00`000000oooo0?ooo`3o0?oookd0oooo0P00003k0?ooo`030000003oool0oooo00X0
oooo000l0?ooo`030000003oool0oooo0?l0oooo_`3oool00`000000oooo0?ooo`3h0?ooo`030000
003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0oooo`03oool200000?P0oooo00<0
00000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3oooo20?ooo`030000003oool0
oooo0?D0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3oooo30?oo
o`800000m@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooolD0
oooo00<000000?ooo`3oool0lP3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo
0?ooo`3o0?ooolH0oooo0P00003b0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003o
ool0oooo0?l0oooob03oool00`000000oooo0?ooo`3_0?ooo`030000003oool0oooo00X0oooo000l
0?ooo`030000003oool0oooo0?l0oooob@3oool200000>l0oooo00<000000?ooo`3oool02P3oool0
03`0oooo00<000000?ooo`3oool0o`3oooo;0?ooo`030000003oool0oooo0>`0oooo00<000000?oo
o`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3oooo<0?ooo`030000003oool0oooo0>/0
oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3oooo=0?ooo`030000
003oool0oooo0>X0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3o
ooo>0?ooo`030000003oool0oooo0>T0oooo00<000000?ooo`3oool02P3oool003`0oooo1000003o
0?ooolh0oooo00<000000?ooo`3oool0i@3oool4000000`0oooo000l0?ooo`030000003oool0oooo
0?l0ooood03oool00`000000oooo0?ooo`3W0?ooo`030000003oool0oooo00X0oooo000l0?ooo`03
0000003oool0oooo0?l0ooood@3oool00`000000oooo0?ooo`3V0?ooo`030000003oool0oooo00X0
oooo000l0?ooo`030000003oool0oooo0?l0oooodP3oool00`000000oooo0?ooo`3U0?ooo`030000
003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooood`3oool00`000000oooo0?oo
o`3T0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooood`3oool0
0`000000oooo0?ooo`3T0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo
0?l0ooooe03oool00`000000oooo0?ooo`3S0?ooo`030000003oool0oooo00X0oooo000l0?ooo`03
0000003oool0oooo0?l0ooooe@3oool00`000000oooo0?ooo`3R0?ooo`030000003oool0oooo00X0
oooo000l0?ooo`030000003oool0oooo0?l0ooooeP3oool00`000000oooo0?ooo`3Q0?ooo`030000
003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooe`3oool00`000000oooo0?oo
o`3P0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0oooof03oool0
0`000000oooo0?ooo`3O0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo
0?l0oooof@3oool00`000000oooo0?ooo`3N0?ooo`030000003oool0oooo00X0oooo000l0?ooo`03
0000003oool0oooo0?l0oooofP3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00X0
oooo000l0?ooo`030000003oool0oooo0?l0oooof`3oool00`000000oooo0?ooo`3L0?ooo`030000
003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0oooog03oool00`000000oooo0?oo
o`3K0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0oooog@3oool0
0`000000oooo0?ooo`3J0?ooo`030000003oool0oooo00X0oooo000l0?ooo`@00000o`3ooooM0?oo
o`030000003oool0oooo0=H0oooo1000000<0?ooo`00?03oool00`000000oooo0?ooo`3o0?oooml0
oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo
0?ooo`3o0?ooon00oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`0:0?ooo`00?03o
ool00`000000oooo0?ooo`3o0?ooon40oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?oo
o`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooon80oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooon<0oooo00<000000?oo
o`3oool0e03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooon<0
oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo
0?ooo`3o0?ooon@0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`0:0?ooo`00?03o
ool00`000000oooo0?ooo`3o0?ooonD0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?oo
o`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooonH0oooo00<000000?ooo`3oool0d@3oool0
0`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooonL0oooo00<000000?oo
o`3oool0d03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooonP0
oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo
0?ooo`3o0?ooonT0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0:0?ooo`009@3o
ool3000000@0oooo0`00000=0?ooo`030000003oool0oooo0?l0oooojP3oool00`000000oooo0?oo
o`3=0?ooo`030000003oool0oooo00X0oooo000V0?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo0?l0ooooj`3oool00`000000oooo0?oo
o`3<0?ooo`030000003oool0oooo00X0oooo000V0?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo0?l0ooook03oool00`000000oooo0?oo
o`3;0?ooo`030000003oool0oooo00X0oooo000V0?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo0000000<0?ooo`H00000o`3ooooZ0?ooo`030000003oool0oooo0<H0oooo1@00
000<0?ooo`009P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000303o
ool00`000000oooo0?ooo`3o0?ooonh0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?oo
o`0:0?ooo`009P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000303o
ool00`000000oooo0?ooo`3o0?ooonl0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?oo
o`0:0?ooo`009P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000303o
ool00`000000oooo0?ooo`3o0?oooo00oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?oo
o`0:0?ooo`009P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000303o
ool00`000000oooo0?ooo`3o0?oooo40oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?oo
o`0:0?ooo`009@3oool2000000@0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003o
ool0oooo0?l0oooolP3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00X0oooo000V
0?ooo`030000003oool0oooo00<0oooo0`00000=0?ooo`030000003oool0oooo0?l0ooool`3oool0
0`000000oooo0?ooo`340?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo
0?l0ooool`3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo00X0oooo000l0?ooo`03
0000003oool0oooo0?l0oooom03oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo00X0
oooo000l0?ooo`030000003oool0oooo0?l0oooom@3oool00`000000oooo0?ooo`320?ooo`030000
003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0oooomP3oool00`000000oooo0?oo
o`310?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0oooom`3oool0
0`000000oooo0?ooo`300?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo
0?l0oooon03oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo00X0oooo000l0?ooo`03
0000003oool0oooo0?l0oooon@3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo00X0
oooo000l0?ooo`030000003oool0oooo0?l0oooonP3oool00`000000oooo0?ooo`2m0?ooo`030000
003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0oooon`3oool00`000000oooo0?oo
o`2l0?ooo`030000003oool0oooo00X0oooo000l0?ooo`@00000o`3ooook0?ooo`030000003oool0
oooo0;P0oooo1000000<0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooood0oooo00<000000?oo
o`3oool0^P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooooh0
oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo
0?ooo`3o0?ooool0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0:0?ooo`00?03o
ool00`000000oooo0?ooo`3o0?ooool0oooo0@3oool00`000000oooo0?ooo`2g0?ooo`030000003o
ool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3oool20?ooo`030000003oool0
oooo0;H0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oo
o`<0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000
oooo0?ooo`3o0?ooool0oooo0`3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo00X0
oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3oool40?ooo`030000003oool0oooo0;@0oooo
00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`D0oooo00<0
00000?ooo`3oool0/`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o
0?ooool0oooo1P3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo00X0oooo000l0?oo
o`030000003oool0oooo0?l0ooooo`3oool70?ooo`030000003oool0oooo0;40oooo00<000000?oo
o`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`P0oooo00<000000?ooo`3o
ool0/03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo
2@3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003o
ool0oooo0?l0ooooo`3oool:0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool02P3o
ool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`/0oooo00<000000?ooo`3oool0[@3oool0
0`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo303oool00`00
0000oooo0?ooo`2/0?ooo`030000003oool0oooo00X0oooo000H0?ooo`030000003oool0oooo0240
oooo1000003o0?ooool0oooo303oool00`000000oooo0?ooo`2X0?ooo`@00000303oool001D0oooo
1000000S0?ooo`030000003oool0oooo0?l0ooooo`3oool>0?ooo`030000003oool0oooo0:X0oooo
00<000000?ooo`3oool02P3oool001<0oooo0P0000030?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool0o`3ooooo0?ooo`l0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?oo
o`0:0?ooo`00403oool3000000D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3o
0?ooool0oooo403oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo00X0oooo000?0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3o0?oo
ool0oooo4@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo00X0oooo000@0?ooo`<0
00001@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0ooooo`3ooolB0?ooo`03
0000003oool0oooo0:H0oooo00<000000?ooo`3oool02P3oool001<0oooo0P0000030?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool0o`3ooooo0?oooa<0oooo00<000000?ooo`3oool0
Y@3oool00`000000oooo0?ooo`0:0?ooo`005@3oool4000002<0oooo00<000000?ooo`3oool0o`3o
oooo0?oooa<0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0:0?ooo`00603oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0ooooo`3ooolD0?ooo`030000003oool0
oooo0:@0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`3o0?ooool0oooo5@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo
00X0oooo000I0?ooo`8000008@3oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool00`000000
oooo0?ooo`2R0?ooo`030000003oool0oooo00X0oooo000B0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool00`000000oooo
0?ooo`2Q0?ooo`030000003oool0oooo00X0oooo000B0?ooo`<000000P3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo0?l0ooooo`3ooolH0?ooo`030000003oool0oooo0:00oooo00<0
00000?ooo`3oool02P3oool001D0oooo1`00000P0?ooo`030000003oool0oooo0?l0ooooo`3ooolI
0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool02P3oool001D0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0?l0ooooo`3ooolJ0?oo
o`030000003oool0oooo09h0oooo00<000000?ooo`3oool02P3oool001@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0ooooo`3ooolK0?ooo`03
0000003oool0oooo09d0oooo00<000000?ooo`3oool02P3oool001<0oooo00<000000?ooo`3oool0
9P3oool400000?l0ooooo`3ooolK0?ooo`030000003oool0oooo09T0oooo1000000<0?ooo`00303o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0o`3o
oooo0?oooad0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0:0?ooo`00303oool0
0`000000oooo0?ooo`020?ooo`800000:@3oool00`000000oooo0?ooo`3o0?ooool0oooo7P3oool0
0`000000oooo0?ooo`2J0?ooo`030000003oool0oooo00X0oooo000<0?ooo`070000003oool0oooo
0?ooo`000000oooo0000000Y0?ooo`030000003oool0oooo0?l0ooooo`3ooolO0?ooo`030000003o
ool0oooo09T0oooo00<000000?ooo`3oool02P3oool000d0oooo0`0000000`3oool000000000000Y
0?ooo`030000003oool0oooo0?l0ooooo`3ooolP0?ooo`030000003oool0oooo09P0oooo00<00000
0?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo00<000000?oo
o`3oool0U`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0
oooo8P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000
003oool0oooo0?l0ooooo`3ooolS0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool0
2P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooob<0oooo00<000000?ooo`3oool0U@3o
ool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo903oool0
0`000000oooo0?ooo`2D0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo
0?l0ooooo`3ooolU0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool02P3oool003`0
oooo00<000000?ooo`3oool0o`3ooooo0?ooobH0oooo00<000000?ooo`3oool0TP3oool00`000000
oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo9`3oool00`000000oooo
0?ooo`2A0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3o
oolX0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02P3oool003`0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooobT0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0:
0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo:P3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo00X0oooo000l0?ooo`@00000o`3ooooo0?ooobX0oooo00<000000?ooo`3o
ool0RP3oool4000000`0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3oool/0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3o
oooo0?ooobd0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool0
0`000000oooo0?ooo`3o0?ooool0oooo;P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0
oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3oool_0?ooo`030000003oool0oooo
08T0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooc00
oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo
0?ooo`3o0?ooool0oooo<@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00X0oooo
000l0?ooo`030000003oool0oooo0?l0ooooo`3ooolb0?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooc<0oooo00<00000
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oo
ool0oooo<`3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo00X0oooo000l0?ooo`03
0000003oool0oooo0?l0ooooo`3ooold0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3o
ool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooocD0oooo00<000000?ooo`3oool0
P`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo=P3o
ool00`000000oooo0?ooo`220?ooo`030000003oool0oooo00X0oooo000U0?ooo`<000000`3oool3
000000h0oooo00<000000?ooo`3oool0o`3ooooo0?ooocL0oooo00<000000?ooo`3oool0P@3oool0
0`000000oooo0?ooo`0:0?ooo`009P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0o`3ooooo0?ooocP0oooo00<000000?ooo`3oool0P03oool00`00
0000oooo0?ooo`0:0?ooo`009P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0o`3ooooo0?ooocT0oooo00<000000?ooo`3oool0O`3oool00`000000
oooo0?ooo`0:0?ooo`009P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0o`3ooooo0?ooocX0oooo00<000000?ooo`3oool0OP3oool00`000000oooo
0?ooo`0:0?ooo`009P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo1P00
003o0?ooool0oooo>03oool00`000000oooo0?ooo`1i0?ooo`D00000303oool002H0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooo`3oooll
0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool02P3oool002H0oooo00<000000?oo
o`3oool00P3oool3000000h0oooo00<000000?ooo`3oool0o`3ooooo0?oooc`0oooo00<000000?oo
o`3oool0O03oool00`000000oooo0?ooo`0:0?ooo`009P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooooo0?ooocd0oooo00<000000?ooo`3o
ool0N`3oool00`000000oooo0?ooo`0:0?ooo`009@3oool2000000D0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`3o0?ooool0oooo?P3oool00`000000oooo0?ooo`1j0?ooo`030000
003oool0oooo00X0oooo000V0?ooo`030000003oool0oooo00<0oooo1000000<0?ooo`030000003o
ool0oooo0?l0ooooo`3oooln0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool02P3o
ool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooocl0oooo00<000000?ooo`3oool0N@3oool0
0`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo@03oool00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0
ooooo`3ooom00?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool02P3oool003`0oooo
00<000000?ooo`3oool0o`3ooooo0?oood40oooo00<000000?ooo`3oool0M`3oool00`000000oooo
0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo@P3oool00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooom2
0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?oo
o`3oool0o`3ooooo0?oood<0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0:0?oo
o`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooA03oool00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooom40?ooo`030000
003oool0oooo07@0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3o
oooo0?ooodD0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool4
00000?l0ooooo`3ooom50?ooo`030000003oool0oooo06l0oooo1000000<0?ooo`00?03oool00`00
0000oooo0?ooo`3o0?ooool0ooooAP3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo
00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooom70?ooo`030000003oool0oooo0740
oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo
00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?oo
o`3o0?ooool0ooooB03oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo00X0oooo000l
0?ooo`030000003oool0oooo0?l0ooooo`3ooom90?ooo`030000003oool0oooo06l0oooo00<00000
0?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooodX0oooo00<000000?oo
o`3oool0KP3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0
ooooBP3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000
003oool0oooo0?l0ooooo`3ooom;0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0
2P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oood`0oooo00<000000?ooo`3oool0K03o
ool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`2g0?ooo`800000o`3ooonB
0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?oo
o`3oool0]P3oool00`000000oooo0?ooo`3o0?oooi<0oooo00<000000?ooo`3oool0J`3oool00`00
0000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo0?l0
ooooU@3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000
003oool0oooo0;<0oooo100000050?ooo`80000000<0oooo0000003oool01P0000001@3oool00000
000000000000oooo008000000`3oool300000080oooo0`0000030?ooo`<00000103oool300000005
0?ooo`00000000000000003oool00`0000020?ooo`<00000103oool3000000@0oooo0`0000030?oo
o`030000003oool0oooo00<000000P3oool3000000@0oooo0P0000000`3oool000000?ooo`020?oo
o`<0000000D0oooo00000000000000000?ooo`0300000?l0oooo:03oool00`000000oooo0?ooo`1Z
0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0;80oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo0`0000001@3oool000000?ooo`3o
ool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool2000000<0oooo00@000000?oo
o`3oool000000`3oool010000000oooo0?ooo`0000020?ooo`<0000000<0oooo0000003oool00P3o
ool00`000000oooo000000020?ooo`040000003oool0oooo00000?l0oooo:03oool00`000000oooo
0?ooo`1Y0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0;40oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo00000080
oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000203oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo000000D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000P3oool010000000oooo0?ooo`0000030?ooo`040000003oool0
oooo000000<0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0?l0oooo9`3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00X0oooo
000l0?ooo`@00000/03oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000<0oooo
00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?oo
o`3oool0oooo000000060?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`060?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01@000000
oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool0oooo0P00003o0?ooobX0oooo00<000000?ooo`3oool0I@3o
ool4000000`0oooo000l0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0103oool0
10000000oooo0?ooo`0000030?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo0?ooo`D0000000<0oooo0000003oool0103oool00`00
0000oooo0?ooo`030?ooo`D0000000<0oooo0000003oool00P3oool010000000oooo0?ooo`000006
0?ooo`D00000103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool50000
00050?ooo`000000oooo0?ooo`000000o`3oool]0?ooo`030000003oool0oooo06L0oooo00<00000
0?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`040?oo
o`040000003oool0oooo000000<0oooo00D000000?ooo`00000000000?ooo`0300000080oooo00@0
00000?ooo`3oool000000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo100000020?ooo`040000003o
ool0oooo000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool00P0000020?ooo`070000003oool0oooo0?ooo`000000oooo
000000020?ooo`040000003oool0oooo00000?l0oooo:`3oool00`000000oooo0?ooo`1V0?ooo`03
0000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0
103oool010000000oooo0000000000020?ooo`8000000P3oool01@000000oooo0?ooo`000000oooo
008000000P3oool3000000<0oooo0`0000030?ooo`<000000`3oool3000000<0oooo0`0000020?oo
o`040000003oool00000000000@0oooo0`0000040?ooo`<000001@3oool00`000000oooo00000004
0?ooo`030000003oool0000000<0oooo0`0000040?ooo`80000000<0oooo0000003oool00P3oool3
00000080oooo00@000000?ooo`3oool0oooo0`00003o0?ooob/0oooo00<000000?ooo`3oool0IP3o
ool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`2a0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
000000@0oooo00<000000?ooo`0000003@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0?l0oooo<03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00X0oooo000l0?oo
o`030000003oool0oooo0;80oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo0300oooo0P0000060?ooo`800000303oool2000000L0oooo0P00003o0?oo
oc<0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000
oooo0?ooo`2c0?ooo`@000002`3oool00`000000oooo0?ooo`0i0?ooo`<000001P3oool3000000`0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?oooc40oooo00<000000?ooo`3o
ool0I03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo
E@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003o
ool0oooo0?l0ooooo`3ooomF0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool02P3o
ool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooeH0oooo00<000000?ooo`3oool0HP3oool0
0`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooE`3oool00`00
0000oooo0?ooo`1Q0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0
ooooo`3ooomH0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool02P3oool003`0oooo
00<000000?ooo`3oool0o`3ooooo0?oooeP0oooo00<000000?ooo`3oool0H03oool00`000000oooo
0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooF@3oool00`000000oooo0?oo
o`1O0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomJ
0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?oo
o`3oool0o`3ooooo0?oooeX0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0:0?oo
o`00?03oool400000?l0ooooo`3ooomJ0?ooo`030000003oool0oooo05X0oooo1000000<0?ooo`00
?03oool00`000000oooo0?ooo`3o0?ooool0ooooG03oool00`000000oooo0?ooo`1L0?ooo`030000
003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomL0?ooo`030000003o
ool0oooo05`0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo
0?oooed0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`00
0000oooo0?ooo`3o0?ooool0ooooGP3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo
00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomN0?ooo`030000003oool0oooo05X0
oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooel0oooo
00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?oo
o`3o0?ooool0ooooH03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo00X0oooo000l
0?ooo`030000003oool0oooo0?l0ooooo`3ooomP0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooof40oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0
ooooHP3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000
003oool0oooo0?l0ooooo`3ooomR0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
2P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooof<0oooo00<000000?ooo`3oool0E@3o
ool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooI03oool0
0`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo
0?l0ooooo`3ooomT0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool02P3oool003`0
oooo00<000000?ooo`3oool0o`3ooooo0?ooofD0oooo00<000000?ooo`3oool0D`3oool00`000000
oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooIP3oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo00X0oooo000l0?ooo`@00000o`3ooooo0?ooofD0oooo00<0
00000?ooo`3oool0C`3oool4000000`0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomW
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?oo
o`3oool0o`3ooooo0?ooofP0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0:0?oo
o`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooJ03oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomY0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3o
oooo0?ooofX0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0:0?ooo`00?03oool0
0`000000oooo0?ooo`3o0?ooool0ooooJP3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0
oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooom[0?ooo`030000003oool0oooo
04d0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooof`0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo
0?ooo`3o0?ooool0ooooK03oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00X0oooo
000l0?ooo`030000003oool0oooo0?l0ooooo`3ooom]0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooofh0oooo00<00000
0?ooo`3oool0BP3oool00`000000oooo0?ooo`0:0?ooo`00903oool5000000<0oooo0`00000=0?oo
o`030000003oool0oooo0?l0ooooo`3ooom^0?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool02P3oool002D0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0
000000`0oooo00<000000?ooo`3oool0o`3ooooo0?ooofl0oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`0:0?ooo`009P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000303oool00`000000oooo0?ooo`3o0?ooool0ooooL03oool00`000000oooo0?ooo`18
0?ooo`030000003oool0oooo00X0oooo000W0?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooo`3ooom`0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool02P3oool002L0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo00X0oooo1P00003o0?ooool0ooooKP3oool00`000000oooo0?ooo`13
0?ooo`D00000303oool002P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0?l0ooooo`3ooomb0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool02P3oool002P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0?l0ooooo`3ooomb0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool02P3oool002P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0?l0ooooo`3ooomc0?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool02P3oool002@0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`000000303oool00`000000oooo0?ooo`3o0?ooool0ooooL`3oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo00X0oooo000U0?ooo`<00000103oool3000000d0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooog@0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0:
0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooM@3oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooome0?ooo`03
0000003oool0oooo04<0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0
o`3ooooo0?ooogH0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0:0?ooo`00?03o
ool00`000000oooo0?ooo`3o0?ooool0ooooM`3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomg0?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ogP0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000
oooo0?ooo`3o0?ooool0ooooN@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00X0
oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomi0?ooo`030000003oool0oooo03l0oooo
00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooogX0oooo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o
0?ooool0ooooN`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00X0oooo000l0?oo
o`@00000o`3ooooo0?ooogX0oooo00<000000?ooo`3oool0>P3oool4000000`0oooo000l0?ooo`03
0000003oool0oooo0?l0ooooo`3oooml0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooogd0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooO@3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0
oooo0?l0ooooo`3ooomn0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool02P3oool0
03`0oooo00<000000?ooo`3oool0o`3ooooo0?ooogl0oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooO`3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0oooo
o`3ooon00?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool02P3oool003`0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooh40oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooP@3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooon20?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooh<0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0:0?ooo`00
?03oool00`000000oooo0?ooo`3o0?ooool0ooooP`3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooon40?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo
0?ooohD0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`00
0000oooo0?ooo`3o0?ooool0ooooQ@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooon60?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool02P3oool003`0oooo1000003o0?ooool0ooooQP3oool00`000000oooo
0?ooo`0^0?ooo`@00000303oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooohL0oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o
0?ooool0ooooR03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000l0?oo
o`030000003oool0oooo0?l0ooooo`3ooon90?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooohT0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo
RP3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003o
ool0oooo0?l0ooooo`3ooon;0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02P3o
ool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooh/0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooS03oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0
ooooo`3ooon=0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02P3oool003`0oooo
00<000000?ooo`3oool0o`3ooooo0?ooohd0oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooSP3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooon?
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?oo
o`3oool0o`3ooooo0?ooohl0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0:0?oo
o`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooT03oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonA0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool02P3oool003`0oooo1000003o0?ooool0ooooT03o
ool00`000000oooo0?ooo`0T0?ooo`@00000303oool003`0oooo00<000000?ooo`3oool0o`3ooooo
0?oooi80oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`00
0000oooo0?ooo`3o0?ooool0ooooT`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonC0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooi@0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?oo
o`3o0?ooool0ooooU@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00X0oooo000l
0?ooo`030000003oool0oooo0?l0ooooo`3ooonE0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooiH0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0
ooooU`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000
003oool0oooo0?l0ooooo`3ooonG0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
2P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooiP0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooV@3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo
0?l0ooooo`3ooonI0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool02P3oool003`0
oooo00<000000?ooo`3oool0o`3ooooo0?oooiX0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooV`3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3o
oonK0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool02P3oool003`0oooo1000003o
0?ooool0ooooV`3oool00`000000oooo0?ooo`0I0?ooo`@00000303oool003`0oooo00<000000?oo
o`3oool0o`3ooooo0?oooid0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0:0?oo
o`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooW@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonN0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3o
oooo0?oooil0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool0
0`000000oooo0?ooo`3o0?ooool0ooooW`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonP0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooj40
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo
0?ooo`3o0?ooool0ooooX@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00X0oooo
000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonR0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooj<0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oo
ool0ooooX`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00X0oooo000l0?ooo`03
0000003oool0oooo0?l0ooooo`3ooonT0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool02P3oool002@0oooo1@0000020?ooo`<000003P3oool00`000000oooo0?ooo`3o0?ooool0oooo
Y@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00X0oooo000U0?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?ooool0oooo
Y@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00X0oooo000V0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?ooool0ooooYP3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00X0oooo000W0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool02P3oool600000?l0ooooo`3ooonT0?ooo`030000003oool0
oooo00d0oooo1@00000<0?ooo`009`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0o`3ooooo0?ooojL0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0:0?ooo`00:03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0o`3ooooo0?ooojP0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0:0?ooo`00:03oool00`000000oooo0?ooo`03000000h0oooo00<000000?ooo`3oool0
o`3ooooo0?ooojT0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`00:03o
ool010000000oooo0?ooo`00000@0?ooo`030000003oool0oooo0?l0ooooo`3ooonY0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool002@0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooooo0?ooojX0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`009@3oool3000000@0oooo1000
000<0?ooo`030000003oool0oooo0?l0ooooo`3ooonk0?ooo`030000003oool0oooo00X0oooo000l
0?ooo`030000003oool0oooo0?l0ooooo`3ooonk0?ooo`030000003oool0oooo00X0oooo000l0?oo
o`030000003oool0oooo0?l0ooooo`3ooonk0?ooo`030000003oool0oooo00X0oooo000l0?ooo`03
0000003oool0oooo0?l0ooooo`3ooonk0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000
003oool0oooo0?l0ooooo`3ooonk0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1/0?ooo`030000003o
ool0oooo06`0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1/0?ooo`030000003o
ool0oooo06`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0K03oool0
0`000000oooo0?ooo`1/0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0K03oool0
0`000000oooo0?ooo`1/0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02P3oool0
03`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00X0oooo000l0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0:0?ooo`00?03ooooo00000?l00000_`00000<0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 772.188}, {476.875, 0}} -> {-0.348048, -3.35676, \
0.00450128, 0.0613978}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(plwq = 
      Show[{plw02q, plw10q, plw15q, plw20q, plw25q, plw30q}, 
        Epilog \[Rule] {Text["\<s=3\>", {0.5, \(-0.75\)}], 
            Text["\<s=0.2\>", {0.1, \(-0.975\)}], 
            Text["\<s=1.0\>", {0.1, \(-0.895\)}], 
            Text["\<s=1.5\>", {0.1, \(-0.785\)}], 
            Text["\<s=2.\>", {0.1, \(-0.66\)}], 
            Text["\<s=2.5\>", {0.02, \(-0.42\)}]}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.476191 0.757258 0.742788 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.2619 -0.0125 -10.7813 -17.8125 ]
[.2619 -0.0125 10.7813 0 ]
[.5 -0.0125 -5.53125 -17.8125 ]
[.5 -0.0125 5.53125 0 ]
[.7381 -0.0125 -10.7813 -17.8125 ]
[.7381 -0.0125 10.7813 0 ]
[.97619 -0.0125 -5.53125 -17.8125 ]
[.97619 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.125 -35.625 ]
[.5 -0.0125 5.125 -17.8125 ]
[-0.0125 .01447 -20.75 -8.90625 ]
[-0.0125 .01447 0 8.90625 ]
[-0.0125 .16303 -31.25 -8.90625 ]
[-0.0125 .16303 0 8.90625 ]
[-0.0125 .31159 -31.25 -8.90625 ]
[-0.0125 .31159 0 8.90625 ]
[-0.0125 .46014 -31.25 -8.90625 ]
[-0.0125 .46014 0 8.90625 ]
[-0.0125 .6087 -31.25 -8.90625 ]
[-0.0125 .6087 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -49.0625 -14.7188 ]
[-0.01875 .30902 -31.25 14.7188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.2619 .20017 -12.7813 -8.90625 ]
[.2619 .20017 12.7813 8.90625 ]
[.07143 .03304 -18.0313 -8.90625 ]
[.07143 .03304 18.0313 8.90625 ]
[.07143 .09246 -18.0313 -8.90625 ]
[.07143 .09246 18.0313 8.90625 ]
[.07143 .17417 -18.0313 -8.90625 ]
[.07143 .17417 18.0313 8.90625 ]
[.07143 .26702 -14.5 -8.90625 ]
[.07143 .26702 14.5 8.90625 ]
[.03333 .44529 -18.0313 -8.90625 ]
[.03333 .44529 18.0313 8.90625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.125 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01447 m
.00625 .01447 L
s
gsave
-0.0125 .01447 -81.75 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .16303 m
.00625 .16303 L
s
gsave
-0.0125 .16303 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .31159 m
.00625 .31159 L
s
gsave
-0.0125 .31159 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .46014 m
.00625 .46014 L
s
gsave
-0.0125 .46014 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .6087 m
.00625 .6087 L
s
gsave
-0.0125 .6087 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05161 m
.00375 .05161 L
s
0 .08875 m
.00375 .08875 L
s
0 .12589 m
.00375 .12589 L
s
0 .20017 m
.00375 .20017 L
s
0 .23731 m
.00375 .23731 L
s
0 .27445 m
.00375 .27445 L
s
0 .34872 m
.00375 .34872 L
s
0 .38586 m
.00375 .38586 L
s
0 .423 m
.00375 .423 L
s
0 .49728 m
.00375 .49728 L
s
0 .53442 m
.00375 .53442 L
s
0 .57156 m
.00375 .57156 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -115.875 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.7188 12.9063 translate
90 rotate
-75.7188 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.063 17.500 moveto
(H) show
77.625 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.875 17.500 moveto
(L) show
88.438 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01447 m
1 .01447 L
s
.99375 .16303 m
1 .16303 L
s
.99375 .31159 m
1 .31159 L
s
.99375 .46014 m
1 .46014 L
s
.99375 .6087 m
1 .6087 L
s
.125 Mabswid
.99625 .05161 m
1 .05161 L
s
.99625 .08875 m
1 .08875 L
s
.99625 .12589 m
1 .12589 L
s
.99625 .20017 m
1 .20017 L
s
.99625 .23731 m
1 .23731 L
s
.99625 .27445 m
1 .27445 L
s
.99625 .34872 m
1 .34872 L
s
.99625 .38586 m
1 .38586 L
s
.99625 .423 m
1 .423 L
s
.99625 .49728 m
1 .49728 L
s
.99625 .53442 m
1 .53442 L
s
.99625 .57156 m
1 .57156 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01756 m
.06244 .01721 L
.10458 .01688 L
.14415 .0166 L
.18221 .01636 L
.22272 .01614 L
.26171 .01595 L
.30316 .01577 L
.34309 .01563 L
.3815 .0155 L
.42237 .01539 L
.46172 .01529 L
.49955 .01521 L
.53984 .01514 L
.57861 .01507 L
.61984 .01501 L
.65954 .01496 L
.69774 .01492 L
.73838 .01488 L
.77751 .01484 L
.81909 .01481 L
.85916 .01478 L
.89771 .01476 L
.93871 .01473 L
.97619 .01472 L
s
.02381 .09008 m
.06244 .07992 L
.10458 .07069 L
.14415 .06343 L
.18221 .05747 L
.22272 .05206 L
.26171 .0476 L
.30316 .04354 L
.34309 .04018 L
.3815 .03739 L
.42237 .03481 L
.46172 .03266 L
.49955 .03086 L
.53984 .02917 L
.57861 .02775 L
.61984 .02642 L
.65954 .0253 L
.69774 .02435 L
.73838 .02345 L
.77751 .02267 L
.81909 .02195 L
.85916 .02132 L
.89771 .02078 L
.93871 .02027 L
.97619 .01985 L
s
.02381 .17887 m
.06244 .15246 L
.10458 .13023 L
.14415 .11368 L
.18221 .10065 L
.22272 .08916 L
.26171 .0799 L
.30316 .07161 L
.34309 .06484 L
.3815 .05926 L
.42237 .05416 L
.46172 .04992 L
.49955 .04637 L
.53984 .04307 L
.57861 .04029 L
.61984 .0377 L
.65954 .03552 L
.69774 .03366 L
.73838 .03191 L
.77751 .03041 L
.81909 .02899 L
.85916 .02778 L
.89771 .02673 L
.93871 .02573 L
.97619 .02491 L
s
.02381 .29757 m
.06244 .24276 L
.10458 .20048 L
.14415 .17094 L
.18221 .14868 L
.22272 .12967 L
.26171 .11472 L
.30316 .10159 L
.34309 .09101 L
.3815 .08238 L
.42237 .07453 L
.46172 .06806 L
.49955 .06265 L
.53984 .05765 L
.57861 .05344 L
.61984 .04954 L
.65954 .04624 L
.69774 .04343 L
.73838 .04078 L
.77751 .03853 L
.81909 .03639 L
.85916 .03457 L
.89771 .03299 L
.93871 .03148 L
.97619 .03024 L
s
.02381 .43996 m
.04262 .38666 L
.06244 .34222 L
.08426 .30311 L
.10458 .27334 L
.14264 .22964 L
.18163 .19594 L
.22307 .16824 L
.263 .14706 L
.30142 .13041 L
.34228 .11572 L
.38164 .10387 L
.41947 .09417 L
.45976 .08532 L
.49853 .07798 L
.53975 .07123 L
.57946 .06558 L
.61766 .06082 L
.6583 .05637 L
.69743 .05259 L
.73901 .04905 L
.77908 .04603 L
.81763 .04343 L
.85863 .04097 L
.89812 .03885 L
.93609 .03702 L
.97619 .03527 L
s
.02381 .60332 m
.04262 .51541 L
.06244 .44596 L
.08255 .39159 L
.10458 .3447 L
.14509 .28089 L
.18408 .23679 L
.22553 .20149 L
.26546 .17501 L
.30387 .15446 L
.34474 .13651 L
.38409 .12214 L
.42192 .11043 L
.46221 .09977 L
.50098 .09096 L
.54221 .08287 L
.58192 .0761 L
.62011 .0704 L
.66075 .06506 L
.69988 .06054 L
.74147 .05628 L
.78153 .05266 L
.82008 .04955 L
.86109 .04659 L
.90057 .04404 L
.93855 .04183 L
.97619 .03985 L
s
gsave
.2619 .20017 -73.7813 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
68.500 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
84.563 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.07143 .03304 -79.0313 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
68.500 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
95.063 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.07143 .09246 -79.0313 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
68.500 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.0) show
95.063 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.07143 .17417 -79.0313 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
68.500 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
95.063 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.07143 .26702 -75.5 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
68.500 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
88.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.03333 .44529 -79.0313 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
68.500 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
95.063 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{751.438, 464.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ \(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(\
--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(-\(---\)\)\)\)\)\)\)\)\)\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)*) \[IndentingNewLine]\[IndentingNewLine] \
(*\ Find\ H \((z)\)\ for\ given\ slope\ s\ of\ the\ linear\ potential . \ 
            Present\ time\  = \ \(tt\ \((corresponds\ to\ a = 1)\) . \ 
              Run\ trials\ for\ initial\ condition\ for\ field\ fi\ \((f0)\)\ \
and\ initial\ time\ ti\ until\ we\ get\ field\ energy\ enf\  = \ \(0.7\ and\ \
H \((z = 0)\)\  = 
            1\ at\ present\ time\ \(\(tt\)\(.\)\)\)\)\ *) \[IndentingNewLine]\
\[IndentingNewLine] (*\ \(--\(--\(--\(--\ \ s\)\)\)\)\  = \ \(0.2\ \ \ --\) \
\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(---\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\ *) \
\[IndentingNewLine]\[IndentingNewLine]\(Clear[aa, fi, a, aad, aadd, fidas, 
        tas, f, rr, hht, hha];\)\), "\n", 
    \(aa = a[t]; \ fi = f[t];\), "\n", 
    \(\(aad = D[aa, t];\)\), "\n", 
    \(\(aadd = D[aa, {t, 2}];\)\), "\n", 
    \(\(fid = D[fi, t];\)\), "\n", 
    \(\(fidd = D[fi, {t, 2}];\)\n\), "\n", 
    \(ti = 0.0000017; \ t0 = 4;\), "\n", 
    \(\(f0 = 3.43;\)\ \), "\n", 
    \(om0m = 0.3; \ ss = 0.2;\), "\n", 
    \(\(eq1 = 
        aadd/aa\  \[Equal] \ 
          fid^2\ \  + \ \ ss\ fi\  - \ om0m/\((2\ aa^3)\);\)\), "\n", 
    \(\(eq2 = 
        fidd\ \  + \ \ \ 3\ \ fid\ \((aad/aa)\)\  - \ ss \[Equal] 
          0;\)\), "\n", 
    \(\(eqb1 = f[ti] == f0;\)\), "\n", 
    \(\(eqb2 = \(f'\)[ti] == 0;\)\), "\n", 
    \(\(eqb3 = 
        a[ti] \[Equal] \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((2/3)\);\)\), "\n", 
    \(\(eqb4 = \(a'\)[
            ti] \[Equal] \((2/
                3)\)\ \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((\(-1\)/
                  3)\);\)\), "\n", 
    \(\(sol2 = 
        NDSolve[{eq1, eq2, eqb1, eqb2, eqb3, eqb4}, {aa, fi}, {t, ti, t0}, 
          MaxSteps \[Rule] 10000000];\)\), "\n", 
    \(\(asol = Part[Evaluate[a[t] /. sol2], 1];\)\), "\n", 
    \(\(fsol = 
        Part[Evaluate[f[t] /. sol2], 1];\)\[IndentingNewLine]\), "\n", 
    \(\(dfsol = D[fsol, t];\)\), "\n", 
    \(\(enf = \(-0.5\)\ dfsol^2\  + \ ss\ fsol;\)\), "\n", 
    \(\(as[t1_] := asol\  /. \ t -> t1\ ;\)\), "\n", 
    \(\(tt = Part[FindRoot[as[t] == 1, {t, 0.1}], 1, 2];\)\), "\n", 
    \(\(tas[a_] := 
        Part[FindRoot[as[t] \[Equal] a, {t, 0.3}], 1, 2];\)\), "\n", 
    \(\(hht[t1_] := D[asol, t]/asol\  /. \ t -> t1\ ;\)\), "\n", 
    \(\(hha[a_] := hht[tas[a]];\)\), "\n", 
    \(\(hhz[z_] := hha[1/\((z + 1)\)];\)\), "\n", 
    \(enf\  /. \ t \[Rule] tt\), "\n", 
    \(hhz[0]\), "\[IndentingNewLine]", 
    \(\(hhzt = 
        Sqrt[\((1 - om0m)\) + om0m \((1 + z)\)^3] /. 
          om0m \[Rule] 0.3;\)\), "\[IndentingNewLine]", 
    \(\(Plot[{hhz[z], hhzt}, {z, 0, 1}];\)\), "\[IndentingNewLine]", 
    \(\(enf = \(-0.5\)\ dfsol^2\  + \ ss\ fsol;\)\), "\n", 
    \(\(ppf = \(-0.5\)\ dfsol^2\  - \ ss\ fsol;\)\), "\n", 
    \(\(wft[t1_] := ppf/enf\  /. \ t -> t1\ ;\)\ \), "\n", 
    \(\(wfa[a_] := wft[tas[a]];\)\), "\n", 
    \(\(wfz[z_] := wfa[1/\((z + 1)\)];\)\), "\n", 
    \(\(plw02p = 
        Plot[wfz[z], {z, 0, 2}, Frame \[Rule] True, PlotRange \[Rule] All, 
          FrameLabel \[Rule] {"\<z\>", "\<w(z)\>"}];\)\)}], "Input"],

Cell[BoxData[
    \(0.6901611860521968`\)], "Output"],

Cell[BoxData[
    \(1.0025028628803767`\)], "Output"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.746014 0.760729 [
[.21429 .00222 -10.7813 -17.8125 ]
[.21429 .00222 10.7813 0 ]
[.40476 .00222 -10.7813 -17.8125 ]
[.40476 .00222 10.7813 0 ]
[.59524 .00222 -10.7813 -17.8125 ]
[.59524 .00222 10.7813 0 ]
[.78571 .00222 -10.7813 -17.8125 ]
[.78571 .00222 10.7813 0 ]
[.97619 .00222 -5.53125 -17.8125 ]
[.97619 .00222 5.53125 0 ]
[.01131 .16686 -21.5625 -8.90625 ]
[.01131 .16686 0 8.90625 ]
[.01131 .31901 -21.5625 -8.90625 ]
[.01131 .31901 0 8.90625 ]
[.01131 .47115 -21.5625 -8.90625 ]
[.01131 .47115 0 8.90625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
gsave
.21429 .00222 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 .01472 m
.40476 .02097 L
s
gsave
.40476 .00222 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 .01472 m
.59524 .02097 L
s
gsave
.59524 .00222 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 .01472 m
.78571 .02097 L
s
gsave
.78571 .00222 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 .01472 m
.97619 .02097 L
s
gsave
.97619 .00222 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16686 m
.03006 .16686 L
s
gsave
.01131 .16686 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
.02381 .31901 m
.03006 .31901 L
s
gsave
.01131 .31901 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
.02381 .47115 m
.03006 .47115 L
s
gsave
.01131 .47115 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .05275 m
.02756 .05275 L
s
.02381 .09079 m
.02756 .09079 L
s
.02381 .12882 m
.02756 .12882 L
s
.02381 .2049 m
.02756 .2049 L
s
.02381 .24293 m
.02756 .24293 L
s
.02381 .28097 m
.02756 .28097 L
s
.02381 .35704 m
.02756 .35704 L
s
.02381 .39508 m
.02756 .39508 L
s
.02381 .43312 m
.02756 .43312 L
s
.02381 .50919 m
.02756 .50919 L
s
.02381 .54723 m
.02756 .54723 L
s
.02381 .58526 m
.02756 .58526 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01662 m
.06244 .03124 L
.10458 .0482 L
.14415 .06507 L
.18221 .08215 L
.22272 .10123 L
.26171 .12048 L
.30316 .14184 L
.34309 .16331 L
.3815 .18474 L
.42237 .20838 L
.46172 .23194 L
.49955 .25531 L
.53984 .28094 L
.57861 .30633 L
.61984 .33407 L
.65954 .36151 L
.69774 .38854 L
.73838 .41798 L
.77751 .44697 L
.81909 .47844 L
.85916 .50941 L
.89771 .53979 L
.93871 .5727 L
.97619 .60332 L
s
.02381 .01472 m
.06244 .02904 L
.10458 .04565 L
.14415 .06219 L
.18221 .07893 L
.22272 .09766 L
.26171 .11655 L
.30316 .13754 L
.34309 .15863 L
.3815 .17972 L
.42237 .20299 L
.46172 .22619 L
.49955 .24922 L
.53984 .2745 L
.57861 .29954 L
.61984 .32693 L
.65954 .35403 L
.69774 .38074 L
.73838 .40985 L
.77751 .43853 L
.81909 .46968 L
.85916 .50034 L
.89771 .53043 L
.93871 .56304 L
.97619 .59339 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{422.188, 260.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006V000112000`400?l00000o`00003oo`3ooonW
0?ooo`00o`3ooonW0?ooo`00o`3ooonW0?ooo`00o`3ooonW0?ooo`00o`3ooonW0?ooo`00I03oool3
000000<0oooo00@000000?ooo`3oool0oooo1@00000k0?ooo`<000000`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo03/0oooo0`0000030?ooo`030000003oool0oooo0080oooo0`00
000m0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`<00000@P3oool3000000l0oooo001S
0?ooo`050000003oool0oooo0?ooo`0000001`3oool010000000oooo0?ooo`00000j0?ooo`050000
003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0j0?ooo`050000003oool0oooo0?oo
o`0000001P3oool01@000000oooo0?ooo`3oool0000003/0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`050000003oool0oooo0?ooo`000000@P3oool00`000000oooo0?ooo`0>0?ooo`00H`3o
ool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0>P3oool01@000000oooo
0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0>P3oool01@000000oooo0?ooo`3oool00000
00H0oooo00D000000?ooo`3oool0oooo0000000k0?ooo`050000003oool0oooo0?ooo`0000001P3o
ool01@000000oooo0?ooo`3oool000000480oooo00<000000?ooo`3oool03P3oool006<0oooo00D0
00000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo03T0oooo00D000000?ooo`3oool0
oooo000000050?ooo`H00000>`3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?oo
o`3oool0oooo0000000k0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?oo
o`3oool000000480oooo00<000000?ooo`3oool03P3oool006<0oooo00D000000?ooo`3oool0oooo
000000090?ooo`030000003oool0oooo03T0oooo00D000000?ooo`3oool0oooo000000050?ooo`05
0000003oool0oooo0?ooo`000000?03oool01@000000oooo0?ooo`3oool0000000H0oooo00D00000
0?ooo`3oool0oooo0000000k0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo
000000130?ooo`030000003oool0oooo00h0oooo001S0?ooo`050000003oool0oooo0?ooo`000000
2P3oool00`000000oooo0?ooo`0h0?ooo`050000003oool0oooo0?ooo`0000001P3oool010000000
oooo0?ooo`00000l0?ooo`050000003oool0oooo0?ooo`0000001P3oool200000080oooo00<00000
0?ooo`3oool0>@3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0>0?ooo`00H`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<0
00000?ooo`3oool0>03oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`000000
?03oool01@000000oooo0?ooo`3oool0000000H0oooo00@000000?ooo`0000000000?03oool01@00
0000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`000000@`3oool00`000000oooo0?ooo`0>
0?ooo`00H`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0>03oool0
1@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`000000?03oool01@000000oooo0?oo
o`3oool0000000L0oooo00<000000?ooo`3oool0?03oool01@000000oooo0?ooo`3oool0000000H0
oooo00D000000?ooo`3oool0oooo000000120?ooo`030000003oool0oooo00h0oooo001S0?ooo`05
0000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000003X0oooo00D00000
0?ooo`3oool0oooo000000080?ooo`800000?03oool01@000000oooo0?ooo`3oool0000000P0oooo
00<000000?ooo`3oool0>`3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3o
ool0oooo000000110?ooo`800000403oool006@0oooo0`0000080?ooo`<00000?03oool3000000X0
oooo00<000000?ooo`3oool0>`3oool3000000X0oooo0P00000l0?ooo`<00000203oool3000004<0
oooo00<000000?ooo`3oool03P3oool00?l0ooooY`3oool00?l0ooooY`3oool001l0oooo00<00000
0?ooo`3oool0o`3ooon50?ooo`007`3oool00`000000oooo0?ooo`3o0?ooohD0oooo000O0?ooo`03
0000003oool0oooo0?l0ooooQ@3oool001l0oooo00<000000?ooo`3oool0o`3ooon50?ooo`007`3o
ool00`000000oooo0?ooo`3o0?ooohD0oooo000F0?ooool00000R`0000060?ooo`007`3oool40000
00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000
oooo00000004000000`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0=0?ooo`00
7`3oool010000000oooo0?ooo`3oool600000440oooo00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`040?ooo`D00000o`3oooml0?ooo`007`3o
ool00`000000oooo0?ooo`070?ooo`D00000o`3ooomi0?ooo`007`3oool00`000000oooo0?ooo`09
0?ooo`H00000o`3ooomf0?ooo`007`3oool00`000000oooo0?ooo`0<0?ooo`D00000o`3ooomd0?oo
o`007`3oool00`000000oooo0?ooo`0?0?ooo`D00000o`3oooma0?ooo`007`3oool00`000000oooo
0?ooo`0A0?ooo`H00000o`3ooom^0?ooo`007`3oool00`000000oooo0?ooo`0D0?ooo`D00000o`3o
oom/0?ooo`007`3oool00`000000oooo0?ooo`0G0?ooo`D00000o`3ooomY0?ooo`007`3oool00`00
0000oooo0?ooo`0I0?ooo`H00000o`3ooomV0?ooo`007`3oool00`000000oooo0?ooo`0L0?ooo`D0
0000o`3ooomT0?ooo`007`3oool00`000000oooo0?ooo`0O0?ooo`@00000o`3ooomR0?ooo`007`3o
ool300000240oooo1000003o0?ooof00oooo000O0?ooo`030000003oool0oooo02<0oooo1@00003o
0?oooed0oooo000O0?ooo`030000003oool0oooo02D0oooo1@00003o0?oooe/0oooo000O0?ooo`03
0000003oool0oooo02P0oooo1000003o0?oooeT0oooo000O0?ooo`030000003oool0oooo02X0oooo
1@00003o0?oooeH0oooo000O0?ooo`030000003oool0oooo02`0oooo1@00003o0?oooe@0oooo000O
0?ooo`030000003oool0oooo02l0oooo1000003o0?oooe80oooo000O0?ooo`030000003oool0oooo
0340oooo1000003o0?oooe00oooo000O0?ooo`030000003oool0oooo03<0oooo1000003o0?ooodh0
oooo000O0?ooo`030000003oool0oooo03D0oooo1000003o0?oood`0oooo000O0?ooo`030000003o
ool0oooo03L0oooo1000003o0?ooodX0oooo000O0?ooo`030000003oool0oooo03T0oooo1@00003o
0?ooodL0oooo000O0?ooo`030000003oool0oooo03/0oooo1@00003o0?ooodD0oooo000O0?ooo`03
0000003oool0oooo03h0oooo1000003o0?oood<0oooo000O0?ooo`030000003oool0oooo0400oooo
1000003o0?oood40oooo000O0?ooo`<00000@P3oool500000?l0oooo?P3oool001l0oooo00<00000
0?ooo`3oool0A03oool500000?l0oooo?03oool001l0oooo00<000000?ooo`3oool0A`3oool40000
0?l0oooo>P3oool001l0oooo00<000000?ooo`3oool0B@3oool500000?l0oooo=`3oool001l0oooo
00<000000?ooo`3oool0B`3oool2000000030?ooo`00000000000?l0oooo=@3oool001l0oooo00<0
00000?ooo`3oool0C@3oool2000000030?ooo`00000000000?l0oooo<`3oool001l0oooo00<00000
0?ooo`3oool0C`3oool2000000030?ooo`00000000000?l0oooo<@3oool001l0oooo00<000000?oo
o`3oool0D@3oool2000000030?ooo`00000000000?l0oooo;`3oool001l0oooo00<000000?ooo`3o
ool0D`3oool2000000030?ooo`00000000000?l0oooo;@3oool001l0oooo00<000000?ooo`3oool0
E@3oool2000000030?ooo`00000000000?l0oooo:`3oool001l0oooo00<000000?ooo`3oool0E`3o
ool2000000030?ooo`00000000000?l0oooo:@3oool001l0oooo00<000000?ooo`3oool0F@3oool2
000000030?ooo`00000000000?l0oooo9`3oool001l0oooo00<000000?ooo`3oool0F`3oool00`00
0000oooo0?ooo`0200000?l0oooo9@3oool001l0oooo00<000000?ooo`3oool0G03oool200000080
oooo0P00003o0?ooob<0oooo000O0?ooo`030000003oool0oooo05h0oooo0P0000020?ooo`030000
003oool0oooo0?l0oooo803oool001l0oooo0`00001P0?ooo`80000000<0oooo000000000000o`3o
oolP0?ooo`007`3oool00`000000oooo0?ooo`1R0?ooo`80000000<0oooo000000000000o`3ooolN
0?ooo`007`3oool00`000000oooo0?ooo`1T0?ooo`80000000<0oooo000000000000o`3ooolL0?oo
o`007`3oool00`000000oooo0?ooo`1V0?ooo`80000000<0oooo000000000000o`3ooolJ0?ooo`00
7`3oool00`000000oooo0?ooo`1X0?ooo`80000000<0oooo0000003oool0o`3ooolH0?ooo`007`3o
ool00`000000oooo0?ooo`1Z0?ooo`@00000o`3ooolG0?ooo`007`3oool00`000000oooo0?ooo`1/
0?ooo`@00000o`3ooolE0?ooo`007`3oool00`000000oooo0?ooo`1^0?ooo`@00000o`3ooolC0?oo
o`007`3oool00`000000oooo0?ooo`1`0?ooo`@00000o`3ooolA0?ooo`007`3oool00`000000oooo
0?ooo`1b0?ooo`040000003oool0000000000?l0oooo3`3oool001l0oooo00<000000?ooo`3oool0
L`3oool2000000030?ooo`00000000000?l0oooo3@3oool001l0oooo00<000000?ooo`3oool0M@3o
ool2000000030?ooo`00000000000?l0oooo2`3oool000T0oooo0`0000030?ooo`040000003oool0
oooo0?ooo`D000001`3oool00`000000oooo0?ooo`1g0?ooo`80000000<0oooo000000000000o`3o
ool90?ooo`002P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000L0oooo00<0
00000?ooo`3oool0N@3oool2000000030?ooo`00000000000?l0oooo1`3oool000X0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo07/0oooo00<00000
0?ooo`3oool00P00003o0?ooo`D0oooo000:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01P3oool4000007/0oooo0P0000020?ooo`800000o`3oool30?ooo`002P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0OP3oool200000080
oooo0P00003o0?ooo`40oooo000:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`200?ooo`8000000P3oool200000?h0oooo000:0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`220?ooo`8000000P3o
ool200000?`0oooo000:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`240?ooo`8000000P3oool200000?X0oooo00090?ooo`800000203oool01@00
0000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0QP3oool200000080oooo00<00000
0?ooo`3oool0m`3oool000X0oooo00<000000?ooo`3oool01`3oool3000000P0oooo00<000000?oo
o`3oool0R03oool2000000030?ooo`00000000000?L0oooo000O0?ooo`030000003oool0oooo08X0
oooo00<000000?ooo`3oool00P00003e0?ooo`007`3oool00`000000oooo0?ooo`2;0?ooo`800000
0P3oool200000?<0oooo000O0?ooo`030000003oool0oooo08d0oooo0P0000020?ooo`030000003o
ool0oooo0?00oooo000O0?ooo`030000003oool0oooo08l0oooo0P0000000`3oool000000000003`
0?ooo`007`3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo00800000kP3oool001l0
oooo00<000000?ooo`3oool0TP3oool200000080oooo0P00003/0?ooo`007`3oool00`000000oooo
0?ooo`2D0?ooo`8000000P3oool200000>X0oooo000O0?ooo`030000003oool0oooo09H0oooo0P00
00020?ooo`030000003oool0oooo0>L0oooo000O0?ooo`<00000V03oool2000000030?ooo`000000
00000>L0oooo000O0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool00P00003U0?oo
o`007`3oool00`000000oooo0?ooo`2K0?ooo`8000000P3oool200000><0oooo000O0?ooo`030000
003oool0oooo09d0oooo00D000000?ooo`3oool0oooo0000003R0?ooo`007`3oool00`000000oooo
0?ooo`2N0?ooo`8000000P3oool200000>00oooo000O0?ooo`030000003oool0oooo0:00oooo0P00
00020?ooo`800000gP3oool001l0oooo00<000000?ooo`3oool0XP3oool010000000oooo0?ooo`3o
ool200000=`0oooo000O0?ooo`030000003oool0oooo0:<0oooo0P0000030?ooo`800000fP3oool0
01l0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0=L0oooo000O0?ooo`030000003oool0oooo0:H0oooo0P0000030?ooo`800000e`3oool001l0oooo
00<000000?ooo`3oool0Z03oool2000000<0oooo00<000000?ooo`3oool0e03oool001l0oooo00<0
00000?ooo`3oool0ZP3oool010000000oooo0?ooo`3oool200000=@0oooo000O0?ooo`030000003o
ool0oooo0:/0oooo0P0000030?ooo`030000003oool0oooo0=40oooo000O0?ooo`030000003oool0
oooo0:d0oooo00@000000?ooo`3oool0oooo0P00003A0?ooo`007`3oool00`000000oooo0?ooo`2^
0?ooo`8000000`3oool200000<l0oooo000O0?ooo`<00000/03oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0<`0oooo000O0?ooo`030000003oool0oooo0;40oooo0P0000030?ooo`80
0000c03oool001l0oooo00<000000?ooo`3oool0/`3oool2000000<0oooo00<000000?ooo`3oool0
b@3oool001l0oooo00<000000?ooo`3oool0]@3oool010000000oooo0?ooo`3oool200000<T0oooo
000O0?ooo`030000003oool0oooo0;H0oooo0P0000030?ooo`030000003oool0oooo0<H0oooo000O
0?ooo`030000003oool0oooo0;P0oooo00@000000?ooo`3oool0oooo0P0000360?ooo`007`3oool0
0`000000oooo0?ooo`2i0?ooo`8000000`3oool200000<@0oooo000O0?ooo`030000003oool0oooo
0;/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`310?ooo`007`3oool00`000000
oooo0?ooo`2l0?ooo`8000000`3oool200000<40oooo000O0?ooo`030000003oool0oooo0;h0oooo
0P0000030?ooo`030000003oool0oooo0;h0oooo000O0?ooo`030000003oool0oooo0<00oooo00@0
00000?ooo`3oool0oooo0P00002n0?ooo`007`3oool00`000000oooo0?ooo`310?ooo`8000000`3o
ool200000;`0oooo000O0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`2i0?ooo`007`3oool00`000000oooo0?ooo`340?ooo`8000000`3oool20000
0;T0oooo000O0?ooo`030000003oool0oooo0<H0oooo0P0000030?ooo`030000003oool0oooo0;H0
oooo000O0?ooo`<00000b03oool010000000oooo0?ooo`3oool200000;H0oooo000O0?ooo`030000
003oool0oooo0<T0oooo0P0000030?ooo`800000]03oool001l0oooo00<000000?ooo`3oool0b`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0;40oooo000O0?ooo`030000003oool0
oooo0<`0oooo0P0000030?ooo`800000/@3oool001l0oooo00<000000?ooo`3oool0cP3oool20000
00<0oooo00<000000?ooo`3oool0[P3oool001l0oooo00<000000?ooo`3oool0d03oool010000000
oooo0?ooo`3oool200000:h0oooo000O0?ooo`030000003oool0oooo0=40oooo0P0000030?ooo`80
0000[03oool001l0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0:T0oooo000O0?ooo`030000003oool0oooo0=@0oooo0P0000030?ooo`800000Z@3o
ool001l0oooo00<000000?ooo`3oool0eP3oool2000000<0oooo00<000000?ooo`3oool0YP3oool0
01l0oooo00<000000?ooo`3oool0f03oool010000000oooo0?ooo`3oool200000:H0oooo00090?oo
o`<000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0f@3oool2000000<0oooo00<000000?ooo`3oool0X`3oool000X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0=/0oooo00D000000?ooo`3o
ool0oooo0000002T0?ooo`002P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0g03oool200000080oooo0P00002R0?ooo`002P3oool00`000000oooo
0?ooo`050?ooo`H000001`3oool00`000000oooo0?ooo`3N0?ooo`050000003oool0oooo0?ooo`00
0000X@3oool000X0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000P0
oooo1000003N0?ooo`040000003oool0oooo0?ooo`800000W`3oool000X0oooo00<000000?ooo`3o
ool01P3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo0>00oooo0P0000030?oo
o`030000003oool0oooo09`0oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`00
0000203oool00`000000oooo0?ooo`3R0?ooo`040000003oool0oooo0?ooo`800000W03oool000X0
oooo00<000000?ooo`3oool01`3oool00`000000oooo000000080?ooo`030000003oool0oooo0><0
oooo0P0000030?ooo`030000003oool0oooo09T0oooo00090?ooo`8000002P3oool2000000P0oooo
00<000000?ooo`3oool0i@3oool010000000oooo0?ooo`3oool2000009T0oooo000:0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3V0?ooo`800000
0`3oool00`000000oooo0?ooo`2F0?ooo`007`3oool00`000000oooo0?ooo`3X0?ooo`050000003o
ool0oooo0?ooo`000000U`3oool001l0oooo00<000000?ooo`3oool0j@3oool200000080oooo0P00
002E0?ooo`007`3oool00`000000oooo0?ooo`3[0?ooo`050000003oool0oooo0?ooo`000000U03o
ool001l0oooo00<000000?ooo`3oool0k03oool01@000000oooo0?ooo`3oool0000009<0oooo000O
0?ooo`030000003oool0oooo0>d0oooo0P0000020?ooo`800000T@3oool001l0oooo00<000000?oo
o`3oool0k`3oool01@000000oooo0?ooo`3oool000000900oooo000O0?ooo`030000003oool0oooo
0?00oooo00D000000?ooo`3oool0oooo0000002?0?ooo`007`3oool00`000000oooo0?ooo`3a0?oo
o`8000000P3oool2000008d0oooo000O0?ooo`030000003oool0oooo0?<0oooo00D000000?ooo`3o
ool0oooo0000002<0?ooo`007`3oool300000?@0oooo00@000000?ooo`3oool0oooo0P00002:0?oo
o`007`3oool00`000000oooo0?ooo`3e0?ooo`8000000`3oool00`000000oooo0?ooo`270?ooo`00
7`3oool00`000000oooo0?ooo`3g0?ooo`040000003oool0oooo0?ooo`800000Q`3oool001l0oooo
00<000000?ooo`3oool0n03oool2000000<0oooo00<000000?ooo`3oool0Q03oool001l0oooo00<0
00000?ooo`3oool0nP3oool010000000oooo0?ooo`3oool2000008@0oooo000O0?ooo`030000003o
ool0oooo0?/0oooo0P0000030?ooo`030000003oool0oooo0840oooo000O0?ooo`030000003oool0
oooo0?d0oooo00@000000?ooo`3oool0oooo0P0000210?ooo`007`3oool00`000000oooo0?ooo`3n
0?ooo`8000000`3oool00`000000oooo0?ooo`1n0?ooo`007`3oool00`000000oooo0?ooo`3o0?oo
o`40oooo00@000000?ooo`3oool0oooo0P00001n0?ooo`007`3oool00`000000oooo0?ooo`3o0?oo
o`80oooo0P0000030?ooo`030000003oool0oooo07/0oooo000O0?ooo`030000003oool0oooo0?l0
oooo103oool01@000000oooo0?ooo`3oool0000007`0oooo000O0?ooo`030000003oool0oooo0?l0
oooo1@3oool200000080oooo0P00001j0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooo`L0oooo
00D000000?ooo`3oool0oooo0000001i0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooo`P0oooo
00D000000?ooo`3oool0oooo0000001h0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooo`T0oooo
0P0000020?ooo`800000MP3oool001l0oooo0`00003o0?ooo`/0oooo00D000000?ooo`3oool0oooo
0000001e0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooo``0oooo00D000000?ooo`3oool0oooo
0000001d0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooo`d0oooo0P0000020?ooo`800000LP3o
ool001l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`050000003oool0oooo0?ooo`000000L@3o
ool001l0oooo00<000000?ooo`3oool0o`3oool@0?ooo`050000003oool0oooo0?ooo`000000L03o
ool001l0oooo00<000000?ooo`3oool0o`3ooolA0?ooo`8000000P3oool2000006h0oooo000O0?oo
o`030000003oool0oooo0?l0oooo4`3oool01@000000oooo0?ooo`3oool0000006d0oooo000O0?oo
o`030000003oool0oooo0?l0oooo503oool010000000oooo0?ooo`3oool2000006/0oooo000O0?oo
o`030000003oool0oooo0?l0oooo5@3oool2000000<0oooo00<000000?ooo`3oool0J03oool001l0
oooo00<000000?ooo`3oool0o`3ooolG0?ooo`040000003oool0oooo0?ooo`800000J03oool001l0
oooo00<000000?ooo`3oool0o`3ooolH0?ooo`8000000`3oool00`000000oooo0?ooo`1U0?ooo`00
7`3oool00`000000oooo0?ooo`3o0?oooaX0oooo00D000000?ooo`3oool0oooo0000001V0?ooo`00
7`3oool00`000000oooo0?ooo`3o0?oooa/0oooo0P0000020?ooo`800000I03oool001l0oooo00<0
00000?ooo`3oool0o`3ooolM0?ooo`050000003oool0oooo0?ooo`000000H`3oool001l0oooo00<0
00000?ooo`3oool0o`3ooolN0?ooo`040000003oool0oooo0?ooo`800000H@3oool001l0oooo0`00
003o0?oooal0oooo0P0000030?ooo`030000003oool0oooo05h0oooo000O0?ooo`030000003oool0
oooo0?l0oooo8@3oool010000000oooo0?ooo`3oool2000005h0oooo000O0?ooo`030000003oool0
oooo0?l0oooo8P3oool2000000<0oooo00<000000?ooo`3oool0F`3oool001l0oooo00<000000?oo
o`3oool0o`3ooolT0?ooo`050000003oool0oooo0?ooo`000000G03oool001l0oooo00<000000?oo
o`3oool0o`3ooolU0?ooo`8000000P3oool2000005X0oooo000O0?ooo`030000003oool0oooo0?l0
oooo9`3oool01@000000oooo0?ooo`3oool0000005T0oooo000O0?ooo`030000003oool0oooo0?l0
oooo:03oool01@000000oooo0?ooo`3oool0000005P0oooo000O0?ooo`030000003oool0oooo0?l0
oooo:@3oool200000080oooo0P00001F0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooob/0oooo
00D000000?ooo`3oool0oooo0000001E0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooob`0oooo
00D000000?ooo`3oool0oooo0000001D0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooobd0oooo
00@000000?ooo`3oool0oooo0P00001B0?ooo`002@3oool3000000<0oooo00<000000?ooo`3oool0
0P3oool3000000P0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0C`3oool000X0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?oo
o`3oool0000000L0oooo00<000000?ooo`3oool0o`3oool_0?ooo`8000000`3oool00`000000oooo
0?ooo`1>0?ooo`002P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000
1`3oool00`000000oooo0?ooo`3o0?oooc40oooo00@000000?ooo`3oool0oooo0P00001>0?ooo`00
2P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000
oooo0?ooo`3o0?oooc80oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1;0?ooo`00
2P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000001`3oool400000?l0
oooo<P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04X0oooo000:0?ooo`030000
003oool0oooo00H0oooo0P0000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
o`3ooold0?ooo`8000000`3oool2000004X0oooo000:0?ooo`030000003oool0oooo00H0oooo00@0
00000?ooo`0000000000203oool00`000000oooo0?ooo`3o0?ooocH0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`170?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0o`3ooolg0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0AP3oool000T0oooo0P00000:0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo0080oooo0P0000160?ooo`002P3oool00`00
0000oooo0?ooo`090?ooo`8000001`3oool00`000000oooo0?ooo`3o0?ooocT0oooo0P0000040?oo
o`030000003oool0oooo04<0oooo000O0?ooo`030000003oool0oooo0?l0oooo>`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0480oooo000O0?ooo`030000003oool0oooo0?l0oooo
?03oool00`000000oooo0?ooo`020?ooo`800000@P3oool001l0oooo00<000000?ooo`3oool0o`3o
oolm0?ooo`800000103oool00`000000oooo0?ooo`0o0?ooo`007`3oool00`000000oooo0?ooo`3o
0?ooocl0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0n0?ooo`007`3oool00`00
0000oooo0?ooo`3o0?oood00oooo00<000000?ooo`3oool00P3oool2000003h0oooo000O0?ooo`03
0000003oool0oooo0?l0oooo@@3oool2000000@0oooo00<000000?ooo`3oool0>`3oool001l0oooo
00<000000?ooo`3oool0o`3ooom30?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
>P3oool001l0oooo00<000000?ooo`3oool0o`3ooom40?ooo`030000003oool0oooo0080oooo0P00
000j0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooodD0oooo0P0000040?ooo`030000003oool0
oooo03L0oooo000O0?ooo`<00000o`3ooom70?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0=P3oool001l0oooo00<000000?ooo`3oool0o`3ooom80?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0=@3oool001l0oooo00<000000?ooo`3oool0o`3ooom90?ooo`800000
0`3oool2000003D0oooo000O0?ooo`030000003oool0oooo0?l0ooooB`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0380oooo000O0?ooo`030000003oool0oooo0?l0ooooC03oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0340oooo000O0?ooo`030000003oool0oooo
0?l0ooooC@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0300oooo000O0?ooo`03
0000003oool0oooo0?l0ooooCP3oool2000000<0oooo0P00000`0?ooo`007`3oool00`000000oooo
0?ooo`3o0?oooe00oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0]0?ooo`007`3o
ool00`000000oooo0?ooo`3o0?oooe40oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0/0?ooo`007`3oool00`000000oooo0?ooo`3o0?oooe80oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0[0?ooo`007`3oool00`000000oooo0?ooo`3o0?oooe<0oooo0P0000030?oo
o`800000:`3oool001l0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0:03oool001l0oooo00<000000?ooo`3oool0o`3ooomF0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool09`3oool001l0oooo00<000000?ooo`3oool0o`3o
oomG0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09P3oool001l0oooo00<00000
0?ooo`3oool0o`3ooomH0?ooo`8000000`3oool00`000000oooo0?ooo`0U0?ooo`007`3oool30000
0?l0ooooFP3oool010000000oooo0?ooo`3oool2000002D0oooo000O0?ooo`030000003oool0oooo
0?l0ooooF`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo000O0?ooo`03
0000003oool0oooo0?l0ooooG03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0240
oooo000O0?ooo`030000003oool0oooo0?l0ooooG@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0200oooo000O0?ooo`030000003oool0oooo0?l0ooooGP3oool2000000<0oooo0P00
000P0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooof00oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0M0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooof40oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0L0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooof80
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0K0?ooo`007`3oool00`000000oooo
0?ooo`3o0?ooof<0oooo0P0000030?ooo`8000006`3oool001l0oooo00<000000?ooo`3oool0o`3o
oomU0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool001l0oooo00<00000
0?ooo`3oool0o`3ooomV0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool0
01l0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool05P3oool001l0oooo00<000000?ooo`3oool0o`3ooomX0?ooo`8000000`3oool2000001H0
oooo000O0?ooo`030000003oool0oooo0?l0ooooJP3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01<0oooo000O0?ooo`030000003oool0oooo0?l0ooooJ`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0180oooo000O0?ooo`<00000o`3ooom/0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool04@3oool001l0oooo00<000000?ooo`3oool0o`3ooom]0?oo
o`8000000`3oool200000140oooo000O0?ooo`030000003oool0oooo0?l0ooooK`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo0?l0oooo
L03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003o
ool0oooo0?l0ooooL@3oool00`000000oooo0?ooo`0A0?ooo`007`3oool00`000000oooo0?ooo`3o
0?ooog80oooo0P00000A0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooog@0oooo00<000000?oo
o`3oool03P3oool001l0oooo00<000000?ooo`3oool0o`3ooome0?ooo`030000003oool0oooo00d0
oooo000O0?ooo`030000003oool0oooo0?l0ooooQ@3oool001l0oooo00<000000?ooo`3oool0o`3o
oon50?ooo`007`3oool00`000000oooo0?ooo`3o0?ooohD0oooo000O0?ooo`030000003oool0oooo
0?l0ooooQ@3oool001l0oooo00<000000?ooo`3oool0o`3ooon50?ooo`00\
\>"],
  ImageRangeCache->{{{0, 421.188}, {259.938, 0}} -> {-0.0852553, 0.924018, \
0.00267055, 0.00334335}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.476191 153.907 153.253 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.2619 -0.0125 -10.7813 -17.8125 ]
[.2619 -0.0125 10.7813 0 ]
[.5 -0.0125 -5.53125 -17.8125 ]
[.5 -0.0125 5.53125 0 ]
[.7381 -0.0125 -10.7813 -17.8125 ]
[.7381 -0.0125 10.7813 0 ]
[.97619 -0.0125 -5.53125 -17.8125 ]
[.97619 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.125 -35.625 ]
[.5 -0.0125 5.125 -17.8125 ]
[-0.0125 .0415 -45.375 -8.90625 ]
[-0.0125 .0415 0 8.90625 ]
[-0.0125 .19475 -45.375 -8.90625 ]
[-0.0125 .19475 0 8.90625 ]
[-0.0125 .348 -45.375 -8.90625 ]
[-0.0125 .348 0 8.90625 ]
[-0.0125 .50126 -45.375 -8.90625 ]
[-0.0125 .50126 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -63.1875 -14.7188 ]
[-0.01875 .30902 -45.375 14.7188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.125 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0415 m
.00625 .0415 L
s
gsave
-0.0125 .0415 -106.375 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.004) show
1.000 setlinewidth
grestore
0 .19475 m
.00625 .19475 L
s
gsave
-0.0125 .19475 -106.375 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.003) show
1.000 setlinewidth
grestore
0 .348 m
.00625 .348 L
s
gsave
-0.0125 .348 -106.375 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.002) show
1.000 setlinewidth
grestore
0 .50126 m
.00625 .50126 L
s
gsave
-0.0125 .50126 -106.375 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.001) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .07215 m
.00375 .07215 L
s
0 .1028 m
.00375 .1028 L
s
0 .13345 m
.00375 .13345 L
s
0 .1641 m
.00375 .1641 L
s
0 .2254 m
.00375 .2254 L
s
0 .25605 m
.00375 .25605 L
s
0 .2867 m
.00375 .2867 L
s
0 .31735 m
.00375 .31735 L
s
0 .37865 m
.00375 .37865 L
s
0 .4093 m
.00375 .4093 L
s
0 .43996 m
.00375 .43996 L
s
0 .47061 m
.00375 .47061 L
s
0 .01085 m
.00375 .01085 L
s
0 .53191 m
.00375 .53191 L
s
0 .56256 m
.00375 .56256 L
s
0 .59321 m
.00375 .59321 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -130 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.7188 12.9063 translate
90 rotate
-75.7188 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.063 17.500 moveto
(H) show
77.625 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.875 17.500 moveto
(L) show
88.438 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0415 m
1 .0415 L
s
.99375 .19475 m
1 .19475 L
s
.99375 .348 m
1 .348 L
s
.99375 .50126 m
1 .50126 L
s
.125 Mabswid
.99625 .07215 m
1 .07215 L
s
.99625 .1028 m
1 .1028 L
s
.99625 .13345 m
1 .13345 L
s
.99625 .1641 m
1 .1641 L
s
.99625 .2254 m
1 .2254 L
s
.99625 .25605 m
1 .25605 L
s
.99625 .2867 m
1 .2867 L
s
.99625 .31735 m
1 .31735 L
s
.99625 .37865 m
1 .37865 L
s
.99625 .4093 m
1 .4093 L
s
.99625 .43996 m
1 .43996 L
s
.99625 .47061 m
1 .47061 L
s
.99625 .01085 m
1 .01085 L
s
.99625 .53191 m
1 .53191 L
s
.99625 .56256 m
1 .56256 L
s
.99625 .59321 m
1 .59321 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.06244 .08523 L
.10458 .15453 L
.14415 .21242 L
.18221 .26182 L
.22272 .30815 L
.26171 .34721 L
.30316 .38343 L
.34309 .41378 L
.3815 .43929 L
.42237 .46299 L
.46172 .48289 L
.49955 .49971 L
.53984 .51544 L
.57861 .52874 L
.61984 .54119 L
.65954 .55174 L
.69774 .56075 L
.73838 .56926 L
.77751 .57654 L
.81909 .58342 L
.85916 .58933 L
.89771 .59443 L
.93871 .59931 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{422.188, 260.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006V000112000`400?l00000o`00003oo`3ooonW
0?ooo`00o`3ooonW0?ooo`00o`3ooonW0?ooo`00o`3ooonW0?ooo`00o`3ooonW0?ooo`00o`3ooonW
0?ooo`00lP3oool600000:h0oooo003c0?ooo`050000003oool0oooo0?ooo`000000[P3oool00?@0
oooo00<000000?ooo`3oool0[`3oool00?@0oooo00<000000?ooo`3oool0[`3oool00?D0oooo00<0
00000?ooo`3oool0[P3oool00?80oooo00D000000?ooo`3oool0oooo0000002_0?ooo`00lP3oool6
00000:h0oooo003o0?ooojL0oooo003o0?ooojL0oooo003o0?ooojL0oooo003o0?ooojL0oooo003o
0?ooojL0oooo003o0?ooojL0oooo003o0?ooojL0oooo003o0?ooojL0oooo003o0?ooojL0oooo003o
0?ooojL0oooo003o0?ooojL0oooo001<0?ooo`<00000B`3oool3000000<0oooo00@000000?ooo`3o
ool0oooo0`00001<0?ooo`<00000C03oool3000000<0oooo00@000000?ooo`3oool0oooo0`00001;
0?ooo`D000001`3oool004/0oooo00D000000?ooo`3oool0oooo000000190?ooo`050000003oool0
oooo0?ooo`0000002@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04`0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`190?ooo`040000003oool0oooo000000L0oooo
001;0?ooo`050000003oool0oooo0?ooo`000000B@3oool01@000000oooo0?ooo`3oool0000000X0
oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`070?ooo`00B`3oool01@000000oooo
0?ooo`3oool0000004T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
04X0oooo00<000000?ooo`3oool01P3oool004/0oooo00D000000?ooo`3oool0oooo000000190?oo
o`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo04`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo00H0oooo001;0?ooo`050000003oool0oooo0?ooo`000000B@3oool01@000000oooo0?ooo`3o
ool0000000T0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1<0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`050?ooo`00B`3oool0
1@000000oooo0?ooo`3oool0000004T0oooo00D000000?ooo`3oool0oooo000000060?ooo`<00000
C@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00H0oooo0`00001?0?ooo`030000
003oool0oooo00D0oooo001;0?ooo`050000003oool0oooo0?ooo`000000B@3oool01@000000oooo
0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1<0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`050?ooo`00
B`3oool01@000000oooo0?ooo`3oool0000004T0oooo00D000000?ooo`3oool0oooo000000070?oo
o`030000003oool0oooo04/0oooo0P00001=0?ooo`8000002@3oool00`000000oooo0?ooo`1:0?oo
o`050000003oool0oooo0?ooo`0000001`3oool004`0oooo0`00001;0?ooo`<00000203oool40000
04/0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`070?ooo`@00000BP3oool30000
00P0oooo003o0?ooojL0oooo003o0?ooojL0oooo003o0?ooojL0oooo003o0?ooojL0oooo003o0?oo
ojL0oooo003o0?ooojL0oooo003o0?ooojL0oooo00150?ooool00000HP00000004D0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool01P3oool100000000A@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0500oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo
0500oooo00<000000?ooo`3oool01P3oool100000000A@3oool00`000000oooo0?ooo`3o0?oooeh0
oooo0@00000004D0oooo0`00003o0?oooe`0oooo0`00000004D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`3o0?oooeD0oooo0@00000004D0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`3o0?oooe@0oooo0@00000004D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`3o0?oooe@0oooo0@00000004D0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`3o0?oooe<0oooo0@00000004D0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`3o0?oooe<0oooo0@00000004D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`3o0?oooe80oooo0@0000000240oooo0`0000030?ooo`030000003oool0oooo0080oooo0`000004
0?ooo`<000001P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0o`3ooomB0?ooo`400000000R0?ooo`030000003oool0oooo00H0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`400000000R
0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003o
ool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0o`3ooomA0?ooo`400000000G0?ooo`L00000103oool00`000000oooo0?oo
o`060?ooo`050000003oool0oooo0?ooo`0000000P3oool01P000000oooo0?ooo`3oool000000?oo
o`H000001`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooD03oool10000
00008P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`<000002`3o
ool00`000000oooo0?ooo`3o0?ooodd0oooo100000000280oooo00<000000?ooo`3oool01P3oool0
1@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooodl0
oooo0@0000000280oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000080
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0000000P0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`3o0?ooodl0oooo0@0000000280oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o
0?ooodh0oooo0@0000000240oooo0P0000080?ooo`050000003oool0oooo0?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool0000000@0oooo0P0000080?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0o`3ooom>0?ooo`400000000R0?ooo`030000003oool0oooo00L0oooo0`000004
0?ooo`<000001P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0o`3ooom=0?ooo`40000000150?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0o`3ooom=0?ooo`40000000150?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0o`3ooom<0?ooo`40000000150?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
o`3ooom<0?ooo`40000000150?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0o`3o
oom;0?ooo`40000000150?ooo`<00000403oool00`000000oooo0?ooo`3o0?ooodT0oooo0`000000
04D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?ooodX0oooo0@00000004D0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?ooodX0oooo0@00000004D0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3o0?ooodT0oooo0@00000004D0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`3o0?ooodT0oooo0@00000004D0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`3o0?ooodP0oooo0@00000004D0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`3o0?ooodL0oooo0@00000004D0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`3o0?ooodL0oooo0@00000004D0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`3o0?ooodH0oooo0@00000004D0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`3o0?ooodH0oooo0@00000004D0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`3o0?ooodD0oooo0@00000004D0oooo0`00000G0?ooo`030000003oool0oooo
0?l0oooo@P3oool300000000A@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0?l0
ooooA03oool100000000A@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0?l0oooo
@`3oool100000000A@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0oooo@P3o
ool100000000A@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0oooo@P3oool1
00000000A@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0?l0oooo@@3oool10000
0000A@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0?l0oooo@@3oool100000000
A@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0?l0oooo@03oool100000000A@3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0?l0oooo?`3oool100000000A@3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0?l0oooo?`3oool100000000A@3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo0?l0oooo?P3oool100000000A@3oool3000001h0
oooo00<000000?ooo`3oool0o`3ooolk0?ooo`<0000000150?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0o`3ooolm0?ooo`40000000150?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0o`3oooll0?ooo`40000000150?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool0o`3oooll0?ooo`40000000150?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0o`3ooolk0?ooo`40000000150?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool0o`3ooolj0?ooo`40000000150?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
o`3ooolj0?ooo`40000000150?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0o`3o
ooli0?ooo`40000000150?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0o`3ooolh
0?ooo`40000000150?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0o`3ooolh0?oo
o`40000000150?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0o`3ooolg0?ooo`40
000000150?ooo`<000009@3oool00`000000oooo0?ooo`3o0?oooc@0oooo0`00000004D0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`3o0?ooocH0oooo0@00000004D0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`3o0?ooocD0oooo0@00000004D0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`3o0?oooc@0oooo0@00000004D0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`3o0?oooc@0oooo0@00000004D0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`3o0?oooc<0oooo0@00000004D0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`3o0?oooc80oooo0@0000000240oooo0`0000030?ooo`030000003oool0
oooo0080oooo0`0000040?ooo`<000000`3oool4000000P0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`3o0?oooc80oooo0@0000000280oooo00<000000?ooo`3oool01P3oool01@00
0000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`3o0?oooc40oooo0@00
00000280oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000080oooo00D0
00000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`3o0?oooc00oooo0@00000001L0oooo1`0000040?ooo`030000003o
ool0oooo00H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`00
00001P3oool00`000000oooo0?ooo`050?ooo`<00000:`3oool00`000000oooo0?ooo`3o0?ooobd0
oooo100000000280oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000080
oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`3o0?ooobl0oooo0@0000000280oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo00000004
0?ooo`800000203oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0oooo;P3oool1
000000008P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo0?l0oooo;P3oool1000000008P3oool00`000000oooo0?ooo`06
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0?l0oooo
;@3oool1000000008@3oool2000000P0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?oo
o`3oool0;`3oool00`000000oooo0?ooo`3o0?ooob`0oooo0@0000000280oooo00<000000?ooo`3o
ool01`3oool3000000@0oooo0`0000040?ooo`<00000203oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo0?l0oooo;03oool100000000A@3oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo0?l0oooo:`3oool100000000A@3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo0?l0oooo:P3oool100000000A@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo0?l0oooo:@3oool100000000A@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
0?l0oooo:@3oool100000000A@3oool3000003<0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`<0
000000150?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`400000
00150?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`4000000015
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`40000000150?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`40000000150?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`40000000150?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`40000000150?ooo`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`40000000150?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool0o`3ooolR0?ooo`40000000150?ooo`030000003oool0oooo
03X0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`40000000150?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool0o`3ooolP0?ooo`40000000150?ooo`<00000>`3oool00`000000oooo
0?ooo`3o0?oooah0oooo0`00000004D0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`3o0?oooal0oooo0@00000004D0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`3o
0?oooah0oooo0@00000004D0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`3o0?oo
oad0oooo0@00000004D0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`3o0?oooa`0
oooo0@00000004D0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`3o0?oooa/0oooo
0@00000004D0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3o0?oooaX0oooo0@00
000000H0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`120?ooo`030000003oool0
oooo0?l0oooo6@3oool1000000001P3oool3000003`0oooo00<000000?ooo`3oool0@`3oool00`00
0000oooo0?ooo`3o0?oooaP0oooo0@00000000H0oooo00<000000?ooo`3oool00`00000i0?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool0o`3ooolG0?ooo`400000000;0?ooo`800000
>03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0?l0oooo5`3oool1000000001P3o
ool00`000000oooo0?ooo`02000003X0oooo0`0000150?ooo`030000003oool0oooo0?l0oooo503o
ool3000000001P3oool3000003`0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`3o
0?oooaD0oooo0@00000000H0oooo00<000000?ooo`3oool00`00000i0?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`400000000;0?ooo`800000>03oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo0?l0oooo4`3oool1000000001P3oool00`000000oooo
0?ooo`02000003X0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3o0?oooa80oooo
0@00000000H0oooo0`00000l0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0o`3o
oolA0?ooo`40000000060?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`3o0?oooa00oooo0@00000000D0oooo2@00000g0?ooo`030000003oool0oooo
04`0oooo00<000000?ooo`3oool0o`3oool?0?ooo`40000000040?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0?l0
oooo3P3oool1000000000`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`3o0?ooo`d0oooo0@00000000H0oooo0P00
00040?ooo`030000003oool0oooo03H0oooo0`00001?0?ooo`030000003oool0oooo0?l0oooo2P3o
ool3000000001P3oool00`000000oooo0?ooo`020?ooo`800000>03oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo0?l0oooo2`3oool1000000001P3oool00`000000oooo0?ooo`020000
00030?ooo`000000oooo03L0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`3o0?oo
o`X0oooo0@00000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo0580oooo00<000000?ooo`3oool0o`3oool90?ooo`40000000060?ooo`800000
103oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0
o`3oool90?ooo`40000000060?ooo`030000003oool0oooo0080oooo0P00000h0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool0o`3oool80?ooo`40000000150?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool0o`3oool70?ooo`40000000030?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo
0?l0oooo1P3oool100000000103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0100
oooo0`0000030?ooo`030000003oool0oooo0080oooo0`0000040?ooo`<000000`3oool5000000L0
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`3o0?ooo`D0oooo0@00000000D0oooo
2@00000D0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000070?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool0o`3oool40?ooo`400000000R0?ooo`030000003oool0oooo
00H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0o`3o
ool30?ooo`400000000G0?ooo`L00000103oool00`000000oooo0?ooo`060?ooo`050000003oool0
oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0
1P3oool3000005T0oooo00<000000?ooo`3oool0oP3oool4000000008P3oool00`000000oooo0?oo
o`060?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0?l0
oooo0@3oool1000000008P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`1K0?ooo`030000003oool0oooo0?l0oooo0@0000000280oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo00000006
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0G03oool200000?l0oooo0@000000
0280oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000080oooo00D00000
0?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0GP3o
ool00`000000oooo0?ooo`3l0?ooo`400000000Q0?ooo`800000203oool01@000000oooo0?ooo`3o
ool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`00
00001`3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0?/0oooo0@0000000280oooo
00<000000?ooo`3oool01`3oool3000000@0oooo0`0000040?ooo`<00000203oool00`000000oooo
0?ooo`1P0?ooo`030000003oool0oooo0?X0oooo0@00000004D0oooo00<000000?ooo`3oool0H@3o
ool00`000000oooo0?ooo`3i0?ooo`40000000150?ooo`030000003oool0oooo0680oooo00<00000
0?ooo`3oool0n03oool100000000A@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo
0?L0oooo0@00000004D0oooo00<000000?ooo`3oool0I03oool200000?L0oooo0@00000004D0oooo
0`00001V0?ooo`030000003oool0oooo0?80oooo0`00000004D0oooo00<000000?ooo`3oool0I`3o
ool00`000000oooo0?ooo`3c0?ooo`40000000150?ooo`030000003oool0oooo06P0oooo00<00000
0?ooo`3oool0lP3oool100000000A@3oool00`000000oooo0?ooo`1Y0?ooo`800000lP3oool10000
0000A@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0>l0oooo0@00000004D0oooo
00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`3^0?ooo`40000000150?ooo`030000003o
ool0oooo06d0oooo0P00003^0?ooo`40000000150?ooo`030000003oool0oooo06l0oooo00<00000
0?ooo`3oool0j`3oool100000000A@3oool00`000000oooo0?ooo`1`0?ooo`800000j`3oool10000
0000A@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0>P0oooo0@00000004D0oooo
00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`3W0?ooo`40000000150?ooo`<00000M03o
ool200000>D0oooo0`00000004D0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`3T
0?ooo`40000000150?ooo`030000003oool0oooo07L0oooo0P00003T0?ooo`40000000150?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool0h@3oool100000000A@3oool00`000000oooo
0?ooo`1j0?ooo`800000h@3oool100000000A@3oool00`000000oooo0?ooo`1l0?ooo`030000003o
ool0oooo0=h0oooo0@00000004D0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`3M
0?ooo`40000000150?ooo`030000003oool0oooo07h0oooo0P00003M0?ooo`40000000150?ooo`03
0000003oool0oooo0800oooo00<000000?ooo`3oool0fP3oool100000000A@3oool00`000000oooo
0?ooo`210?ooo`800000fP3oool100000000A@3oool00`000000oooo0?ooo`230?ooo`030000003o
ool0oooo0=L0oooo0@00000004D0oooo0`0000240?ooo`800000e@3oool300000000A@3oool00`00
0000oooo0?ooo`260?ooo`800000e@3oool100000000A@3oool00`000000oooo0?ooo`280?ooo`03
0000003oool0oooo0=80oooo0@00000004D0oooo00<000000?ooo`3oool0R@3oool200000=80oooo
0@00000004D0oooo00<000000?ooo`3oool0R`3oool200000=00oooo0@00000004D0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`3=0?ooo`40000000150?ooo`030000003oool0oooo
08h0oooo0P00003=0?ooo`40000000150?ooo`030000003oool0oooo0900oooo0P00003;0?ooo`40
000000150?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0b03oool100000000A@3o
ool00`000000oooo0?ooo`2C0?ooo`800000b03oool100000000A@3oool3000009D0oooo0P000034
0?ooo`<0000000150?ooo`030000003oool0oooo09L0oooo0P0000340?ooo`40000000150?ooo`03
0000003oool0oooo09T0oooo0P0000320?ooo`40000000150?ooo`030000003oool0oooo09/0oooo
0P0000300?ooo`40000000150?ooo`030000003oool0oooo09d0oooo0P00002n0?ooo`4000000015
0?ooo`030000003oool0oooo09l0oooo0P00002l0?ooo`40000000150?ooo`030000003oool0oooo
0:40oooo0P00002j0?ooo`400000000Q0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`<0
0000103oool3000000@0oooo0`0000080?ooo`030000003oool0oooo0:<0oooo0P00002h0?ooo`40
0000000R0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0:D0oooo0`00002e0?ooo`400000000R0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0:P0oooo0P00002c0?ooo`400000000G0?ooo`L00000103oool00`00
0000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2Z0?ooo`800000/@3o
ool1000000008P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01`3oool300000:`0oooo
0`00002[0?ooo`@00000000R0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0:l0oooo0`00002[0?ooo`400000000R0?ooo`030000003oool0oooo00H0oooo
00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0;80oooo0P00002Y0?ooo`400000000R0?ooo`03
0000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0;@0oooo0`00002V
0?ooo`400000000Q0?ooo`800000203oool01@000000oooo0?ooo`3oool000000080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`8000002@3oool00`000000oooo0?ooo`2g0?ooo`<00000X`3o
ool1000000008P3oool00`000000oooo0?ooo`070?ooo`<00000103oool3000000D0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`2j0?ooo`<00000X03oool100000000A@3oool00`00
0000oooo0?ooo`2m0?ooo`<00000W@3oool100000000A@3oool00`000000oooo0?ooo`300?ooo`80
0000V`3oool100000000A@3oool00`000000oooo0?ooo`320?ooo`<00000V03oool100000000A@3o
ool00`000000oooo0?ooo`350?ooo`<00000U@3oool100000000A@3oool00`000000oooo0?ooo`38
0?ooo`<00000TP3oool100000000A@3oool300000</0oooo1000002<0?ooo`<0000000150?ooo`03
0000003oool0oooo0<l0oooo0`00002;0?ooo`40000000150?ooo`030000003oool0oooo0=80oooo
100000270?ooo`40000000150?ooo`030000003oool0oooo0=H0oooo0`0000240?ooo`4000000015
0?ooo`030000003oool0oooo0=T0oooo100000200?ooo`40000000150?ooo`030000003oool0oooo
0=d0oooo0`00001m0?ooo`40000000150?ooo`030000003oool0oooo0>00oooo1000001i0?ooo`40
000000150?ooo`030000003oool0oooo0>@0oooo1000001e0?ooo`40000000150?ooo`030000003o
ool0oooo0>P0oooo1000001a0?ooo`40000000150?ooo`030000003oool0oooo0>`0oooo1000001]
0?ooo`40000000150?ooo`030000003oool0oooo0?00oooo1@00001X0?ooo`40000000150?ooo`<0
0000m@3oool500000640oooo0`00000004D0oooo00<000000?ooo`3oool0nP3oool5000005h0oooo
0@00000004D0oooo00<000000?ooo`3oool0o`3oool5000005T0oooo0@00000004D0oooo00<00000
0?ooo`3oool0o`3oool50?ooo`@00000E@3oool100000000A@3oool00`000000oooo0?ooo`3o0?oo
o`T0oooo1000001A0?ooo`40000000150?ooo`030000003oool0oooo0?l0oooo3@3oool6000004/0
oooo0@00000004D0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`P00000@`3oool100000000A@3o
ool00`000000oooo0?ooo`3o0?oooa/0oooo1`00000l0?ooo`40000000150?ooo`030000003oool0
oooo0?l0oooo8P3oool7000003D0oooo0@00000004D0oooo00<000000?ooo`3oool0o`3ooolY0?oo
o`L00000;P3oool100000000A@3oool300000?l0oooo<03oool7000002D0oooo0`00000004D0oooo
00<000000?ooo`3oool0o`3ooolg0?ooo`L00000803oool100000000A@3oool00`000000oooo0?oo
o`3o0?oooch0oooo1`00000I0?ooo`40000000150?ooo`030000003oool0oooo0?l0ooooA@3oool:
000000l0oooo0@00000004D0oooo00<000000?ooo`3oool0o`3ooom?0?ooo`L00000203oool10000
0000A@3oool00`000000oooo0?ooo`3o0?oooeh0oooo0@00000004D0oooo00<000000?ooo`3oool0
o`3ooomN0?ooo`40000000150?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0D03o
ool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0D03o
ool00`000000oooo0?ooo`060?ooo`40000000150?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo0@000000
04D0ooooo`00001R00000000o`3ooonW0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 421.188}, {259.938, 0}} -> {-0.467123, -1.00504, \
0.00597805, 1.85751*^-05}}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[{
    \( (*\ 
      Find\ chi\ square\ for\ given\ H \((z)\)\ \ *) \[IndentingNewLine]\(f[
          z_] := 1/hhz[z];\)\), "\n", 
    \(\(rr[zz_] := NIntegrate[f[z], {z, 0, zz}];\)\), "\n", 
    \(\(qq = Table[rr[zz[i]], {i, 1, ndat}];\)\)}], "Input"],

Cell[BoxData[{
    \( (*\ Construct\ marginalization\ coefficients\ \((see\ \ astro - 
              ph/0401556\  .. )\)\ *) \[IndentingNewLine]Clear[chi2fa, 
      chi2fb, chi2fc]\), "\n", 
    \(\(chi2fa = 
        Sum[\((ld[i] - 5\ Log[10, qq[\([i]\)]*\((1 + zz[i])\)])\)^2/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\n", 
    \(\(chi2fb = 
        Sum[\((ld[i] - 
                5\ Log[10, qq[\([i]\)]*\((1 + zz[i])\)])\)/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\n", 
    \(\(chi2fc = Sum[1/\((sld[i]^2)\), {i, 1, ndat}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ Construct\ function\ after\ marginalization, \ 
      find\ same\ result\ as\ with\ mb\ minimization\ *) \
\[IndentingNewLine]chi2fm = 
      chi2fa - chi2fb^2/chi2fc\), "\[IndentingNewLine]", 
    \(dchi2p02 = chi2fm - chi2l\)}], "Input"],

Cell[BoxData[
    \(177.10825752653182`\)], "Output"],

Cell[BoxData[
    \(\(-0.019113908521831036`\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ \(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(\
--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(-\(---\)\)\)\)\)\)\)\)\)\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)*) \[IndentingNewLine]\[IndentingNewLine] \
(*\ Find\ H \((z)\)\ for\ given\ slope\ s\ of\ the\ linear\ potential . \ 
            Present\ time\  = \ \(tt\ \((corresponds\ to\ a = 1)\) . \ 
              Run\ trials\ for\ initial\ condition\ for\ field\ fi\ \((f0)\)\ \
and\ initial\ time\ ti\ until\ we\ get\ field\ energy\ enf\  = \ \(0.7\ and\ \
H \((z = 0)\)\  = 
            1\ at\ present\ time\ \(\(tt\)\(.\)\)\)\)\ *) \[IndentingNewLine]\
\[IndentingNewLine] (*\ \(--\(--\(--\(--\ \ s\)\)\)\)\  = \ \(0.5\ \ \ --\) \
\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(---\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\ *) \
\[IndentingNewLine]\[IndentingNewLine]\(Clear[aa, fi, a, aad, aadd, fidas, 
        tas, f, rr, hht, hha];\)\), "\n", 
    \(aa = a[t]; \ fi = f[t];\), "\n", 
    \(\(aad = D[aa, t];\)\), "\n", 
    \(\(aadd = D[aa, {t, 2}];\)\), "\n", 
    \(\(fid = D[fi, t];\)\), "\n", 
    \(\(fidd = D[fi, {t, 2}];\)\n\), "\n", 
    \(ti = 0.0000017; \ t0 = 4;\), "\n", 
    \(\(f0 = 1.33;\)\ \), "\n", 
    \(om0m = 0.3; \ ss = 0.5;\), "\n", 
    \(\(eq1 = 
        aadd/aa\  \[Equal] \ 
          fid^2\ \  + \ \ ss\ fi\  - \ om0m/\((2\ aa^3)\);\)\), "\n", 
    \(\(eq2 = 
        fidd\ \  + \ \ \ 3\ \ fid\ \((aad/aa)\)\  - \ ss \[Equal] 
          0;\)\), "\n", 
    \(\(eqb1 = f[ti] == f0;\)\), "\n", 
    \(\(eqb2 = \(f'\)[ti] == 0;\)\), "\n", 
    \(\(eqb3 = 
        a[ti] \[Equal] \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((2/3)\);\)\), "\n", 
    \(\(eqb4 = \(a'\)[
            ti] \[Equal] \((2/
                3)\)\ \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((\(-1\)/
                  3)\);\)\), "\n", 
    \(\(sol2 = 
        NDSolve[{eq1, eq2, eqb1, eqb2, eqb3, eqb4}, {aa, fi}, {t, ti, t0}, 
          MaxSteps \[Rule] 10000000];\)\), "\n", 
    \(\(asol = Part[Evaluate[a[t] /. sol2], 1];\)\), "\n", 
    \(\(fsol = 
        Part[Evaluate[f[t] /. sol2], 1];\)\[IndentingNewLine]\), "\n", 
    \(\(dfsol = D[fsol, t];\)\), "\n", 
    \(\(enf = \(-0.5\)\ dfsol^2\  + \ ss\ fsol;\)\), "\n", 
    \(\(as[t1_] := asol\  /. \ t -> t1\ ;\)\), "\n", 
    \(\(tt = Part[FindRoot[as[t] == 1, {t, 0.1}], 1, 2];\)\), "\n", 
    \(\(tas[a_] := 
        Part[FindRoot[as[t] \[Equal] a, {t, 0.3}], 1, 2];\)\), "\n", 
    \(\(hht[t1_] := D[asol, t]/asol\  /. \ t -> t1\ ;\)\), "\n", 
    \(\(hha[a_] := hht[tas[a]];\)\), "\n", 
    \(\(hhz[z_] := hha[1/\((z + 1)\)];\)\), "\n", 
    \(enf\  /. \ t \[Rule] tt\), "\n", 
    \(hhz[0]\), "\[IndentingNewLine]", 
    \(\(hhzt = 
        Sqrt[\((1 - om0m)\) + om0m \((1 + z)\)^3] /. 
          om0m \[Rule] 0.3;\)\), "\[IndentingNewLine]", 
    \(\(Plot[{hhz[z], hhzt}, {z, 0, 1}];\)\), "\[IndentingNewLine]", 
    \(\(enf = \(-0.5\)\ dfsol^2\  + \ ss\ fsol;\)\), "\n", 
    \(\(ppf = \(-0.5\)\ dfsol^2\  - \ ss\ fsol;\)\), "\n", 
    \(\(wft[t1_] := ppf/enf\  /. \ t -> t1\ ;\)\ \), "\n", 
    \(\(wfa[a_] := wft[tas[a]];\)\), "\n", 
    \(\(wfz[z_] := wfa[1/\((z + 1)\)];\)\), "\n", 
    \(\(plw05p = 
        Plot[wfz[z], {z, 0, 2}, Frame \[Rule] True, PlotRange \[Rule] All, 
          FrameLabel \[Rule] {"\<z\>", "\<w(z)\>"}];\)\)}], "Input"],

Cell[BoxData[
    \(0.6911348111913524`\)], "Output"],

Cell[BoxData[
    \(1.002988375648715`\)], "Output"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.750776 0.765491 [
[.21429 .00222 -10.7813 -17.8125 ]
[.21429 .00222 10.7813 0 ]
[.40476 .00222 -10.7813 -17.8125 ]
[.40476 .00222 10.7813 0 ]
[.59524 .00222 -10.7813 -17.8125 ]
[.59524 .00222 10.7813 0 ]
[.78571 .00222 -10.7813 -17.8125 ]
[.78571 .00222 10.7813 0 ]
[.97619 .00222 -5.53125 -17.8125 ]
[.97619 .00222 5.53125 0 ]
[.01131 .16781 -21.5625 -8.90625 ]
[.01131 .16781 0 8.90625 ]
[.01131 .32091 -21.5625 -8.90625 ]
[.01131 .32091 0 8.90625 ]
[.01131 .47401 -21.5625 -8.90625 ]
[.01131 .47401 0 8.90625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
gsave
.21429 .00222 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 .01472 m
.40476 .02097 L
s
gsave
.40476 .00222 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 .01472 m
.59524 .02097 L
s
gsave
.59524 .00222 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 .01472 m
.78571 .02097 L
s
gsave
.78571 .00222 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 .01472 m
.97619 .02097 L
s
gsave
.97619 .00222 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16781 m
.03006 .16781 L
s
gsave
.01131 .16781 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
.02381 .32091 m
.03006 .32091 L
s
gsave
.01131 .32091 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
.02381 .47401 m
.03006 .47401 L
s
gsave
.01131 .47401 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .05299 m
.02756 .05299 L
s
.02381 .09126 m
.02756 .09126 L
s
.02381 .12954 m
.02756 .12954 L
s
.02381 .20609 m
.02756 .20609 L
s
.02381 .24436 m
.02756 .24436 L
s
.02381 .28264 m
.02756 .28264 L
s
.02381 .35919 m
.02756 .35919 L
s
.02381 .39746 m
.02756 .39746 L
s
.02381 .43574 m
.02756 .43574 L
s
.02381 .51228 m
.02756 .51228 L
s
.02381 .55056 m
.02756 .55056 L
s
.02381 .58883 m
.02756 .58883 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .017 m
.06244 .03105 L
.10458 .04748 L
.14415 .06395 L
.18221 .08071 L
.22272 .09953 L
.26171 .11858 L
.30316 .13979 L
.34309 .16116 L
.3815 .18255 L
.42237 .20618 L
.46172 .22977 L
.49955 .25318 L
.53984 .2789 L
.57861 .30439 L
.61984 .33227 L
.65954 .35985 L
.69774 .38704 L
.73838 .41667 L
.77751 .44584 L
.81909 .47754 L
.85916 .50872 L
.89771 .53932 L
.93871 .57247 L
.97619 .60332 L
s
.02381 .01472 m
.06244 .02913 L
.10458 .04584 L
.14415 .06248 L
.18221 .07934 L
.22272 .09818 L
.26171 .11719 L
.30316 .13831 L
.34309 .15954 L
.3815 .18075 L
.42237 .20417 L
.46172 .22751 L
.49955 .25069 L
.53984 .27612 L
.57861 .30133 L
.61984 .32888 L
.65954 .35615 L
.69774 .38303 L
.73838 .41233 L
.77751 .44118 L
.81909 .47253 L
.85916 .50338 L
.89771 .53365 L
.93871 .56647 L
.97619 .59701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{430.688, 266.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006^00012R000`400?l00000o`00003oo`3ooon_
0?ooo`00o`3ooon_0?ooo`00o`3ooon_0?ooo`00o`3ooon_0?ooo`00o`3ooon_0?ooo`00o`3ooon_
0?ooo`00I@3oool3000000<0oooo00@000000?ooo`3oool0oooo1@00000n0?ooo`<000000`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo0`0000030?ooo`030000003oool0
oooo0080oooo0`00000o0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`<00000A03oool3
000000h0oooo001T0?ooo`050000003oool0oooo0?ooo`0000001`3oool010000000oooo0?ooo`00
000m0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0k0?ooo`050000
003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000003d0oooo00D000000?oo
o`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`000000A03oool00`000000oooo0?oo
o`0=0?ooo`00I03oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0?@3o
ool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0>`3oool01@000000oooo
0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo0000000m0?ooo`050000003oool0oooo
0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000004@0oooo00<000000?ooo`3oool03@3o
ool006@0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo03`0oooo00D0
00000?ooo`3oool0oooo000000050?ooo`H00000?03oool01@000000oooo0?ooo`3oool0000000H0
oooo00D000000?ooo`3oool0oooo0000000m0?ooo`050000003oool0oooo0?ooo`0000001P3oool0
1@000000oooo0?ooo`3oool0000004@0oooo00<000000?ooo`3oool03@3oool006@0oooo00D00000
0?ooo`3oool0oooo000000090?ooo`030000003oool0oooo03`0oooo00D000000?ooo`3oool0oooo
000000050?ooo`050000003oool0oooo0?ooo`000000?@3oool01@000000oooo0?ooo`3oool00000
00H0oooo00D000000?ooo`3oool0oooo0000000m0?ooo`050000003oool0oooo0?ooo`0000001`3o
ool00`000000oooo000000150?ooo`030000003oool0oooo00d0oooo001T0?ooo`050000003oool0
oooo0?ooo`0000002P3oool00`000000oooo0?ooo`0k0?ooo`050000003oool0oooo0?ooo`000000
1P3oool010000000oooo0?ooo`00000m0?ooo`050000003oool0oooo0?ooo`0000001P3oool20000
0080oooo00<000000?ooo`3oool0>`3oool01@000000oooo0?ooo`3oool0000000P0oooo00<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`0=0?ooo`00I03oool01@000000oooo0?ooo`3oool0
000000X0oooo00<000000?ooo`3oool0>`3oool01@000000oooo0?ooo`3oool0000000L0oooo00<0
00000?ooo`000000?@3oool01@000000oooo0?ooo`3oool0000000H0oooo00@000000?ooo`000000
0000?P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`000000A@3oool00`00
0000oooo0?ooo`0=0?ooo`00I03oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?oo
o`3oool0>`3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`000000?@3oool0
1@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0?P3oool01@000000oooo0?oo
o`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000140?ooo`030000003oool0oooo00d0
oooo001T0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool00000
03d0oooo00D000000?ooo`3oool0oooo000000080?ooo`800000?@3oool01@000000oooo0?ooo`3o
ool0000000P0oooo00<000000?ooo`3oool0?@3oool01@000000oooo0?ooo`3oool0000000H0oooo
00D000000?ooo`3oool0oooo000000130?ooo`8000003`3oool006D0oooo0`0000080?ooo`<00000
?`3oool3000000X0oooo00<000000?ooo`3oool0?03oool3000000X0oooo0P00000n0?ooo`<00000
203oool3000004D0oooo00<000000?ooo`3oool03@3oool00?l0oooo[`3oool00200oooo00<00000
0?ooo`3oool0o`3ooon<0?ooo`00803oool00`000000oooo0?ooo`3o0?oooh`0oooo000P0?ooo`03
0000003oool0oooo0?l0ooooS03oool00200oooo00<000000?ooo`3oool0o`3ooon<0?ooo`00803o
ool00`000000oooo0?ooo`3o0?oooh`0oooo000P0?ooo`030000003oool0oooo0?l0ooooS03oool0
01H0ooooo`00002D000000D0oooo000P0?ooo`@000003`3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00d0oooo000P0?ooo`030000003oool0000000@00000303oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00d0oooo000P0?ooo`040000003oool0oooo0?ooo`D00000
@`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
BP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00d0oooo000P0?ooo`030000003o
ool0oooo00@0oooo1@00003o0?oooh<0oooo000P0?ooo`030000003oool0oooo00H0oooo1@00003o
0?oooh40oooo000P0?ooo`030000003oool0oooo00T0oooo1@00003o0?ooogh0oooo000P0?ooo`03
0000003oool0oooo00/0oooo1@00003o0?ooog`0oooo000P0?ooo`030000003oool0oooo00h0oooo
1@00003o0?ooogT0oooo000P0?ooo`030000003oool0oooo0140oooo1000003o0?ooogL0oooo000P
0?ooo`030000003oool0oooo01@0oooo0`00003o0?ooogD0oooo000P0?ooo`030000003oool0oooo
01H0oooo1000003o0?ooog80oooo000P0?ooo`030000003oool0oooo01T0oooo0`00003o0?ooog00
oooo000P0?ooo`030000003oool0oooo01`0oooo0`00003o0?ooofd0oooo000P0?ooo`030000003o
ool0oooo01l0oooo0P00003o0?ooof/0oooo000P0?ooo`030000003oool0oooo0240oooo0`00003o
0?ooofP0oooo000P0?ooo`800000903oool400000?l0ooooI@3oool00200oooo00<000000?ooo`3o
ool09@3oool400000?l0ooooH`3oool00200oooo00<000000?ooo`3oool0:03oool400000?l0oooo
H03oool00200oooo00<000000?ooo`3oool0:P3oool500000?l0ooooG@3oool00200oooo00<00000
0?ooo`3oool0;03oool500000?l0ooooF`3oool00200oooo00<000000?ooo`3oool0;`3oool40000
0?l0ooooF@3oool00200oooo00<000000?ooo`3oool0<@3oool400000?l0ooooE`3oool00200oooo
00<000000?ooo`3oool0<`3oool400000?l0ooooE@3oool00200oooo00<000000?ooo`3oool0=@3o
ool400000?l0ooooD`3oool00200oooo00<000000?ooo`3oool0=`3oool400000?l0ooooD@3oool0
0200oooo00<000000?ooo`3oool0>@3oool400000?l0ooooC`3oool00200oooo00<000000?ooo`3o
ool0>`3oool400000?l0ooooC@3oool00200oooo00<000000?ooo`3oool0?P3oool300000?l0oooo
B`3oool00200oooo00<000000?ooo`3oool0@03oool300000?l0ooooB@3oool00200oooo00<00000
0?ooo`3oool0@P3oool300000?l0ooooA`3oool00200oooo0P0000150?ooo`<00000o`3ooom50?oo
o`00803oool00`000000oooo0?ooo`170?ooo`800000o`3ooom30?ooo`00803oool00`000000oooo
0?ooo`190?ooo`800000o`3ooom10?ooo`00803oool00`000000oooo0?ooo`1;0?ooo`<00000o`3o
ooln0?ooo`00803oool00`000000oooo0?ooo`1=0?ooo`<00000o`3oooll0?ooo`00803oool00`00
0000oooo0?ooo`1?0?ooo`<00000o`3ooolj0?ooo`00803oool00`000000oooo0?ooo`1A0?ooo`<0
0000o`3ooolh0?ooo`00803oool00`000000oooo0?ooo`1C0?ooo`@00000o`3ooole0?ooo`00803o
ool00`000000oooo0?ooo`1E0?ooo`@00000o`3ooolc0?ooo`00803oool00`000000oooo0?ooo`1G
0?ooo`@00000o`3ooola0?ooo`00803oool00`000000oooo0?ooo`1I0?ooo`@00000o`3oool_0?oo
o`00803oool00`000000oooo0?ooo`1K0?ooo`@00000o`3oool]0?ooo`00803oool00`000000oooo
0?ooo`1N0?ooo`<00000o`3oool[0?ooo`00803oool00`000000oooo0?ooo`1P0?ooo`<00000o`3o
oolY0?ooo`00803oool00`000000oooo0?ooo`1R0?ooo`<00000o`3ooolW0?ooo`00803oool20000
06D0oooo0`00003o0?ooobD0oooo000P0?ooo`030000003oool0oooo06H0oooo0`00003o0?ooob<0
oooo000P0?ooo`030000003oool0oooo06P0oooo0`00003o0?ooob40oooo000P0?ooo`030000003o
ool0oooo06X0oooo0`00003o0?oooal0oooo000P0?ooo`030000003oool0oooo06`0oooo0P00003o
0?oooah0oooo000P0?ooo`030000003oool0oooo06h0oooo0P00003o0?oooa`0oooo000P0?ooo`03
0000003oool0oooo0700oooo0P00003o0?oooaX0oooo000P0?ooo`030000003oool0oooo0780oooo
0P00003o0?oooaP0oooo000P0?ooo`030000003oool0oooo07@0oooo0P00003o0?oooaH0oooo000P
0?ooo`030000003oool0oooo07D0oooo0`00003o0?oooa@0oooo000P0?ooo`030000003oool0oooo
07L0oooo0`00003o0?oooa80oooo000P0?ooo`030000003oool0oooo07T0oooo0`00003o0?oooa00
oooo00090?ooo`<000000`3oool010000000oooo0?ooo`3oool5000000P0oooo00<000000?ooo`3o
ool0N`3oool300000?l0oooo3P3oool000X0oooo00<000000?ooo`3oool01`3oool010000000oooo
0?ooo`0000080?ooo`030000003oool0oooo07d0oooo0`00003o0?ooo``0oooo000:0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1n0?ooo`@00000
o`3oool:0?ooo`002P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0P03oool300000?l0oooo2@3oool000X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`070?ooo`<00000PP3oool300000?l0oooo1`3oool000X0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08<0oooo1000003o0?oo
o`D0oooo000:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`250?ooo`<00000o`3oool40?ooo`002P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0Q`3oool300000?l0oooo0P3oool000T0oooo0P00
00080?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`280?ooo`@00000
o`3oool000X0oooo00<000000?ooo`3oool01`3oool3000000T0oooo00<000000?ooo`3oool0RP3o
ool300000?h0oooo000P0?ooo`030000003oool0oooo08`0oooo0`00003l0?ooo`00803oool00`00
0000oooo0?ooo`2=0?ooo`@00000nP3oool00200oooo00<000000?ooo`3oool0S`3oool400000?P0
oooo000P0?ooo`030000003oool0oooo0940oooo1000003f0?ooo`00803oool00`000000oooo0?oo
o`2C0?ooo`@00000m03oool00200oooo00<000000?ooo`3oool0U@3oool400000?80oooo000P0?oo
o`030000003oool0oooo09L0oooo1000003`0?ooo`00803oool00`000000oooo0?ooo`2I0?ooo`@0
0000kP3oool00200oooo00<000000?ooo`3oool0V`3oool300000>d0oooo000P0?ooo`800000WP3o
ool300000>/0oooo000P0?ooo`030000003oool0oooo09h0oooo0`00003Z0?ooo`00803oool00`00
0000oooo0?ooo`2P0?ooo`<00000j03oool00200oooo00<000000?ooo`3oool0X@3oool300000>L0
oooo000P0?ooo`030000003oool0oooo0:<0oooo0`00003U0?ooo`00803oool00`000000oooo0?oo
o`2T0?ooo`<00000i03oool00200oooo00<000000?ooo`3oool0YP3oool300000>80oooo000P0?oo
o`030000003oool0oooo0:L0oooo0`00003Q0?ooo`00803oool00`000000oooo0?ooo`2Y0?ooo`<0
0000g`3oool00200oooo00<000000?ooo`3oool0ZP3oool300000=h0oooo000P0?ooo`030000003o
ool0oooo0:`0oooo0`00003L0?ooo`00803oool00`000000oooo0?ooo`2]0?ooo`@00000fP3oool0
0200oooo00<000000?ooo`3oool0[`3oool400000=P0oooo000P0?ooo`030000003oool0oooo0;40
oooo0`00003G0?ooo`00803oool00`000000oooo0?ooo`2c0?ooo`<00000e@3oool00200oooo0P00
002e0?ooo`@00000d`3oool00200oooo00<000000?ooo`3oool0]P3oool400000=40oooo000P0?oo
o`030000003oool0oooo0;P0oooo1000003?0?ooo`00803oool00`000000oooo0?ooo`2j0?ooo`<0
0000cP3oool00200oooo00<000000?ooo`3oool0_03oool300000<`0oooo000P0?ooo`030000003o
ool0oooo0;d0oooo0`00003;0?ooo`00803oool00`000000oooo0?ooo`2o0?ooo`<00000b@3oool0
0200oooo00<000000?ooo`3oool0`03oool400000<L0oooo000P0?ooo`030000003oool0oooo0<80
oooo0`0000360?ooo`00803oool00`000000oooo0?ooo`340?ooo`<00000a03oool00200oooo00<0
00000?ooo`3oool0a@3oool300000<<0oooo000P0?ooo`030000003oool0oooo0<L0oooo0`000031
0?ooo`00803oool00`000000oooo0?ooo`380?ooo`@00000_`3oool00200oooo00<000000?ooo`3o
ool0bP3oool300000;h0oooo000P0?ooo`030000003oool0oooo0<`0oooo0`00002l0?ooo`00803o
ool00`000000oooo0?ooo`3=0?ooo`<00000^`3oool00200oooo0P00003@0?ooo`<00000^@3oool0
0200oooo00<000000?ooo`3oool0d03oool00`000000oooo0000002h0?ooo`00803oool00`000000
oooo0?ooo`3A0?ooo`@00000]P3oool00200oooo00<000000?ooo`3oool0d`3oool00`000000oooo
0000002e0?ooo`00803oool00`000000oooo0?ooo`3D0?ooo`040000003oool0000000000;<0oooo
000P0?ooo`030000003oool0oooo0=D0oooo0P0000000`3oool000000?ooo`2a0?ooo`00803oool0
0`000000oooo0?ooo`3G0?ooo`040000003oool0000000000;00oooo000P0?ooo`030000003oool0
oooo0=P0oooo00@000000?ooo`3oool00000[`3oool00200oooo00<000000?ooo`3oool0f@3oool2
000000030?ooo`00000000000:d0oooo000P0?ooo`030000003oool0oooo0=/0oooo00@000000?oo
o`3oool00000[03oool00200oooo00<000000?ooo`3oool0g03oool2000000030?ooo`0000000000
0:X0oooo000P0?ooo`030000003oool0oooo0=h0oooo00@000000?ooo`3oool00000Z@3oool000T0
oooo0`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`3O0?ooo`80000000<0oooo000000000000Y`3oool000X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0>40oooo00<000000?ooo`3oool0
0P00002U0?ooo`002P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0hP3oool200000080oooo00<000000?ooo`3oool0XP3oool000X0oooo00<00000
0?ooo`3oool01@3oool6000000P0oooo0`00003T0?ooo`80000000<0oooo000000000000XP3oool0
00X0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool0iP3oool010000000oooo0?ooo`00002Q0?ooo`002P3oool00`000000oooo0?ooo`06
0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0i`3oool2000000030?ooo`00
0000000009l0oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000002@3oool0
0`000000oooo0?ooo`3Y0?ooo`040000003oool0oooo000009h0oooo000:0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`3Z0?ooo`80000000<0oooo
000000000000W03oool000T0oooo0P00000:0?ooo`8000002@3oool00`000000oooo0?ooo`3/0?oo
o`040000003oool0oooo000009/0oooo000:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`3]0?ooo`80000000<0oooo000000000000V@3oool00200
oooo00<000000?ooo`3oool0k`3oool010000000oooo0?ooo`00002H0?ooo`00803oool00`000000
oooo0?ooo`3`0?ooo`80000000<0oooo0000003oool0UP3oool00200oooo00<000000?ooo`3oool0
lP3oool010000000oooo00000000002E0?ooo`00803oool00`000000oooo0?ooo`3c0?ooo`040000
003oool0oooo000009@0oooo000P0?ooo`030000003oool0oooo0?@0oooo0P0000000`3oool00000
0000002B0?ooo`00803oool00`000000oooo0?ooo`3f0?ooo`040000003oool0oooo00000940oooo
000P0?ooo`030000003oool0oooo0?L0oooo0P0000000`3oool000000000002?0?ooo`00803oool0
0`000000oooo0?ooo`3i0?ooo`040000003oool0oooo000008h0oooo000P0?ooo`030000003oool0
oooo0?X0oooo0P0000000`3oool000000000002<0?ooo`00803oool200000?d0oooo00@000000?oo
o`3oool00000R`3oool00200oooo00<000000?ooo`3oool0o@3oool2000000030?ooo`000000oooo
08T0oooo000P0?ooo`030000003oool0oooo0?l0oooo00@000000?ooo`0000000000R03oool00200
oooo00<000000?ooo`3oool0o`3oool10?ooo`040000003oool0oooo000008L0oooo000P0?ooo`03
0000003oool0oooo0?l0oooo0P3oool2000000030?ooo`000000oooo08D0oooo000P0?ooo`030000
003oool0oooo0?l0oooo103oool010000000oooo0000000000240?ooo`00803oool00`000000oooo
0?ooo`3o0?ooo`D0oooo00@000000?ooo`3oool00000P`3oool00200oooo00<000000?ooo`3oool0
o`3oool60?ooo`80000000<0oooo0000003oool0P@3oool00200oooo00<000000?ooo`3oool0o`3o
ool80?ooo`040000003oool0000000000800oooo000P0?ooo`030000003oool0oooo0?l0oooo2@3o
ool010000000oooo0?ooo`00001o0?ooo`00803oool00`000000oooo0?ooo`3o0?ooo`X0oooo0P00
00000`3oool000000000001m0?ooo`00803oool00`000000oooo0?ooo`3o0?ooo``0oooo00@00000
0?ooo`3oool00000O03oool00200oooo00<000000?ooo`3oool0o`3oool=0?ooo`80000000<0oooo
0000003oool0NP3oool00200oooo00<000000?ooo`3oool0o`3oool?0?ooo`040000003oool00000
000007T0oooo000P0?ooo`030000003oool0oooo0?l0oooo403oool010000000oooo0?ooo`00001h
0?ooo`00803oool200000?l0oooo4P3oool2000000030?ooo`000000000007H0oooo000P0?ooo`03
0000003oool0oooo0?l0oooo4`3oool010000000oooo0?ooo`00001e0?ooo`00803oool00`000000
oooo0?ooo`3o0?oooa@0oooo0P0000000`3oool000000000001c0?ooo`00803oool00`000000oooo
0?ooo`3o0?oooaH0oooo00@000000?ooo`3oool00000LP3oool00200oooo00<000000?ooo`3oool0
o`3ooolG0?ooo`80000000<0oooo0000003oool0L03oool00200oooo00<000000?ooo`3oool0o`3o
oolI0?ooo`040000003oool00000000006l0oooo000P0?ooo`030000003oool0oooo0?l0oooo6P3o
ool010000000oooo0?ooo`00001^0?ooo`00803oool00`000000oooo0?ooo`3o0?oooa/0oooo0P00
00000`3oool000000000001/0?ooo`00803oool00`000000oooo0?ooo`3o0?oooad0oooo00@00000
0?ooo`3oool00000J`3oool00200oooo00<000000?ooo`3oool0o`3ooolN0?ooo`80000000<0oooo
0000003oool0J@3oool00200oooo00<000000?ooo`3oool0o`3ooolP0?ooo`040000003oool00000
000006P0oooo000P0?ooo`030000003oool0oooo0?l0oooo8@3oool010000000oooo0?ooo`00001W
0?ooo`00803oool00`000000oooo0?ooo`3o0?ooob80oooo0P0000000`3oool000000?ooo`1U0?oo
o`00803oool00`000000oooo0?ooo`3o0?ooob@0oooo00@000000?ooo`0000000000I03oool00200
oooo00<000000?ooo`3oool0o`3ooolU0?ooo`040000003oool0oooo000006<0oooo000P0?ooo`80
0000o`3ooolW0?ooo`80000000<0oooo0000003oool0H@3oool00200oooo00<000000?ooo`3oool0
o`3ooolX0?ooo`040000003oool0000000000600oooo000P0?ooo`030000003oool0oooo0?l0oooo
:@3oool010000000oooo0?ooo`00001O0?ooo`00803oool00`000000oooo0?ooo`3o0?ooobX0oooo
0P0000000`3oool000000?ooo`1M0?ooo`00803oool00`000000oooo0?ooo`3o0?ooob`0oooo00@0
00000?ooo`0000000000G03oool00200oooo00<000000?ooo`3oool0o`3oool]0?ooo`040000003o
ool0oooo000005/0oooo000P0?ooo`030000003oool0oooo0?l0oooo;P3oool2000000030?ooo`00
0000oooo05T0oooo000P0?ooo`030000003oool0oooo0?l0oooo<03oool010000000oooo00000000
001H0?ooo`00803oool00`000000oooo0?ooo`3o0?oooc40oooo00@000000?ooo`3oool00000E`3o
ool00200oooo00<000000?ooo`3oool0o`3ooolb0?ooo`80000000<0oooo0000003oool0E@3oool0
0200oooo00<000000?ooo`3oool0o`3ooold0?ooo`040000003oool00000000005@0oooo000P0?oo
o`030000003oool0oooo0?l0oooo=@3oool010000000oooo0?ooo`00001C0?ooo`002@3oool30000
00<0oooo00<000000?ooo`3oool00P3oool3000000T0oooo00<000000?ooo`3oool0o`3ooolf0?oo
o`80000000<0oooo0000003oool0D@3oool000X0oooo00<000000?ooo`3oool01P3oool01@000000
oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`040000003oool00000
00000500oooo000:0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo00000008
0?ooo`030000003oool0oooo0?l0oooo>@3oool010000000oooo0?ooo`00001?0?ooo`002P3oool0
0`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?oo
o`3o0?ooocX0oooo0P0000000`3oool000000?ooo`1=0?ooo`002P3oool00`000000oooo0?ooo`06
0?ooo`050000003oool0oooo0?ooo`000000203oool300000?l0oooo?03oool00`000000oooo0000
001=0?ooo`002P3oool00`000000oooo0?ooo`060?ooo`8000000P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0?l0oooo?@3oool010000000oooo00000000001;0?ooo`002P3oool0
0`000000oooo0?ooo`060?ooo`040000003oool00000000000T0oooo00<000000?ooo`3oool0o`3o
ooln0?ooo`040000003oool0oooo000004X0oooo000:0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooocl0oooo0P0000000`3oool000000?oo
o`180?ooo`002@3oool2000000X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o
0?oood40oooo00@000000?ooo`0000000000A`3oool000X0oooo00<000000?ooo`3oool02@3oool2
000000P0oooo00<000000?ooo`3oool0o`3ooom20?ooo`040000003oool0oooo000004H0oooo000P
0?ooo`030000003oool0oooo0?l0oooo@`3oool010000000oooo0?ooo`0000150?ooo`00803oool0
0`000000oooo0?ooo`3o0?oood@0oooo00<000000?ooo`3oool00P0000130?ooo`00803oool00`00
0000oooo0?ooo`3o0?ooodD0oooo0P0000020?ooo`030000003oool0oooo0400oooo000P0?ooo`03
0000003oool0oooo0?l0ooooA`3oool010000000oooo0?ooo`0000110?ooo`00803oool00`000000
oooo0?ooo`3o0?ooodP0oooo00<000000?ooo`3oool00P00000o0?ooo`00803oool00`000000oooo
0?ooo`3o0?ooodT0oooo00D000000?ooo`3oool0oooo0000000n0?ooo`00803oool00`000000oooo
0?ooo`3o0?ooodX0oooo0P0000020?ooo`030000003oool0oooo03/0oooo000P0?ooo`030000003o
ool0oooo0?l0ooooC03oool00`000000oooo0?ooo`02000003/0oooo000P0?ooo`030000003oool0
oooo0?l0ooooC@3oool01@000000oooo0?ooo`3oool0000003X0oooo000P0?ooo`800000o`3ooom?
0?ooo`050000003oool0oooo0?ooo`000000>@3oool00200oooo00<000000?ooo`3oool0o`3ooom?
0?ooo`8000000P3oool00`000000oooo0?ooo`0f0?ooo`00803oool00`000000oooo0?ooo`3o0?oo
oe40oooo00@000000?ooo`3oool00000=`3oool00200oooo00<000000?ooo`3oool0o`3ooomB0?oo
o`030000003oool0oooo00800000=@3oool00200oooo00<000000?ooo`3oool0o`3ooomC0?ooo`80
00000P3oool00`000000oooo0?ooo`0b0?ooo`00803oool00`000000oooo0?ooo`3o0?oooeD0oooo
00@000000?ooo`3oool00000<`3oool00200oooo00<000000?ooo`3oool0o`3ooomF0?ooo`040000
003oool0oooo00000380oooo000P0?ooo`030000003oool0oooo0?l0ooooE`3oool2000000030?oo
o`00000000000300oooo000P0?ooo`030000003oool0oooo0?l0ooooF@3oool010000000oooo0?oo
o`00000_0?ooo`00803oool00`000000oooo0?ooo`3o0?oooeX0oooo00@000000?ooo`3oool00000
;P3oool00200oooo00<000000?ooo`3oool0o`3ooomK0?ooo`80000000<0oooo0000003oool0;03o
ool00200oooo00<000000?ooo`3oool0o`3ooomM0?ooo`040000003oool00000000002/0oooo000P
0?ooo`030000003oool0oooo0?l0ooooGP3oool010000000oooo0?ooo`00000Z0?ooo`00803oool0
0`000000oooo0?ooo`3o0?oooel0oooo0P0000000`3oool000000?ooo`0X0?ooo`00803oool00`00
0000oooo0?ooo`3o0?ooof40oooo00<000000?ooo`000000:03oool00200oooo0P00003o0?ooof<0
oooo00<000000?ooo`0000009`3oool00200oooo00<000000?ooo`3oool0o`3ooomS0?ooo`040000
003oool00000000002D0oooo000P0?ooo`030000003oool0oooo0?l0ooooI03oool010000000oooo
0?ooo`00000T0?ooo`00803oool00`000000oooo0?ooo`3o0?ooofD0oooo0P0000000`3oool00000
0?ooo`0R0?ooo`00803oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`0000008P3o
ool00200oooo00<000000?ooo`3oool0o`3ooomX0?ooo`040000003oool0000000000200oooo000P
0?ooo`030000003oool0oooo0?l0ooooJ@3oool010000000oooo0?ooo`00000O0?ooo`00803oool0
0`000000oooo0?ooo`3o0?ooofX0oooo0P0000000`3oool000000?ooo`0M0?ooo`00803oool00`00
0000oooo0?ooo`3o0?ooof`0oooo00<000000?ooo`0000007@3oool00200oooo00<000000?ooo`3o
ool0o`3ooom]0?ooo`040000003oool00000000001/0oooo000P0?ooo`030000003oool0oooo0?l0
ooooKP3oool010000000oooo0?ooo`00000J0?ooo`00803oool00`000000oooo0?ooo`3o0?ooofl0
oooo00@000000?ooo`3oool000006@3oool00200oooo00<000000?ooo`3oool0o`3ooom`0?ooo`80
000000<0oooo0000003oool05`3oool00200oooo00<000000?ooo`3oool0o`3ooomb0?ooo`040000
003oool00000000001H0oooo000P0?ooo`030000003oool0oooo0?l0ooooL`3oool010000000oooo
0?ooo`00000E0?ooo`00803oool00`000000oooo0?ooo`3o0?ooog@0oooo00@000000?ooo`3oool0
0000503oool00200oooo0P00003o0?ooogH0oooo00@000000?ooo`3oool000004`3oool00200oooo
00<000000?ooo`3oool0o`3ooomf0?ooo`030000003oool0oooo008000004@3oool00200oooo00<0
00000?ooo`3oool0o`3ooomg0?ooo`050000003oool0oooo0?ooo`000000403oool00200oooo00<0
00000?ooo`3oool0o`3ooomh0?ooo`8000000P3oool00`000000oooo0?ooo`0=0?ooo`00803oool0
0`000000oooo0?ooo`3o0?ooogX0oooo00<000000?ooo`3oool03`3oool00200oooo00<000000?oo
o`3oool0o`3ooomk0?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0?l0
ooooO03oool00`000000oooo0?ooo`0=0?ooo`00803oool00`000000oooo0?ooo`3o0?oooh`0oooo
000P0?ooo`030000003oool0oooo0?l0ooooS03oool00200oooo00<000000?ooo`3oool0o`3ooon<
0?ooo`00803oool00`000000oooo0?ooo`3o0?oooh`0oooo000P0?ooo`030000003oool0oooo0?l0
ooooS03oool00001\
\>"],
  ImageRangeCache->{{{0, 429.688}, {265.188, 0}} -> {-0.0838174, 0.925746, \
0.00261387, 0.00325203}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.476191 25.1696 24.5135 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.2619 -0.0125 -10.7813 -17.8125 ]
[.2619 -0.0125 10.7813 0 ]
[.5 -0.0125 -5.53125 -17.8125 ]
[.5 -0.0125 5.53125 0 ]
[.7381 -0.0125 -10.7813 -17.8125 ]
[.7381 -0.0125 10.7813 0 ]
[.97619 -0.0125 -5.53125 -17.8125 ]
[.97619 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.125 -35.625 ]
[.5 -0.0125 5.125 -17.8125 ]
[-0.0125 .04325 -45.375 -8.90625 ]
[-0.0125 .04325 0 8.90625 ]
[-0.0125 .16581 -38.3125 -8.90625 ]
[-0.0125 .16581 0 8.90625 ]
[-0.0125 .28838 -45.375 -8.90625 ]
[-0.0125 .28838 0 8.90625 ]
[-0.0125 .41095 -38.3125 -8.90625 ]
[-0.0125 .41095 0 8.90625 ]
[-0.0125 .53352 -45.375 -8.90625 ]
[-0.0125 .53352 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -63.1875 -14.7188 ]
[-0.01875 .30902 -45.375 14.7188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.125 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .04325 m
.00625 .04325 L
s
gsave
-0.0125 .04325 -106.375 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.025) show
1.000 setlinewidth
grestore
0 .16581 m
.00625 .16581 L
s
gsave
-0.0125 .16581 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.02) show
1.000 setlinewidth
grestore
0 .28838 m
.00625 .28838 L
s
gsave
-0.0125 .28838 -106.375 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.015) show
1.000 setlinewidth
grestore
0 .41095 m
.00625 .41095 L
s
gsave
-0.0125 .41095 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.01) show
1.000 setlinewidth
grestore
0 .53352 m
.00625 .53352 L
s
gsave
-0.0125 .53352 -106.375 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.005) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .06776 m
.00375 .06776 L
s
0 .09227 m
.00375 .09227 L
s
0 .11679 m
.00375 .11679 L
s
0 .1413 m
.00375 .1413 L
s
0 .19033 m
.00375 .19033 L
s
0 .21484 m
.00375 .21484 L
s
0 .23936 m
.00375 .23936 L
s
0 .26387 m
.00375 .26387 L
s
0 .3129 m
.00375 .3129 L
s
0 .33741 m
.00375 .33741 L
s
0 .36192 m
.00375 .36192 L
s
0 .38644 m
.00375 .38644 L
s
0 .43546 m
.00375 .43546 L
s
0 .45998 m
.00375 .45998 L
s
0 .48449 m
.00375 .48449 L
s
0 .509 m
.00375 .509 L
s
0 .01873 m
.00375 .01873 L
s
0 .55803 m
.00375 .55803 L
s
0 .58254 m
.00375 .58254 L
s
0 .60706 m
.00375 .60706 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -130 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.7188 12.9063 translate
90 rotate
-75.7188 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.063 17.500 moveto
(H) show
77.625 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.875 17.500 moveto
(L) show
88.438 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04325 m
1 .04325 L
s
.99375 .16581 m
1 .16581 L
s
.99375 .28838 m
1 .28838 L
s
.99375 .41095 m
1 .41095 L
s
.99375 .53352 m
1 .53352 L
s
.125 Mabswid
.99625 .06776 m
1 .06776 L
s
.99625 .09227 m
1 .09227 L
s
.99625 .11679 m
1 .11679 L
s
.99625 .1413 m
1 .1413 L
s
.99625 .19033 m
1 .19033 L
s
.99625 .21484 m
1 .21484 L
s
.99625 .23936 m
1 .23936 L
s
.99625 .26387 m
1 .26387 L
s
.99625 .3129 m
1 .3129 L
s
.99625 .33741 m
1 .33741 L
s
.99625 .36192 m
1 .36192 L
s
.99625 .38644 m
1 .38644 L
s
.99625 .43546 m
1 .43546 L
s
.99625 .45998 m
1 .45998 L
s
.99625 .48449 m
1 .48449 L
s
.99625 .509 m
1 .509 L
s
.99625 .01873 m
1 .01873 L
s
.99625 .55803 m
1 .55803 L
s
.99625 .58254 m
1 .58254 L
s
.99625 .60706 m
1 .60706 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.06244 .08192 L
.10458 .14925 L
.14415 .20631 L
.18221 .25549 L
.22272 .30197 L
.26171 .34138 L
.30316 .37809 L
.34309 .40896 L
.3815 .43498 L
.42237 .45919 L
.46172 .47957 L
.49955 .4968 L
.53984 .51294 L
.57861 .5266 L
.61984 .53938 L
.65954 .55023 L
.69774 .55949 L
.73838 .56825 L
.77751 .57574 L
.81909 .58283 L
.85916 .58891 L
.89771 .59417 L
.93871 .59918 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{430.688, 266.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006^00012R000`400?l00000o`00003oo`3ooon_
0?ooo`00o`3ooon_0?ooo`00o`3ooon_0?ooo`00o`3ooon_0?ooo`00o`3ooon_0?ooo`00o`3ooon_
0?ooo`00o`3ooon_0?ooo`00mP3oool600000;80oooo003g0?ooo`050000003oool0oooo0?ooo`00
0000/P3oool00?P0oooo00<000000?ooo`3oool0/`3oool00?P0oooo00<000000?ooo`3oool0/`3o
ool00?T0oooo00<000000?ooo`3oool0/P3oool00?H0oooo00D000000?ooo`3oool0oooo0000002c
0?ooo`00mP3oool600000;80oooo003o0?ooojl0oooo003o0?ooojl0oooo003o0?ooojl0oooo003o
0?ooojl0oooo003o0?ooojl0oooo003o0?ooojl0oooo003o0?ooojl0oooo003o0?ooojl0oooo003o
0?ooojl0oooo003o0?ooojl0oooo003o0?ooojl0oooo001<0?ooo`<00000CP3oool3000000<0oooo
00@000000?ooo`3oool0oooo0`00001>0?ooo`<00000C@3oool3000000<0oooo00@000000?ooo`3o
ool0oooo0`00001=0?ooo`D000001`3oool004/0oooo00D000000?ooo`3oool0oooo0000001<0?oo
o`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0
oooo04d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1;0?ooo`040000003oool0
oooo000000L0oooo001;0?ooo`050000003oool0oooo0?ooo`000000C03oool01@000000oooo0?oo
o`3oool0000000X0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1=0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`070?ooo`00B`3o
ool01@000000oooo0?ooo`3oool0000004`0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo04`0oooo00<000000?ooo`3oool01P3oool004/0oooo00D000000?ooo`3oool0
oooo0000001<0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1;0?oo
o`030000003oool0oooo04d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1<0?oo
o`030000003oool0oooo00H0oooo001;0?ooo`050000003oool0oooo0?ooo`000000C03oool01@00
0000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`05
0?ooo`00B`3oool01@000000oooo0?ooo`3oool0000004`0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`<00000C`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00H0oooo0`00
001A0?ooo`030000003oool0oooo00D0oooo001;0?ooo`050000003oool0oooo0?ooo`000000C03o
ool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0D@3oool00`000000oooo
0?ooo`050?ooo`00B`3oool01@000000oooo0?ooo`3oool0000004`0oooo00D000000?ooo`3oool0
oooo000000070?ooo`030000003oool0oooo04d0oooo0P00001>0?ooo`8000002@3oool00`000000
oooo0?ooo`1<0?ooo`050000003oool0oooo0?ooo`0000001`3oool004`0oooo0`00001>0?ooo`<0
0000203oool4000004d0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`070?ooo`@0
0000C03oool3000000P0oooo003o0?ooojl0oooo003o0?ooojl0oooo003o0?ooojl0oooo003o0?oo
ojl0oooo003o0?ooojl0oooo003o0?ooojl0oooo003o0?ooojl0oooo00150?ooool00000JP000000
04D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool01P3oool100000000A@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo05<0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`1C0?ooo`03
0000003oool0oooo0580oooo00<000000?ooo`3oool01P3oool100000000A@3oool00`000000oooo
0?ooo`3o0?ooofH0oooo0@00000004D0oooo00<000000?ooo`3oool0o`3ooomV0?ooo`4000000015
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooomM0?ooo`40000000150?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooomL0?ooo`40000000150?ooo`<0
00001`3oool00`000000oooo0?ooo`3o0?oooe/0oooo0P00000004D0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`3o0?oooe/0oooo0@00000004D0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`3o0?oooe/0oooo0@00000004D0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`3o0?oooeX0oooo0@00000004D0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`3o0?oooeX0oooo0@0000000240oooo0`0000030?ooo`030000003oool0oooo0080
oooo0`0000030?ooo`D000000P3oool3000000T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`3o0?oooeT0oooo0@0000000280oooo00<000000?ooo`3oool01P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooomH0?ooo`400000000R0?ooo`03
0000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0?l0ooooF03oool1000000005`3oool7000000@0oooo00<000000?ooo`3oool01P3oool01@000000
oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`@000002`3oool00`000000oooo0?ooo`3o0?oooeD0oooo0`0000000280oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooomG0?oo
o`400000000R0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000060?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0?l0ooooEP3oool1000000008P3oool00`000000oooo0?ooo`060?ooo`05
0000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`03000000T0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`3o0?oooeD0oooo0@0000000280oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0?ooo`3oool0000000H0oooo00@000000?ooo`3oool000002`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0ooooE@3oool1000000008@3oool20000
00P0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3o
oomD0?ooo`400000000R0?ooo`030000003oool0oooo00L0oooo0`0000040?ooo`<00000103oool4
000000L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?oooe@0oooo0@000000
04D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?oooe<0oooo0@00000004D0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?oooe<0oooo0@00000004D0oooo
0`00000A0?ooo`030000003oool0oooo0?l0ooooD@3oool200000000A@3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0?l0ooooD@3oool100000000A@3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0?l0ooooD@3oool100000000A@3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo0?l0ooooD03oool100000000A@3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0?l0ooooD03oool100000000A@3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo0?l0ooooC`3oool100000000A@3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo0?l0ooooCP3oool100000000A@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo0?l0ooooCP3oool100000000A@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
0?l0ooooC@3oool100000000A@3oool3000001H0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`80
000000150?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`400000
00150?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3ooom;0?ooo`4000000015
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3ooom;0?ooo`40000000150?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0o`3ooom:0?ooo`40000000150?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0o`3ooom:0?ooo`40000000150?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool0o`3ooom90?ooo`40000000150?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0o`3ooom80?ooo`40000000150?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0o`3ooom80?ooo`40000000150?ooo`<00000703oool00`00
0000oooo0?ooo`3o0?ooodH0oooo0P00000004D0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`3o0?ooodL0oooo0@00000004D0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`3o0?ooodH0oooo0@00000004D0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`3o0?ooodD0oooo0@00000004D0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3o
0?ooodD0oooo0@00000004D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3o0?oo
od@0oooo0@00000004D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3o0?oood@0
oooo0@00000004D0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`3o0?oood<0oooo
0@00000004D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3o0?oood80oooo0@00
000004D0oooo0`00000Q0?ooo`030000003oool0oooo0?l0oooo@@3oool200000000A@3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo0?l0oooo@@3oool100000000A@3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo0?l0oooo@@3oool100000000A@3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo0?l0oooo@03oool100000000A@3oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo0?l0oooo?`3oool100000000:03oool3000000<0oooo00<00000
0?ooo`3oool00P3oool3000000<0oooo1@0000070?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool0o`3ooolo0?ooo`400000000Y0?ooo`030000003oool0oooo00H0oooo00D000000?oo
o`3oool0oooo000000030?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`3o0?oooch0oooo0@00000002T0oooo00<000000?ooo`3oool01P3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo0?l0oooo?@3oool1000000007P3oool7000000@0oooo00<00000
0?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool01P3o
ool4000002D0oooo00<000000?ooo`3oool0o`3ooolk0?ooo`<00000000Y0?ooo`030000003oool0
oooo00H0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`3o0?oooc`0oooo0@00000002T0oooo00<00000
0?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0?l0oooo>`3oool100000000:@3oool0
0`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3ooolj0?ooo`400000000Y
0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?ooocX0oooo0@00
000002P0oooo0P0000080?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?oo
o`3oool0000000L0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`3o0?ooocT0oooo
0@00000002T0oooo00<000000?ooo`3oool01`3oool3000000@0oooo0`0000080?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`40000000150?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`40000000150?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool0o`3ooolg0?ooo`40000000150?ooo`<00000;@3oool00`000000
oooo0?ooo`3o0?ooocD0oooo0P00000004D0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`3o0?ooocH0oooo0@00000004D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`3o0?ooocD0oooo0@00000004D0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`3o
0?oooc@0oooo0@00000004D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`3o0?oo
oc<0oooo0@00000004D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`3o0?oooc<0
oooo0@00000004D0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`3o0?oooc80oooo
0@00000004D0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`3o0?oooc40oooo0@00
000004D0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`3o0?oooc00oooo0@000000
04D0oooo0`00000c0?ooo`030000003oool0oooo0?l0oooo;`3oool200000000A@3oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo0?l0oooo;`3oool100000000A@3oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo0?l0oooo;P3oool100000000A@3oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo0?l0oooo;@3oool100000000A@3oool00`000000oooo0?ooo`0f
0?ooo`030000003oool0oooo0?l0oooo;@3oool100000000A@3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo0?l0oooo;03oool100000000A@3oool00`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo0?l0oooo:`3oool100000000A@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo0?l0oooo:P3oool100000000A@3oool00`000000oooo0?ooo`0j0?ooo`030000003o
ool0oooo0?l0oooo:@3oool100000000A@3oool3000003X0oooo00<000000?ooo`3oool0o`3ooolX
0?ooo`80000000150?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooolX0?oo
o`40000000150?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`40
000000150?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`400000
00150?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`4000000015
0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`40000000150?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`40000000150?ooo`03
0000003oool0oooo0400oooo00<000000?ooo`3oool0o`3ooolS0?ooo`40000000150?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool0o`3ooolR0?ooo`40000000150?ooo`<00000@P3o
ool00`000000oooo0?ooo`3o0?ooob00oooo0P00000004D0oooo00<000000?ooo`3oool0@`3oool0
0`000000oooo0?ooo`3o0?ooob00oooo0@00000004D0oooo00<000000?ooo`3oool0A03oool00`00
0000oooo0?ooo`3o0?oooal0oooo0@00000004D0oooo00<000000?ooo`3oool0A@3oool00`000000
oooo0?ooo`3o0?oooah0oooo0@00000000H0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`160?ooo`030000003oool0oooo0?l0oooo7@3oool1000000001P3oool3000001P0oooo0`00
00030?ooo`030000003oool0oooo0080oooo0`0000040?ooo`<000000`3oool3000000T0oooo00<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`3o0?oooad0oooo0@00000000H0oooo00<00000
0?ooo`3oool00`00000F0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`170?ooo`030000003oool0oooo0?l0oooo703oool1000000002`3oool2000001D0oooo00<00000
0?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0o`3o
oolK0?ooo`40000000060?ooo`030000003oool0oooo00800000303oool7000000@0oooo00<00000
0?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0o`3o
oolJ0?ooo`40000000060?ooo`<000006@3oool00`000000oooo0?ooo`060?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo1000
00190?ooo`030000003oool0oooo0?l0oooo5`3oool3000000001P3oool00`000000oooo0?ooo`03
000001H0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0o`3ooolH0?ooo`400000000;0?ooo`8000005@3oool00`000000oooo0?ooo`06
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`<000002@3o
ool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0?l0oooo5`3oool1000000001P3oool0
0`000000oooo0?ooo`02000001L0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo04d0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`40000000060?ooo`<00000603oool2
000000P0oooo00D000000?ooo`3oool0oooo000000030?ooo`8000001@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0o`3ooolE0?ooo`4000000006
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01`3oool3000000D0oooo00<00000
0?ooo`3oool00`3oool4000000L0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`3o
0?oooa@0oooo0@00000000D0oooo2@00000g0?ooo`030000003oool0oooo0500oooo00<000000?oo
o`3oool0o`3ooolC0?ooo`40000000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0?l0oooo4P3oool100000000
0`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03<0oooo0`00001B0?ooo`030000
003oool0oooo0?l0oooo403oool200000000A@3oool00`000000oooo0?ooo`1C0?ooo`030000003o
ool0oooo0?l0oooo403oool1000000001P3oool2000000@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0?l0oooo3`3oool1000000001P3oool00`00
0000oooo0?ooo`020?ooo`800000>03oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo
0?l0oooo3P3oool1000000001P3oool00`000000oooo0?ooo`02000000030?ooo`000000oooo03L0
oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`3o0?ooo`h0oooo0@00000000H0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool0o`3oool=0?ooo`40000000060?ooo`800000103oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0o`3oool<0?ooo`4000000006
0?ooo`030000003oool0oooo0080oooo0P00000h0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0o`3oool;0?ooo`40000000030?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0?l0oooo2P3oool10000
0000103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03@0oooo0`00001J0?ooo`03
0000003oool0oooo0?l0oooo203oool2000000001@3oool9000003L0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`3o0?ooo`P0oooo0@00000004D0oooo00<000000?ooo`3oool0G03o
ool00`000000oooo0?ooo`3o0?ooo`L0oooo0@00000004D0oooo00<000000?ooo`3oool0G@3oool0
0`000000oooo0?ooo`3o0?ooo`H0oooo0@00000004D0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`3o0?ooo`D0oooo0@00000004D0oooo00<000000?ooo`3oool0G`3oool00`000000
oooo0?ooo`3o0?ooo`@0oooo0@00000004D0oooo00<000000?ooo`3oool0H03oool00`000000oooo
0?ooo`3o0?ooo`<0oooo0@00000004D0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?oo
o`3o0?ooo`80oooo0@00000004D0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`3o
0?ooo`40oooo0@00000004D0oooo0`00001S0?ooo`800000o`3oool200000000A@3oool00`000000
oooo0?ooo`1U0?ooo`030000003oool0oooo0?d0oooo0@00000004D0oooo00<000000?ooo`3oool0
IP3oool00`000000oooo0?ooo`3l0?ooo`40000000150?ooo`030000003oool0oooo06L0oooo00<0
00000?ooo`3oool0n`3oool100000000A@3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0
oooo0?X0oooo0@00000004D0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`3i0?oo
o`40000000150?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0n03oool100000000
A@3oool00`000000oooo0?ooo`1[0?ooo`800000n03oool100000000A@3oool00`000000oooo0?oo
o`1]0?ooo`030000003oool0oooo0?D0oooo0@00000004D0oooo0`00001^0?ooo`030000003oool0
oooo0?<0oooo0P00000004D0oooo00<000000?ooo`3oool0K`3oool200000?@0oooo0@00000004D0
oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`3a0?ooo`40000000150?ooo`030000
003oool0oooo0780oooo00<000000?ooo`3oool0l03oool100000000A@3oool00`000000oooo0?oo
o`1c0?ooo`800000l03oool100000000:03oool3000000<0oooo00<000000?ooo`3oool00P3oool3
000000@0oooo0`0000080?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0k@3oool1
00000000:@3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0k03oool1
00000000:@3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo07L0oooo0P00003/0?ooo`400000000N0?oo
o`L00000103oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0j@3oool1
00000000:@3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`070?ooo`@00000N@3oool200000>L0oooo0`00000002T0oooo00<000000?oo
o`3oool01P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0>H0oooo0@00000002T0oooo00<000000?oo
o`3oool01P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`1m0?ooo`800000iP3oool100000000:@3oool00`000000oooo0?ooo`060?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo07l0oooo00<000000?ooo`3oool0h`3oool100000000:03oool2000000P0oooo00D000000?oo
o`3oool0oooo000000030?ooo`8000002@3oool00`000000oooo0?ooo`200?ooo`800000h`3oool1
00000000:@3oool00`000000oooo0?ooo`070?ooo`<000001@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0880oooo0P00003Q0?ooo`40000000150?ooo`030000003oool0oooo08@0
oooo00<000000?ooo`3oool0gP3oool100000000A@3oool00`000000oooo0?ooo`250?ooo`800000
gP3oool100000000A@3oool3000008L0oooo00<000000?ooo`3oool0fP3oool200000000A@3oool0
0`000000oooo0?ooo`280?ooo`800000f`3oool100000000A@3oool00`000000oooo0?ooo`2:0?oo
o`030000003oool0oooo0=P0oooo0@00000004D0oooo00<000000?ooo`3oool0R`3oool200000=P0
oooo0@00000004D0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`3E0?ooo`400000
00150?ooo`030000003oool0oooo08h0oooo0P00003E0?ooo`40000000150?ooo`030000003oool0
oooo0900oooo0P00003C0?ooo`40000000150?ooo`030000003oool0oooo0980oooo00<000000?oo
o`3oool0d03oool100000000A@3oool00`000000oooo0?ooo`2C0?ooo`800000d03oool100000000
A@3oool3000009D0oooo00<000000?ooo`3oool0c03oool200000000A@3oool00`000000oooo0?oo
o`2F0?ooo`800000c@3oool100000000A@3oool00`000000oooo0?ooo`2H0?ooo`800000b`3oool1
00000000A@3oool00`000000oooo0?ooo`2J0?ooo`800000b@3oool100000000A@3oool00`000000
oooo0?ooo`2L0?ooo`800000a`3oool100000000A@3oool00`000000oooo0?ooo`2N0?ooo`800000
a@3oool100000000A@3oool00`000000oooo0?ooo`2P0?ooo`800000``3oool100000000A@3oool0
0`000000oooo0?ooo`2R0?ooo`<00000`03oool100000000A@3oool00`000000oooo0?ooo`2U0?oo
o`800000_P3oool100000000A@3oool300000:L0oooo0P00002k0?ooo`80000000150?ooo`030000
003oool0oooo0:T0oooo0`00002i0?ooo`40000000150?ooo`030000003oool0oooo0:`0oooo0P00
002g0?ooo`40000000150?ooo`030000003oool0oooo0:h0oooo0P00002e0?ooo`40000000150?oo
o`030000003oool0oooo0;00oooo0`00002b0?ooo`40000000150?ooo`030000003oool0oooo0;<0
oooo0P00002`0?ooo`40000000150?ooo`030000003oool0oooo0;D0oooo0`00002]0?ooo`400000
00150?ooo`030000003oool0oooo0;P0oooo0P00002[0?ooo`40000000150?ooo`030000003oool0
oooo0;X0oooo0`00002X0?ooo`40000000150?ooo`<00000_@3oool200000:D0oooo0P00000004D0
oooo00<000000?ooo`3oool0_`3oool300000:<0oooo0@00000004D0oooo00<000000?ooo`3oool0
`P3oool300000:00oooo0@00000004D0oooo00<000000?ooo`3oool0a@3oool2000009h0oooo0@00
000004D0oooo00<000000?ooo`3oool0a`3oool3000009/0oooo0@0000000240oooo0`0000030?oo
o`030000003oool0oooo0080oooo0`0000040?ooo`<000000`3oool3000000T0oooo00<000000?oo
o`3oool0bP3oool3000009P0oooo0@0000000280oooo00<000000?ooo`3oool01P3oool01@000000
oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0c@3oool3000009D0oooo0@0000000280oooo00<000000?oo
o`3oool01P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0d03oool300000980oooo0@00
000001L0oooo1`0000040?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0=<0oooo0P00002@0?ooo`400000000R0?ooo`030000003oool0oooo00H0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000
oooo0?ooo`050?ooo`@00000e03oool3000008/0oooo0`0000000280oooo00<000000?ooo`3oool0
1P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000050?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0f03oool3000008X0oooo0@0000000280
oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?oo
o`3oool0oooo000000020?ooo`<000002@3oool00`000000oooo0?ooo`3K0?ooo`<00000Q`3oool1
000000008P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`3N0?ooo`@00000P`3oool1000000008@3oool2000000P0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0>80oooo1000001o0?ooo`400000000R0?ooo`030000003oool0oooo00L0oooo0`00
00040?ooo`<00000103oool4000000L0oooo00<000000?ooo`3oool0iP3oool4000007/0oooo0@00
000004D0oooo00<000000?ooo`3oool0jP3oool4000007L0oooo0@00000004D0oooo00<000000?oo
o`3oool0kP3oool4000007<0oooo0@00000004D0oooo00<000000?ooo`3oool0lP3oool4000006l0
oooo0@00000004D0oooo0`00003f0?ooo`D00000J@3oool200000000A@3oool00`000000oooo0?oo
o`3k0?ooo`D00000I@3oool100000000A@3oool00`000000oooo0?ooo`3o0?ooo`40oooo1@00001P
0?ooo`40000000150?ooo`030000003oool0oooo0?l0oooo1P3oool5000005/0oooo0@00000004D0
oooo00<000000?ooo`3oool0o`3oool;0?ooo`@00000E`3oool100000000A@3oool00`000000oooo
0?ooo`3o0?ooo`l0oooo1@00001B0?ooo`40000000150?ooo`030000003oool0oooo0?l0oooo503o
ool6000004`0oooo0@00000004D0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`P00000A03oool1
00000000A@3oool300000?l0oooo8P3oool6000003d0oooo0P00000004D0oooo00<000000?ooo`3o
ool0o`3ooolX0?ooo`@00000>P3oool100000000A@3oool00`000000oooo0?ooo`3o0?ooob`0oooo
1@00000e0?ooo`40000000150?ooo`030000003oool0oooo0?l0oooo<@3oool6000002l0oooo0@00
000004D0oooo00<000000?ooo`3oool0o`3ooolg0?ooo`L00000:03oool100000000A@3oool00`00
0000oooo0?ooo`3o0?oooch0oooo2`00000M0?ooo`40000000150?ooo`030000003oool0oooo0?l0
ooooB@3oool;00000180oooo0@00000004D0oooo00<000000?ooo`3oool0o`3ooomD0?ooo`H00000
303oool100000000A@3oool00`000000oooo0?ooo`3o0?oooeX0oooo100000080?ooo`4000000015
0?ooo`<00000o`3ooomU0?ooo`80000000150?ooo`030000003oool0oooo0?l0ooooIP3oool10000
0000A@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3o
ool01P3oool100000000A@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`40000000150?ooool00000JP00
00000?l0oooo[`3oool00001\
\>"],
  ImageRangeCache->{{{0, 429.688}, {265.188, 0}} -> {-0.45836, -1.03147, \
0.00583936, 0.000113433}}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[{
    \( (*\ 
      Find\ chi\ square\ for\ given\ H \((z)\)\ \ *) \[IndentingNewLine]\(f[
          z_] := 1/hhz[z];\)\), "\n", 
    \(\(rr[zz_] := NIntegrate[f[z], {z, 0, zz}];\)\), "\n", 
    \(\(qq = Table[rr[zz[i]], {i, 1, ndat}];\)\)}], "Input"],

Cell[BoxData[{
    \( (*\ Construct\ marginalization\ coefficients\ \((see\ astro - 
              ph/0401556\  .. )\)\ *) \[IndentingNewLine]Clear[chi2fa, 
      chi2fb, chi2fc]\), "\n", 
    \(\(chi2fa = 
        Sum[\((ld[i] - 5\ Log[10, qq[\([i]\)]*\((1 + zz[i])\)])\)^2/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\n", 
    \(\(chi2fb = 
        Sum[\((ld[i] - 
                5\ Log[10, qq[\([i]\)]*\((1 + zz[i])\)])\)/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\n", 
    \(\(chi2fc = Sum[1/\((sld[i]^2)\), {i, 1, ndat}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ Construct\ function\ after\ marginalization, \ 
      find\ same\ result\ as\ with\ mb\ minimization\ *) \
\[IndentingNewLine]chi2fm = 
      chi2fa - chi2fb^2/chi2fc\), "\[IndentingNewLine]", 
    \(dchi2p05 = chi2fm - chi2l\)}], "Input"],

Cell[BoxData[
    \(176.98213953431696`\)], "Output"],

Cell[BoxData[
    \(\(-0.14523190073668957`\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ \(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(\
--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(-\(---\)\)\)\)\)\)\)\)\)\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)*) \[IndentingNewLine]\[IndentingNewLine] \
(*\ Find\ H \((z)\)\ for\ given\ slope\ s\ of\ the\ linear\ potential . \ 
            Present\ time\  = \ \(tt\ \((corresponds\ to\ a = 1)\) . \ 
              Run\ trials\ for\ initial\ condition\ for\ field\ fi\ \((f0)\)\ \
and\ initial\ time\ ti\ until\ we\ get\ field\ energy\ enf\  = \ \(0.7\ and\ \
H \((z = 0)\)\  = 
            1\ at\ present\ time\ \(\(tt\)\(.\)\)\)\)\ *) \[IndentingNewLine]\
\[IndentingNewLine] (*\ \(--\(--\(--\(--\ \ s\)\)\)\)\  = \ \(0.7\ \ \ --\) \
\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(---\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\ *) \
\[IndentingNewLine]\[IndentingNewLine]\(Clear[aa, fi, a, aad, aadd, fidas, 
        tas, f, rr, hht, hha];\)\), "\n", 
    \(aa = a[t]; \ fi = f[t];\), "\n", 
    \(\(aad = D[aa, t];\)\), "\n", 
    \(\(aadd = D[aa, {t, 2}];\)\), "\n", 
    \(\(fid = D[fi, t];\)\), "\n", 
    \(\(fidd = D[fi, {t, 2}];\)\n\), "\n", 
    \(ti = 0.0000017; \ t0 = 4;\), "\n", 
    \(\(f0 = 0.92;\)\ \), "\n", 
    \(om0m = 0.3; \ ss = 0.7;\), "\n", 
    \(\(eq1 = 
        aadd/aa\  \[Equal] \ 
          fid^2\ \  + \ \ ss\ fi\  - \ om0m/\((2\ aa^3)\);\)\), "\n", 
    \(\(eq2 = 
        fidd\ \  + \ \ \ 3\ \ fid\ \((aad/aa)\)\  - \ ss \[Equal] 
          0;\)\), "\n", 
    \(\(eqb1 = f[ti] == f0;\)\), "\n", 
    \(\(eqb2 = \(f'\)[ti] == 0;\)\), "\n", 
    \(\(eqb3 = 
        a[ti] \[Equal] \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((2/3)\);\)\), "\n", 
    \(\(eqb4 = \(a'\)[
            ti] \[Equal] \((2/
                3)\)\ \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((\(-1\)/
                  3)\);\)\), "\n", 
    \(\(sol2 = 
        NDSolve[{eq1, eq2, eqb1, eqb2, eqb3, eqb4}, {aa, fi}, {t, ti, t0}, 
          MaxSteps \[Rule] 10000000];\)\), "\n", 
    \(\(asol = Part[Evaluate[a[t] /. sol2], 1];\)\), "\n", 
    \(\(fsol = 
        Part[Evaluate[f[t] /. sol2], 1];\)\[IndentingNewLine]\), "\n", 
    \(\(dfsol = D[fsol, t];\)\), "\n", 
    \(\(enf = \(-0.5\)\ dfsol^2\  + \ ss\ fsol;\)\), "\n", 
    \(\(as[t1_] := asol\  /. \ t -> t1\ ;\)\), "\n", 
    \(\(tt = Part[FindRoot[as[t] == 1, {t, 0.1}], 1, 2];\)\), "\n", 
    \(\(tas[a_] := 
        Part[FindRoot[as[t] \[Equal] a, {t, 0.3}], 1, 2];\)\), "\n", 
    \(\(hht[t1_] := D[asol, t]/asol\  /. \ t -> t1\ ;\)\), "\n", 
    \(\(hha[a_] := hht[tas[a]];\)\), "\n", 
    \(\(hhz[z_] := hha[1/\((z + 1)\)];\)\), "\n", 
    \(enf\  /. \ t \[Rule] tt\), "\n", 
    \(hhz[0]\), "\[IndentingNewLine]", 
    \(\(hhzt = 
        Sqrt[\((1 - om0m)\) + om0m \((1 + z)\)^3] /. 
          om0m \[Rule] 0.3;\)\), "\[IndentingNewLine]", 
    \(\(Plot[{hhz[z], hhzt}, {z, 0, 1}];\)\), "\[IndentingNewLine]", 
    \(\(enf = \(-0.5\)\ dfsol^2\  + \ ss\ fsol;\)\), "\n", 
    \(\(ppf = \(-0.5\)\ dfsol^2\  - \ ss\ fsol;\)\), "\n", 
    \(\(wft[t1_] := ppf/enf\  /. \ t -> t1\ ;\)\ \), "\n", 
    \(\(wfa[a_] := wft[tas[a]];\)\), "\n", 
    \(\(wfz[z_] := wfa[1/\((z + 1)\)];\)\), "\n", 
    \(\(plw07p = 
        Plot[wfz[z], {z, 0, 2}, Frame \[Rule] True, PlotRange \[Rule] All, 
          FrameLabel \[Rule] {"\<z\>", "\<w(z)\>"}];\)\)}], "Input"],

Cell[BoxData[
    \(0.6954428632798968`\)], "Output"],

Cell[BoxData[
    \(1.0051337555613324`\)], "Output"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.755446 0.770161 [
[.21429 .00222 -10.7813 -17.8125 ]
[.21429 .00222 10.7813 0 ]
[.40476 .00222 -10.7813 -17.8125 ]
[.40476 .00222 10.7813 0 ]
[.59524 .00222 -10.7813 -17.8125 ]
[.59524 .00222 10.7813 0 ]
[.78571 .00222 -10.7813 -17.8125 ]
[.78571 .00222 10.7813 0 ]
[.97619 .00222 -5.53125 -17.8125 ]
[.97619 .00222 5.53125 0 ]
[.01131 .16875 -21.5625 -8.90625 ]
[.01131 .16875 0 8.90625 ]
[.01131 .32278 -21.5625 -8.90625 ]
[.01131 .32278 0 8.90625 ]
[.01131 .47681 -21.5625 -8.90625 ]
[.01131 .47681 0 8.90625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
gsave
.21429 .00222 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 .01472 m
.40476 .02097 L
s
gsave
.40476 .00222 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 .01472 m
.59524 .02097 L
s
gsave
.59524 .00222 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 .01472 m
.78571 .02097 L
s
gsave
.78571 .00222 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 .01472 m
.97619 .02097 L
s
gsave
.97619 .00222 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16875 m
.03006 .16875 L
s
gsave
.01131 .16875 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
.02381 .32278 m
.03006 .32278 L
s
gsave
.01131 .32278 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
.02381 .47681 m
.03006 .47681 L
s
gsave
.01131 .47681 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .05322 m
.02756 .05322 L
s
.02381 .09173 m
.02756 .09173 L
s
.02381 .13024 m
.02756 .13024 L
s
.02381 .20726 m
.02756 .20726 L
s
.02381 .24576 m
.02756 .24576 L
s
.02381 .28427 m
.02756 .28427 L
s
.02381 .36129 m
.02756 .36129 L
s
.02381 .3998 m
.02756 .3998 L
s
.02381 .4383 m
.02756 .4383 L
s
.02381 .51532 m
.02756 .51532 L
s
.02381 .55383 m
.02756 .55383 L
s
.02381 .59234 m
.02756 .59234 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01867 m
.06244 .03201 L
.10458 .04778 L
.14415 .06374 L
.18221 .08008 L
.22272 .09854 L
.26171 .11731 L
.30316 .1383 L
.34309 .15951 L
.3815 .1808 L
.42237 .20436 L
.46172 .22792 L
.49955 .25135 L
.53984 .27711 L
.57861 .30267 L
.61984 .33065 L
.65954 .35835 L
.69774 .38567 L
.73838 .41546 L
.77751 .44481 L
.81909 .47669 L
.85916 .50808 L
.89771 .53888 L
.93871 .57226 L
.97619 .60332 L
s
.02381 .01472 m
.06244 .02922 L
.10458 .04603 L
.14415 .06277 L
.18221 .07973 L
.22272 .09869 L
.26171 .11781 L
.30316 .13906 L
.34309 .16042 L
.3815 .18177 L
.42237 .20532 L
.46172 .22881 L
.49955 .25213 L
.53984 .27772 L
.57861 .30307 L
.61984 .3308 L
.65954 .35824 L
.69774 .38528 L
.73838 .41475 L
.77751 .44378 L
.81909 .47532 L
.85916 .50636 L
.89771 .53682 L
.93871 .56984 L
.97619 .60056 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{422.188, 260.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006V000112000`400?l00000o`00003oo`3ooonW
0?ooo`00o`3ooonW0?ooo`00o`3ooonW0?ooo`00o`3ooonW0?ooo`00o`3ooonW0?ooo`00I03oool3
000000<0oooo00@000000?ooo`3oool0oooo1@00000k0?ooo`<000000`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo03/0oooo0`0000030?ooo`030000003oool0oooo0080oooo0`00
000m0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`<00000@P3oool3000000l0oooo001S
0?ooo`050000003oool0oooo0?ooo`0000001`3oool010000000oooo0?ooo`00000j0?ooo`050000
003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0j0?ooo`050000003oool0oooo0?oo
o`0000001P3oool01@000000oooo0?ooo`3oool0000003/0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`050000003oool0oooo0?ooo`000000@P3oool00`000000oooo0?ooo`0>0?ooo`00H`3o
ool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0>P3oool01@000000oooo
0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0>P3oool01@000000oooo0?ooo`3oool00000
00H0oooo00D000000?ooo`3oool0oooo0000000k0?ooo`050000003oool0oooo0?ooo`0000001P3o
ool01@000000oooo0?ooo`3oool000000480oooo00<000000?ooo`3oool03P3oool006<0oooo00D0
00000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo03T0oooo00D000000?ooo`3oool0
oooo000000050?ooo`H00000>`3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?oo
o`3oool0oooo0000000k0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?oo
o`3oool000000480oooo00<000000?ooo`3oool03P3oool006<0oooo00D000000?ooo`3oool0oooo
000000090?ooo`030000003oool0oooo03T0oooo00D000000?ooo`3oool0oooo000000050?ooo`05
0000003oool0oooo0?ooo`000000?03oool01@000000oooo0?ooo`3oool0000000H0oooo00D00000
0?ooo`3oool0oooo0000000k0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo
000000130?ooo`030000003oool0oooo00h0oooo001S0?ooo`050000003oool0oooo0?ooo`000000
2P3oool00`000000oooo0?ooo`0h0?ooo`050000003oool0oooo0?ooo`0000001P3oool010000000
oooo0?ooo`00000l0?ooo`050000003oool0oooo0?ooo`0000001P3oool200000080oooo00<00000
0?ooo`3oool0>@3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0>0?ooo`00H`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<0
00000?ooo`3oool0>03oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`000000
?03oool01@000000oooo0?ooo`3oool0000000H0oooo00@000000?ooo`0000000000?03oool01@00
0000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`000000@`3oool00`000000oooo0?ooo`0>
0?ooo`00H`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0>03oool0
1@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`000000?03oool01@000000oooo0?oo
o`3oool0000000L0oooo00<000000?ooo`3oool0?03oool01@000000oooo0?ooo`3oool0000000H0
oooo00D000000?ooo`3oool0oooo000000120?ooo`030000003oool0oooo00h0oooo001S0?ooo`05
0000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000003X0oooo00D00000
0?ooo`3oool0oooo000000080?ooo`800000?03oool01@000000oooo0?ooo`3oool0000000P0oooo
00<000000?ooo`3oool0>`3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3o
ool0oooo000000110?ooo`800000403oool006@0oooo0`0000080?ooo`<00000?03oool3000000X0
oooo00<000000?ooo`3oool0>`3oool3000000X0oooo0P00000l0?ooo`<00000203oool3000004<0
oooo00<000000?ooo`3oool03P3oool00?l0ooooY`3oool00?l0ooooY`3oool001l0oooo00<00000
0?ooo`3oool0o`3ooon50?ooo`007`3oool00`000000oooo0?ooo`3o0?ooohD0oooo000O0?ooo`03
0000003oool0oooo0?l0ooooQ@3oool001l0oooo00<000000?ooo`3oool0o`3ooon50?ooo`007`3o
ool00`000000oooo0?ooo`3o0?ooohD0oooo000F0?ooool00000R`0000060?ooo`007`3oool01000
0000oooo00000000000?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03@3oool0
01l0oooo0P0000020?ooo`<00000303oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00d0oooo000O0?ooo`030000003oool00000008000000P3oool300000440oooo00<000000?ooo`3o
ool0B03oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3o
ool0B03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`020?ooo`<00000
0P3oool200000?l0ooooO03oool001l0oooo00<000000?ooo`3oool01@3oool700000?l0ooooN@3o
ool001l0oooo00<000000?ooo`3oool02@3oool600000?l0ooooMP3oool001l0oooo00<000000?oo
o`3oool0303oool500000?l0ooooM03oool001l0oooo00<000000?ooo`3oool03`3oool400000?l0
ooooLP3oool001l0oooo00<000000?ooo`3oool04@3oool400000?l0ooooL03oool001l0oooo00<0
00000?ooo`3oool0503oool400000?l0ooooK@3oool001l0oooo00<000000?ooo`3oool05`3oool3
00000?l0ooooJ`3oool001l0oooo00<000000?ooo`3oool06@3oool300000?l0ooooJ@3oool001l0
oooo00<000000?ooo`3oool0703oool300000?l0ooooIP3oool001l0oooo00<000000?ooo`3oool0
7`3oool200000?l0ooooI03oool001l0oooo0`00000Q0?ooo`<00000o`3ooomQ0?ooo`007`3oool0
0`000000oooo0?ooo`0S0?ooo`@00000o`3ooomN0?ooo`007`3oool00`000000oooo0?ooo`0U0?oo
o`@00000o`3ooomL0?ooo`007`3oool00`000000oooo0?ooo`0X0?ooo`@00000o`3ooomI0?ooo`00
7`3oool00`000000oooo0?ooo`0Z0?ooo`D00000o`3ooomF0?ooo`007`3oool00`000000oooo0?oo
o`0/0?ooo`D00000o`3ooomD0?ooo`007`3oool00`000000oooo0?ooo`0_0?ooo`@00000o`3ooomB
0?ooo`007`3oool00`000000oooo0?ooo`0a0?ooo`@00000o`3ooom@0?ooo`007`3oool00`000000
oooo0?ooo`0d0?ooo`<00000o`3ooom>0?ooo`007`3oool00`000000oooo0?ooo`0f0?ooo`<00000
o`3ooom<0?ooo`007`3oool00`000000oooo0?ooo`0i0?ooo`800000o`3ooom:0?ooo`007`3oool0
0`000000oooo0?ooo`0k0?ooo`<00000o`3ooom70?ooo`007`3oool00`000000oooo0?ooo`0n0?oo
o`800000o`3ooom50?ooo`007`3oool00`000000oooo0?ooo`100?ooo`800000o`3ooom30?ooo`00
7`3oool00`000000oooo0?ooo`120?ooo`800000o`3ooom10?ooo`007`3oool00`000000oooo0?oo
o`140?ooo`<00000o`3oooln0?ooo`007`3oool3000004L0oooo0P00003o0?oooc`0oooo000O0?oo
o`030000003oool0oooo04T0oooo0P00003o0?ooocX0oooo000O0?ooo`030000003oool0oooo04/0
oooo0P00003o0?ooocP0oooo000O0?ooo`030000003oool0oooo04d0oooo0P00003o0?ooocH0oooo
000O0?ooo`030000003oool0oooo04l0oooo0P00003o0?oooc@0oooo000O0?ooo`030000003oool0
oooo0540oooo0P00003o0?oooc80oooo000O0?ooo`030000003oool0oooo05<0oooo0P00003o0?oo
oc00oooo000O0?ooo`030000003oool0oooo05D0oooo0P00003o0?ooobh0oooo000O0?ooo`030000
003oool0oooo05L0oooo0P00003o0?ooob`0oooo000O0?ooo`030000003oool0oooo05T0oooo0P00
003o0?ooobX0oooo000O0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0o`3ooolW
0?ooo`007`3oool00`000000oooo0?ooo`1L0?ooo`800000o`3ooolW0?ooo`007`3oool00`000000
oooo0?ooo`1N0?ooo`800000o`3ooolU0?ooo`007`3oool00`000000oooo0?ooo`1P0?ooo`800000
o`3ooolS0?ooo`007`3oool00`000000oooo0?ooo`1R0?ooo`800000o`3ooolQ0?ooo`007`3oool3
000006@0oooo0P00003o0?oooal0oooo000O0?ooo`030000003oool0oooo06H0oooo0P00003o0?oo
oad0oooo000O0?ooo`030000003oool0oooo06P0oooo0P00003o0?oooa/0oooo000O0?ooo`030000
003oool0oooo06X0oooo0P00003o0?oooaT0oooo000O0?ooo`030000003oool0oooo06`0oooo0P00
003o0?oooaL0oooo000O0?ooo`030000003oool0oooo06h0oooo0P00003o0?oooaD0oooo000O0?oo
o`030000003oool0oooo0700oooo0P00003o0?oooa<0oooo000O0?ooo`030000003oool0oooo0780
oooo0P00003o0?oooa40oooo000O0?ooo`030000003oool0oooo07<0oooo0`00003o0?ooo`l0oooo
000O0?ooo`030000003oool0oooo07D0oooo0`00003o0?ooo`d0oooo000O0?ooo`030000003oool0
oooo07L0oooo0`00003o0?ooo`/0oooo00090?ooo`<000000`3oool010000000oooo0?ooo`3oool5
000000L0oooo00<000000?ooo`3oool0N@3oool300000?l0oooo2@3oool000X0oooo00<000000?oo
o`3oool01`3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo07/0oooo0`00003o
0?ooo`L0oooo000:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`1l0?ooo`@00000o`3oool50?ooo`002P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0OP3oool300000?l0oooo103oool000X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`@00000O`3oool300000?l0oooo
0P3oool000X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0880oooo0`00003o0?ooo`002P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0Q03oool200000?h0oooo000:0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`260?ooo`800000o03oool000T0
oooo0P0000080?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`280?oo
o`800000nP3oool000X0oooo00<000000?ooo`3oool01`3oool3000000P0oooo00<000000?ooo`3o
ool0RP3oool00`000000oooo0?ooo`3g0?ooo`007`3oool00`000000oooo0?ooo`2;0?ooo`800000
m`3oool001l0oooo00<000000?ooo`3oool0S@3oool200000?D0oooo000O0?ooo`030000003oool0
oooo08l0oooo0P00003c0?ooo`007`3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo
0?00oooo000O0?ooo`030000003oool0oooo0980oooo0P00003`0?ooo`007`3oool00`000000oooo
0?ooo`2D0?ooo`800000kP3oool001l0oooo00<000000?ooo`3oool0UP3oool200000>`0oooo000O
0?ooo`030000003oool0oooo09P0oooo0P00003Z0?ooo`007`3oool00`000000oooo0?ooo`2J0?oo
o`030000003oool0oooo0>L0oooo000O0?ooo`<00000V`3oool200000>L0oooo000O0?ooo`030000
003oool0oooo09d0oooo0P00003U0?ooo`007`3oool00`000000oooo0?ooo`2O0?ooo`800000h`3o
ool001l0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`3P0?ooo`007`3oool00`00
0000oooo0?ooo`2R0?ooo`800000h03oool001l0oooo00<000000?ooo`3oool0Y03oool200000=h0
oooo000O0?ooo`030000003oool0oooo0:H0oooo0P00003L0?ooo`007`3oool00`000000oooo0?oo
o`2X0?ooo`800000fP3oool001l0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`3G
0?ooo`007`3oool00`000000oooo0?ooo`2[0?ooo`800000e`3oool001l0oooo00<000000?ooo`3o
ool0[@3oool00`000000oooo0?ooo`3D0?ooo`007`3oool00`000000oooo0?ooo`2^0?ooo`800000
e03oool001l0oooo00<000000?ooo`3oool0[`3oool200000=<0oooo000O0?ooo`030000003oool0
oooo0;40oooo0P00003A0?ooo`007`3oool00`000000oooo0?ooo`2b0?ooo`<00000c`3oool001l0
oooo0`00002d0?ooo`800000cP3oool001l0oooo00<000000?ooo`3oool0]@3oool300000<`0oooo
000O0?ooo`030000003oool0oooo0;H0oooo0`00003;0?ooo`007`3oool00`000000oooo0?ooo`2h
0?ooo`<00000b@3oool001l0oooo00<000000?ooo`3oool0^@3oool300000<P0oooo000O0?ooo`03
0000003oool0oooo0;/0oooo0`0000360?ooo`007`3oool00`000000oooo0?ooo`2l0?ooo`@00000
a03oool001l0oooo00<000000?ooo`3oool0_P3oool300000<<0oooo000O0?ooo`030000003oool0
oooo0<00oooo0`0000310?ooo`007`3oool00`000000oooo0?ooo`310?ooo`<00000`03oool001l0
oooo00<000000?ooo`3oool0``3oool300000;h0oooo000O0?ooo`030000003oool0oooo0<@0oooo
1000002l0?ooo`007`3oool00`000000oooo0?ooo`360?ooo`<00000^`3oool001l0oooo00<00000
0?ooo`3oool0b03oool300000;T0oooo000O0?ooo`030000003oool0oooo0<T0oooo0`00002h0?oo
o`007`3oool300000</0oooo0`00002f0?ooo`007`3oool00`000000oooo0?ooo`3<0?ooo`<00000
]@3oool001l0oooo00<000000?ooo`3oool0cP3oool200000;@0oooo000O0?ooo`030000003oool0
oooo0=00oooo0P00002b0?ooo`007`3oool00`000000oooo0?ooo`3A0?ooo`800000/@3oool001l0
oooo00<000000?ooo`3oool0d`3oool200000:l0oooo000O0?ooo`030000003oool0oooo0=@0oooo
0P00002^0?ooo`007`3oool00`000000oooo0?ooo`3F0?ooo`800000[03oool001l0oooo00<00000
0?ooo`3oool0f03oool00`000000oooo0?ooo`2Y0?ooo`007`3oool00`000000oooo0?ooo`3I0?oo
o`800000Z@3oool001l0oooo00<000000?ooo`3oool0f`3oool00`000000oooo0?ooo`2V0?ooo`00
7`3oool00`000000oooo0?ooo`3L0?ooo`800000YP3oool000T0oooo0`0000030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3N0?ooo`030000003o
ool0oooo0:<0oooo000:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`3O0?ooo`030000003oool0oooo0:80oooo000:0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3P0?ooo`800000XP3oool000X0
oooo00<000000?ooo`3oool01@3oool6000000L0oooo1000003Q0?ooo`030000003oool0oooo09l0
oooo000:0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000080?ooo`03
0000003oool0oooo0><0oooo0P00002O0?ooo`002P3oool00`000000oooo0?ooo`060?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool0i@3oool00`000000oooo0?ooo`2L0?ooo`00
2P3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool0
iP3oool2000009`0oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000203o
ool00`000000oooo0?ooo`3X0?ooo`030000003oool0oooo09T0oooo00090?ooo`8000002P3oool2
000000P0oooo00<000000?ooo`3oool0j@3oool2000009T0oooo000:0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3[0?ooo`030000003oool0oooo
09H0oooo000O0?ooo`030000003oool0oooo0>`0oooo0P00002F0?ooo`007`3oool00`000000oooo
0?ooo`3^0?ooo`030000003oool0oooo09<0oooo000O0?ooo`030000003oool0oooo0>l0oooo0P00
002C0?ooo`007`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo0900oooo000O0?oo
o`030000003oool0oooo0?80oooo0P00002@0?ooo`007`3oool00`000000oooo0?ooo`3d0?ooo`03
0000003oool0oooo08d0oooo000O0?ooo`030000003oool0oooo0?D0oooo0P00002=0?ooo`007`3o
ool00`000000oooo0?ooo`3g0?ooo`030000003oool0oooo08X0oooo000O0?ooo`030000003oool0
oooo0?P0oooo0P00002:0?ooo`007`3oool300000?X0oooo00<000000?ooo`3oool0Q`3oool001l0
oooo00<000000?ooo`3oool0n`3oool00`000000oooo0?ooo`260?ooo`007`3oool00`000000oooo
0?ooo`3l0?ooo`800000QP3oool001l0oooo00<000000?ooo`3oool0oP3oool00`000000oooo0?oo
o`230?ooo`007`3oool00`000000oooo0?ooo`3o0?ooo`030000003oool0oooo0880oooo000O0?oo
o`030000003oool0oooo0?l0oooo0@3oool200000880oooo000O0?ooo`030000003oool0oooo0?l0
oooo0`3oool00`000000oooo0?ooo`1o0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooo`@0oooo
00<000000?ooo`3oool0OP3oool001l0oooo00<000000?ooo`3oool0o`3oool50?ooo`800000OP3o
ool001l0oooo00<000000?ooo`3oool0o`3oool70?ooo`030000003oool0oooo07/0oooo000O0?oo
o`030000003oool0oooo0?l0oooo203oool00`000000oooo0?ooo`1j0?ooo`007`3oool00`000000
oooo0?ooo`3o0?ooo`T0oooo0P00001j0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooo`/0oooo
00<000000?ooo`3oool0M`3oool001l0oooo00<000000?ooo`3oool0o`3oool<0?ooo`030000003o
ool0oooo07H0oooo000O0?ooo`030000003oool0oooo0?l0oooo3@3oool2000007H0oooo000O0?oo
o`<00000o`3oool?0?ooo`030000003oool0oooo07<0oooo000O0?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`1b0?ooo`007`3oool00`000000oooo0?ooo`3o0?oooa40oooo
0P00001b0?ooo`007`3oool00`000000oooo0?ooo`3o0?oooa<0oooo00<000000?ooo`3oool0K`3o
ool001l0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`030000003oool0oooo06h0oooo000O0?oo
o`030000003oool0oooo0?l0oooo5@3oool2000006h0oooo000O0?ooo`030000003oool0oooo0?l0
oooo5`3oool00`000000oooo0?ooo`1[0?ooo`007`3oool00`000000oooo0?ooo`3o0?oooaP0oooo
0P00001[0?ooo`007`3oool00`000000oooo0?ooo`3o0?oooaX0oooo00<000000?ooo`3oool0J03o
ool001l0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`800000J03oool001l0oooo00<000000?oo
o`3oool0o`3ooolM0?ooo`030000003oool0oooo06D0oooo000O0?ooo`030000003oool0oooo0?l0
oooo7P3oool00`000000oooo0?ooo`1T0?ooo`007`3oool00`000000oooo0?ooo`3o0?oooal0oooo
0P00001T0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooob40oooo00<000000?ooo`3oool0H@3o
ool001l0oooo00<000000?ooo`3oool0o`3ooolR0?ooo`800000H@3oool001l0oooo0`00003o0?oo
ob@0oooo00<000000?ooo`3oool0GP3oool001l0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`80
0000GP3oool001l0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo05/0oooo
000O0?ooo`030000003oool0oooo0?l0oooo:03oool00`000000oooo0?ooo`1J0?ooo`007`3oool0
0`000000oooo0?ooo`3o0?ooobT0oooo0P00001J0?ooo`007`3oool00`000000oooo0?ooo`3o0?oo
ob/0oooo00<000000?ooo`3oool0E`3oool001l0oooo00<000000?ooo`3oool0o`3oool/0?ooo`03
0000003oool0oooo05H0oooo000O0?ooo`030000003oool0oooo0?l0oooo;@3oool2000005H0oooo
000O0?ooo`030000003oool0oooo0?l0oooo;P3oool2000005D0oooo000O0?ooo`030000003oool0
oooo0?l0oooo;`3oool2000005@0oooo000O0?ooo`030000003oool0oooo0?l0oooo<@3oool20000
0580oooo00090?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`<00000203oool00`000000
oooo0?ooo`3o0?oooc80oooo0P00001A0?ooo`002P3oool00`000000oooo0?ooo`060?ooo`050000
003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`3o0?oooc<0oooo0P00001@0?ooo`00
2P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000
oooo0?ooo`3o0?oooc@0oooo0`00001>0?ooo`002P3oool00`000000oooo0?ooo`060?ooo`050000
003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`3o0?ooocH0oooo0P00001=0?ooo`00
2P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000001`3oool400000?l0
oooo=P3oool2000004`0oooo000:0?ooo`030000003oool0oooo00H0oooo0P0000020?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`<00000BP3oool000X0oooo00<0
00000?ooo`3oool01P3oool010000000oooo0000000000080?ooo`030000003oool0oooo0?l0oooo
>@3oool3000004T0oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`3o0?oooc/0oooo0P0000180?ooo`002@3oool2000000X0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oooc`0oooo0P0000170?ooo`002P3oool00`00
0000oooo0?ooo`090?ooo`8000001`3oool00`000000oooo0?ooo`3o0?ooocd0oooo0P0000160?oo
o`007`3oool00`000000oooo0?ooo`3o0?ooocl0oooo0P0000140?ooo`007`3oool00`000000oooo
0?ooo`3o0?oood00oooo0P0000130?ooo`007`3oool00`000000oooo0?ooo`3o0?oood40oooo0P00
00120?ooo`007`3oool00`000000oooo0?ooo`3o0?oood<0oooo00<000000?ooo`3oool0?`3oool0
01l0oooo00<000000?ooo`3oool0o`3ooom40?ooo`800000?`3oool001l0oooo00<000000?ooo`3o
ool0o`3ooom50?ooo`800000?P3oool001l0oooo00<000000?ooo`3oool0o`3ooom70?ooo`030000
003oool0oooo03/0oooo000O0?ooo`030000003oool0oooo0?l0ooooB03oool00`000000oooo0?oo
o`0j0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooodT0oooo0P00000j0?ooo`007`3oool30000
0?l0ooooB`3oool00`000000oooo0?ooo`0g0?ooo`007`3oool00`000000oooo0?ooo`3o0?oood`0
oooo00<000000?ooo`3oool0=P3oool001l0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000
003oool0oooo03D0oooo000O0?ooo`030000003oool0oooo0?l0ooooCP3oool2000003D0oooo000O
0?ooo`030000003oool0oooo0?l0ooooD03oool00`000000oooo0?ooo`0b0?ooo`007`3oool00`00
0000oooo0?ooo`3o0?oooe40oooo00<000000?ooo`3oool0<@3oool001l0oooo00<000000?ooo`3o
ool0o`3ooomB0?ooo`030000003oool0oooo0300oooo000O0?ooo`030000003oool0oooo0?l0oooo
D`3oool200000300oooo000O0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?oo
o`0]0?ooo`007`3oool00`000000oooo0?ooo`3o0?oooeH0oooo00<000000?ooo`3oool0;03oool0
01l0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`030000003oool0oooo02/0oooo000O0?ooo`03
0000003oool0oooo0?l0ooooF03oool2000002/0oooo000O0?ooo`030000003oool0oooo0?l0oooo
F@3oool2000002X0oooo000O0?ooo`030000003oool0oooo0?l0ooooFP3oool2000002T0oooo000O
0?ooo`030000003oool0oooo0?l0ooooG03oool00`000000oooo0?ooo`0V0?ooo`007`3oool30000
0?l0ooooG@3oool00`000000oooo0?ooo`0U0?ooo`007`3oool00`000000oooo0?ooo`3o0?oooeh0
oooo0P00000U0?ooo`007`3oool00`000000oooo0?ooo`3o0?oooel0oooo0P00000T0?ooo`007`3o
ool00`000000oooo0?ooo`3o0?ooof00oooo0P00000S0?ooo`007`3oool00`000000oooo0?ooo`3o
0?ooof40oooo0P00000R0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooof80oooo0`00000P0?oo
o`007`3oool00`000000oooo0?ooo`3o0?ooof@0oooo0P00000O0?ooo`007`3oool00`000000oooo
0?ooo`3o0?ooofD0oooo0P00000N0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooofH0oooo0P00
000M0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooofL0oooo0`00000K0?ooo`007`3oool00`00
0000oooo0?ooo`3o0?ooofP0oooo0`00000J0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooofX0
oooo0P00000I0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooof/0oooo0P00000H0?ooo`007`3o
ool00`000000oooo0?ooo`3o0?ooof`0oooo0`00000F0?ooo`007`3oool00`000000oooo0?ooo`3o
0?ooofd0oooo0`00000E0?ooo`007`3oool300000?l0ooooK`3oool2000001@0oooo000O0?ooo`03
0000003oool0oooo0?l0ooooL03oool2000001<0oooo000O0?ooo`030000003oool0oooo0?l0oooo
L@3oool300000140oooo000O0?ooo`030000003oool0oooo0?l0ooooLP3oool300000100oooo000O
0?ooo`030000003oool0oooo0?l0ooooM03oool2000000l0oooo000O0?ooo`030000003oool0oooo
0?l0ooooM@3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooohD0
oooo000O0?ooo`030000003oool0oooo0?l0ooooQ@3oool001l0oooo00<000000?ooo`3oool0o`3o
oon50?ooo`007`3oool00`000000oooo0?ooo`3o0?ooohD0oooo000O0?ooo`030000003oool0oooo
0?l0ooooQ@3oool00001\
\>"],
  ImageRangeCache->{{{0, 421.188}, {259.938, 0}} -> {-0.0852553, 0.924948, \
0.00267055, 0.0033024}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.476191 13.2528 12.5947 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.2619 -0.0125 -10.7813 -17.8125 ]
[.2619 -0.0125 10.7813 0 ]
[.5 -0.0125 -5.53125 -17.8125 ]
[.5 -0.0125 5.53125 0 ]
[.7381 -0.0125 -10.7813 -17.8125 ]
[.7381 -0.0125 10.7813 0 ]
[.97619 -0.0125 -5.53125 -17.8125 ]
[.97619 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.125 -35.625 ]
[.5 -0.0125 5.125 -17.8125 ]
[-0.0125 .02841 -38.3125 -8.90625 ]
[-0.0125 .02841 0 8.90625 ]
[-0.0125 .15435 -38.3125 -8.90625 ]
[-0.0125 .15435 0 8.90625 ]
[-0.0125 .2803 -38.3125 -8.90625 ]
[-0.0125 .2803 0 8.90625 ]
[-0.0125 .40625 -38.3125 -8.90625 ]
[-0.0125 .40625 0 8.90625 ]
[-0.0125 .53219 -38.3125 -8.90625 ]
[-0.0125 .53219 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -56.125 -14.7188 ]
[-0.01875 .30902 -38.3125 14.7188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.125 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02841 m
.00625 .02841 L
s
gsave
-0.0125 .02841 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
1.000 setlinewidth
grestore
0 .15435 m
.00625 .15435 L
s
gsave
-0.0125 .15435 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.04) show
1.000 setlinewidth
grestore
0 .2803 m
.00625 .2803 L
s
gsave
-0.0125 .2803 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.03) show
1.000 setlinewidth
grestore
0 .40625 m
.00625 .40625 L
s
gsave
-0.0125 .40625 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.02) show
1.000 setlinewidth
grestore
0 .53219 m
.00625 .53219 L
s
gsave
-0.0125 .53219 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.01) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .0536 m
.00375 .0536 L
s
0 .07878 m
.00375 .07878 L
s
0 .10397 m
.00375 .10397 L
s
0 .12916 m
.00375 .12916 L
s
0 .17954 m
.00375 .17954 L
s
0 .20473 m
.00375 .20473 L
s
0 .22992 m
.00375 .22992 L
s
0 .25511 m
.00375 .25511 L
s
0 .30549 m
.00375 .30549 L
s
0 .33068 m
.00375 .33068 L
s
0 .35587 m
.00375 .35587 L
s
0 .38106 m
.00375 .38106 L
s
0 .43144 m
.00375 .43144 L
s
0 .45662 m
.00375 .45662 L
s
0 .48181 m
.00375 .48181 L
s
0 .507 m
.00375 .507 L
s
0 .00322 m
.00375 .00322 L
s
0 .55738 m
.00375 .55738 L
s
0 .58257 m
.00375 .58257 L
s
0 .60776 m
.00375 .60776 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -122.938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.7188 12.9063 translate
90 rotate
-75.7188 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.063 17.500 moveto
(H) show
77.625 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.875 17.500 moveto
(L) show
88.438 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02841 m
1 .02841 L
s
.99375 .15435 m
1 .15435 L
s
.99375 .2803 m
1 .2803 L
s
.99375 .40625 m
1 .40625 L
s
.99375 .53219 m
1 .53219 L
s
.125 Mabswid
.99625 .0536 m
1 .0536 L
s
.99625 .07878 m
1 .07878 L
s
.99625 .10397 m
1 .10397 L
s
.99625 .12916 m
1 .12916 L
s
.99625 .17954 m
1 .17954 L
s
.99625 .20473 m
1 .20473 L
s
.99625 .22992 m
1 .22992 L
s
.99625 .25511 m
1 .25511 L
s
.99625 .30549 m
1 .30549 L
s
.99625 .33068 m
1 .33068 L
s
.99625 .35587 m
1 .35587 L
s
.99625 .38106 m
1 .38106 L
s
.99625 .43144 m
1 .43144 L
s
.99625 .45662 m
1 .45662 L
s
.99625 .48181 m
1 .48181 L
s
.99625 .507 m
1 .507 L
s
.99625 .00322 m
1 .00322 L
s
.99625 .55738 m
1 .55738 L
s
.99625 .58257 m
1 .58257 L
s
.99625 .60776 m
1 .60776 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.06244 .07798 L
.10458 .14288 L
.14415 .19886 L
.18221 .24771 L
.22272 .29431 L
.26171 .33412 L
.30316 .37141 L
.34309 .4029 L
.3815 .42953 L
.42237 .45439 L
.46172 .47535 L
.49955 .4931 L
.53984 .50975 L
.57861 .52385 L
.61984 .53707 L
.65954 .5483 L
.69774 .55788 L
.73838 .56695 L
.77751 .57471 L
.81909 .58206 L
.85916 .58837 L
.89771 .59382 L
.93871 .59903 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{422.188, 260.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006V000112000`400?l00000o`00003oo`3ooonW
0?ooo`00o`3ooonW0?ooo`00o`3ooonW0?ooo`00o`3ooonW0?ooo`00o`3ooonW0?ooo`00kP3oool6
00000;80oooo003_0?ooo`050000003oool0oooo0?ooo`000000/P3oool00?00oooo00<000000?oo
o`3oool0/`3oool00?00oooo00<000000?ooo`3oool0/`3oool00?40oooo00<000000?ooo`3oool0
/P3oool00>h0oooo00D000000?ooo`3oool0oooo0000002c0?ooo`00kP3oool600000;80oooo003o
0?ooojL0oooo003o0?ooojL0oooo003o0?ooojL0oooo003o0?ooojL0oooo003o0?ooojL0oooo003o
0?ooojL0oooo003o0?ooojL0oooo003o0?ooojL0oooo003o0?ooojL0oooo003o0?ooojL0oooo003o
0?ooojL0oooo00160?ooo`<00000C@3oool3000000<0oooo00@000000?ooo`3oool0oooo0`00001=
0?ooo`<00000C03oool3000000<0oooo00@000000?ooo`3oool0oooo0`00001<0?ooo`D000002@3o
ool004D0oooo00D000000?ooo`3oool0oooo0000001;0?ooo`050000003oool0oooo0?ooo`000000
2@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`1:0?ooo`040000003oool0oooo000000T0oooo00150?ooo`050000
003oool0oooo0?ooo`000000B`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`090?ooo`00A@3oool01@000000oooo0?ooo`3oool00000
04/0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo04X0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool0203oool004D0oooo00D000000?ooo`3oool0oooo0000001;0?ooo`050000003oool0
oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04`0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00P0oooo0015
0?ooo`050000003oool0oooo0?ooo`000000B`3oool01@000000oooo0?ooo`3oool0000000T0oooo
00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`070?ooo`00A@3oool01@000000oooo0?oo
o`3oool0000004/0oooo00D000000?ooo`3oool0oooo000000060?ooo`<00000CP3oool00`000000
oooo0?ooo`1<0?ooo`030000003oool0oooo00H0oooo0`00001@0?ooo`030000003oool0oooo00L0
oooo00150?ooo`050000003oool0oooo0?ooo`000000B`3oool01@000000oooo0?ooo`3oool00000
00H0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`00A@3oool01@000000
oooo0?ooo`3oool0000004/0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0
oooo04`0oooo0P00001=0?ooo`8000002@3oool00`000000oooo0?ooo`1;0?ooo`050000003oool0
oooo0?ooo`0000002@3oool004H0oooo0`00001=0?ooo`<00000203oool4000004`0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`070?ooo`@00000B`3oool3000000X0oooo003o0?oo
ojL0oooo003o0?ooojL0oooo003o0?ooojL0oooo003o0?ooojL0oooo003o0?ooojL0oooo003o0?oo
ojL0oooo003o0?ooojL0oooo00100?ooool00000I@0000020?ooo`00@03oool2000000H0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo0P00
00020?ooo`00@03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0580oooo00<00000
0?ooo`3oool0D@3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0580oooo00<00000
0?ooo`3oool01@3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0o`3ooomQ0?oo
o`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`3o0?ooof40oooo0@0000010?ooo`40
oooo00100?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooomI0?ooo`400000
0@3oool10?ooo`008`3oool3000000<0oooo00<000000?ooo`3oool00P3oool3000000<0oooo0`00
00090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooomH0?ooo`4000000@3o
ool10?ooo`00903oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000001@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3o
oomH0?ooo`4000000@3oool10?ooo`00903oool00`000000oooo0?ooo`060?ooo`050000003oool0
oooo0?ooo`0000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0o`3ooomG0?ooo`4000000@3oool10?ooo`00603oool7000000D0oooo00<00000
0?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooEP3oool100000040oooo0@3o
ool002@0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<0
00000?ooo`3oool01@3oool3000000P0oooo00<000000?ooo`3oool0o`3ooomD0?ooo`<000000P3o
ool002@0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0ooooE@3o
ool100000040oooo0@3oool002@0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3o
ool000000080oooo0`0000090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3o
oomE0?ooo`4000000@3oool10?ooo`00903oool00`000000oooo0?ooo`060?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0o`3ooomD0?ooo`4000000@3oool10?ooo`008`3oool2000000P0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`3o0?oooe<0oooo0@0000010?ooo`40oooo000T0?ooo`030000003oool0
oooo00L0oooo0`0000040?ooo`@000001`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo0?l0ooooD`3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`3o0?oooe80oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0o`3ooomA0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooD@3oool100000040oooo0@3oool00400oooo0P00
000?0?ooo`030000003oool0oooo0?l0ooooC`3oool200000080oooo00100?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0o`3ooom?0?ooo`4000000@3oool10?ooo`00@03oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooC`3oool100000040oooo0@3oool00400
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`40
oooo00100?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0o`3ooom>0?ooo`400000
0@3oool10?ooo`00@03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0ooooC@3o
ool100000040oooo0@3oool00400oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3o
0?oood`0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0o`3ooom<0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0?l0ooooB`3oool100000040oooo0@3oool00400oooo0P00000E0?ooo`030000
003oool0oooo0?l0ooooB@3oool200000080oooo00100?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0o`3ooom:0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0?l0ooooB@3oool100000040oooo0@3oool00400oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`3o0?ooodP0oooo0@0000010?ooo`40oooo00100?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0o`3ooom80?ooo`4000000@3oool10?ooo`00
@03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0?l0ooooA`3oool100000040oooo
0@3oool00400oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`3o0?ooodH0oooo0@00
00010?ooo`40oooo00100?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3ooom6
0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
0?l0ooooA@3oool100000040oooo0@3oool00400oooo0P00000K0?ooo`030000003oool0oooo0?l0
oooo@`3oool200000080oooo00100?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
o`3ooom40?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo0?l0oooo@`3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`3o0?oood<0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool10?ooo`00@03oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo0?l0oooo@@3oool100000040oooo0@3oool00400oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3o0?oood40oooo0@0000010?ooo`40oooo
00100?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0o`3ooom00?ooo`4000000@3o
ool10?ooo`00@03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0oooo?`3oool1
00000040oooo0@3oool00400oooo0P00000P0?ooo`030000003oool0oooo0?l0oooo?P3oool20000
0080oooo00100?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0o`3oooln0?ooo`40
00000@3oool10?ooo`00@03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0oooo
?@3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`3o0?ooocd0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool0o`3oooll0?ooo`4000000@3oool10?ooo`008`3oool3000000<0oooo00<000000?oo
o`3oool00P3oool3000000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0?l0oooo>`3oool100000040oooo0@3oool002@0oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo0?l0oooo>`3oool100000040oooo0@3oool002@0
oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0?l0oooo>P3oool10000
0040oooo0@3oool001P0oooo1`0000050?ooo`030000003oool0oooo00H0oooo00H000000?ooo`3o
ool0oooo0000003oool6000000L0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3o
0?ooocT0oooo0@0000010?ooo`40oooo000T0?ooo`030000003oool0oooo00H0oooo00L000000?oo
o`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool01P3oool3000002D0oooo00<0
00000?ooo`3oool0o`3ooolg0?ooo`<000000P3oool002@0oooo00<000000?ooo`3oool01P3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000203oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo0?l0oooo>03oool100000040oooo0@3oool002@0oooo00<0
00000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`000000
203oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0?l0oooo=`3oool100000040oooo
0@3oool002@0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`000000203oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0?l0oooo
=P3oool100000040oooo0@3oool002<0oooo0P0000080?ooo`050000003oool0oooo0?ooo`000000
103oool2000000P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`3o0?ooocH0oooo
0@0000010?ooo`40oooo000T0?ooo`030000003oool0oooo00L0oooo0`0000060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?ooocD0oooo0@00
00010?ooo`40oooo00100?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0o`3ooold
0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
0?l0oooo=03oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`3o0?oooc<0oooo0@0000010?ooo`40oooo00100?ooo`800000;@3oool00`000000oooo
0?ooo`3o0?oooc40oooo0P0000020?ooo`00@03oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo0?l0oooo<P3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`3o0?oooc40oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool0o`3oool`0?ooo`4000000@3oool10?ooo`00@03oool00`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo0?l0oooo;`3oool100000040oooo0@3oool00400oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`3o0?ooobl0oooo0@0000010?ooo`40oooo
00100?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0o`3oool^0?ooo`4000000@3o
ool10?ooo`00@03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0?l0oooo;@3oool1
00000040oooo0@3oool00400oooo0P00000b0?ooo`030000003oool0oooo0?l0oooo;03oool20000
0080oooo00100?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0o`3oool/0?ooo`40
00000@3oool10?ooo`00@03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0?l0oooo
:`3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`3o0?ooobX0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0o`3ooolZ0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo0?l0oooo:@3oool100000040oooo0@3oool00400oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`3o0?ooobP0oooo0@0000010?ooo`40oooo00100?ooo`030000
003oool0oooo03H0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`4000000@3oool10?ooo`00@03o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0?l0oooo9`3oool100000040oooo0@3o
ool00400oooo0P00000i0?ooo`030000003oool0oooo0?l0oooo9@3oool200000080oooo00100?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`4000000@3oool10?oo
o`00@03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0?l0oooo9@3oool100000040
oooo0@3oool00400oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`3o0?ooob@0oooo
0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3o
oolS0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo0?l0oooo8P3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0?03oool00`00
0000oooo0?ooo`3o0?ooob80oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo0?l0oooo803oool100000040oooo0@3oool00400oooo0P00
00100?ooo`030000003oool0oooo0?l0oooo7P3oool200000080oooo00100?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool0o`3ooolN0?ooo`4000000@3oool10?ooo`00@03oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo0?l0oooo7@3oool100000040oooo0@3oool00400
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`40
oooo00100?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`400000
0@3oool10?ooo`00@03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0?l0oooo6P3o
ool100000040oooo0@3oool002<0oooo0`0000030?ooo`030000003oool0oooo0080oooo0`000003
0?ooo`@00000203oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0?l0oooo6P3oool1
00000040oooo0@3oool002@0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0
000000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo0?l0oooo6@3oool100000040oooo0@3oool000L0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0o`3ooolH0?ooo`4000000@3oool1
0?ooo`001`3oool3000000h0oooo1`0000050?ooo`030000003oool0oooo00H0oooo00D000000?oo
o`3oool0oooo000000060?ooo`030000003oool0oooo00D0oooo0`0000170?ooo`030000003oool0
oooo0?l0oooo5@3oool300000080oooo00070?ooo`030000003oool0oooo00<000005`3oool00`00
0000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`4000000@3oool1
0?ooo`00303oool2000001H0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0
000000@0oooo0P0000080?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0o`3ooolE
0?ooo`4000000@3oool10?ooo`001`3oool00`000000oooo0?ooo`02000001P0oooo00<000000?oo
o`3oool01P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0?l0oooo503oool100000040oooo0@3oool0
00L0oooo0`00000J0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo00000006
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o
0?oooa<0oooo0@0000010?ooo`40oooo00070?ooo`030000003oool0oooo00<000005P3oool20000
00P0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000001`3o
ool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0?l0oooo4P3oool100000040oooo0@3o
ool000`0oooo0P00000F0?ooo`030000003oool0oooo00L0oooo0`0000040?ooo`<00000203oool0
0`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0?l0oooo4@3oool100000040oooo0@3oool0
00L0oooo00<000000?ooo`3oool00P00000d0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`4000000@3oool10?ooo`001`3oool3000003H0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo0@0000010?ooo`40oooo00070?ooo`030000
003oool0oooo03H0oooo0P00001A0?ooo`030000003oool0oooo0?l0oooo3@3oool200000080oooo
00060?ooo`T00000<@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0?l0oooo3@3o
ool100000040oooo0@3oool000D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0o`3oool<0?ooo`4000000@3oool1
0?ooo`00103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool0D`3oool00`000000oooo0?ooo`3o0?ooo`/0oooo0@0000010?ooo`40oooo00070?ooo`80
0000103oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3o
ool0o`3oool:0?ooo`4000000@3oool10?ooo`001`3oool00`000000oooo0?ooo`020?ooo`800000
<P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0?l0oooo2@3oool100000040oooo
0@3oool000L0oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`0a0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool0o`3oool80?ooo`4000000@3oool10?ooo`001`3oool0
0`000000oooo000000030?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`40oooo00070?ooo`800000103oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0o`3oool60?oo
o`4000000@3oool10?ooo`001`3oool00`000000oooo0?ooo`020?ooo`800000<P3oool2000005X0
oooo00<000000?ooo`3oool0o`3oool40?ooo`8000000P3oool00400oooo00<000000?ooo`3oool0
FP3oool00`000000oooo0?ooo`3o0?ooo`@0oooo0@0000010?ooo`40oooo00040?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1K0?ooo`030000003o
ool0oooo0?l0oooo0`3oool100000040oooo0@3oool000D0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0o`3oool2
0?ooo`4000000@3oool10?ooo`001P3oool900000340oooo00<000000?ooo`3oool0G@3oool00`00
0000oooo0?ooo`3o0?ooo`40oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo05h0
oooo00<000000?ooo`3oool0o`3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0
G`3oool00`000000oooo0?ooo`3n0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?oo
o`1P0?ooo`030000003oool0oooo0?d0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0
oooo0640oooo00<000000?ooo`3oool0o03oool100000040oooo0@3oool00400oooo0P00001S0?oo
o`030000003oool0oooo0?X0oooo0P0000020?ooo`00@03oool00`000000oooo0?ooo`1S0?ooo`03
0000003oool0oooo0?X0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo06@0oooo
00<000000?ooo`3oool0n@3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`3h0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo0?L0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo
06L0oooo00<000000?ooo`3oool0mP3oool100000040oooo0@3oool00400oooo00<000000?ooo`3o
ool0J03oool00`000000oooo0?ooo`3e0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo
0?ooo`1Y0?ooo`800000m@3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0J`3o
ool00`000000oooo0?ooo`3b0?ooo`4000000@3oool10?ooo`00@03oool2000006d0oooo00<00000
0?ooo`3oool0l03oool200000080oooo00100?ooo`030000003oool0oooo06d0oooo0P00003a0?oo
o`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0>h0
oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0
k@3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0L@3oool200000>d0oooo0@00
00010?ooo`40oooo00100?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0jP3oool1
00000040oooo0@3oool002<0oooo0`0000030?ooo`030000003oool0oooo0080oooo0`0000030?oo
o`D000001`3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0>T0oooo0@0000010?oo
o`40oooo000T0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000030?oo
o`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0M@3oool200000>T0oooo0@000001
0?ooo`40oooo000T0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`3V
0?ooo`4000000@3oool10?ooo`00603oool7000000D0oooo00<000000?ooo`3oool01P3oool01@00
0000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool01P3oool3000007P0oooo0P00003T
0?ooo`<000000P3oool002@0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0
000000D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0
oooo0><0oooo0@0000010?ooo`40oooo000T0?ooo`030000003oool0oooo00H0oooo00D000000?oo
o`3oool0oooo000000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0N`3oool2
00000><0oooo0@0000010?ooo`40oooo000T0?ooo`030000003oool0oooo00H0oooo00D000000?oo
o`3oool0oooo000000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0O@3oool0
0`000000oooo0?ooo`3P0?ooo`4000000@3oool10?ooo`00903oool00`000000oooo0?ooo`060?oo
o`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo07h0oooo00<000000?ooo`3oool0g`3oool100000040oooo0@3oool002<0oooo0P0000080?oo
o`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<0
00000?ooo`3oool0O`3oool200000=l0oooo0@0000010?ooo`40oooo000T0?ooo`030000003oool0
oooo00L0oooo0`0000040?ooo`<00000203oool00`000000oooo0?ooo`210?ooo`030000003oool0
oooo0=`0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo0880oooo0P00003L0?oo
o`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0=T0
oooo0@0000010?ooo`40oooo00100?ooo`800000QP3oool200000=P0oooo0P0000020?ooo`00@03o
ool00`000000oooo0?ooo`270?ooo`800000e`3oool100000040oooo0@3oool00400oooo00<00000
0?ooo`3oool0R@3oool00`000000oooo0?ooo`3D0?ooo`4000000@3oool10?ooo`00@03oool00`00
0000oooo0?ooo`2:0?ooo`800000e03oool100000040oooo0@3oool00400oooo00<000000?ooo`3o
ool0S03oool200000=80oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo08h0oooo
00<000000?ooo`3oool0c`3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0S`3o
ool200000<l0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo0940oooo0P00003=
0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo
0<X0oooo0@0000010?ooo`40oooo00100?ooo`800000U@3oool200000<T0oooo0P0000020?ooo`00
@03oool00`000000oooo0?ooo`2F0?ooo`800000b03oool100000040oooo0@3oool00400oooo00<0
00000?ooo`3oool0V03oool200000<H0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0
oooo09X0oooo00<000000?ooo`3oool0``3oool100000040oooo0@3oool00400oooo00<000000?oo
o`3oool0V`3oool200000<<0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo09d0
oooo0P0000310?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`2O0?ooo`800000
_`3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0X@3oool200000;d0oooo0@00
00010?ooo`40oooo00100?ooo`030000003oool0oooo0:<0oooo0P00002k0?ooo`4000000@3oool1
0?ooo`00@03oool200000:H0oooo0P00002h0?ooo`8000000P3oool00400oooo00<000000?ooo`3o
ool0Y`3oool200000;L0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo0:T0oooo
0P00002e0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`2[0?ooo`800000/`3o
ool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0[@3oool300000;00oooo0@000001
0?ooo`40oooo00100?ooo`030000003oool0oooo0;00oooo0P00002^0?ooo`4000000@3oool10?oo
o`00@03oool00`000000oooo0?ooo`2b0?ooo`<00000Z`3oool100000040oooo0@3oool00400oooo
00<000000?ooo`3oool0]@3oool200000:T0oooo0@0000010?ooo`40oooo00100?ooo`030000003o
ool0oooo0;L0oooo0`00002V0?ooo`4000000@3oool10?ooo`00@03oool200000;/0oooo0P00002S
0?ooo`8000000P3oool00400oooo00<000000?ooo`3oool0_03oool300000:40oooo0@0000010?oo
o`40oooo00100?ooo`030000003oool0oooo0;l0oooo0P00002O0?ooo`4000000@3oool10?ooo`00
@03oool00`000000oooo0?ooo`310?ooo`<00000W03oool100000040oooo0@3oool00400oooo00<0
00000?ooo`3oool0a03oool3000009T0oooo0@0000010?ooo`40oooo000S0?ooo`<000000`3oool0
0`000000oooo0?ooo`020?ooo`<00000103oool3000000P0oooo00<000000?ooo`3oool0a`3oool2
000009L0oooo0@0000010?ooo`40oooo000T0?ooo`030000003oool0oooo00H0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0b@3oool3
000009@0oooo0@0000010?ooo`40oooo000T0?ooo`030000003oool0oooo00H0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0c03oool3
00000940oooo0@0000010?ooo`40oooo000H0?ooo`L000001@3oool00`000000oooo0?ooo`060?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0<l0oooo0`00002>0?ooo`4000000@3oool10?ooo`00903oool00`000000oooo0?ooo`060?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`070?ooo`<00000dP3oool3
000008T0oooo0`0000020?ooo`00903oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0=D0oooo0`000028
0?ooo`4000000@3oool10?ooo`00903oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0=P0oooo0`000025
0?ooo`4000000@3oool10?ooo`00903oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0=/0oooo10000021
0?ooo`4000000@3oool10?ooo`008`3oool2000000P0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`8000002@3oool00`000000oooo0?ooo`3O0?ooo`<00000OP3oool100000040oooo0@3oool0
02@0oooo00<000000?ooo`3oool01`3oool3000000D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`3R0?ooo`@00000NP3oool100000040oooo0@3oool00400oooo00<000000?ooo`3o
ool0iP3oool4000007H0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo0>X0oooo
1000001b0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`3^0?ooo`D00000K@3o
ool100000040oooo0@3oool00400oooo0P00003d0?ooo`D00000I`3oool200000080oooo00100?oo
o`030000003oool0oooo0?P0oooo1000001T0?ooo`4000000@3oool10?ooo`00@03oool00`000000
oooo0?ooo`3l0?ooo`D00000G`3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0
o`3oool20?ooo`D00000FP3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0o`3o
ool70?ooo`@00000EP3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0o`3oool;
0?ooo`D00000D@3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0o`3oool@0?oo
o`D00000C03oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0o`3ooolE0?ooo`D0
0000A`3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`D00000
@P3oool100000040oooo0@3oool00400oooo0P00003o0?ooob00oooo1P00000k0?ooo`8000000P3o
ool00400oooo00<000000?ooo`3oool0o`3ooolU0?ooo`L00000=@3oool100000040oooo0@3oool0
0400oooo00<000000?ooo`3oool0o`3oool/0?ooo`L00000;P3oool100000040oooo0@3oool00400
oooo00<000000?ooo`3oool0o`3ooolc0?ooo`L000009`3oool100000040oooo0@3oool00400oooo
00<000000?ooo`3oool0o`3ooolj0?ooo`L00000803oool100000040oooo0@3oool00400oooo00<0
00000?ooo`3oool0o`3ooom10?ooo`P00000603oool100000040oooo0@3oool00400oooo00<00000
0?ooo`3oool0o`3ooom90?ooo`X000003P3oool100000040oooo0@3oool00400oooo00<000000?oo
o`3oool0o`3ooomC0?ooo`L000001`3oool100000040oooo0@3oool00400oooo00<000000?ooo`3o
ool0o`3ooomQ0?ooo`4000000@3oool10?ooo`00@03oool200000?l0ooooH@3oool200000080oooo
00100?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`1A0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`050?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`4000000@3oool1
0?ooo`00@03ooooo000006D000000P3oool00001\
\>"],
  ImageRangeCache->{{{0, 421.188}, {259.938, 0}} -> {-0.428116, -1.0612, \
0.00590304, 0.000223187}}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[{
    \( (*\ 
      Find\ chi\ square\ for\ given\ H \((z)\)\ \ *) \[IndentingNewLine]\(f[
          z_] := 1/hhz[z];\)\), "\n", 
    \(\(rr[zz_] := NIntegrate[f[z], {z, 0, zz}];\)\), "\n", 
    \(\(qq = Table[rr[zz[i]], {i, 1, ndat}];\)\)}], "Input"],

Cell[BoxData[{
    \( (*\ Construct\ marginalization\ coefficients\ \((see\ astro - 
              ph/0401556\  .. )\)\ *) \[IndentingNewLine]Clear[chi2fa, 
      chi2fb, chi2fc]\), "\n", 
    \(\(chi2fa = 
        Sum[\((ld[i] - 5\ Log[10, qq[\([i]\)]*\((1 + zz[i])\)])\)^2/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\n", 
    \(\(chi2fb = 
        Sum[\((ld[i] - 
                5\ Log[10, qq[\([i]\)]*\((1 + zz[i])\)])\)/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\n", 
    \(\(chi2fc = Sum[1/\((sld[i]^2)\), {i, 1, ndat}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ Construct\ function\ after\ marginalization, \ 
      find\ same\ result\ as\ with\ mb\ minimization\ *) \
\[IndentingNewLine]chi2fm = 
      chi2fa - chi2fb^2/chi2fc\), "\[IndentingNewLine]", 
    \(dchi2p07 = chi2fm - chi2l\)}], "Input"],

Cell[BoxData[
    \(176.92009966727346`\)], "Output"],

Cell[BoxData[
    \(\(-0.20727176778018475`\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ \(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(\
--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(-\(---\)\)\)\)\)\)\)\)\)\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)*) \[IndentingNewLine]\[IndentingNewLine] \
(*\ Find\ H \((z)\)\ for\ given\ slope\ s\ of\ the\ linear\ potential . \ 
            Present\ time\  = \ \(tt\ \((corresponds\ to\ a = 1)\) . \ 
              Run\ trials\ for\ initial\ condition\ for\ field\ fi\ \((f0)\)\ \
and\ initial\ time\ ti\ until\ we\ get\ field\ energy\ enf\  = \ \(0.7\ and\ \
H \((z = 0)\)\  = 
            1\ at\ present\ time\ \(\(tt\)\(.\)\)\)\)\ *) \[IndentingNewLine]\
\[IndentingNewLine] (*\ \(--\(--\(--\(--\ \ s\)\)\)\)\  = \ \(1\ \ \ --\) \(\
--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(---\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\ *) \
\[IndentingNewLine]\[IndentingNewLine]\(Clear[aa, fi, a, aad, aadd, fidas, 
        tas, f, rr, hht, hha];\)\), "\n", 
    \(aa = a[t]; \ fi = f[t];\), "\n", 
    \(\(aad = D[aa, t];\)\), "\n", 
    \(\(aadd = D[aa, {t, 2}];\)\), "\n", 
    \(\(fid = D[fi, t];\)\), "\n", 
    \(\(fidd = D[fi, {t, 2}];\)\n\), "\n", 
    \(ti = 0.0000017; \ t0 = 4;\), "\n", 
    \(\(f0 = 0.6;\)\ \), "\n", 
    \(om0m = 0.3; \ ss = 1;\), "\n", 
    \(\(eq1 = 
        aadd/aa\  \[Equal] \ 
          fid^2\ \  + \ \ ss\ fi\  - \ om0m/\((2\ aa^3)\);\)\), "\n", 
    \(\(eq2 = 
        fidd\ \  + \ \ \ 3\ \ fid\ \((aad/aa)\)\  - \ ss \[Equal] 
          0;\)\), "\n", 
    \(\(eqb1 = f[ti] == f0;\)\), "\n", 
    \(\(eqb2 = \(f'\)[ti] == 0;\)\), "\n", 
    \(\(eqb3 = 
        a[ti] \[Equal] \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((2/3)\);\)\), "\n", 
    \(\(eqb4 = \(a'\)[
            ti] \[Equal] \((2/
                3)\)\ \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((\(-1\)/
                  3)\);\)\), "\n", 
    \(\(sol2 = 
        NDSolve[{eq1, eq2, eqb1, eqb2, eqb3, eqb4}, {aa, fi}, {t, ti, t0}, 
          MaxSteps \[Rule] 10000000];\)\), "\n", 
    \(\(asol = Part[Evaluate[a[t] /. sol2], 1];\)\), "\n", 
    \(\(fsol = 
        Part[Evaluate[f[t] /. sol2], 
          1];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(fs[t1_] := fsol\  /. \ t -> t1\ ;\)\), "\[IndentingNewLine]", 
    \(\(plfsp1 = 
        Plot[ss\ fs[t], {t, ti, t0}, Frame \[Rule] True, 
          PlotRange \[Rule] All, 
          FrameLabel \[Rule] {\*"\"\<\!\(H\_0\)t\>\"", \
"\<V(\[Phi](t))\>"}];\)\), "\[IndentingNewLine]", 
    \(\(plasp1 = 
        Plot[asol, {t, ti, t0}, Frame \[Rule] True, PlotRange \[Rule] All, 
          FrameLabel \[Rule] {\*"\"\<\!\(H\_0\)t\>\"", "\<a(t)\>"}];\)\n\), "\
\[IndentingNewLine]", 
    \(\(dfsol = D[fsol, t];\)\), "\n", 
    \(\(enf = \(-0.5\)\ dfsol^2\  + \ ss\ fsol;\)\), "\n", 
    \(\(as[t1_] := asol\  /. \ t -> t1\ ;\)\), "\n", 
    \(\(tt = Part[FindRoot[as[t] == 1, {t, 0.1}], 1, 2];\)\), "\n", 
    \(\(tas[a_] := 
        Part[FindRoot[as[t] \[Equal] a, {t, 0.3}], 1, 2];\)\), "\n", 
    \(\(hht[t1_] := D[asol, t]/asol\  /. \ t -> t1\ ;\)\), "\n", 
    \(\(hha[a_] := hht[tas[a]];\)\), "\n", 
    \(\(hhz[z_] := hha[1/\((z + 1)\)];\)\), "\n", 
    \(enf\  /. \ t \[Rule] tt\), "\n", 
    \(hhz[0]\), "\[IndentingNewLine]", 
    \(\(hhzt = 
        Sqrt[\((1 - om0m)\) + om0m \((1 + z)\)^3] /. 
          om0m \[Rule] 0.3;\)\), "\[IndentingNewLine]", 
    \(\(Plot[{hhz[z], hhzt}, {z, 0, 1}];\)\), "\[IndentingNewLine]", 
    \(\(enf = \(-0.5\)\ dfsol^2\  + \ ss\ fsol;\)\), "\n", 
    \(\(ppf = \(-0.5\)\ dfsol^2\  - \ ss\ fsol;\)\), "\n", 
    \(\(wft[t1_] := ppf/enf\  /. \ t -> t1\ ;\)\ \), "\n", 
    \(\(wfa[a_] := wft[tas[a]];\)\), "\n", 
    \(\(wfz[z_] := wfa[1/\((z + 1)\)];\)\), "\n", 
    \(\(plw10p = 
        Plot[wfz[z], {z, 0, 2}, Frame \[Rule] True, PlotRange \[Rule] All, 
          FrameLabel \[Rule] {"\<z\>", "\<w(z)\>"}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238091 0.238095 -0.314576 0.548819 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.2619 -0.0125 -5.53125 -17.8125 ]
[.2619 -0.0125 5.53125 0 ]
[.5 -0.0125 -5.53125 -17.8125 ]
[.5 -0.0125 5.53125 0 ]
[.7381 -0.0125 -5.53125 -17.8125 ]
[.7381 -0.0125 5.53125 0 ]
[.97619 -0.0125 -5.53125 -17.8125 ]
[.97619 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -11.75 -35.625 ]
[.5 -0.0125 11.75 -17.8125 ]
[-0.0125 .01472 -21.5625 -8.90625 ]
[-0.0125 .01472 0 8.90625 ]
[-0.0125 .12448 -21.5625 -8.90625 ]
[-0.0125 .12448 0 8.90625 ]
[-0.0125 .23424 -11.0625 -8.90625 ]
[-0.0125 .23424 0 8.90625 ]
[-0.0125 .34401 -21.5625 -8.90625 ]
[-0.0125 .34401 0 8.90625 ]
[-0.0125 .45377 -21.5625 -8.90625 ]
[-0.0125 .45377 0 8.90625 ]
[-0.0125 .56353 -21.5625 -8.90625 ]
[-0.0125 .56353 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -39.375 -21.9688 ]
[-0.01875 .30902 -21.5625 21.9688 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -72.75 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
73.063 19.750 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
78.563 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
82.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .12448 m
.00625 .12448 L
s
gsave
-0.0125 .12448 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .23424 m
.00625 .23424 L
s
gsave
-0.0125 .23424 -72.0625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .34401 m
.00625 .34401 L
s
gsave
-0.0125 .34401 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
0 .45377 m
.00625 .45377 L
s
gsave
-0.0125 .45377 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
0 .56353 m
.00625 .56353 L
s
gsave
-0.0125 .56353 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04216 m
.00375 .04216 L
s
0 .0696 m
.00375 .0696 L
s
0 .09704 m
.00375 .09704 L
s
0 .15192 m
.00375 .15192 L
s
0 .17936 m
.00375 .17936 L
s
0 .2068 m
.00375 .2068 L
s
0 .26168 m
.00375 .26168 L
s
0 .28912 m
.00375 .28912 L
s
0 .31657 m
.00375 .31657 L
s
0 .37145 m
.00375 .37145 L
s
0 .39889 m
.00375 .39889 L
s
0 .42633 m
.00375 .42633 L
s
0 .48121 m
.00375 .48121 L
s
0 .50865 m
.00375 .50865 L
s
0 .53609 m
.00375 .53609 L
s
0 .59098 m
.00375 .59098 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -113.438 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
82.9688 12.9063 translate
90 rotate
-82.9688 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(V) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.063 17.500 moveto
(H) show
77.625 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
85.313 17.500 moveto
(H) show
89.875 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.813 17.500 moveto
(L) show
98.375 17.500 moveto
(L) show
102.938 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .12448 m
1 .12448 L
s
.99375 .23424 m
1 .23424 L
s
.99375 .34401 m
1 .34401 L
s
.99375 .45377 m
1 .45377 L
s
.99375 .56353 m
1 .56353 L
s
.125 Mabswid
.99625 .04216 m
1 .04216 L
s
.99625 .0696 m
1 .0696 L
s
.99625 .09704 m
1 .09704 L
s
.99625 .15192 m
1 .15192 L
s
.99625 .17936 m
1 .17936 L
s
.99625 .2068 m
1 .2068 L
s
.99625 .26168 m
1 .26168 L
s
.99625 .28912 m
1 .28912 L
s
.99625 .31657 m
1 .31657 L
s
.99625 .37145 m
1 .37145 L
s
.99625 .39889 m
1 .39889 L
s
.99625 .42633 m
1 .42633 L
s
.99625 .48121 m
1 .48121 L
s
.99625 .50865 m
1 .50865 L
s
.99625 .53609 m
1 .53609 L
s
.99625 .59098 m
1 .59098 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01473 L
.02846 .01475 L
.03053 .01479 L
.03279 .01485 L
.03527 .01493 L
.0379 .01504 L
.04262 .01529 L
.04749 .01562 L
.05205 .016 L
.06244 .01712 L
.07305 .01861 L
.08274 .02028 L
.10458 .02512 L
.14429 .03755 L
.18248 .05364 L
.22313 .0747 L
.26226 .09824 L
.30384 .12603 L
.34391 .15482 L
.38246 .18377 L
.42346 .21532 L
.46295 .24597 L
.50092 .27538 L
.54134 .30636 L
.58025 .33571 L
.62161 .3663 L
.66146 .39514 L
.69979 .42229 L
.74057 .45057 L
.77984 .47723 L
.81759 .50236 L
.85779 .52863 L
.89648 .55345 L
.93762 .57939 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00YP3oool2000007P0oooo002U0?ooo`040000003o
ool0oooo000007L0oooo002K0?ooo`<000000`3oool3000000050?ooo`000000oooo0?ooo`000000
0`3oool200000780oooo002L0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
0P3oool01`000000oooo0?ooo`3oool000000?ooo`000000L@3oool009`0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`000000L`3oool0
09`0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`050000003oool0
oooo0?ooo`000000L`3oool009`0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3o
ool2000000@0oooo00<000000?ooo`3oool0L@3oool009`0oooo1`0000090?ooo`030000003oool0
oooo0740oooo002L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool30000
0780oooo002L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`1a0?ooo`00W03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0L@3oool009/0oooo0`0000030?ooo`<00000O03oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool003P0oooo0`00000c0?ooo`<00000<@3oool500000340oooo
1000000d0?ooo`030000003oool0oooo00d0oooo000g0?ooo`050000003oool0oooo0?ooo`000000
<`3oool00`000000oooo0?ooo`0a0?ooo`040000003oool0oooo000003D0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`0=0?ooo`00=`3oool01@000000oooo0?ooo`3oool0000003<0
oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool03@3oool003L0oooo00D000000?ooo`3oool0oooo0000000c0?ooo`03
0000003oool0oooo03<0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0]0?ooo`H0
00003P3oool003L0oooo00D000000?ooo`3oool0oooo0000000c0?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0]0?ooo`050000003oool0oooo0?oo
o`0000003`3oool003L0oooo00D000000?ooo`3oool0oooo0000000c0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0<@3oool200000340oooo00@000000?ooo`3oool000003`3oool0
03L0oooo00D000000?ooo`3oool0oooo0000000c0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0000000l0oooo000g0?oo
o`050000003oool0oooo0?ooo`000000<`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0000000?0?ooo`00=`3oool01@00
0000oooo0?ooo`3oool000000380oooo0P00000b0?ooo`050000003oool0oooo0?ooo`000000<@3o
ool01@000000oooo0?ooo`3oool000000380oooo0P00000?0?ooo`00>03oool3000003@0oooo00<0
00000?ooo`3oool0<@3oool3000003<0oooo0`00000d0?ooo`030000003oool0oooo00d0oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000P
0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`<000001`3ooooQ000000X0oooo000O0?oo
o`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`007`3oool01@000000oooo0?ooo`3o
ool0000000H0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo0=d0oooo
00<000000?ooo`3oool0203oool001l0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000
003oool0oooo0?ooo`0000001P3oool2000000<0oooo1P00003C0?ooo`<000002P3oool001l0oooo
00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`00
0000oooo0?ooo`080?ooo`H00000c`3oool00`000000oooo0?ooo`080?ooo`007`3oool01@000000
oooo0?ooo`3oool0000000H0oooo0P0000020?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool03P3oool400000</0oooo00<000000?ooo`3oool0203oool001l0oooo00D000000?ooo`3o
ool0oooo000000060?ooo`040000003oool00000000000L0oooo00<000000?ooo`3oool04P3oool5
00000<H0oooo00<000000?ooo`3oool0203oool001l0oooo00D000000?ooo`3oool0oooo00000007
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool05`3oool400000<80oooo00<00000
0?ooo`3oool0203oool001l0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool06`3oool400000;h0oooo00<000000?ooo`3oool0203oool0
0200oooo0`00000:0?ooo`8000001P3oool00`000000oooo0?ooo`0O0?ooo`800000^`3oool20000
00X0oooo000e0?ooo`030000003oool0oooo0240oooo0P00002j0?ooo`030000003oool0oooo00P0
oooo000e0?ooo`030000003oool0oooo02<0oooo0P00002h0?ooo`030000003oool0oooo00P0oooo
000e0?ooo`030000003oool0oooo02D0oooo0P00002f0?ooo`030000003oool0oooo00P0oooo000e
0?ooo`030000003oool0oooo02L0oooo0P00002d0?ooo`030000003oool0oooo00P0oooo000e0?oo
o`030000003oool0oooo02T0oooo0P00002b0?ooo`030000003oool0oooo00P0oooo000e0?ooo`03
0000003oool0oooo02/0oooo0P00002`0?ooo`030000003oool0oooo00P0oooo000e0?ooo`030000
003oool0oooo02d0oooo0P00002]0?ooo`8000002P3oool003D0oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo00P0oooo000e0?ooo`030000003oool0
oooo0300oooo0P00002[0?ooo`030000003oool0oooo00P0oooo000e0?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`080?ooo`00=@3oool00`000000
oooo0?ooo`0c0?ooo`800000Z03oool00`000000oooo0?ooo`080?ooo`00=@3oool00`000000oooo
0?ooo`0e0?ooo`800000YP3oool00`000000oooo0?ooo`080?ooo`00=@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo0:80oooo0P00000:0?ooo`00=@3oool00`000000oooo0?ooo`0h
0?ooo`800000X`3oool00`000000oooo0?ooo`080?ooo`00803oool3000000<0oooo00<000000?oo
o`3oool00P3oool3000000L0oooo00<000000?ooo`3oool0>P3oool200000:40oooo00<000000?oo
o`3oool0203oool001l0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo
0?ooo`0000001P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo09h0oooo00<00000
0?ooo`3oool0203oool001l0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0
oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0m0?ooo`800000WP3oool00`000000oooo0?oo
o`080?ooo`007`3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo
000000060?ooo`030000003oool0oooo03l0oooo0P00002L0?ooo`030000003oool0oooo00P0oooo
000O0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo000000070?ooo`800000
@P3oool00`000000oooo0?ooo`2G0?ooo`<000002P3oool001l0oooo00D000000?ooo`3oool0oooo
000000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`2H0?ooo`030000003oool0oooo00P0oooo000O0?ooo`050000003oool0oooo0?ooo`000000
1`3oool00`000000oooo000000070?ooo`030000003oool0oooo04<0oooo0P00002H0?ooo`030000
003oool0oooo00P0oooo000O0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo
0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`2E0?ooo`03
0000003oool0oooo00P0oooo000O0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000
oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`2D0?oo
o`030000003oool0oooo00P0oooo000P0?ooo`<00000203oool3000000L0oooo00<000000?ooo`3o
ool0A`3oool2000009@0oooo00<000000?ooo`3oool0203oool003D0oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`2@0?ooo`8000002P3oool003D0oooo00<000000?ooo`3oool0BP3o
ool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo000e0?ooo`030000003oool0
oooo04/0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`080?ooo`00=@3oool00`00
0000oooo0?ooo`1<0?ooo`800000S`3oool00`000000oooo0?ooo`080?ooo`00=@3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0203oool003D0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00P0oooo
000e0?ooo`030000003oool0oooo0500oooo0P00002:0?ooo`8000002P3oool003D0oooo00<00000
0?ooo`3oool0DP3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00P0oooo000e0?oo
o`030000003oool0oooo05<0oooo0P0000280?ooo`030000003oool0oooo00P0oooo000e0?ooo`03
0000003oool0oooo05D0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`080?ooo`00
=@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0
203oool003D0oooo00<000000?ooo`3oool0E`3oool2000008@0oooo00<000000?ooo`3oool0203o
ool003D0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`200?ooo`8000002P3oool0
03D0oooo00<000000?ooo`3oool0FP3oool200000840oooo00<000000?ooo`3oool0203oool003D0
oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00P0
oooo000[0?ooo`<000001`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo07d0oooo
00<000000?ooo`3oool0203oool000d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?oo
o`080?ooo`003@3oool3000001`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1O
0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0203oool000d0oooo00<000000?oo
o`3oool00`00000I0?ooo`030000003oool0oooo00H0oooo0P00001Q0?ooo`800000N@3oool30000
00X0oooo000C0?ooo`8000005`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0680
oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`080?ooo`005@3oool2000001D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo07L0oooo
00<000000?ooo`3oool0203oool001<0oooo0P00000G0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0I03oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo00P0oooo000=
0?ooo`030000003oool0oooo00<000006@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo06D0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`080?ooo`003@3oool30000
01/0oooo0P0000080?ooo`030000003oool0oooo06H0oooo0P00001e0?ooo`030000003oool0oooo
00P0oooo000=0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`1X0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0203oool003D0oooo
00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`1`0?ooo`8000002P3oool003D0oooo00<0
00000?ooo`3oool0JP3oool200000740oooo00<000000?ooo`3oool0203oool000l0oooo2@00000M
0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`08
0?ooo`003P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool0K@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00P0oooo000=0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1^0?ooo`03
0000003oool0oooo06`0oooo00<000000?ooo`3oool0203oool003D0oooo00<000000?ooo`3oool0
K`3oool2000006`0oooo00<000000?ooo`3oool0203oool00180oooo1000000O0?ooo`030000003o
ool0oooo0740oooo00<000000?ooo`3oool0J03oool2000000X0oooo000A0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000006`3oool00`000000oooo0?ooo`1b0?ooo`030000003o
ool0oooo06P0oooo00<000000?ooo`3oool0203oool00100oooo00<000000?ooo`3oool00P3oool4
000001`0oooo00<000000?ooo`3oool0L`3oool2000006P0oooo00<000000?ooo`3oool0203oool0
0100oooo1@0000000`3oool000000?ooo`0M0?ooo`030000003oool0oooo07D0oooo00<000000?oo
o`3oool0I@3oool00`000000oooo0?ooo`080?ooo`003P3oool3000000D0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3o
ool0203oool00100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo07L0oooo0P00001T0?ooo`030000003oool0oooo00P0oooo000A0?ooo`@00000803o
ool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0600oooo0P00000:0?ooo`00=@3oool0
0`000000oooo0?ooo`1j0?ooo`800000H@3oool00`000000oooo0?ooo`080?ooo`00803oool30000
00<0oooo00@000000?ooo`3oool0oooo1@0000060?ooo`030000003oool0oooo07`0oooo00<00000
0?ooo`3oool0GP3oool00`000000oooo0?ooo`080?ooo`003`3oool9000000T0oooo00<000000?oo
o`3oool01`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo07d0oooo0P00001N
0?ooo`030000003oool0oooo00P0oooo000>0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0O`3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00P0oooo000=0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`1J0?ooo`03
0000003oool0oooo00P0oooo000@0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`050?ooo`800000PP3oool2000005P0oooo0`00000:0?ooo`003P3o
ool9000000X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo08<0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`080?ooo`00403oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`080?ooo`005@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`250?ooo`800000EP3oool00`00
0000oooo0?ooo`080?ooo`003@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0
oooo0P0000080?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`270?oo
o`030000003oool0oooo05<0oooo00<000000?ooo`3oool0203oool000h0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo0`0000070?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`080?ooo`00
3`3oool9000001d0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`1@0?ooo`800000
2P3oool003D0oooo00<000000?ooo`3oool0RP3oool200000540oooo00<000000?ooo`3oool0203o
ool003D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`1>0?ooo`030000003oool0
oooo00P0oooo000=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0203oool000h0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo08h0
oooo0P00001=0?ooo`030000003oool0oooo00P0oooo000?0?ooo`T000007@3oool00`000000oooo
0?ooo`2@0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0203oool003D0oooo00<0
00000?ooo`3oool0T@3oool00`000000oooo0?ooo`180?ooo`8000002P3oool003D0oooo00<00000
0?ooo`3oool0TP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00P0oooo000e0?oo
o`030000003oool0oooo09<0oooo0P0000180?ooo`030000003oool0oooo00P0oooo000e0?ooo`03
0000003oool0oooo09D0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`080?ooo`00
=@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
203oool003D0oooo00<000000?ooo`3oool0U`3oool2000004@0oooo00<000000?ooo`3oool0203o
ool003D0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo00P0oooo000e0?ooo`030000003oool0oooo09X0oooo0P0000100?ooo`8000002P3oool003D0
oooo00<000000?ooo`3oool0W03oool2000003l0oooo00<000000?ooo`3oool0203oool00200oooo
0`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`2N0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0203oool00240oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo09l0oooo0P00
000l0?ooo`030000003oool0oooo00P0oooo000Q0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`2Q0?ooo`800000>P3oool00`000000oooo0?ooo`08
0?ooo`008@3oool00`000000oooo0?ooo`050?ooo`H000001P3oool00`000000oooo0?ooo`2S0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0203oool00240oooo00<000000?ooo`3o
ool01@3oool01@000000oooo0?ooo`3oool0000000L0oooo0P00002U0?ooo`030000003oool0oooo
03@0oooo0`00000:0?ooo`008@3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo0000
00L0oooo00<000000?ooo`3oool0Y@3oool2000003H0oooo00<000000?ooo`3oool0203oool00240
oooo00<000000?ooo`3oool01`3oool00`000000oooo000000070?ooo`030000003oool0oooo0:L0
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`080?ooo`008@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0Z03oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo00P0oooo000P0?ooo`8000002P3oool2000000L0oooo00<0
00000?ooo`3oool0Z@3oool200000380oooo00<000000?ooo`3oool0203oool00240oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0:/0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`080?ooo`00=@3oool00`000000oooo0?ooo`2/0?oo
o`800000;P3oool2000000X0oooo000e0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`080?ooo`00=@3oool00`000000oooo0?ooo`2_0?ooo`800000
;03oool00`000000oooo0?ooo`080?ooo`00=@3oool00`000000oooo0?ooo`2a0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0203oool003D0oooo00<000000?ooo`3oool0/P3oool2
000002T0oooo00<000000?ooo`3oool0203oool003D0oooo00<000000?ooo`3oool0]03oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000e0?ooo`030000003oool0oooo0;D0
oooo0P00000U0?ooo`8000002P3oool003D0oooo00<000000?ooo`3oool0]`3oool2000002@0oooo
00<000000?ooo`3oool0203oool003D0oooo00<000000?ooo`3oool0^@3oool200000280oooo00<0
00000?ooo`3oool0203oool003D0oooo00<000000?ooo`3oool0^`3oool200000200oooo00<00000
0?ooo`3oool0203oool003D0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo00P0oooo000e0?ooo`030000003oool0oooo0;h0oooo0P00000M0?ooo`03
0000003oool0oooo00P0oooo000e0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0
6@3oool2000000X0oooo000e0?ooo`030000003oool0oooo0<40oooo0P00000J0?ooo`030000003o
ool0oooo00P0oooo000e0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`080?ooo`00803oool3000000<0oooo00<000000?ooo`3oool00P3oool30000
00L0oooo00<000000?ooo`3oool0a03oool2000001L0oooo00<000000?ooo`3oool0203oool00240
oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?oo
o`3oool0aP3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo000Q0?ooo`03
0000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo
0<L0oooo0P00000D0?ooo`030000003oool0oooo00P0oooo000Q0?ooo`030000003oool0oooo00H0
oooo00D000000?ooo`3oool0oooo000000060?ooo`800000bP3oool00`000000oooo0?ooo`0?0?oo
o`<000002P3oool00240oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool00000
00H0oooo00<000000?ooo`3oool0bP3oool200000140oooo00<000000?ooo`3oool0203oool00240
oooo00<000000?ooo`3oool01P3oool200000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`3<0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool00240oooo
00<000000?ooo`3oool01P3oool010000000oooo0000000000070?ooo`030000003oool0oooo0<d0
oooo0P00000>0?ooo`030000003oool0oooo00P0oooo000Q0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0203oool00200oooo0P00000:0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0d03oool2000000/0oooo00<000000?ooo`3oool0203oool00240oooo00<00000
0?ooo`3oool02@3oool2000000H0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`07
0?ooo`8000002P3oool003D0oooo00<000000?ooo`3oool0d`3oool2000000P0oooo00<000000?oo
o`3oool0203oool003D0oooo00<000000?ooo`3oool0e@3oool2000000H0oooo00<000000?ooo`3o
ool0203oool003D0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00P0oooo000e0?ooo`030000003oool0oooo0=d0oooo00<000000?ooo`3oool0203o
ool003D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0203oool003D0ooooh@00000:0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.09575, 0.260767, \
0.0187404, 0.00813018}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238091 0.238095 0.0147123 0.0212413 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.2619 -0.0125 -5.53125 -17.8125 ]
[.2619 -0.0125 5.53125 0 ]
[.5 -0.0125 -5.53125 -17.8125 ]
[.5 -0.0125 5.53125 0 ]
[.7381 -0.0125 -5.53125 -17.8125 ]
[.7381 -0.0125 5.53125 0 ]
[.97619 -0.0125 -5.53125 -17.8125 ]
[.97619 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -11.75 -35.625 ]
[.5 -0.0125 11.75 -17.8125 ]
[-0.0125 .01471 -11.0625 -8.90625 ]
[-0.0125 .01471 0 8.90625 ]
[-0.0125 .12092 -11.0625 -8.90625 ]
[-0.0125 .12092 0 8.90625 ]
[-0.0125 .22713 -18.125 -8.90625 ]
[-0.0125 .22713 0 8.90625 ]
[-0.0125 .33333 -18.125 -8.90625 ]
[-0.0125 .33333 0 8.90625 ]
[-0.0125 .43954 -18.125 -8.90625 ]
[-0.0125 .43954 0 8.90625 ]
[-0.0125 .54575 -18.125 -8.90625 ]
[-0.0125 .54575 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -35.9375 -11.6563 ]
[-0.01875 .30902 -18.125 11.6563 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -72.75 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
73.063 19.750 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
78.563 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
82.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01471 m
.00625 .01471 L
s
gsave
-0.0125 .01471 -72.0625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .12092 m
.00625 .12092 L
s
gsave
-0.0125 .12092 -72.0625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .22713 m
.00625 .22713 L
s
gsave
-0.0125 .22713 -79.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .33333 m
.00625 .33333 L
s
gsave
-0.0125 .33333 -79.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
0 .43954 m
.00625 .43954 L
s
gsave
-0.0125 .43954 -79.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .54575 m
.00625 .54575 L
s
gsave
-0.0125 .54575 -79.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03595 m
.00375 .03595 L
s
0 .05719 m
.00375 .05719 L
s
0 .07844 m
.00375 .07844 L
s
0 .09968 m
.00375 .09968 L
s
0 .14216 m
.00375 .14216 L
s
0 .1634 m
.00375 .1634 L
s
0 .18464 m
.00375 .18464 L
s
0 .20588 m
.00375 .20588 L
s
0 .24837 m
.00375 .24837 L
s
0 .26961 m
.00375 .26961 L
s
0 .29085 m
.00375 .29085 L
s
0 .31209 m
.00375 .31209 L
s
0 .35457 m
.00375 .35457 L
s
0 .37581 m
.00375 .37581 L
s
0 .39706 m
.00375 .39706 L
s
0 .4183 m
.00375 .4183 L
s
0 .46078 m
.00375 .46078 L
s
0 .48202 m
.00375 .48202 L
s
0 .50326 m
.00375 .50326 L
s
0 .5245 m
.00375 .5245 L
s
0 .56699 m
.00375 .56699 L
s
0 .58823 m
.00375 .58823 L
s
0 .60947 m
.00375 .60947 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -99.6875 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
72.6563 12.9063 translate
90 rotate
-72.6563 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.250 17.500 moveto
(H) show
73.813 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
77.750 17.500 moveto
(L) show
82.313 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01471 m
1 .01471 L
s
.99375 .12092 m
1 .12092 L
s
.99375 .22713 m
1 .22713 L
s
.99375 .33333 m
1 .33333 L
s
.99375 .43954 m
1 .43954 L
s
.99375 .54575 m
1 .54575 L
s
.125 Mabswid
.99625 .03595 m
1 .03595 L
s
.99625 .05719 m
1 .05719 L
s
.99625 .07844 m
1 .07844 L
s
.99625 .09968 m
1 .09968 L
s
.99625 .14216 m
1 .14216 L
s
.99625 .1634 m
1 .1634 L
s
.99625 .18464 m
1 .18464 L
s
.99625 .20588 m
1 .20588 L
s
.99625 .24837 m
1 .24837 L
s
.99625 .26961 m
1 .26961 L
s
.99625 .29085 m
1 .29085 L
s
.99625 .31209 m
1 .31209 L
s
.99625 .35457 m
1 .35457 L
s
.99625 .37581 m
1 .37581 L
s
.99625 .39706 m
1 .39706 L
s
.99625 .4183 m
1 .4183 L
s
.99625 .46078 m
1 .46078 L
s
.99625 .48202 m
1 .48202 L
s
.99625 .50326 m
1 .50326 L
s
.99625 .5245 m
1 .5245 L
s
.99625 .56699 m
1 .56699 L
s
.99625 .58823 m
1 .58823 L
s
.99625 .60947 m
1 .60947 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.02499 .01525 L
.02605 .01554 L
.02846 .01606 L
.03279 .01681 L
.04262 .01815 L
.06244 .02029 L
.10458 .02397 L
.14451 .0271 L
.18292 .03007 L
.22379 .03336 L
.26314 .03682 L
.30098 .04054 L
.34126 .04509 L
.38004 .0502 L
.42126 .05666 L
.46097 .06414 L
.49916 .07279 L
.53981 .08394 L
.57894 .09703 L
.62052 .1141 L
.66059 .13439 L
.69914 .15837 L
.74014 .18984 L
.77963 .22744 L
.8176 .27204 L
.85802 .33091 L
.89693 .40151 L
.93829 .49553 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00Y03oool2000007X0oooo002S0?ooo`040000003o
ool0oooo000007T0oooo002I0?ooo`<000000`3oool3000000050?ooo`000000oooo0?ooo`000000
0`3oool2000007@0oooo002J0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
0P3oool01`000000oooo0?ooo`3oool000000?ooo`000000L`3oool009X0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`000000M@3oool0
09X0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`050000003oool0
oooo0?ooo`000000M@3oool009X0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3o
ool2000000@0oooo00<000000?ooo`3oool0L`3oool009X0oooo1`0000090?ooo`030000003oool0
oooo07<0oooo002J0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool30000
07@0oooo002J0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`1c0?ooo`00VP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0L`3oool009T0oooo0`0000030?ooo`<00000OP3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool003L0oooo0`00000b0?ooo`<00000<@3oool500000340oooo
1000000d0?ooo`030000003oool0oooo00l0oooo000f0?ooo`050000003oool0oooo0?ooo`000000
<P3oool00`000000oooo0?ooo`0a0?ooo`040000003oool0oooo000003D0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`0?0?ooo`00=P3oool01@000000oooo0?ooo`3oool000000380
oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool03`3oool003H0oooo00D000000?ooo`3oool0oooo0000000b0?ooo`03
0000003oool0oooo03<0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0]0?ooo`H0
0000403oool003H0oooo00D000000?ooo`3oool0oooo0000000b0?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0]0?ooo`050000003oool0oooo0?oo
o`0000004@3oool003H0oooo00D000000?ooo`3oool0oooo0000000b0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0<@3oool200000340oooo00@000000?ooo`3oool000004@3oool0
03H0oooo00D000000?ooo`3oool0oooo0000000b0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool000000140oooo000f0?oo
o`050000003oool0oooo0?ooo`000000<P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0000000A0?ooo`00=P3oool01@00
0000oooo0?ooo`3oool000000340oooo0P00000b0?ooo`050000003oool0oooo0?ooo`000000<@3o
ool01@000000oooo0?ooo`3oool000000380oooo0P00000A0?ooo`00=`3oool3000003<0oooo00<0
00000?ooo`3oool0<@3oool3000003<0oooo0`00000d0?ooo`030000003oool0oooo00l0oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000Y
0?ooo`<000001`3ooooQ000000`0oooo000X0?ooo`050000003oool0oooo0?ooo`0000001P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo000X0?ooo`050000003oool0oooo
0?ooo`0000001P3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00X0oooo000X0?oo
o`050000003oool0oooo0?ooo`0000001P3oool2000000<0oooo0P00003H0?ooo`800000303oool0
02P0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00<0oooo1P00003D
0?ooo`030000003oool0oooo00X0oooo000X0?ooo`050000003oool0oooo0?ooo`0000001P3oool0
0`000000oooo0?ooo`090?oooa000000a03oool00`000000oooo0?ooo`0:0?ooo`00:03oool01@00
0000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool06@3oool900000;/0oooo00<00000
0?ooo`3oool02P3oool002P0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0
oooo0280oooo4P00002Y0?ooo`030000003oool0oooo00X0oooo000X0?ooo`050000003oool0oooo
0?ooo`0000001P3oool2000003D0oooo2000002P0?ooo`800000303oool002T0oooo0`0000070?oo
o`030000003oool0oooo03`0oooo2@00002H0?ooo`030000003oool0oooo00X0oooo000c0?ooo`03
0000003oool0oooo04D0oooo2@00002?0?ooo`030000003oool0oooo00X0oooo000c0?ooo`030000
003oool0oooo04h0oooo1`0000280?ooo`030000003oool0oooo00X0oooo000c0?ooo`030000003o
ool0oooo05D0oooo100000240?ooo`030000003oool0oooo00X0oooo000c0?ooo`800000FP3oool7
000007`0oooo0P00000<0?ooo`00<`3oool00`000000oooo0?ooo`1P0?ooo`L00000MP3oool00`00
0000oooo0?ooo`0:0?ooo`00<`3oool00`000000oooo0?ooo`1W0?ooo`@00000LP3oool00`000000
oooo0?ooo`0:0?ooo`00<`3oool00`000000oooo0?ooo`1[0?ooo`@00000KP3oool00`000000oooo
0?ooo`0:0?ooo`00<`3oool00`000000oooo0?ooo`1_0?ooo`<00000J`3oool00`000000oooo0?oo
o`0:0?ooo`00<`3oool2000007<0oooo0`00001W0?ooo`800000303oool003<0oooo00<000000?oo
o`3oool0M@3oool3000006D0oooo00<000000?ooo`3oool02P3oool003<0oooo00<000000?ooo`3o
ool0N03oool300000680oooo00<000000?ooo`3oool02P3oool003<0oooo00<000000?ooo`3oool0
N`3oool3000005l0oooo00<000000?ooo`3oool02P3oool003<0oooo0P00001o0?ooo`<00000F`3o
ool2000000`0oooo000X0?ooo`<00000203oool00`000000oooo0?ooo`210?ooo`800000FP3oool0
0`000000oooo0?ooo`0:0?ooo`00:`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
08<0oooo0P00001H0?ooo`030000003oool0oooo00X0oooo000/0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0Q@3oool2000005H0oooo00<000000?ooo`3oool02P3oool002`0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`270?ooo`<00000D`3oool00`000000oooo
0?ooo`0:0?ooo`00;03oool00`000000oooo0?ooo`040?ooo`800000R`3oool200000500oooo0P00
000<0?ooo`00:`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08`0oooo0P00001?
0?ooo`030000003oool0oooo00X0oooo000X0?ooo`<00000203oool00`000000oooo0?ooo`2>0?oo
o`800000C@3oool00`000000oooo0?ooo`0:0?ooo`00:03oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0900oooo0P00001;0?ooo`030000003oool0oooo00X0oooo000Y0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0TP3oool2000004T0oooo00<000000?ooo`3oool0
2P3oool002T0oooo100000060?ooo`800000U@3oool2000004H0oooo0P00000<0?ooo`00<`3oool0
0`000000oooo0?ooo`2F0?ooo`800000A@3oool00`000000oooo0?ooo`0:0?ooo`00<`3oool00`00
0000oooo0?ooo`2H0?ooo`800000@`3oool00`000000oooo0?ooo`0:0?ooo`00<`3oool00`000000
oooo0?ooo`2J0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool02P3oool003<0oooo
00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00X0oooo
000c0?ooo`800000W@3oool00`000000oooo0?ooo`0m0?ooo`800000303oool003<0oooo00<00000
0?ooo`3oool0W@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00X0oooo000c0?oo
o`030000003oool0oooo09h0oooo0P00000m0?ooo`030000003oool0oooo00X0oooo000c0?ooo`03
0000003oool0oooo0:00oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0:0?ooo`00
<`3oool200000:80oooo00<000000?ooo`3oool0>03oool2000000`0oooo000c0?ooo`030000003o
ool0oooo0:80oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0:0?ooo`00<`3oool0
0`000000oooo0?ooo`2S0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool02P3oool0
03<0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
00X0oooo000c0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0=@3oool00`000000
oooo0?ooo`0:0?ooo`00<`3oool200000:L0oooo00<000000?ooo`3oool0<`3oool2000000`0oooo
000R0?ooo`<00000103oool3000000L0oooo00<000000?ooo`3oool0Y`3oool2000003@0oooo00<0
00000?ooo`3oool02P3oool002<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000H0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo00X0oooo000S0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0:0?ooo`008`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001P3o
ool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3o
ool002<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000H0oooo0P00
002]0?ooo`030000003oool0oooo02d0oooo0P00000<0?ooo`008`3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`2]0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool02P3oool002<0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo00X0oooo000S0?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000060?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`0:0?ooo`008P3oool2000000@0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`0:0?ooo`008`3oool00`000000oooo0?ooo`030?ooo`<000001`3oool200000;40oooo00<00000
0?ooo`3oool0:@3oool2000000`0oooo000c0?ooo`030000003oool0oooo0;40oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0:0?ooo`00<`3oool00`000000oooo0?ooo`2b0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool02P3oool003<0oooo00<000000?ooo`3oool0
/P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00X0oooo000c0?ooo`800000]03o
ool00`000000oooo0?ooo`0V0?ooo`800000303oool00180oooo00<000000?ooo`3oool00P00000L
0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0:
0?ooo`004@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0]@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00X0oooo000A0?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`2e
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool02P3oool00140oooo00H000000?oo
o`3oool000000?ooo`00000L0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0:0?ooo`004P3oool6000001/0oooo0P00002h0?ooo`030000003oool0
oooo0280oooo0P00000<0?ooo`005`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
0;L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0:0?ooo`00<`3oool00`000000
oooo0?ooo`2h0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool02P3oool00100oooo
2@00000J0?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0:0?ooo`003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0^P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00X0oooo000>
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05P3oool200000;/0oooo00<00000
0?ooo`3oool07`3oool2000000`0oooo000A0?ooo`030000003oool0oooo00h0oooo0`0000030?oo
o`<00000203oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool02P3oool000l0oooo2@00000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool02P3oool00140oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2l0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool02P3oool001H0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0_@3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00X0oooo000>0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00@0oooo0P00002o0?ooo`030000003oool0oooo01/0oooo0P00000<0?ooo`003`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0:0?ooo`00403oool9000000X0oooo00<000000?ooo`3oool00P3oool3000000P0
oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00X0
oooo000S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`2o0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool02P3oool00280oooo0P00
00050?ooo`030000003oool0oooo00L0oooo0P0000310?ooo`030000003oool0oooo01T0oooo0P00
000<0?ooo`008`3oool00`000000oooo0?ooo`030?ooo`@000001P3oool00`000000oooo0?ooo`30
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool02P3oool003<0oooo00<000000?oo
o`3oool0`@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00X0oooo000c0?ooo`03
0000003oool0oooo0<40oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0:0?ooo`00
<`3oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
2P3oool003<0oooo0P0000340?ooo`030000003oool0oooo01H0oooo0P00000<0?ooo`00<`3oool0
0`000000oooo0?ooo`330?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02P3oool0
03<0oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
00X0oooo000c0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0:0?ooo`00<`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool02P3oool003<0oooo0P0000360?ooo`030000003oool0oooo01@0oooo0P00
000<0?ooo`00<`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool02P3oool003<0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00X0oooo000c0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0:0?ooo`00<`3oool00`000000oooo0?ooo`370?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool02P3oool003<0oooo0P0000390?ooo`030000003o
ool0oooo0140oooo0P00000<0?ooo`008@3oool5000000<0oooo0`0000070?ooo`030000003oool0
oooo0<P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0:0?ooo`008P3oool01000
0000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?oo
o`390?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02P3oool002<0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0b@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000T0?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`800000bP3oool00`000000oooo0?oo
o`0@0?ooo`800000303oool002@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00X0oooo000U0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02P3o
ool002D0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0</0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`009@3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0b`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo000Q0?ooo`050000003oool0
oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000H0oooo0P00003=0?ooo`030000
003oool0oooo00d0oooo0P00000<0?ooo`008P3oool3000000@0oooo0`0000070?ooo`030000003o
ool0oooo0<`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`00<`3oool0
0`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02P3oool0
03<0oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00X0oooo000c0?ooo`030000003oool0oooo0<d0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0:0?ooo`00<`3oool200000<l0oooo00<000000?ooo`3oool02`3oool2000000`0oooo
000c0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0:0?ooo`00<`3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02P3oool003<0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00X0oooo000c0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0:0?ooo`00<`3oool200000=40oooo00<000000?ooo`3oool0
2@3oool2000000`0oooo000c0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0:0?ooo`00<`3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02P3oool003<0oooo00<000000?ooo`3oool0d@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo000c0?ooo`030000003oool0oooo0=40
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`00<`3oool200000=<0oooo
00<000000?ooo`3oool01`3oool2000000`0oooo000Q0?ooo`D000000P3oool3000000P0oooo00<0
00000?ooo`3oool0dP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo000R
0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`3B0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool002<0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0=<0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`00903oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo0P00003D0?ooo`030000003oool0oooo00H0oooo0P00000<0?oo
o`00903oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0d`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo000U0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3D0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool002D0oooo00<000000?ooo`3oool00`00
00080?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0:0?ooo`009@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0=D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`008@3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool01`3oool200000=H0oooo00<000000?ooo`3oool0103o
ool2000000`0oooo000R0?ooo`<00000103oool4000000H0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo000c0?ooo`030000003oool0oooo
0=H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`00<`3oool00`000000
oooo0?ooo`3F0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool003<0oooo
00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo
000c0?ooo`800000f03oool00`000000oooo0?ooo`020?ooo`800000303oool003<0oooo00<00000
0?ooo`3oool0e`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo000c0?oo
o`030000003oool0oooo0=P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?oo
o`00<`3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02P3oool003<0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`0:0?ooo`00<`3o
ool2000000<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool0<`3oool010000000oooo0?ooo`3oool2000000`0oooo
000c0?ooon400000303oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.06353, -8.76473, \
0.0187404, 0.210062}}]
}, Open  ]],

Cell[BoxData[
    \(0.7059061727217075`\)], "Output"],

Cell[BoxData[
    \(1.0103254793222194`\)], "Output"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.75907 0.773785 [
[.21429 .00222 -10.7813 -17.8125 ]
[.21429 .00222 10.7813 0 ]
[.40476 .00222 -10.7813 -17.8125 ]
[.40476 .00222 10.7813 0 ]
[.59524 .00222 -10.7813 -17.8125 ]
[.59524 .00222 10.7813 0 ]
[.78571 .00222 -10.7813 -17.8125 ]
[.78571 .00222 10.7813 0 ]
[.97619 .00222 -5.53125 -17.8125 ]
[.97619 .00222 5.53125 0 ]
[.01131 .09209 -21.5625 -8.90625 ]
[.01131 .09209 0 8.90625 ]
[.01131 .16947 -21.5625 -8.90625 ]
[.01131 .16947 0 8.90625 ]
[.01131 .24685 -21.5625 -8.90625 ]
[.01131 .24685 0 8.90625 ]
[.01131 .32423 -21.5625 -8.90625 ]
[.01131 .32423 0 8.90625 ]
[.01131 .40161 -21.5625 -8.90625 ]
[.01131 .40161 0 8.90625 ]
[.01131 .47899 -21.5625 -8.90625 ]
[.01131 .47899 0 8.90625 ]
[.01131 .55636 -21.5625 -8.90625 ]
[.01131 .55636 0 8.90625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
gsave
.21429 .00222 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 .01472 m
.40476 .02097 L
s
gsave
.40476 .00222 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 .01472 m
.59524 .02097 L
s
gsave
.59524 .00222 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 .01472 m
.78571 .02097 L
s
gsave
.78571 .00222 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 .01472 m
.97619 .02097 L
s
gsave
.97619 .00222 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .09209 m
.03006 .09209 L
s
gsave
.01131 .09209 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
1.000 setlinewidth
grestore
.02381 .16947 m
.03006 .16947 L
s
gsave
.01131 .16947 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
.02381 .24685 m
.03006 .24685 L
s
gsave
.01131 .24685 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
1.000 setlinewidth
grestore
.02381 .32423 m
.03006 .32423 L
s
gsave
.01131 .32423 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
.02381 .40161 m
.03006 .40161 L
s
gsave
.01131 .40161 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.02381 .47899 m
.03006 .47899 L
s
gsave
.01131 .47899 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
1.000 setlinewidth
grestore
.02381 .55636 m
.03006 .55636 L
s
gsave
.01131 .55636 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .03019 m
.02756 .03019 L
s
.02381 .04567 m
.02756 .04567 L
s
.02381 .06114 m
.02756 .06114 L
s
.02381 .07662 m
.02756 .07662 L
s
.02381 .10757 m
.02756 .10757 L
s
.02381 .12304 m
.02756 .12304 L
s
.02381 .13852 m
.02756 .13852 L
s
.02381 .154 m
.02756 .154 L
s
.02381 .18495 m
.02756 .18495 L
s
.02381 .20042 m
.02756 .20042 L
s
.02381 .2159 m
.02756 .2159 L
s
.02381 .23137 m
.02756 .23137 L
s
.02381 .26233 m
.02756 .26233 L
s
.02381 .2778 m
.02756 .2778 L
s
.02381 .29328 m
.02756 .29328 L
s
.02381 .30875 m
.02756 .30875 L
s
.02381 .3397 m
.02756 .3397 L
s
.02381 .35518 m
.02756 .35518 L
s
.02381 .37066 m
.02756 .37066 L
s
.02381 .38613 m
.02756 .38613 L
s
.02381 .41708 m
.02756 .41708 L
s
.02381 .43256 m
.02756 .43256 L
s
.02381 .44803 m
.02756 .44803 L
s
.02381 .46351 m
.02756 .46351 L
s
.02381 .49446 m
.02756 .49446 L
s
.02381 .50994 m
.02756 .50994 L
s
.02381 .52541 m
.02756 .52541 L
s
.02381 .54089 m
.02756 .54089 L
s
.02381 .57184 m
.02756 .57184 L
s
.02381 .58732 m
.02756 .58732 L
s
.02381 .60279 m
.02756 .60279 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .0227 m
.06244 .03441 L
.10458 .04862 L
.14415 .06331 L
.18221 .0786 L
.22272 .09611 L
.26171 .1141 L
.30316 .1344 L
.34309 .15506 L
.3815 .17592 L
.42237 .19912 L
.46172 .22242 L
.49955 .24566 L
.53984 .27129 L
.57861 .29677 L
.61984 .32472 L
.65954 .35244 L
.69774 .37981 L
.73838 .40968 L
.77751 .43914 L
.81909 .47117 L
.85916 .50272 L
.89771 .5337 L
.93871 .56728 L
.97619 .59854 L
s
.02381 .01472 m
.06244 .02928 L
.10458 .04618 L
.14415 .063 L
.18221 .08004 L
.22272 .09908 L
.26171 .1183 L
.30316 .13965 L
.34309 .1611 L
.3815 .18255 L
.42237 .20622 L
.46172 .22982 L
.49955 .25324 L
.53984 .27895 L
.57861 .30443 L
.61984 .33229 L
.65954 .35985 L
.69774 .38703 L
.73838 .41664 L
.77751 .4458 L
.81909 .47749 L
.85916 .50867 L
.89771 .53928 L
.93871 .57245 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00B03oool3
000000<0oooo00@000000?ooo`3oool0oooo1@00000R0?ooo`<000000`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0240oooo0`0000030?ooo`030000003oool0oooo0080oooo0`00
000S0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`<00000:@3oool3000000/0oooo0017
0?ooo`050000003oool0oooo0?ooo`0000001`3oool010000000oooo0?ooo`00000Q0?ooo`050000
003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0P0?ooo`050000003oool0oooo0?oo
o`0000001P3oool01@000000oooo0?ooo`3oool000000240oooo00D000000?ooo`3oool0oooo0000
00060?ooo`050000003oool0oooo0?ooo`000000:@3oool00`000000oooo0?ooo`0:0?ooo`00A`3o
ool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool08@3oool01@000000oooo
0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0803oool01@000000oooo0?ooo`3oool00000
00H0oooo00D000000?ooo`3oool0oooo0000000Q0?ooo`050000003oool0oooo0?ooo`0000001P3o
ool01@000000oooo0?ooo`3oool0000002T0oooo00<000000?ooo`3oool02P3oool004L0oooo00D0
00000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo0200oooo00D000000?ooo`3oool0
oooo000000050?ooo`H000008@3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?oo
o`3oool0oooo0000000Q0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?oo
o`3oool0000002T0oooo00<000000?ooo`3oool02P3oool004L0oooo00D000000?ooo`3oool0oooo
000000090?ooo`030000003oool0oooo0200oooo00D000000?ooo`3oool0oooo000000050?ooo`05
0000003oool0oooo0?ooo`0000008P3oool01@000000oooo0?ooo`3oool0000000H0oooo00D00000
0?ooo`3oool0oooo0000000Q0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo
0000000Z0?ooo`030000003oool0oooo00X0oooo00170?ooo`050000003oool0oooo0?ooo`000000
2P3oool00`000000oooo0?ooo`0O0?ooo`050000003oool0oooo0?ooo`0000001P3oool010000000
oooo0?ooo`00000R0?ooo`050000003oool0oooo0?ooo`0000001P3oool200000080oooo00<00000
0?ooo`3oool07`3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0:0?ooo`00A`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<0
00000?ooo`3oool07`3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`000000
8P3oool01@000000oooo0?ooo`3oool0000000H0oooo00@000000?ooo`00000000008P3oool01@00
0000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`000000:P3oool00`000000oooo0?ooo`0:
0?ooo`00A`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool07`3oool0
1@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`0000008P3oool01@000000oooo0?oo
o`3oool0000000L0oooo00<000000?ooo`3oool08P3oool01@000000oooo0?ooo`3oool0000000H0
oooo00D000000?ooo`3oool0oooo0000000Y0?ooo`030000003oool0oooo00X0oooo00170?ooo`05
0000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool000000240oooo00D00000
0?ooo`3oool0oooo000000080?ooo`8000008P3oool01@000000oooo0?ooo`3oool0000000P0oooo
00<000000?ooo`3oool08@3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3o
ool0oooo0000000X0?ooo`800000303oool004P0oooo0`0000080?ooo`<000008`3oool3000000X0
oooo00<000000?ooo`3oool08@3oool3000000X0oooo0P00000R0?ooo`<00000203oool3000002X0
oooo00<000000?ooo`3oool02P3oool00?l0oooo8@3oool00?l0oooo8@3oool001d0oooo00<00000
0?ooo`3oool0o`3oool10?ooo`007@3oool00`000000oooo0?ooo`3o0?ooo`40oooo000M0?ooo`03
0000003oool0oooo0?l0oooo0@3oool001d0oooo00<000000?ooo`3oool0o`3oool10?ooo`005`3o
oooo000000D000001@3oool001d0oooo00<000000?ooo`0000000P0000080?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02P3oool001d0oooo0P0000030?ooo`@00000nP3oool001d0
oooo00<000000?ooo`0000000P0000040?ooo`<00000m`3oool001d0oooo0P0000030?ooo`@00000
0`3oool200000?D0oooo000M0?ooo`030000003oool0oooo00H0oooo0`0000020?ooo`800000l`3o
ool001d0oooo00<000000?ooo`3oool02@3oool600000?40oooo000M0?ooo`030000003oool0oooo
00d0oooo1000003_0?ooo`007@3oool200000180oooo0`00003/0?ooo`007@3oool00`000000oooo
0?ooo`0D0?ooo`800000jP3oool001d0oooo00<000000?ooo`3oool05P3oool300000>L0oooo000M
0?ooo`030000003oool0oooo01T0oooo0P00003U0?ooo`007@3oool2000001`0oooo0`00003R0?oo
o`007@3oool00`000000oooo0?ooo`0N0?ooo`800000h03oool001d0oooo00<000000?ooo`3oool0
803oool300000=d0oooo000M0?ooo`030000003oool0oooo02<0oooo0P00003K0?ooo`002@3oool3
000000<0oooo00<000000?ooo`3oool00P3oool3000000H0oooo0P00000V0?ooo`<00000f03oool0
00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
02P0oooo0P00003F0?ooo`002P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0:P3oool200000=@0oooo000:0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0/0?ooo`800000dP3oool000X0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`<00000;P3oool200000=00oooo000:
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0`
0?ooo`<00000c@3oool000X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0380oooo0`00003;0?ooo`002P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0=03oool400000<P0oooo00090?ooo`800000
2@3oool2000000L0oooo0P00000g0?ooo`@00000aP3oool000X0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03P0oooo100000340?ooo`007@3oool0
0`000000oooo0?ooo`0j0?ooo`@00000`P3oool001d0oooo00<000000?ooo`3oool0?03oool40000
0<00oooo000M0?ooo`800000?`3oool300000;l0oooo000M0?ooo`030000003oool0oooo0400oooo
0`00002m0?ooo`007@3oool00`000000oooo0?ooo`110?ooo`@00000^`3oool001d0oooo00<00000
0?ooo`3oool0@`3oool400000;T0oooo000M0?ooo`800000AP3oool400000;L0oooo000M0?ooo`03
0000003oool0oooo04L0oooo1000002e0?ooo`007@3oool00`000000oooo0?ooo`190?ooo`@00000
/`3oool001d0oooo00<000000?ooo`3oool0B`3oool400000;40oooo00090?ooo`<000000`3oool0
10000000oooo0?ooo`3oool5000000D0oooo0P00001>0?ooo`@00000[`3oool000X0oooo00<00000
0?ooo`3oool01`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo04l0oooo1000
002]0?ooo`002P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0D@3oool400000:/0oooo000:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`1C0?ooo`@00000Z@3oool000X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`040?ooo`<00000E@3oool010000000oooo00000000002W0?oo
o`002P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0EP3oool2000000030?ooo`00000000000:D0oooo000:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1H0?ooo`80000000<0oooo000000000000
X`3oool000X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo05X0oooo00<000000?ooo`3oool00P00002Q0?ooo`002@3oool2000000P0oooo00D00000
0?ooo`3oool0oooo000000050?ooo`800000G03oool200000080oooo00<000000?ooo`3oool0WP3o
ool000X0oooo00<000000?ooo`3oool01`3oool3000000H0oooo00<000000?ooo`3oool0G@3oool2
000000030?ooo`000000000009h0oooo000M0?ooo`030000003oool0oooo05l0oooo00<000000?oo
o`3oool00P00002L0?ooo`007@3oool00`000000oooo0?ooo`1P0?ooo`8000000P3oool00`000000
oooo0?ooo`2I0?ooo`007@3oool2000006<0oooo0P0000000`3oool000000000002I0?ooo`007@3o
ool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00800000U`3oool001d0oooo00<00000
0?ooo`3oool0I@3oool200000080oooo00<000000?ooo`3oool0U03oool001d0oooo00<000000?oo
o`3oool0I`3oool2000000030?ooo`000000000009@0oooo000M0?ooo`800000JP3oool00`000000
oooo0?ooo`0200000980oooo000M0?ooo`030000003oool0oooo06X0oooo0P0000020?ooo`030000
003oool0oooo08l0oooo000M0?ooo`030000003oool0oooo06`0oooo0P0000000`3oool000000000
002?0?ooo`007@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo00800000S@3oool0
00T0oooo0`0000030?ooo`040000003oool0oooo0?ooo`@000001P3oool200000700oooo0P000002
0?ooo`030000003oool0oooo08X0oooo000:0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`1a0?ooo`80000000<0oooo000000000000RP3oool000X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07<0
oooo00<000000?ooo`3oool00P0000280?ooo`002P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0M03oool200000080oooo00<000000?ooo`3oool0
Q@3oool000X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`<00000MP3o
ool2000000030?ooo`000000000008D0oooo000:0?ooo`030000003oool0oooo00P0oooo0P000006
0?ooo`030000003oool0oooo07P0oooo00@000000?ooo`3oool00000Q03oool000X0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo07T0oooo0P000000
0`3oool00000000000220?ooo`002P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0200000800oooo00090?ooo`80
0000203oool01@000000oooo0?ooo`3oool0000000D0oooo0P00001m0?ooo`8000000P3oool00`00
0000oooo0?ooo`1m0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`<000001P3oool00`000000
oooo0?ooo`1n0?ooo`80000000<0oooo000000000000O@3oool001d0oooo00<000000?ooo`3oool0
P03oool010000000oooo0?ooo`00001l0?ooo`007@3oool00`000000oooo0?ooo`210?ooo`800000
00<0oooo000000000000NP3oool001d0oooo0P0000240?ooo`030000003oool0oooo00800000N03o
ool001d0oooo00<000000?ooo`3oool0Q03oool200000080oooo00<000000?ooo`3oool0M@3oool0
01d0oooo00<000000?ooo`3oool0QP3oool2000000030?ooo`000000000007D0oooo000M0?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool00P00001c0?ooo`007@3oool2000008X0oooo
0P0000020?ooo`030000003oool0oooo0700oooo000M0?ooo`030000003oool0oooo08/0oooo0P00
00000`3oool000000?ooo`1`0?ooo`007@3oool00`000000oooo0?ooo`2=0?ooo`040000003oool0
0000000006l0oooo000M0?ooo`030000003oool0oooo08h0oooo00@000000?ooo`3oool00000KP3o
ool000T0oooo0`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool2
00000900oooo0P0000000`3oool000000?ooo`1/0?ooo`002P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0000001/0?oo
o`002P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0TP3oool010000000oooo00000000001Z0?ooo`002P3oool00`000000oooo0?ooo`050?ooo`H0
00001@3oool00`000000oooo0?ooo`2C0?ooo`040000003oool0oooo000006T0oooo000:0?ooo`03
0000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000060?ooo`<00000U03oool20000
00030?ooo`000000oooo06L0oooo000:0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3o
ool000001P3oool00`000000oooo0?ooo`2F0?ooo`040000003oool00000000006H0oooo000:0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`2G0?oo
o`040000003oool0oooo000006D0oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`0000001P3oool00`000000oooo0?ooo`2H0?ooo`80000000<0oooo000000000000H`3oool000T0
oooo0P00000:0?ooo`8000001P3oool2000009/0oooo00<000000?ooo`3oool00P00001Q0?ooo`00
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
V`3oool200000080oooo00<000000?ooo`3oool0GP3oool001d0oooo00<000000?ooo`3oool0W@3o
ool2000000030?ooo`000000000005h0oooo000M0?ooo`030000003oool0oooo09l0oooo00@00000
0?ooo`3oool00000G@3oool001d0oooo0P00002Q0?ooo`80000000<0oooo0000003oool0F`3oool0
01d0oooo00<000000?ooo`3oool0XP3oool010000000oooo00000000001J0?ooo`007@3oool00`00
0000oooo0?ooo`2S0?ooo`040000003oool0oooo000005T0oooo000M0?ooo`030000003oool0oooo
0:@0oooo0P0000000`3oool000000?ooo`1G0?ooo`007@3oool200000:L0oooo00@000000?ooo`00
00000000EP3oool001d0oooo00<000000?ooo`3oool0Y`3oool010000000oooo0?ooo`00001E0?oo
o`007@3oool00`000000oooo0?ooo`2X0?ooo`80000000<0oooo0000003oool0D`3oool001d0oooo
00<000000?ooo`3oool0ZP3oool010000000oooo00000000001B0?ooo`002@3oool3000000<0oooo
00@000000?ooo`3oool0oooo0`0000070?ooo`800000[03oool010000000oooo0?ooo`00001A0?oo
o`002P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0[03oool2000000030?ooo`000000oooo04l0oooo000:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2^0?ooo`040000003oool00000000004h0
oooo000:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`2_0?ooo`80000000<0oooo0000003oool0C03oool000X0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`030?ooo`<00000/@3oool3000004`0oooo000:0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2c0?ooo`<00000BP3oool0
00X0oooo00<000000?ooo`3oool01P3oool3000000L0oooo00<000000?ooo`3oool0]03oool30000
04T0oooo000:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`2f0?ooo`<00000A`3oool000T0oooo0P0000090?ooo`030000003oool0oooo00H0oooo
0P00002h0?ooo`030000003oool0000004H0oooo000:0?ooo`030000003oool0oooo00L0oooo1000
00050?ooo`030000003oool0oooo0;P0oooo0`0000150?ooo`007@3oool00`000000oooo0?ooo`2j
0?ooo`<00000@`3oool001d0oooo00<000000?ooo`3oool0^`3oool00`000000oooo000000120?oo
o`007@3oool200000;d0oooo00@000000?ooo`0000000000@03oool001d0oooo00<000000?ooo`3o
ool0_@3oool2000000030?ooo`000000oooo03h0oooo000M0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`000000?P3oool001d0oooo00<000000?ooo`3oool0`03oool010000000oooo0000
0000000l0?ooo`007@3oool200000<80oooo0P0000000`3oool000000?ooo`0j0?ooo`007@3oool0
0`000000oooo0?ooo`330?ooo`030000003oool0000003X0oooo000M0?ooo`030000003oool0oooo
0<@0oooo00<000000?ooo`000000>@3oool001d0oooo00<000000?ooo`3oool0a@3oool3000003P0
oooo00090?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`<000001P3oool200000<P0oooo
0`00000f0?ooo`002P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000
1@3oool00`000000oooo0?ooo`380?ooo`030000003oool0000003D0oooo000:0?ooo`030000003o
ool0oooo00H0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0<T0oooo
0`00000d0?ooo`002P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000
1@3oool00`000000oooo0?ooo`3;0?ooo`800000<`3oool000X0oooo00<000000?ooo`3oool01P3o
ool01@000000oooo0?ooo`3oool0000000D0oooo0`00003<0?ooo`<00000<@3oool000X0oooo00<0
00000?ooo`3oool01P3oool200000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`3=0?ooo`<00000<03oool000X0oooo00<000000?ooo`3oool01P3oool010000000oooo00000000
00060?ooo`030000003oool0oooo0<l0oooo0P00000_0?ooo`002P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0d03oool2000002h0oooo00090?oo
o`8000002P3oool00`000000oooo0?ooo`050?ooo`800000dP3oool3000002`0oooo000:0?ooo`03
0000003oool0oooo00T0oooo0P0000050?ooo`030000003oool0oooo0=80oooo0`00000[0?ooo`00
7@3oool00`000000oooo0?ooo`3D0?ooo`800000:P3oool001d0oooo00<000000?ooo`3oool0e@3o
ool2000002T0oooo000M0?ooo`800000e`3oool3000002L0oooo000M0?ooo`030000003oool0oooo
0=L0oooo0`00000V0?ooo`007@3oool00`000000oooo0?ooo`3I0?ooo`8000009@3oool001d0oooo
00<000000?ooo`3oool0fP3oool2000002@0oooo000M0?ooo`800000g03oool300000280oooo000M
0?ooo`030000003oool0oooo0=`0oooo0`00000Q0?ooo`007@3oool00`000000oooo0?ooo`3N0?oo
o`800000803oool001d0oooo00<000000?ooo`3oool0g`3oool3000001h0oooo00090?ooo`<00000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo0P00003Q0?ooo`030000
003oool0000001d0oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`3Q0?ooo`<00000703oool000X0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0><0oooo0`00000J0?ooo`002P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0i03oool00`00
0000oooo0000000I0?ooo`002P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0
oooo0`00003U0?ooo`030000003oool0000001P0oooo000:0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3V0?ooo`040000003oool00000000001H0
oooo000:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`3W0?ooo`80000000<0oooo0000003oool0503oool000X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0>T0oooo00<000000?ooo`000000503o
ool000T0oooo0P0000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2
00000>/0oooo00<000000?ooo`0000004`3oool000X0oooo00<000000?ooo`3oool01P3oool50000
00D0oooo00<000000?ooo`3oool0j`3oool00`000000oooo0000000B0?ooo`007@3oool00`000000
oooo0?ooo`3/0?ooo`040000003oool0000000000100oooo000M0?ooo`030000003oool0oooo0>d0
oooo00@000000?ooo`3oool000003`3oool001d0oooo0P00003_0?ooo`80000000<0oooo0000003o
ool03@3oool001d0oooo00<000000?ooo`3oool0l03oool00`000000oooo0000000=0?ooo`007@3o
ool00`000000oooo0?ooo`3a0?ooo`030000003oool0000000`0oooo000M0?ooo`030000003oool0
oooo0?80oooo00<000000?ooo`3oool02`3oool001d0oooo0P00003d0?ooo`030000003oool0oooo
00X0oooo000M0?ooo`030000003oool0oooo0?l0oooo0@3oool001d0oooo00<000000?ooo`3oool0
o`3oool10?ooo`007@3oool00`000000oooo0?ooo`3o0?ooo`40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.120987, 0.894761, \
0.00406352, 0.00500141}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.476191 6.94801 6.28491 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.2619 -0.0125 -10.7813 -17.8125 ]
[.2619 -0.0125 10.7813 0 ]
[.5 -0.0125 -5.53125 -17.8125 ]
[.5 -0.0125 5.53125 0 ]
[.7381 -0.0125 -10.7813 -17.8125 ]
[.7381 -0.0125 10.7813 0 ]
[.97619 -0.0125 -5.53125 -17.8125 ]
[.97619 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.125 -35.625 ]
[.5 -0.0125 5.125 -17.8125 ]
[-0.0125 .0346 -31.25 -8.90625 ]
[-0.0125 .0346 0 8.90625 ]
[-0.0125 .1603 -38.3125 -8.90625 ]
[-0.0125 .1603 0 8.90625 ]
[-0.0125 .286 -38.3125 -8.90625 ]
[-0.0125 .286 0 8.90625 ]
[-0.0125 .4117 -38.3125 -8.90625 ]
[-0.0125 .4117 0 8.90625 ]
[-0.0125 .5374 -38.3125 -8.90625 ]
[-0.0125 .5374 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -56.125 -14.7188 ]
[-0.01875 .30902 -38.3125 14.7188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.125 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0346 m
.00625 .0346 L
s
gsave
-0.0125 .0346 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
1.000 setlinewidth
grestore
0 .1603 m
.00625 .1603 L
s
gsave
-0.0125 .1603 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.08) show
1.000 setlinewidth
grestore
0 .286 m
.00625 .286 L
s
gsave
-0.0125 .286 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.06) show
1.000 setlinewidth
grestore
0 .4117 m
.00625 .4117 L
s
gsave
-0.0125 .4117 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.04) show
1.000 setlinewidth
grestore
0 .5374 m
.00625 .5374 L
s
gsave
-0.0125 .5374 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.02) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .06603 m
.00375 .06603 L
s
0 .09745 m
.00375 .09745 L
s
0 .12888 m
.00375 .12888 L
s
0 .19173 m
.00375 .19173 L
s
0 .22315 m
.00375 .22315 L
s
0 .25458 m
.00375 .25458 L
s
0 .31743 m
.00375 .31743 L
s
0 .34885 m
.00375 .34885 L
s
0 .38028 m
.00375 .38028 L
s
0 .44312 m
.00375 .44312 L
s
0 .47455 m
.00375 .47455 L
s
0 .50597 m
.00375 .50597 L
s
0 .00318 m
.00375 .00318 L
s
0 .56882 m
.00375 .56882 L
s
0 .60025 m
.00375 .60025 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -122.938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.7188 12.9063 translate
90 rotate
-75.7188 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.063 17.500 moveto
(H) show
77.625 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.875 17.500 moveto
(L) show
88.438 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0346 m
1 .0346 L
s
.99375 .1603 m
1 .1603 L
s
.99375 .286 m
1 .286 L
s
.99375 .4117 m
1 .4117 L
s
.99375 .5374 m
1 .5374 L
s
.125 Mabswid
.99625 .06603 m
1 .06603 L
s
.99625 .09745 m
1 .09745 L
s
.99625 .12888 m
1 .12888 L
s
.99625 .19173 m
1 .19173 L
s
.99625 .22315 m
1 .22315 L
s
.99625 .25458 m
1 .25458 L
s
.99625 .31743 m
1 .31743 L
s
.99625 .34885 m
1 .34885 L
s
.99625 .38028 m
1 .38028 L
s
.99625 .44312 m
1 .44312 L
s
.99625 .47455 m
1 .47455 L
s
.99625 .50597 m
1 .50597 L
s
.99625 .00318 m
1 .00318 L
s
.99625 .56882 m
1 .56882 L
s
.99625 .60025 m
1 .60025 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.06244 .06943 L
.10458 .1288 L
.14415 .18215 L
.18221 .23007 L
.22272 .27678 L
.26171 .31737 L
.30316 .3559 L
.34309 .38877 L
.3815 .41679 L
.42237 .4431 L
.46172 .46539 L
.49955 .48435 L
.53984 .50219 L
.57861 .51735 L
.61984 .53158 L
.65954 .54369 L
.69774 .55405 L
.73838 .56386 L
.77751 .57227 L
.81909 .58023 L
.85916 .58708 L
.89771 .593 L
.93871 .59865 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00ZP3oool6
00000700oooo002[0?ooo`050000003oool0oooo0?ooo`000000L03oool00:`0oooo00<000000?oo
o`3oool0L@3oool00:`0oooo00<000000?ooo`3oool0L@3oool00:d0oooo00<000000?ooo`3oool0
L03oool00:X0oooo00D000000?ooo`3oool0oooo0000001a0?ooo`00ZP3oool600000700oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo00110?ooo`<00000;@3oool3000000<0oooo00@000000?ooo`3oool0oooo0`00000^
0?ooo`<00000;@3oool3000000<0oooo00@000000?ooo`3oool0oooo0`00000/0?ooo`D000001P3o
ool00400oooo00D000000?ooo`3oool0oooo0000000[0?ooo`050000003oool0oooo0?ooo`000000
2@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0oooo000000H0oooo00100?ooo`050000
003oool0oooo0?ooo`000000:`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`060?ooo`00@03oool01@000000oooo0?ooo`3oool00000
02/0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool01@3oool00400oooo00D000000?ooo`3oool0oooo0000000[0?ooo`050000003oool0
oooo0?ooo`0000002P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00D0oooo0010
0?ooo`050000003oool0oooo0?ooo`000000:`3oool01@000000oooo0?ooo`3oool0000000T0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?oo
o`3oool0000002/0oooo00D000000?ooo`3oool0oooo000000060?ooo`<00000;`3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo00H0oooo0`00000`0?ooo`030000003oool0oooo00@0
oooo00100?ooo`050000003oool0oooo0?ooo`000000:`3oool01@000000oooo0?ooo`3oool00000
00H0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`040?ooo`00@03oool01@000000
oooo0?ooo`3oool0000002/0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0
oooo02d0oooo0P00000^0?ooo`8000002@3oool00`000000oooo0?ooo`0[0?ooo`050000003oool0
oooo0?ooo`0000001P3oool00440oooo0`00000]0?ooo`<00000203oool4000002d0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`070?ooo`@00000:`3oool3000000L0oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000m0?oo
on4000000P3oool003d0oooo0P0000030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool010000000oooo0?ooo`3oool200000080oooo000m0?ooo`030000003oool0oooo0=d0
oooo0@0000010?ooo`40oooo000m0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
f03oool100000040oooo0@3oool002T0oooo0`0000030?ooo`030000003oool0oooo0080oooo0`00
00060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0e`3oool100000040oooo0@3o
ool002X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0e`3oool100000040oooo0@3oool002X0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0eP3oool100000040oooo0@3oool001h0oooo1`0000050?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0
oooo0@0000010?ooo`40oooo000Z0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1@3oool2000000H0oooo00<000000?ooo`3oool0e03oool200000080oooo000Z0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0=@0oooo0@0000010?ooo`40oooo000Z0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0=<0oooo0@000001
0?ooo`40oooo000Z0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0=80oooo0@0000010?ooo`40oooo000Y0?ooo`80
00002@3oool2000000L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3B0?ooo`40
00000@3oool10?ooo`00:P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3A0?ooo`4000000@3oool10?ooo`00?@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0=00oooo0@0000010?ooo`40oooo000m
0?ooo`8000002`3oool00`000000oooo0?ooo`3?0?ooo`8000000P3oool003d0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`3?0?ooo`4000000@3oool10?ooo`00?@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0<h0oooo0@0000010?ooo`40oooo000m0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0cP3oool100000040oooo0@3oool003d0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`3=0?ooo`4000000@3oool10?ooo`00?@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0<`0oooo0@0000010?ooo`40oooo000m0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0c03oool100000040oooo0@3oool003d0
oooo0P00000@0?ooo`030000003oool0oooo0<X0oooo0P0000020?ooo`00?@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0<X0oooo0@0000010?ooo`40oooo000m0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0b@3oool100000040oooo0@3oool003d0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`390?ooo`4000000@3oool10?ooo`00?@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0<P0oooo0@0000010?ooo`40oooo000m0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0a`3oool100000040oooo0@3oool003d0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`370?ooo`4000000@3oool10?ooo`00?@3o
ool2000001D0oooo00<000000?ooo`3oool0a@3oool200000080oooo000m0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0a@3oool100000040oooo0@3oool003d0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`350?ooo`4000000@3oool10?ooo`008P3oool3000000<0
oooo00<000000?ooo`3oool00P3oool3000000@0oooo0`0000060?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0a03oool100000040oooo0@3oool002<0oooo00<000000?ooo`3oool0
1P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000050?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0``3oool100000040oooo0@3oool002<0
oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?oo
o`3oool0oooo000000050?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0`P3oool1
00000040oooo0@3oool001L0oooo1`0000050?ooo`030000003oool0oooo00H0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo0<80oooo0@0000010?ooo`40oooo000S0?ooo`030000003oool0
oooo00H0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0000000H0oooo0P00
000J0?ooo`030000003oool0oooo0<00oooo0P0000020?ooo`008`3oool00`000000oooo0?ooo`06
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool0`03oool100000040oooo0@3oool002<0oooo00<00000
0?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000001P3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0;l0oooo0@0000010?ooo`40oooo000S
0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003o
ool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0;l0oooo
0@0000010?ooo`40oooo000R0?ooo`800000203oool01@000000oooo0?ooo`3oool000000080oooo
00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0_P3oool100000040oooo0@3oool002<0oooo00<000000?ooo`3oool01`3oool3000000@0oooo
0`0000060?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0_@3oool100000040oooo
0@3oool003d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`2l0?ooo`4000000@3o
ool10?ooo`00?@3oool200000200oooo00<000000?ooo`3oool0^P3oool200000080oooo000m0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0^`3oool100000040oooo0@3oool003d0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`2j0?ooo`4000000@3oool10?ooo`00
?@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;T0oooo0@0000010?ooo`40oooo
000m0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0^03oool100000040oooo0@3o
ool003d0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`2g0?ooo`4000000@3oool1
0?ooo`00?@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0;H0oooo0@0000010?oo
o`40oooo000m0?ooo`8000009@3oool00`000000oooo0?ooo`2e0?ooo`8000000P3oool003d0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`2e0?ooo`4000000@3oool10?ooo`00?@3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0;@0oooo0@0000010?ooo`40oooo000m
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0/`3oool100000040oooo0@3oool0
03d0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`2b0?ooo`4000000@3oool10?oo
o`00?@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0;40oooo0@0000010?ooo`40
oooo000m0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0/03oool100000040oooo
0@3oool003d0oooo0P00000[0?ooo`030000003oool0oooo0:l0oooo0P0000020?ooo`001`3oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0[`3oool1
00000040oooo0@3oool000L0oooo0`00000c0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool0[P3oool100000040oooo0@3oool000L0oooo00<000000?ooo`3oool00`00000E0?ooo`<0
00000`3oool00`000000oooo0?ooo`020?ooo`<00000103oool3000000H0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`2]0?ooo`4000000@3oool10?ooo`00303oool2000001D0oooo
00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3o
ool0oooo000000050?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0[03oool10000
0040oooo0@3oool000L0oooo00<000000?ooo`3oool00P00000G0?ooo`030000003oool0oooo00H0
oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000001@3oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0:/0oooo0@0000010?ooo`40oooo00070?oo
o`<000003@3oool7000000D0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0
00000080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool0ZP3oool100000040oooo0@3oool000L0oooo00<000000?ooo`3oool00`00000F
0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003o
ool0oooo0?ooo`0000001@3oool200000380oooo00<000000?ooo`3oool0Z03oool200000080oooo
000<0?ooo`8000005@3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000
0P3oool200000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo0:P0oooo0@0000010?ooo`40oooo00070?ooo`030000003oool0oooo008000005`3o
ool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0000000000060?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0Y`3oool100000040
oooo0@3oool000L0oooo0`00000I0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`2V0?ooo`4000000@3oool10?ooo`001`3oool00`000000oooo0?ooo`0H0?ooo`800000
203oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo0:D0oooo0@0000010?ooo`40oooo00060?ooo`T00000
503oool00`000000oooo0?ooo`070?ooo`<000001P3oool2000000D0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`2T0?ooo`4000000@3oool10?ooo`001@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`2S0?ooo`4000000@3oool10?ooo`00103oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo02X0oooo0P00000i0?ooo`030000003oool0oooo0:40oooo0P0000020?ooo`001`3oool20000
00@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
0:40oooo0@0000010?ooo`40oooo00070?ooo`030000003oool0oooo0080oooo0P00000_0?ooo`03
0000003oool0oooo03X0oooo00<000000?ooo`3oool0X03oool100000040oooo0@3oool000L0oooo
00<000000?ooo`3oool00P0000000`3oool000000?ooo`0^0?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool0W`3oool100000040oooo0@3oool000L0oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0WP3o
ool100000040oooo0@3oool000L0oooo0P0000040?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`2M0?ooo`4000000@3oool10?ooo`001`3oool00`00
0000oooo0?ooo`020?ooo`800000;`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo
09`0oooo0@0000010?ooo`40oooo00040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0:P3oool200000400oooo00<000000?ooo`3oool0VP3oool200000080oooo00050?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo09X0oooo0@0000010?ooo`40oooo00060?ooo`T00000;P3oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo09T0oooo0@0000010?ooo`40oooo000m0?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool0V03oool100000040oooo0@3oool003d0oooo00<000000?oo
o`3oool0@`3oool2000009P0oooo0@0000010?ooo`40oooo000m0?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool0U@3oool100000040oooo0@3oool003d0oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`2D0?ooo`4000000@3oool10?ooo`00?@3oool2000004P0oooo0P00
002C0?ooo`8000000P3oool003d0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`2A
0?ooo`4000000@3oool10?ooo`00?@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo
0900oooo0@0000010?ooo`40oooo000m0?ooo`030000003oool0oooo04/0oooo0P00002@0?ooo`40
00000@3oool10?ooo`008P3oool3000000<0oooo00<000000?ooo`3oool00P3oool3000000H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo08d0oooo
0@0000010?ooo`40oooo000S0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo
000000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0CP3oool2000008d0oooo
0@0000010?ooo`40oooo000S0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo
000000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0D03oool00`000000oooo
0?ooo`2:0?ooo`4000000@3oool10?ooo`005`3oool7000000D0oooo00<000000?ooo`3oool01P3o
ool01P000000oooo0?ooo`3oool000000?ooo`H000001@3oool200000580oooo0P0000290?ooo`80
00000P3oool002<0oooo00<000000?ooo`3oool01P3oool01`000000oooo0?ooo`3oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo05<0oooo00<000000?oo
o`3oool0Q`3oool100000040oooo0@3oool002<0oooo00<000000?ooo`3oool01P3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1D
0?ooo`800000Q`3oool100000040oooo0@3oool002<0oooo00<000000?ooo`3oool01P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo08@0oooo0@0000010?ooo`40oooo000S0?ooo`030000003oool0oooo
00H0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0000000H0oooo00<00000
0?ooo`3oool0E`3oool2000008@0oooo0@0000010?ooo`40oooo000R0?ooo`800000203oool01@00
0000oooo0?ooo`3oool0000000@0oooo0P0000060?ooo`030000003oool0oooo05T0oooo00<00000
0?ooo`3oool0P@3oool100000040oooo0@3oool002<0oooo00<000000?ooo`3oool01`3oool30000
00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1J0?ooo`800000P@3oool10000
0040oooo0@3oool003d0oooo0P00001M0?ooo`030000003oool0oooo07d0oooo0P0000020?ooo`00
?@3oool00`000000oooo0?ooo`1M0?ooo`800000OP3oool100000040oooo0@3oool003d0oooo00<0
00000?ooo`3oool0G`3oool00`000000oooo0?ooo`1k0?ooo`4000000@3oool10?ooo`00?@3oool0
0`000000oooo0?ooo`1P0?ooo`800000N`3oool100000040oooo0@3oool003d0oooo00<000000?oo
o`3oool0HP3oool2000007T0oooo0@0000010?ooo`40oooo000m0?ooo`030000003oool0oooo06@0
oooo00<000000?ooo`3oool0MP3oool100000040oooo0@3oool003d0oooo00<000000?ooo`3oool0
I@3oool2000007H0oooo0@0000010?ooo`40oooo000m0?ooo`800000J03oool2000007<0oooo0P00
00020?ooo`00?@3oool00`000000oooo0?ooo`1Y0?ooo`800000LP3oool100000040oooo0@3oool0
03d0oooo00<000000?ooo`3oool0J`3oool200000700oooo0@0000010?ooo`40oooo000m0?ooo`03
0000003oool0oooo06d0oooo0P00001^0?ooo`4000000@3oool10?ooo`00?@3oool00`000000oooo
0?ooo`1_0?ooo`800000K03oool100000040oooo0@3oool003d0oooo00<000000?ooo`3oool0L@3o
ool2000006X0oooo0@0000010?ooo`40oooo000m0?ooo`030000003oool0oooo07<0oooo0P00001X
0?ooo`4000000@3oool10?ooo`00?@3oool2000007H0oooo0`00001T0?ooo`8000000P3oool003d0
oooo00<000000?ooo`3oool0N03oool300000680oooo0@0000010?ooo`40oooo000m0?ooo`030000
003oool0oooo07/0oooo0`00001O0?ooo`4000000@3oool10?ooo`00?@3oool00`000000oooo0?oo
o`1n0?ooo`<00000G03oool100000040oooo0@3oool00280oooo0`0000030?ooo`030000003oool0
oooo0080oooo0`0000030?ooo`D000001@3oool00`000000oooo0?ooo`210?ooo`<00000F@3oool1
00000040oooo0@3oool002<0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0
000000<0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`240?ooo`<00000EP3o
ool100000040oooo0@3oool002<0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`270?ooo`<00000D`3o
ool100000040oooo0@3oool001L0oooo1`0000050?ooo`030000003oool0oooo00H0oooo00D00000
0?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00@0oooo0P00002;0?ooo`<00000C`3o
ool200000080oooo000S0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo0000
00050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S@3oool3000004d0oooo0@00
00010?ooo`40oooo000S0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0T03oool3000004X0oooo0@00
00010?ooo`40oooo000S0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0T`3oool4000004H0oooo0@00
00010?ooo`40oooo000S0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0U`3oool500000440oooo0@00
00010?ooo`40oooo000R0?ooo`800000203oool01@000000oooo0?ooo`3oool000000080oooo00D0
00000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo09`0oooo1000000m0?ooo`400000
0@3oool10?ooo`008`3oool00`000000oooo0?ooo`070?ooo`<00000103oool3000000H0oooo00<0
00000?ooo`3oool0X03oool5000003P0oooo0@0000010?ooo`40oooo000m0?ooo`800000YP3oool4
000003<0oooo0P0000020?ooo`00?@3oool00`000000oooo0?ooo`2Y0?ooo`D00000;`3oool10000
0040oooo0@3oool003d0oooo00<000000?ooo`3oool0[P3oool5000002X0oooo0@0000010?ooo`40
oooo000m0?ooo`030000003oool0oooo0;<0oooo1@00000U0?ooo`4000000@3oool10?ooo`00?@3o
ool00`000000oooo0?ooo`2h0?ooo`@000008@3oool100000040oooo0@3oool003d0oooo00<00000
0?ooo`3oool0_03oool6000001/0oooo0@0000010?ooo`40oooo000m0?ooo`030000003oool0oooo
0<80oooo2@00000B0?ooo`4000000@3oool10?ooo`00?@3oool00`000000oooo0?ooo`3;0?ooo`T0
00002@3oool100000040oooo0@3oool003d0oooo0P00003E0?ooo`D000000`3oool200000080oooo
000m0?ooo`030000003oool0oooo0=d0oooo0@0000010?ooo`40oooo000m0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`020?ooo`4000000@3oool1
0?ooo`00?@3ooooQ00000080oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.626348, -1.13279, \
0.00937019, 0.000709954}}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[{
    \( (*\ 
      Find\ chi\ square\ for\ given\ H \((z)\)\ \ *) \[IndentingNewLine]\(f[
          z_] := 1/hhz[z];\)\), "\n", 
    \(\(rr[zz_] := NIntegrate[f[z], {z, 0, zz}];\)\), "\n", 
    \(\(qq = Table[rr[zz[i]], {i, 1, ndat}];\)\)}], "Input"],

Cell[BoxData[{
    \( (*\ Construct\ marginalization\ coefficients\ \((see\ astro - 
              ph/0401556\  .. )\)\ *) \[IndentingNewLine]Clear[chi2fa, 
      chi2fb, chi2fc]\), "\n", 
    \(\(chi2fa = 
        Sum[\((ld[i] - 5\ Log[10, qq[\([i]\)]*\((1 + zz[i])\)])\)^2/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\n", 
    \(\(chi2fb = 
        Sum[\((ld[i] - 
                5\ Log[10, qq[\([i]\)]*\((1 + zz[i])\)])\)/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\n", 
    \(\(chi2fc = Sum[1/\((sld[i]^2)\), {i, 1, ndat}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ Construct\ function\ after\ marginalization, \ 
      find\ same\ result\ as\ with\ mb\ minimization\ *) \
\[IndentingNewLine]chi2fm = 
      chi2fa - chi2fb^2/chi2fc\), "\[IndentingNewLine]", 
    \(dchi2p10 = chi2fm - chi2l\)}], "Input"],

Cell[BoxData[
    \(177.09107539337128`\)], "Output"],

Cell[BoxData[
    \(\(-0.036296041682362556`\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ \(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(\
--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(-\(---\)\)\)\)\)\)\)\)\)\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)*) \[IndentingNewLine]\[IndentingNewLine] \
(*\ Find\ H \((z)\)\ for\ given\ slope\ s\ of\ the\ linear\ potential . \ 
            Present\ time\  = \ \(tt\ \((corresponds\ to\ a = 1)\) . \ 
              Run\ trials\ for\ initial\ condition\ for\ field\ fi\ \((f0)\)\ \
and\ initial\ time\ ti\ until\ we\ get\ field\ energy\ enf\  = \ \(0.7\ and\ \
H \((z = 0)\)\  = 
            1\ at\ present\ time\ \(\(tt\)\(.\)\)\)\)\ *) \[IndentingNewLine]\
\[IndentingNewLine] (*\ \(--\(--\(--\(--\ \ s\)\)\)\)\  = \ \(1.5\ \ \ --\) \
\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(---\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\ *) \
\[IndentingNewLine]\[IndentingNewLine]\(Clear[aa, fi, a, aad, aadd, fidas, 
        tas, f, rr, hht, hha];\)\), "\n", 
    \(aa = a[t]; \ fi = f[t];\), "\n", 
    \(\(aad = D[aa, t];\)\), "\n", 
    \(\(aadd = D[aa, {t, 2}];\)\), "\n", 
    \(\(fid = D[fi, t];\)\), "\n", 
    \(\(fidd = D[fi, {t, 2}];\)\n\), "\n", 
    \(ti = 0.0000017; \ t0 = 4;\), "\n", 
    \(\(f0 = 0.3;\)\ \), "\n", 
    \(om0m = 0.3; \ ss = 1.5;\), "\n", 
    \(\(eq1 = 
        aadd/aa\  \[Equal] \ 
          fid^2\ \  + \ \ ss\ fi\  - \ om0m/\((2\ aa^3)\);\)\), "\n", 
    \(\(eq2 = 
        fidd\ \  + \ \ \ 3\ \ fid\ \((aad/aa)\)\  - \ ss \[Equal] 
          0;\)\), "\n", 
    \(\(eqb1 = f[ti] == f0;\)\), "\n", 
    \(\(eqb2 = \(f'\)[ti] == 0;\)\), "\n", 
    \(\(eqb3 = 
        a[ti] \[Equal] \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((2/3)\);\)\), "\n", 
    \(\(eqb4 = \(a'\)[
            ti] \[Equal] \((2/
                3)\)\ \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((\(-1\)/
                  3)\);\)\), "\n", 
    \(\(sol2 = 
        NDSolve[{eq1, eq2, eqb1, eqb2, eqb3, eqb4}, {aa, fi}, {t, ti, t0}, 
          MaxSteps \[Rule] 10000000];\)\), "\n", 
    \(\(asol = Part[Evaluate[a[t] /. sol2], 1];\)\), "\n", 
    \(\(fsol = 
        Part[Evaluate[f[t] /. sol2], 1];\)\[IndentingNewLine]\), "\n", 
    \(\(dfsol = D[fsol, t];\)\), "\n", 
    \(\(enf = \(-0.5\)\ dfsol^2\  + \ ss\ fsol;\)\), "\n", 
    \(\(as[t1_] := asol\  /. \ t -> t1\ ;\)\), "\n", 
    \(\(tt = Part[FindRoot[as[t] == 1, {t, 0.1}], 1, 2];\)\), "\n", 
    \(\(tas[a_] := 
        Part[FindRoot[as[t] \[Equal] a, {t, 0.3}], 1, 2];\)\), "\n", 
    \(\(hht[t1_] := D[asol, t]/asol\  /. \ t -> t1\ ;\)\), "\n", 
    \(\(hha[a_] := hht[tas[a]];\)\), "\n", 
    \(\(hhz[z_] := hha[1/\((z + 1)\)];\)\), "\n", 
    \(enf\  /. \ t \[Rule] tt\), "\n", 
    \(hhz[0]\), "\[IndentingNewLine]", 
    \(\(hhzt = 
        Sqrt[\((1 - om0m)\) + om0m \((1 + z)\)^3] /. 
          om0m \[Rule] 0.3;\)\), "\[IndentingNewLine]", 
    \(\(Plot[{hhz[z], hhzt}, {z, 0, 1}];\)\), "\[IndentingNewLine]", 
    \(\(enf = \(-0.5\)\ dfsol^2\  + \ ss\ fsol;\)\), "\n", 
    \(\(ppf = \(-0.5\)\ dfsol^2\  - \ ss\ fsol;\)\), "\n", 
    \(\(wft[t1_] := ppf/enf\  /. \ t -> t1\ ;\)\ \), "\n", 
    \(\(wfa[a_] := wft[tas[a]];\)\), "\n", 
    \(\(wfz[z_] := wfa[1/\((z + 1)\)];\)\), "\n", 
    \(\(plw15p = 
        Plot[wfz[z], {z, 0, 2}, Frame \[Rule] True, PlotRange \[Rule] All, 
          FrameLabel \[Rule] {"\<z\>", "\<w(z)\>"}];\)\)}], "Input"],

Cell[BoxData[
    \(0.6980347646594226`\)], "Output"],

Cell[BoxData[
    \(1.0064229983779227`\)], "Output"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.75907 0.773785 [
[.21429 .00222 -10.7813 -17.8125 ]
[.21429 .00222 10.7813 0 ]
[.40476 .00222 -10.7813 -17.8125 ]
[.40476 .00222 10.7813 0 ]
[.59524 .00222 -10.7813 -17.8125 ]
[.59524 .00222 10.7813 0 ]
[.78571 .00222 -10.7813 -17.8125 ]
[.78571 .00222 10.7813 0 ]
[.97619 .00222 -5.53125 -17.8125 ]
[.97619 .00222 5.53125 0 ]
[.01131 .09209 -21.5625 -8.90625 ]
[.01131 .09209 0 8.90625 ]
[.01131 .16947 -21.5625 -8.90625 ]
[.01131 .16947 0 8.90625 ]
[.01131 .24685 -21.5625 -8.90625 ]
[.01131 .24685 0 8.90625 ]
[.01131 .32423 -21.5625 -8.90625 ]
[.01131 .32423 0 8.90625 ]
[.01131 .40161 -21.5625 -8.90625 ]
[.01131 .40161 0 8.90625 ]
[.01131 .47899 -21.5625 -8.90625 ]
[.01131 .47899 0 8.90625 ]
[.01131 .55636 -21.5625 -8.90625 ]
[.01131 .55636 0 8.90625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
gsave
.21429 .00222 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 .01472 m
.40476 .02097 L
s
gsave
.40476 .00222 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 .01472 m
.59524 .02097 L
s
gsave
.59524 .00222 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 .01472 m
.78571 .02097 L
s
gsave
.78571 .00222 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 .01472 m
.97619 .02097 L
s
gsave
.97619 .00222 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .09209 m
.03006 .09209 L
s
gsave
.01131 .09209 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
1.000 setlinewidth
grestore
.02381 .16947 m
.03006 .16947 L
s
gsave
.01131 .16947 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
.02381 .24685 m
.03006 .24685 L
s
gsave
.01131 .24685 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
1.000 setlinewidth
grestore
.02381 .32423 m
.03006 .32423 L
s
gsave
.01131 .32423 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
.02381 .40161 m
.03006 .40161 L
s
gsave
.01131 .40161 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.02381 .47899 m
.03006 .47899 L
s
gsave
.01131 .47899 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
1.000 setlinewidth
grestore
.02381 .55636 m
.03006 .55636 L
s
gsave
.01131 .55636 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .03019 m
.02756 .03019 L
s
.02381 .04567 m
.02756 .04567 L
s
.02381 .06114 m
.02756 .06114 L
s
.02381 .07662 m
.02756 .07662 L
s
.02381 .10757 m
.02756 .10757 L
s
.02381 .12304 m
.02756 .12304 L
s
.02381 .13852 m
.02756 .13852 L
s
.02381 .154 m
.02756 .154 L
s
.02381 .18495 m
.02756 .18495 L
s
.02381 .20042 m
.02756 .20042 L
s
.02381 .2159 m
.02756 .2159 L
s
.02381 .23137 m
.02756 .23137 L
s
.02381 .26233 m
.02756 .26233 L
s
.02381 .2778 m
.02756 .2778 L
s
.02381 .29328 m
.02756 .29328 L
s
.02381 .30875 m
.02756 .30875 L
s
.02381 .3397 m
.02756 .3397 L
s
.02381 .35518 m
.02756 .35518 L
s
.02381 .37066 m
.02756 .37066 L
s
.02381 .38613 m
.02756 .38613 L
s
.02381 .41708 m
.02756 .41708 L
s
.02381 .43256 m
.02756 .43256 L
s
.02381 .44803 m
.02756 .44803 L
s
.02381 .46351 m
.02756 .46351 L
s
.02381 .49446 m
.02756 .49446 L
s
.02381 .50994 m
.02756 .50994 L
s
.02381 .52541 m
.02756 .52541 L
s
.02381 .54089 m
.02756 .54089 L
s
.02381 .57184 m
.02756 .57184 L
s
.02381 .58732 m
.02756 .58732 L
s
.02381 .60279 m
.02756 .60279 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01969 m
.06244 .02711 L
.10458 .03721 L
.14415 .04853 L
.18221 .06101 L
.22272 .07594 L
.26171 .09183 L
.30316 .11026 L
.34309 .12944 L
.3815 .14913 L
.42237 .17135 L
.46172 .1939 L
.49955 .21661 L
.53984 .24182 L
.57861 .26705 L
.61984 .29484 L
.65954 .32252 L
.69774 .34994 L
.73838 .37994 L
.77751 .40958 L
.81909 .44186 L
.85916 .4737 L
.89771 .50498 L
.93871 .53892 L
.97619 .57053 L
s
.02381 .01472 m
.06244 .02928 L
.10458 .04618 L
.14415 .063 L
.18221 .08004 L
.22272 .09908 L
.26171 .1183 L
.30316 .13965 L
.34309 .1611 L
.3815 .18255 L
.42237 .20622 L
.46172 .22982 L
.49955 .25324 L
.53984 .27895 L
.57861 .30443 L
.61984 .33229 L
.65954 .35985 L
.69774 .38703 L
.73838 .41664 L
.77751 .4458 L
.81909 .47749 L
.85916 .50867 L
.89771 .53928 L
.93871 .57245 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{425.188, 262.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006Y00011R000`400?l00000o`00003oo`3ooonZ
0?ooo`00o`3ooonZ0?ooo`00o`3ooonZ0?ooo`00o`3ooonZ0?ooo`00o`3ooonZ0?ooo`00I03oool3
000000<0oooo00@000000?ooo`3oool0oooo1@00000m0?ooo`<000000`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo03/0oooo0`0000030?ooo`030000003oool0oooo0080oooo0`00
000n0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`<00000@P3oool3000000l0oooo001S
0?ooo`050000003oool0oooo0?ooo`0000001`3oool010000000oooo0?ooo`00000l0?ooo`050000
003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0j0?ooo`050000003oool0oooo0?oo
o`0000001P3oool01@000000oooo0?ooo`3oool0000003`0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`050000003oool0oooo0?ooo`000000@P3oool00`000000oooo0?ooo`0>0?ooo`00H`3o
ool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0?03oool01@000000oooo
0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0>P3oool01@000000oooo0?ooo`3oool00000
00H0oooo00D000000?ooo`3oool0oooo0000000l0?ooo`050000003oool0oooo0?ooo`0000001P3o
ool01@000000oooo0?ooo`3oool000000480oooo00<000000?ooo`3oool03P3oool006<0oooo00D0
00000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo03/0oooo00D000000?ooo`3oool0
oooo000000050?ooo`H00000>`3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?oo
o`3oool0oooo0000000l0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?oo
o`3oool000000480oooo00<000000?ooo`3oool03P3oool006<0oooo00D000000?ooo`3oool0oooo
000000090?ooo`030000003oool0oooo03/0oooo00D000000?ooo`3oool0oooo000000050?ooo`05
0000003oool0oooo0?ooo`000000?03oool01@000000oooo0?ooo`3oool0000000H0oooo00D00000
0?ooo`3oool0oooo0000000l0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo
000000130?ooo`030000003oool0oooo00h0oooo001S0?ooo`050000003oool0oooo0?ooo`000000
2P3oool00`000000oooo0?ooo`0j0?ooo`050000003oool0oooo0?ooo`0000001P3oool010000000
oooo0?ooo`00000l0?ooo`050000003oool0oooo0?ooo`0000001P3oool200000080oooo00<00000
0?ooo`3oool0>P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0>0?ooo`00H`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<0
00000?ooo`3oool0>P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`000000
?03oool01@000000oooo0?ooo`3oool0000000H0oooo00@000000?ooo`0000000000?@3oool01@00
0000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`000000@`3oool00`000000oooo0?ooo`0>
0?ooo`00H`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0>P3oool0
1@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`000000?03oool01@000000oooo0?oo
o`3oool0000000L0oooo00<000000?ooo`3oool0?@3oool01@000000oooo0?ooo`3oool0000000H0
oooo00D000000?ooo`3oool0oooo000000120?ooo`030000003oool0oooo00h0oooo001S0?ooo`05
0000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000003`0oooo00D00000
0?ooo`3oool0oooo000000080?ooo`800000?03oool01@000000oooo0?ooo`3oool0000000P0oooo
00<000000?ooo`3oool0?03oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3o
ool0oooo000000110?ooo`800000403oool006@0oooo0`0000080?ooo`<00000?P3oool3000000X0
oooo00<000000?ooo`3oool0>`3oool3000000X0oooo0P00000m0?ooo`<00000203oool3000004<0
oooo00<000000?ooo`3oool03P3oool00?l0ooooZP3oool00?l0ooooZP3oool001l0oooo00<00000
0?ooo`3oool0o`3ooon80?ooo`007`3oool00`000000oooo0?ooo`3o0?ooohP0oooo000O0?ooo`03
0000003oool0oooo0?l0ooooR03oool001l0oooo00<000000?ooo`3oool0o`3ooon80?ooo`007`3o
ool00`000000oooo0?ooo`3o0?ooohP0oooo000F0?ooool00000SP0000060?ooo`007`3oool01000
0000oooo00000000000?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03@3oool0
01l0oooo0`000000103oool0000000000000000<0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool01`0000120?ooo`030000003oool0oooo
04P0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool01@3oool600000?l0
ooooO@3oool001l0oooo00<000000?ooo`3oool02@3oool600000?l0ooooN@3oool001l0oooo00<0
00000?ooo`3oool0303oool700000?l0ooooM@3oool001l0oooo0`00000?0?ooo`8000000P3oool4
00000?l0ooooL@3oool001l0oooo00<000000?ooo`3oool04@3oool2000000@0oooo1000003o0?oo
ofd0oooo000O0?ooo`030000003oool0oooo01<0oooo0P0000060?ooo`@00000o`3ooomY0?ooo`00
7`3oool00`000000oooo0?ooo`0E0?ooo`<000001`3oool300000?l0ooooIP3oool001l0oooo00<0
00000?ooo`3oool0603oool2000000P0oooo0`00003o0?ooof<0oooo000O0?ooo`030000003oool0
oooo01X0oooo0P0000090?ooo`@00000o`3ooomO0?ooo`007`3oool3000001`0oooo0`00000:0?oo
o`<00000o`3ooomL0?ooo`007`3oool00`000000oooo0?ooo`0O0?ooo`8000002`3oool300000?l0
ooooF@3oool001l0oooo00<000000?ooo`3oool08@3oool2000000`0oooo0`00003o0?oooeH0oooo
000O0?ooo`030000003oool0oooo02<0oooo0P00000=0?ooo`<00000o`3ooomC0?ooo`007`3oool0
0`000000oooo0?ooo`0U0?ooo`<000003@3oool300000?l0ooooD03oool001l0oooo00<000000?oo
o`3oool0:03oool2000000h0oooo0`00003o0?ooodd0oooo000O0?ooo`<00000:P3oool2000000l0
oooo0`00003o0?ooodX0oooo000O0?ooo`030000003oool0oooo02`0oooo0`00000?0?ooo`800000
o`3ooom80?ooo`007`3oool00`000000oooo0?ooo`0_0?ooo`8000003`3oool300000?l0ooooA@3o
ool001l0oooo00<000000?ooo`3oool0<@3oool3000000l0oooo0`00003o0?oood80oooo000O0?oo
o`030000003oool0oooo03@0oooo0P00000@0?ooo`800000o`3ooom00?ooo`007`3oool00`000000
oooo0?ooo`0f0?ooo`<000003`3oool300000?l0oooo?@3oool001l0oooo0`00000i0?ooo`800000
403oool300000?l0oooo>P3oool001l0oooo00<000000?ooo`3oool0>`3oool200000140oooo0P00
003o0?ooocP0oooo000O0?ooo`030000003oool0oooo03d0oooo0P00000A0?ooo`<00000o`3ooole
0?ooo`002@3oool3000000<0oooo00<000000?ooo`3oool00P3oool3000000P0oooo00<000000?oo
o`3oool0?`3oool200000180oooo0`00003o0?oooc80oooo000:0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`110?ooo`8000004`3oool200000?l0
oooo<03oool000X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo04<0oooo0P00000C0?ooo`<00000o`3oool]0?ooo`002P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00L0oooo100000140?ooo`800000503oool300000?l0oooo:P3o
ool000X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo04L0oooo0P00000E0?ooo`800000o`3ooolX0?ooo`002P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0B@3oool2000001D0oooo0P00003o0?oo
obH0oooo000:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`1;0?ooo`<00000503oool200000?l0oooo903oool000X0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04h0oooo0P00000D0?ooo`<00000
o`3ooolQ0?ooo`002@3oool2000000T0oooo0P0000090?ooo`030000003oool0oooo0500oooo0P00
000E0?ooo`800000o`3ooolO0?ooo`002P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00L0oooo0`00001B0?ooo`8000005@3oool200000?l0oooo7@3oool001l0oooo00<000000?oo
o`3oool0E03oool3000001@0oooo0P00003o0?oooa/0oooo000O0?ooo`030000003oool0oooo05L0
oooo0P00000D0?ooo`800000o`3ooolI0?ooo`007`3oool00`000000oooo0?ooo`1I0?ooo`800000
503oool200000?l0oooo5`3oool001l0oooo00<000000?ooo`3oool0F`3oool2000001@0oooo0P00
003o0?oooaD0oooo000O0?ooo`030000003oool0oooo05d0oooo0P00000D0?ooo`800000o`3ooolC
0?ooo`007`3oool3000005l0oooo0P00000D0?ooo`800000o`3ooolA0?ooo`007`3oool00`000000
oooo0?ooo`1Q0?ooo`800000503oool200000?l0oooo3`3oool001l0oooo00<000000?ooo`3oool0
H`3oool00`000000oooo0?ooo`0C0?ooo`800000o`3oool=0?ooo`007`3oool00`000000oooo0?oo
o`1T0?ooo`8000005@3oool200000?l0oooo2`3oool001l0oooo00<000000?ooo`3oool0IP3oool2
000001D0oooo0P00003o0?ooo`T0oooo000O0?ooo`030000003oool0oooo06P0oooo0P00000E0?oo
o`800000o`3oool70?ooo`007`3oool00`000000oooo0?ooo`1Z0?ooo`8000005@3oool200000?l0
oooo1@3oool001l0oooo0`00001/0?ooo`030000003oool0oooo01@0oooo0P00003o0?ooo`<0oooo
000O0?ooo`030000003oool0oooo06d0oooo0P00000F0?ooo`800000o`3oool10?ooo`007`3oool0
0`000000oooo0?ooo`1_0?ooo`8000005P3oool200000?h0oooo000O0?ooo`030000003oool0oooo
0740oooo0P00000F0?ooo`800000o03oool001l0oooo00<000000?ooo`3oool0L`3oool2000001H0
oooo00<000000?ooo`3oool0n@3oool001l0oooo00<000000?ooo`3oool0M@3oool2000001D0oooo
0P00003i0?ooo`007`3oool3000007L0oooo0P00000E0?ooo`800000m`3oool001l0oooo00<00000
0?ooo`3oool0N@3oool2000001D0oooo0P00003e0?ooo`002@3oool3000000<0oooo00@000000?oo
o`3oool0oooo1@0000070?ooo`030000003oool0oooo07/0oooo0P00000E0?ooo`030000003oool0
oooo0?80oooo000:0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000001`3oool0
0`000000oooo0?ooo`1m0?ooo`800000503oool200000?80oooo000:0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1o0?ooo`800000503oool20000
0?00oooo000:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`210?ooo`030000003oool0oooo01<0oooo0P00003^0?ooo`002P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00H0oooo100000210?ooo`8000005@3oool200000>`0oooo
000:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`240?ooo`8000005@3oool00`000000oooo0?ooo`3Y0?ooo`002P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0C
0?ooo`800000j@3oool000X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo08L0oooo0P00000E0?ooo`800000i`3oool000T0oooo0P0000080?ooo`05
0000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`290?ooo`8000005@3oool20000
0>D0oooo000:0?ooo`030000003oool0oooo00L0oooo0`0000080?ooo`030000003oool0oooo08/0
oooo00<000000?ooo`3oool0503oool200000><0oooo000O0?ooo`<00000S03oool2000001H0oooo
0P00003Q0?ooo`007`3oool00`000000oooo0?ooo`2>0?ooo`8000005P3oool200000=l0oooo000O
0?ooo`030000003oool0oooo0900oooo0P00000F0?ooo`800000g@3oool001l0oooo00<000000?oo
o`3oool0TP3oool00`000000oooo0?ooo`0E0?ooo`800000f`3oool001l0oooo00<000000?ooo`3o
ool0T`3oool2000001L0oooo0P00003I0?ooo`007`3oool00`000000oooo0?ooo`2E0?ooo`800000
5`3oool200000=L0oooo000O0?ooo`<00000U`3oool2000001L0oooo00<000000?ooo`3oool0e03o
ool001l0oooo00<000000?ooo`3oool0V@3oool2000001H0oooo0P00003D0?ooo`007`3oool00`00
0000oooo0?ooo`2K0?ooo`030000003oool0oooo01D0oooo0P00003B0?ooo`007`3oool00`000000
oooo0?ooo`2L0?ooo`8000005`3oool00`000000oooo0?ooo`3?0?ooo`007`3oool00`000000oooo
0?ooo`2N0?ooo`030000003oool0oooo01D0oooo0P00003?0?ooo`007`3oool00`000000oooo0?oo
o`2O0?ooo`8000005`3oool200000<d0oooo000O0?ooo`<00000X@3oool2000001L0oooo00<00000
0?ooo`3oool0bP3oool001l0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0E0?oo
o`800000bP3oool001l0oooo00<000000?ooo`3oool0Y03oool2000001L0oooo00<000000?ooo`3o
ool0a`3oool001l0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0E0?ooo`800000
a`3oool001l0oooo00<000000?ooo`3oool0Y`3oool2000001L0oooo0P0000350?ooo`007`3oool0
0`000000oooo0?ooo`2Y0?ooo`8000005`3oool00`000000oooo0?ooo`320?ooo`007`3oool30000
0:/0oooo00<000000?ooo`3oool05@3oool200000<80oooo000O0?ooo`030000003oool0oooo0:`0
oooo0P00000G0?ooo`030000003oool0oooo0;l0oooo000O0?ooo`030000003oool0oooo0:h0oooo
0P00000F0?ooo`800000_`3oool000T0oooo0`0000030?ooo`040000003oool0oooo0?ooo`@00000
203oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01D0oooo0P00002m0?ooo`002P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0/@3o
ool2000001L0oooo00<000000?ooo`3oool0^P3oool000X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0;<0oooo0P00000F0?ooo`800000^P3oool0
00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`@00000]03oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo0;L0oooo000:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2f0?ooo`8000005P3oool200000;L0
oooo000:0?ooo`030000003oool0oooo00P0oooo0P0000080?ooo`030000003oool0oooo0;P0oooo
0P00000F0?ooo`030000003oool0oooo0;@0oooo000:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01@0oooo0P00
002d0?ooo`002P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0^`3oool2000001H0oooo00<000000?ooo`3oool0/@3oool000T0oooo0P0000080?oo
o`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`2m0?ooo`030000003oool0
oooo01@0oooo0P00002a0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`<00000203oool00`00
0000oooo0?ooo`2n0?ooo`8000005P3oool00`000000oooo0?ooo`2^0?ooo`007`3oool300000<00
oooo0P00000E0?ooo`800000[P3oool001l0oooo00<000000?ooo`3oool0`P3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo0:/0oooo000O0?ooo`030000003oool0oooo0<<0oooo0P00
000E0?ooo`800000Z`3oool001l0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo0:P0oooo000O0?ooo`030000003oool0oooo0<H0oooo0P00000E0?oo
o`800000Z03oool001l0oooo00<000000?ooo`3oool0b03oool2000001D0oooo00<000000?ooo`3o
ool0Y@3oool001l0oooo0`00003:0?ooo`030000003oool0oooo01<0oooo0P00002U0?ooo`007`3o
ool00`000000oooo0?ooo`3;0?ooo`8000005@3oool200000:<0oooo000O0?ooo`030000003oool0
oooo0<d0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`2P0?ooo`007`3oool00`00
0000oooo0?ooo`3>0?ooo`8000005@3oool200000:00oooo000O0?ooo`030000003oool0oooo0=00
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`2M0?ooo`007`3oool00`000000oooo
0?ooo`3A0?ooo`8000005@3oool2000009d0oooo000O0?ooo`<00000d`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo09X0oooo000O0?ooo`030000003oool0oooo0=@0oooo0P00000E
0?ooo`800000VP3oool001l0oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo09L0oooo000O0?ooo`030000003oool0oooo0=L0oooo0P00000E0?ooo`03
0000003oool0oooo09H0oooo000O0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`3oool0
4`3oool2000009H0oooo000O0?ooo`030000003oool0oooo0=X0oooo0P00000E0?ooo`030000003o
ool0oooo09<0oooo000O0?ooo`<00000g03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo0980oooo000O0?ooo`030000003oool0oooo0=d0oooo0P00000D0?ooo`800000TP3oool000T0
oooo0`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`3O0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0S`3oool000X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0>00oooo
0P00000D0?ooo`030000003oool0oooo08h0oooo000:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`3R0?ooo`8000004`3oool2000008h0oooo000:
0?ooo`030000003oool0oooo00D0oooo1P0000070?ooo`030000003oool0oooo0>@0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`2;0?ooo`002P3oool00`000000oooo0?ooo`050?oo
o`050000003oool0oooo0?ooo`000000203oool400000>@0oooo0P00000C0?ooo`800000R`3oool0
00X0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000080?ooo`030000003oool0
oooo0>L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`280?ooo`002P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool0j03oool20000
01<0oooo00<000000?ooo`3oool0Q`3oool000X0oooo00<000000?ooo`3oool01`3oool00`000000
oooo000000080?ooo`030000003oool0oooo0>X0oooo00<000000?ooo`3oool04@3oool2000008L0
oooo00090?ooo`8000002P3oool2000000P0oooo00<000000?ooo`3oool0j`3oool2000001<0oooo
00<000000?ooo`3oool0Q03oool000X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0>d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`230?ooo`007`3oool300000>h0oooo00<000000?ooo`3oool04@3oool2000008<0oooo000O0?oo
o`030000003oool0oooo0>l0oooo0P00000C0?ooo`030000003oool0oooo0800oooo000O0?ooo`03
0000003oool0oooo0?40oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1o0?ooo`00
7`3oool00`000000oooo0?ooo`3b0?ooo`030000003oool0oooo0140oooo0P00001o0?ooo`007`3o
ool00`000000oooo0?ooo`3c0?ooo`8000004`3oool00`000000oooo0?ooo`1l0?ooo`007`3oool0
0`000000oooo0?ooo`3e0?ooo`030000003oool0oooo0140oooo0P00001l0?ooo`007`3oool30000
0?H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1i0?ooo`007`3oool00`000000
oooo0?ooo`3g0?ooo`8000004`3oool00`000000oooo0?ooo`1h0?ooo`007`3oool00`000000oooo
0?ooo`3i0?ooo`030000003oool0oooo0140oooo0P00001h0?ooo`007`3oool00`000000oooo0?oo
o`3j0?ooo`8000004`3oool00`000000oooo0?ooo`1e0?ooo`007`3oool00`000000oooo0?ooo`3l
0?ooo`030000003oool0oooo0140oooo0P00001e0?ooo`007`3oool00`000000oooo0?ooo`3m0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0LP3oool001l0oooo0`00003n0?ooo`80
00004`3oool200000780oooo000O0?ooo`030000003oool0oooo0?l0oooo0@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo06l0oooo000O0?ooo`030000003oool0oooo0?l0oooo0P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo06h0oooo000O0?ooo`030000003oool0
oooo0?l0oooo0`3oool2000001<0oooo0P00001^0?ooo`007`3oool00`000000oooo0?ooo`3o0?oo
o`D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1[0?ooo`007`3oool00`000000
oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1Z0?ooo`00
7`3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0P00000C0?ooo`800000JP3oool001l0oooo0`00
003o0?ooo`T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1W0?ooo`007`3oool0
0`000000oooo0?ooo`3o0?ooo`X0oooo0P00000C0?ooo`030000003oool0oooo06H0oooo00090?oo
o`<000000`3oool010000000oooo0?ooo`3oool3000000T0oooo00<000000?ooo`3oool0o`3oool<
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0I@3oool000X0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo3@3oool00`00
0000oooo0?ooo`0A0?ooo`800000I@3oool000X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo3P3oool2000001<0oooo00<000000?ooo`3o
ool0HP3oool000X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0640oooo
000:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool400000?l0oooo403o
ool200000180oooo00<000000?ooo`3oool0H03oool000X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo4`3oool00`000000oooo0?ooo`0@
0?ooo`800000H03oool000X0oooo00<000000?ooo`3oool01P3oool3000000T0oooo00<000000?oo
o`3oool0o`3ooolD0?ooo`8000004P3oool00`000000oooo0?ooo`1M0?ooo`002P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0G03oool000T0oooo0P0000090?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooolG0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0F`3oool000X0oooo00<000000?ooo`3oool01`3oool4000000L0oooo00<0
00000?ooo`3oool0o`3ooolH0?ooo`8000004@3oool2000005/0oooo000O0?ooo`<00000o`3ooolJ
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0F03oool001l0oooo00<000000?oo
o`3oool0o`3ooolK0?ooo`8000004@3oool00`000000oooo0?ooo`1G0?ooo`007`3oool00`000000
oooo0?ooo`3o0?oooad0oooo00<000000?ooo`3oool03`3oool2000005L0oooo000O0?ooo`030000
003oool0oooo0?l0oooo7P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo05@0oooo
000O0?ooo`030000003oool0oooo0?l0oooo7`3oool200000140oooo00<000000?ooo`3oool0D`3o
ool001l0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`030000003oool0oooo00l0oooo0P00001C
0?ooo`007`3oool300000?l0oooo8P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0500oooo000O0?ooo`030000003oool0oooo0?l0oooo8`3oool200000140oooo00<000000?ooo`3o
ool0C`3oool001l0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`030000003oool0oooo00l0oooo
0P00001?0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooobH0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`1<0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooobL0oooo0P00000A
0?ooo`030000003oool0oooo04/0oooo000O0?ooo`030000003oool0oooo0?l0oooo:@3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo04X0oooo000O0?ooo`<00000o`3ooolZ0?ooo`03
0000003oool0oooo00l0oooo0P00001:0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooob/0oooo
0P00000A0?ooo`030000003oool0oooo04L0oooo000O0?ooo`030000003oool0oooo0?l0oooo;@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo04H0oooo000O0?ooo`030000003oool0
oooo0?l0oooo;P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo04D0oooo000O0?oo
o`030000003oool0oooo0?l0oooo;`3oool200000100oooo0P0000150?ooo`007`3oool00`000000
oooo0?ooo`3o0?oooc40oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`120?ooo`00
7`3oool300000?l0oooo<P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0440oooo
000O0?ooo`030000003oool0oooo0?l0oooo<`3oool200000100oooo00<000000?ooo`3oool0@03o
ool001l0oooo00<000000?ooo`3oool0o`3ooole0?ooo`030000003oool0oooo00h0oooo0P000010
0?ooo`002@3oool3000000<0oooo00<000000?ooo`3oool00P3oool3000000P0oooo00<000000?oo
o`3oool0o`3ooolf0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0?@3oool000X0
oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?oo
o`3oool0o`3ooolg0?ooo`800000403oool00`000000oooo0?ooo`0l0?ooo`002P3oool00`000000
oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`3o0?oo
ocT0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0k0?ooo`002P3oool00`000000
oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000001`3oool400000?l0oooo>@3oool00`00
0000oooo0?ooo`0>0?ooo`800000>`3oool000X0oooo00<000000?ooo`3oool01P3oool01@000000
oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0o`3ooolk0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0>03oool000X0oooo00<000000?ooo`3oool01P3oool200000080
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oooc`0oooo0P00000@0?ooo`03
0000003oool0oooo03L0oooo000:0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`000000
0000203oool00`000000oooo0?ooo`3o0?oooch0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0f0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0o`3ooolo0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
=@3oool000T0oooo0P00000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3o
oom00?ooo`030000003oool0oooo00h0oooo0P00000e0?ooo`002P3oool00`000000oooo0?ooo`09
0?ooo`8000001`3oool00`000000oooo0?ooo`3o0?oood40oooo0P00000@0?ooo`030000003oool0
oooo0380oooo000O0?ooo`<00000o`3ooom30?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0<@3oool001l0oooo00<000000?ooo`3oool0o`3ooom40?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0<03oool001l0oooo00<000000?ooo`3oool0o`3ooom50?ooo`030000
003oool0oooo00h0oooo0P00000`0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooodH0oooo0P00
000@0?ooo`030000003oool0oooo02d0oooo000O0?ooo`030000003oool0oooo0?l0ooooB03oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02`0oooo000O0?ooo`030000003oool0oooo
0?l0ooooB@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02/0oooo000O0?ooo`<0
0000o`3ooom:0?ooo`030000003oool0oooo00h0oooo0P00000[0?ooo`007`3oool00`000000oooo
0?ooo`3o0?oood/0oooo0P00000@0?ooo`030000003oool0oooo02P0oooo000O0?ooo`030000003o
ool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02L0oooo000O
0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo02H0oooo000O0?ooo`030000003oool0oooo0?l0ooooC`3oool2000000l0oooo00<000000?oo
o`3oool09@3oool001l0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`030000003oool0oooo00d0
oooo0P00000U0?ooo`007`3oool300000?l0ooooDP3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0280oooo000O0?ooo`030000003oool0oooo0?l0ooooD`3oool2000000l0oooo00<0
00000?ooo`3oool08@3oool001l0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0803oool001l0oooo00<000000?ooo`3oool0o`3ooomF0?oo
o`030000003oool0oooo00d0oooo0P00000P0?ooo`007`3oool00`000000oooo0?ooo`3o0?oooeL0
oooo0P00000?0?ooo`030000003oool0oooo01d0oooo000O0?ooo`030000003oool0oooo0?l0oooo
F@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01`0oooo000O0?ooo`<00000o`3o
oomJ0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool06`3oool001l0oooo00<00000
0?ooo`3oool0o`3ooomK0?ooo`8000003P3oool00`000000oooo0?ooo`0J0?ooo`002@3oool30000
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0?l0ooooG@3oool00`000000oooo0?ooo`0<0?ooo`8000006P3oool000X0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo01L0oooo000:0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oooel0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0F0?ooo`002P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0o`3ooomP0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool05@3oool000X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`07
0?ooo`@00000o`3ooomP0?ooo`8000003P3oool00`000000oooo0?ooo`0D0?ooo`002P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooomS0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool04`3oool000X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0ooooI03oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0180oooo000:0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooofD0oooo00<000000?ooo`3oool0
303oool200000180oooo00090?ooo`8000001`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0o`3ooomV0?ooo`8000003P3oool00`000000oooo0?oo
o`0?0?ooo`002P3oool00`000000oooo0?ooo`060?ooo`D000001`3oool00`000000oooo0?ooo`3o
0?ooofP0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0>0?ooo`007`3oool30000
0?l0ooooJ@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo000O0?ooo`03
0000003oool0oooo0?l0ooooJP3oool00`000000oooo0?ooo`0K0?ooo`007`3oool00`000000oooo
0?ooo`3o0?ooof/0oooo00<000000?ooo`3oool06P3oool001l0oooo00<000000?ooo`3oool0o`3o
oom/0?ooo`8000006P3oool001l0oooo00<000000?ooo`3oool0o`3ooom^0?ooo`030000003oool0
oooo01L0oooo000O0?ooo`030000003oool0oooo0?l0ooooK`3oool00`000000oooo0?ooo`0F0?oo
o`007`3oool300000?l0ooooL03oool00`000000oooo0?ooo`0E0?ooo`007`3oool00`000000oooo
0?ooo`3o0?ooog40oooo00<000000?ooo`3oool0503oool001l0oooo00<000000?ooo`3oool0o`3o
oomb0?ooo`030000003oool0oooo01<0oooo000O0?ooo`030000003oool0oooo0?l0ooooL`3oool0
0`000000oooo0?ooo`0B0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooog@0oooo0P00000B0?oo
o`007`3oool00`000000oooo0?ooo`3o0?ooogH0oooo00<000000?ooo`3oool03`3oool001l0oooo
0`00003o0?ooogL0oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0o`3o
oomh0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0?l0ooooR03oool0
01l0oooo00<000000?ooo`3oool0o`3ooon80?ooo`007`3oool00`000000oooo0?ooo`3o0?ooohP0
oooo000O0?ooo`030000003oool0oooo0?l0ooooR03oool001l0oooo00<000000?ooo`3oool0o`3o
oon80?ooo`00\
\>"],
  ImageRangeCache->{{{0, 424.188}, {261.813, 0}} -> {-0.0846873, 0.925749, \
0.00265003, 0.00326168}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.476191 3.40679 2.7264 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.2619 -0.0125 -10.7813 -17.8125 ]
[.2619 -0.0125 10.7813 0 ]
[.5 -0.0125 -5.53125 -17.8125 ]
[.5 -0.0125 5.53125 0 ]
[.7381 -0.0125 -10.7813 -17.8125 ]
[.7381 -0.0125 10.7813 0 ]
[.97619 -0.0125 -5.53125 -17.8125 ]
[.97619 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.125 -35.625 ]
[.5 -0.0125 5.125 -17.8125 ]
[-0.0125 .13511 -31.25 -8.90625 ]
[-0.0125 .13511 0 8.90625 ]
[-0.0125 .27143 -38.3125 -8.90625 ]
[-0.0125 .27143 0 8.90625 ]
[-0.0125 .40775 -31.25 -8.90625 ]
[-0.0125 .40775 0 8.90625 ]
[-0.0125 .54407 -38.3125 -8.90625 ]
[-0.0125 .54407 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -56.125 -14.7188 ]
[-0.01875 .30902 -38.3125 14.7188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.125 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .13511 m
.00625 .13511 L
s
gsave
-0.0125 .13511 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
0 .27143 m
.00625 .27143 L
s
gsave
-0.0125 .27143 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
1.000 setlinewidth
grestore
0 .40775 m
.00625 .40775 L
s
gsave
-0.0125 .40775 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
1.000 setlinewidth
grestore
0 .54407 m
.00625 .54407 L
s
gsave
-0.0125 .54407 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .02605 m
.00375 .02605 L
s
0 .05331 m
.00375 .05331 L
s
0 .08058 m
.00375 .08058 L
s
0 .10784 m
.00375 .10784 L
s
0 .16237 m
.00375 .16237 L
s
0 .18963 m
.00375 .18963 L
s
0 .2169 m
.00375 .2169 L
s
0 .24416 m
.00375 .24416 L
s
0 .29869 m
.00375 .29869 L
s
0 .32595 m
.00375 .32595 L
s
0 .35322 m
.00375 .35322 L
s
0 .38048 m
.00375 .38048 L
s
0 .43501 m
.00375 .43501 L
s
0 .46227 m
.00375 .46227 L
s
0 .48954 m
.00375 .48954 L
s
0 .5168 m
.00375 .5168 L
s
0 .57133 m
.00375 .57133 L
s
0 .59859 m
.00375 .59859 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -122.938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.7188 12.9063 translate
90 rotate
-75.7188 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.063 17.500 moveto
(H) show
77.625 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.875 17.500 moveto
(L) show
88.438 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .13511 m
1 .13511 L
s
.99375 .27143 m
1 .27143 L
s
.99375 .40775 m
1 .40775 L
s
.99375 .54407 m
1 .54407 L
s
.125 Mabswid
.99625 .02605 m
1 .02605 L
s
.99625 .05331 m
1 .05331 L
s
.99625 .08058 m
1 .08058 L
s
.99625 .10784 m
1 .10784 L
s
.99625 .16237 m
1 .16237 L
s
.99625 .18963 m
1 .18963 L
s
.99625 .2169 m
1 .2169 L
s
.99625 .24416 m
1 .24416 L
s
.99625 .29869 m
1 .29869 L
s
.99625 .32595 m
1 .32595 L
s
.99625 .35322 m
1 .35322 L
s
.99625 .38048 m
1 .38048 L
s
.99625 .43501 m
1 .43501 L
s
.99625 .46227 m
1 .46227 L
s
.99625 .48954 m
1 .48954 L
s
.99625 .5168 m
1 .5168 L
s
.99625 .57133 m
1 .57133 L
s
.99625 .59859 m
1 .59859 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.06244 .04603 L
.10458 .08864 L
.14415 .13297 L
.18221 .17684 L
.22272 .22276 L
.26171 .26488 L
.30316 .30655 L
.34309 .34327 L
.3815 .37535 L
.42237 .40607 L
.46172 .43252 L
.49955 .4553 L
.53984 .47695 L
.57861 .49552 L
.61984 .51308 L
.65954 .52812 L
.69774 .54104 L
.73838 .55334 L
.77751 .56392 L
.81909 .57398 L
.85916 .58266 L
.89771 .59017 L
.93871 .59737 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{425.188, 262.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006Y00011R000`400?l00000o`00003oo`3ooonZ
0?ooo`00o`3ooonZ0?ooo`00o`3ooonZ0?ooo`00o`3ooonZ0?ooo`00o`3ooonZ0?ooo`00l03oool6
00000;<0oooo003a0?ooo`050000003oool0oooo0?ooo`000000/`3oool00?80oooo00<000000?oo
o`3oool0]03oool00?80oooo00<000000?ooo`3oool0]03oool00?<0oooo00<000000?ooo`3oool0
/`3oool00?00oooo00D000000?ooo`3oool0oooo0000002d0?ooo`00l03oool600000;<0oooo003o
0?ooojX0oooo003o0?ooojX0oooo003o0?ooojX0oooo003o0?ooojX0oooo003o0?ooojX0oooo003o
0?ooojX0oooo003o0?ooojX0oooo003o0?ooojX0oooo003o0?ooojX0oooo003o0?ooojX0oooo003o
0?ooojX0oooo00170?ooo`<00000C@3oool3000000<0oooo00@000000?ooo`3oool0oooo0`00001=
0?ooo`<00000CP3oool3000000<0oooo00@000000?ooo`3oool0oooo0`00001<0?ooo`D000002@3o
ool004H0oooo00D000000?ooo`3oool0oooo0000001;0?ooo`050000003oool0oooo0?ooo`000000
2@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`1:0?ooo`040000003oool0oooo000000T0oooo00160?ooo`050000
003oool0oooo0?ooo`000000B`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`090?ooo`00AP3oool01@000000oooo0?ooo`3oool00000
04/0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo04X0oooo00<00000
0?ooo`3oool0CP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool0203oool004H0oooo00D000000?ooo`3oool0oooo0000001;0?ooo`050000003oool0
oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04h0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00P0oooo0016
0?ooo`050000003oool0oooo0?ooo`000000B`3oool01@000000oooo0?ooo`3oool0000000T0oooo
00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`070?ooo`00AP3oool01@000000oooo0?oo
o`3oool0000004/0oooo00D000000?ooo`3oool0oooo000000060?ooo`<00000CP3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo00H0oooo0`00001@0?ooo`030000003oool0oooo00L0
oooo00160?ooo`050000003oool0oooo0?ooo`000000B`3oool01@000000oooo0?ooo`3oool00000
00H0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`00AP3oool01@000000
oooo0?ooo`3oool0000004/0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0
oooo04`0oooo0P00001?0?ooo`8000002@3oool00`000000oooo0?ooo`1;0?ooo`050000003oool0
oooo0?ooo`0000002@3oool004L0oooo0`00001=0?ooo`<00000203oool4000004`0oooo00<00000
0?ooo`3oool0CP3oool00`000000oooo0?ooo`070?ooo`@00000B`3oool3000000X0oooo003o0?oo
ojX0oooo003o0?ooojX0oooo003o0?ooojX0oooo003o0?ooojX0oooo003o0?ooojX0oooo003o0?oo
ojX0oooo003o0?ooojX0oooo00100?ooool00000J00000020?ooo`00@03oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`050?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo05<0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0
oooo05<0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00400oooo00<000000?oo
o`3oool0o`3ooomT0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`3o0?ooof@0
oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
o`3ooomL0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0?l0ooooF`3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool01`3oool2
00000?l0ooooF`3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`3o0?oooeP0oooo0@0000010?ooo`40oooo00100?ooo`8000002`3oool00`000000
oooo0?ooo`3o0?oooeH0oooo0P0000020?ooo`00@03oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo0?l0ooooEP3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0303o
ool200000?l0ooooEP3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`3o0?oooe<0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0o`3ooomB0?ooo`4000000@3oool10?ooo`00@03oool00`000000
oooo0?ooo`0@0?ooo`800000o`3ooomB0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo0?l0ooooC`3oool100000040oooo0@3oool00400oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`40oooo0010
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`4000000@3oool1
0?ooo`00@03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0ooooC03oool10000
0040oooo0@3oool00400oooo0P00000G0?ooo`030000003oool0oooo0?l0ooooBP3oool200000080
oooo00100?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0o`3ooom:0?ooo`400000
0@3oool10?ooo`00@03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0?l0ooooB@3o
ool100000040oooo0@3oool00400oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3o
0?ooodP0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool0o`3ooom70?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo0?l0ooooA`3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`3o0?ooodH0oooo0@0000010?ooo`40oooo00100?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0o`3ooom50?ooo`4000000@3oool10?ooo`00@03oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0?l0ooooA03oool100000040oooo0@3oool0
0400oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3o0?oood<0oooo0@0000010?oo
o`40oooo00100?ooo`800000803oool00`000000oooo0?ooo`3o0?oood40oooo0P0000020?ooo`00
@03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0?l0oooo@@3oool100000040oooo
0@3oool00400oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3o0?oood00oooo0@00
00010?ooo`40oooo00100?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0o`3ooolo
0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
0?l0oooo?P3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`3o0?ooocd0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool0o`3oooll0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo0?l0oooo>`3oool100000040oooo0@3oool00400oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`3o0?ooocX0oooo0@0000010?ooo`40oooo00100?oo
o`800000:@3oool00`000000oooo0?ooo`3o0?ooocP0oooo0P0000020?ooo`00@03oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0oooo>03oool100000040oooo0@3oool00400oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?ooocP0oooo0@0000010?ooo`40oooo
00100?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0o`3ooolg0?ooo`4000000@3o
ool10?ooo`00@03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0oooo=P3oool1
00000040oooo0@3oool00400oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`3o0?oo
ocD0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0o`3ooold0?ooo`4000000@3oool10?ooo`00:P3oool3000000<0oooo00@000000?ooo`3oool0
oooo1@0000070?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0o`3ooolc0?ooo`40
00000@3oool10?ooo`00:`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000L0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`3o0?oooc80oooo0@0000010?ooo`40
oooo000[0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo0?l0oooo<@3oool100000040oooo0@3oool001l0oooo1`00
00050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool300000340oooo00<0
00000?ooo`3oool0o`3oool^0?ooo`<000000P3oool002/0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0o`3oool_
0?ooo`4000000@3oool10?ooo`00:`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`3o0?ooobh0oooo0@0000010?oo
o`40oooo000[0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0c0?ooo`030000003oool0oooo0?l0oooo;P3oool100000040oooo0@3oool002/0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool0o`3oool]0?ooo`4000000@3oool10?ooo`00:P3oool2000000P0oooo00D0
00000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0
o`3oool/0?ooo`4000000@3oool10?ooo`00:`3oool00`000000oooo0?ooo`070?ooo`<00000203o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0?l0oooo:`3oool100000040oooo0@3o
ool00400oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`3o0?ooobX0oooo0@000001
0?ooo`40oooo00100?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0o`3ooolY0?oo
o`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0?l0
oooo:03oool100000040oooo0@3oool00400oooo0P00000k0?ooo`030000003oool0oooo0?l0oooo
9P3oool200000080oooo00100?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0o`3o
oolW0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo0?l0oooo9P3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0?03oool00`00
0000oooo0?ooo`3o0?ooobD0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool0o`3ooolT0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo0?l0oooo8`3oool100000040oooo0@3oool00400oooo00<0
00000?ooo`3oool0?`3oool00`000000oooo0?ooo`3o0?ooob80oooo0@0000010?ooo`40oooo0010
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`4000000@3oool1
0?ooo`00@03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0?l0oooo8@3oool10000
0040oooo0@3oool00400oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3o0?ooob00
oooo0@0000010?ooo`40oooo00100?ooo`800000@`3oool00`000000oooo0?ooo`3o0?oooah0oooo
0P0000020?ooo`00@03oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0?l0oooo7P3o
ool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`3o
0?oooad0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool0o`3ooolL0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo0?l0oooo703oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`3o0?oooa/0oooo0@0000010?ooo`40oooo00100?ooo`030000003o
ool0oooo04L0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`4000000@3oool10?ooo`00@03oool0
0`000000oooo0?ooo`180?ooo`030000003oool0oooo0?l0oooo6@3oool100000040oooo0@3oool0
0400oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3o0?oooaP0oooo0@0000010?oo
o`40oooo00100?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0o`3ooolG0?ooo`40
00000@3oool10?ooo`00@03oool2000004/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`800000
0P3oool00400oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?oooaH0oooo0@00
00010?ooo`40oooo00100?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0o`3ooolE
0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
0?l0oooo503oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0CP3oool00`000000
oooo0?ooo`3o0?oooa<0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`3oool0o`3ooolB0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?oo
o`1@0?ooo`030000003oool0oooo0?l0oooo4@3oool100000040oooo0@3oool00400oooo00<00000
0?ooo`3oool0D@3oool00`000000oooo0?ooo`3o0?oooa00oooo0@0000010?ooo`40oooo00100?oo
o`030000003oool0oooo0580oooo00<000000?ooo`3oool0o`3oool?0?ooo`4000000@3oool10?oo
o`00@03oool2000005@0oooo00<000000?ooo`3oool0o`3oool=0?ooo`8000000P3oool00400oooo
00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`3o0?ooo`h0oooo0@0000010?ooo`40oooo
00100?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0o`3oool=0?ooo`4000000@3o
ool10?ooo`00@03oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0?l0oooo303oool1
00000040oooo0@3oool00400oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`3o0?oo
o`/0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3o
ool0o`3oool:0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo0?l0oooo2@3oool100000040oooo0@3oool002<0oooo0`0000030?ooo`030000003o
ool0oooo0080oooo0`0000030?ooo`<000002@3oool00`000000oooo0?ooo`1I0?ooo`030000003o
ool0oooo0?l0oooo203oool100000040oooo0@3oool002@0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0FP3oool0
0`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`40oooo000T0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
05/0oooo00<000000?ooo`3oool0o`3oool60?ooo`4000000@3oool10?ooo`00603oool7000000D0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0
oooo0`00001L0?ooo`030000003oool0oooo0?l0oooo0`3oool300000080oooo000T0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo05d0oooo00<000000?ooo`3oool0o`3oool40?ooo`4000000@3oool10?ooo`001`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0o`3o
ool30?ooo`4000000@3oool10?ooo`001`3oool3000001X0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`<000002@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0
oooo0?l0oooo0P3oool100000040oooo0@3oool000L0oooo00<000000?ooo`3oool00`00000G0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0600oooo00<000000?ooo`3oool0o`3oool10?ooo`4000000@3oool10?oo
o`00303oool2000001D0oooo0P0000090?ooo`8000001@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0640oooo00<000000?ooo`3oool0o`3oool100000040oooo0@3oool000L0oooo
00<000000?ooo`3oool00P00000H0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0`3oool4000000L0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`3n0?ooo`400000
0@3oool10?ooo`001`3oool3000003H0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?oo
o`3m0?ooo`4000000@3oool10?ooo`001`3oool00`000000oooo0?ooo`03000003<0oooo00<00000
0?ooo`3oool0I03oool00`000000oooo0?ooo`3l0?ooo`4000000@3oool10?ooo`00303oool20000
0380oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3k0?ooo`4000000@3oool10?oo
o`001`3oool00`000000oooo0?ooo`02000003@0oooo0P00001W0?ooo`030000003oool0oooo0?T0
oooo0P0000020?ooo`001`3oool3000003H0oooo00<000000?ooo`3oool0I`3oool00`000000oooo
0?ooo`3i0?ooo`4000000@3oool10?ooo`001`3oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo06P0oooo00<000000?ooo`3oool0n03oool100000040oooo0@3oool000H0oooo2@00000a
0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0m`3oool100000040oooo0@3oool0
00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
06X0oooo00<000000?ooo`3oool0mP3oool100000040oooo0@3oool000@0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3o
ool0m@3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0K03oool200000?D0oooo
0@0000010?ooo`40oooo00070?ooo`800000103oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo06h0oooo00<000000?ooo`3oool0lP3oool100000040oooo0@3oool000L0oooo00<00000
0?ooo`3oool00P3oool200000380oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`3a
0?ooo`4000000@3oool10?ooo`001`3oool00`000000oooo0?ooo`02000000030?ooo`000000oooo
0340oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`3`0?ooo`4000000@3oool10?oo
o`001`3oool00`000000oooo000000030?ooo`030000003oool0oooo0300oooo0P00001b0?ooo`03
0000003oool0oooo0>h0oooo0P0000020?ooo`001`3oool2000000@0oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0>h0oooo0@0000010?ooo`40oooo
00070?ooo`030000003oool0oooo0080oooo0P00000b0?ooo`030000003oool0oooo07<0oooo00<0
00000?ooo`3oool0k@3oool100000040oooo0@3oool000@0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo07@0oooo0P00003]0?ooo`4000000@3oool1
0?ooo`001@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool0MP3oool00`000000oooo0?ooo`3Z0?ooo`4000000@3oool10?ooo`001P3oool900000340
oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`3Y0?ooo`4000000@3oool10?ooo`00
@03oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0>P0oooo0@0000010?ooo`40oooo
00100?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0i`3oool100000040oooo0@3o
ool00400oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`3V0?ooo`4000000@3oool1
0?ooo`00@03oool00`000000oooo0?ooo`1k0?ooo`800000iP3oool100000040oooo0@3oool00400
oooo0P00001n0?ooo`030000003oool0oooo0>80oooo0P0000020?ooo`00@03oool00`000000oooo
0?ooo`1n0?ooo`030000003oool0oooo0>80oooo0@0000010?ooo`40oooo00100?ooo`030000003o
ool0oooo07l0oooo00<000000?ooo`3oool0h@3oool100000040oooo0@3oool00400oooo00<00000
0?ooo`3oool0P03oool00`000000oooo0?ooo`3P0?ooo`4000000@3oool10?ooo`00@03oool00`00
0000oooo0?ooo`210?ooo`800000h03oool100000040oooo0@3oool00400oooo00<000000?ooo`3o
ool0P`3oool00`000000oooo0?ooo`3M0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo
0?ooo`240?ooo`030000003oool0oooo0=`0oooo0@0000010?ooo`40oooo00100?ooo`030000003o
ool0oooo08D0oooo00<000000?ooo`3oool0f`3oool100000040oooo0@3oool00400oooo00<00000
0?ooo`3oool0QP3oool200000=/0oooo0@0000010?ooo`40oooo00100?ooo`800000R@3oool00`00
0000oooo0?ooo`3G0?ooo`8000000P3oool00400oooo00<000000?ooo`3oool0R@3oool00`000000
oooo0?ooo`3G0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`2:0?ooo`800000
e`3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0S03oool00`000000oooo0?oo
o`3D0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo0=<0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo08h0oooo0P00003C0?oo
o`4000000@3oool10?ooo`00:P3oool3000000<0oooo00<000000?ooo`3oool00P3oool3000000P0
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`3@0?ooo`4000000@3oool10?ooo`00
:`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
T@3oool00`000000oooo0?ooo`3?0?ooo`4000000@3oool10?ooo`00:`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0TP3oool200000<l0oooo0@00
00010?ooo`40oooo000O0?ooo`L000001@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`3<0?ooo`4000000@3oool1
0?ooo`00:`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo0`00002E0?oo
o`800000bP3oool300000080oooo000[0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo0<T0oooo0@0000010?ooo`40
oooo000[0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`2H0?ooo`030000003oool0oooo0<P0oooo0@0000010?ooo`40oooo000[0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2I0?ooo`800000b03o
ool100000040oooo0@3oool002X0oooo0P0000090?ooo`8000002@3oool00`000000oooo0?ooo`2K
0?ooo`030000003oool0oooo0<D0oooo0@0000010?ooo`40oooo000[0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2L0?ooo`800000a@3oool10000
0040oooo0@3oool00400oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`320?ooo`40
00000@3oool10?ooo`00@03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo0<40oooo
0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo0:00oooo0P0000310?ooo`4000000@3o
ool10?ooo`00@03oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo0;h0oooo0@000001
0?ooo`40oooo00100?ooo`800000Y03oool200000;d0oooo0P0000020?ooo`00@03oool00`000000
oooo0?ooo`2U0?ooo`800000_03oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0
Y`3oool200000;X0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo0:T0oooo00<0
00000?ooo`3oool0]`3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0ZP3oool2
00000;L0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo0:`0oooo0P00002e0?oo
o`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`2^0?ooo`800000/`3oool100000040
oooo0@3oool00400oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`2`0?ooo`400000
0@3oool10?ooo`00@03oool00`000000oooo0?ooo`2a0?ooo`800000/03oool100000040oooo0@3o
ool00400oooo00<000000?ooo`3oool0/`3oool200000:h0oooo0@0000010?ooo`40oooo00100?oo
o`800000]P3oool200000:/0oooo0P0000020?ooo`00@03oool00`000000oooo0?ooo`2g0?ooo`03
0000003oool0oooo0:T0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo0;P0oooo
0P00002Y0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`2j0?ooo`800000Y`3o
ool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0_03oool200000:D0oooo0@000001
0?ooo`40oooo00100?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0XP3oool10000
0040oooo0@3oool00400oooo00<000000?ooo`3oool0_`3oool200000:80oooo0@0000010?ooo`40
oooo00100?ooo`030000003oool0oooo0<40oooo0P00002P0?ooo`4000000@3oool10?ooo`00@03o
ool00`000000oooo0?ooo`330?ooo`800000WP3oool100000040oooo0@3oool00400oooo0P000036
0?ooo`800000V`3oool200000080oooo00100?ooo`030000003oool0oooo0<L0oooo0P00002J0?oo
o`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`390?ooo`800000V03oool100000040
oooo0@3oool00400oooo00<000000?ooo`3oool0b`3oool3000009D0oooo0@0000010?ooo`40oooo
00100?ooo`030000003oool0oooo0<h0oooo0P00002C0?ooo`4000000@3oool10?ooo`00@03oool0
0`000000oooo0?ooo`3@0?ooo`<00000T03oool100000040oooo0@3oool00400oooo00<000000?oo
o`3oool0d`3oool2000008h0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo0=D0
oooo0`00002;0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`3H0?ooo`800000
R@3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0fP3oool3000008H0oooo0@00
00010?ooo`40oooo00100?ooo`800000gP3oool300000880oooo0P0000020?ooo`00@03oool00`00
0000oooo0?ooo`3P0?ooo`800000P@3oool100000040oooo0@3oool00400oooo00<000000?ooo`3o
ool0hP3oool3000007h0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo0>D0oooo
0`00001k0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`3X0?ooo`<00000N03o
ool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0j`3oool3000007D0oooo0@000001
0?ooo`40oooo000S0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`<000000`3oool30000
00T0oooo00<000000?ooo`3oool0kP3oool2000007<0oooo0@0000010?ooo`40oooo000T0?ooo`03
0000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0l03oool300000700oooo0@0000010?ooo`40oooo000T0?ooo`03
0000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0l`3oool3000006d0oooo0@0000010?ooo`40oooo000H0?ooo`L0
00001@3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0?H0oooo0`00001Z0?ooo`4000000@3oool10?oo
o`00903oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`00
0000oooo0?ooo`050?ooo`<00000n@3oool4000006@0oooo0`0000020?ooo`00903oool00`000000
oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0?d0oooo0`00001S0?ooo`4000000@3oool10?ooo`00903oool00`000000
oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000P3oool3000000T0oooo00<000000?oo
o`3oool0o`3oool10?ooo`@00000G`3oool100000040oooo0@3oool002@0oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`3o0?ooo`D0oooo0`00001L0?ooo`4000000@3oool10?ooo`008`3oool2000000P0
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0o`3oool80?ooo`@00000F03oool100000040oooo0@3oool002@0oooo00<000000?ooo`3o
ool01`3oool3000000@0oooo100000070?ooo`030000003oool0oooo0?l0oooo303oool4000005@0
oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo0?l0oooo403oool400000500oooo
0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo0?l0oooo503oool3000004d0oooo0@00
00010?ooo`40oooo00100?ooo`030000003oool0oooo0?l0oooo5`3oool4000004T0oooo0@000001
0?ooo`40oooo00100?ooo`030000003oool0oooo0?l0oooo6`3oool3000004H0oooo0@0000010?oo
o`40oooo00100?ooo`800000o`3ooolO0?ooo`@00000@@3oool200000080oooo00100?ooo`030000
003oool0oooo0?l0oooo8P3oool4000003h0oooo0@0000010?ooo`40oooo00100?ooo`030000003o
ool0oooo0?l0oooo9P3oool5000003T0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0
oooo0?l0oooo:`3oool5000003@0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo
0?l0oooo<03oool5000002l0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo0?l0
oooo=@3oool4000002/0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo0?l0oooo
>@3oool5000002H0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo0?l0oooo?P3o
ool600000200oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo0?l0ooooA03oool7
000001T0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo0?l0ooooB`3oool70000
0180oooo0@0000010?ooo`40oooo00100?ooo`800000o`3ooomC0?ooo`L000002P3oool200000080
oooo00100?ooo`030000003oool0oooo0?l0ooooF@3oool4000000L0oooo0@0000010?ooo`40oooo
00100?ooo`030000003oool0oooo0?l0ooooI03oool100000040oooo0@3oool00400oooo00<00000
0?ooo`3oool0o`3ooomT0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo05<0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`1B0?oo
o`030000003oool0oooo05<0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00400
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00400ooooo`00001X00000080oooo
0000\
\>"],
  ImageRangeCache->{{{0, 424.188}, {261.813, 0}} -> {-0.425222, -1.29057, \
0.0058541, 0.00102247}}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[{
    \( (*\ 
      Find\ chi\ square\ for\ given\ H \((z)\)\ \ *) \[IndentingNewLine]\(f[
          z_] := 1/hhz[z];\)\), "\n", 
    \(\(rr[zz_] := NIntegrate[f[z], {z, 0, zz}];\)\), "\n", 
    \(\(qq = Table[rr[zz[i]], {i, 1, ndat}];\)\)}], "Input"],

Cell[BoxData[{
    \( (*\ Construct\ marginalization\ coefficients\ \((see\ astro - 
              ph/0401556\  .. )\)\ *) \[IndentingNewLine]Clear[chi2fa, 
      chi2fb, chi2fc]\), "\n", 
    \(\(chi2fa = 
        Sum[\((ld[i] - 5\ Log[10, qq[\([i]\)]*\((1 + zz[i])\)])\)^2/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\n", 
    \(\(chi2fb = 
        Sum[\((ld[i] - 
                5\ Log[10, qq[\([i]\)]*\((1 + zz[i])\)])\)/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\n", 
    \(\(chi2fc = Sum[1/\((sld[i]^2)\), {i, 1, ndat}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ Construct\ function\ after\ marginalization, \ 
      find\ same\ result\ as\ with\ mb\ minimization\ *) \
\[IndentingNewLine]chi2fm = 
      chi2fa - chi2fb^2/chi2fc\), "\[IndentingNewLine]", 
    \(dchi2p15 = chi2fm - chi2l\)}], "Input"],

Cell[BoxData[
    \(178.5877212388441`\)], "Output"],

Cell[BoxData[
    \(1.46034980379045`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ \(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(\
--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(-\(---\)\)\)\)\)\)\)\)\)\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)*) \[IndentingNewLine]\[IndentingNewLine] \
(*\ Find\ H \((z)\)\ for\ given\ slope\ s\ of\ the\ linear\ potential . \ 
            Present\ time\  = \ \(tt\ \((corresponds\ to\ a = 1)\) . \ 
              Run\ trials\ for\ initial\ condition\ for\ field\ fi\ \((f0)\)\ \
and\ initial\ time\ ti\ until\ we\ get\ field\ energy\ enf\  = \ \(0.7\ and\ \
H \((z = 0)\)\  = 
            1\ at\ present\ time\ \(\(tt\)\(.\)\)\)\)\ *) \[IndentingNewLine]\
\[IndentingNewLine] (*\ \(--\(--\(--\(--\ \ s\)\)\)\)\  = \ \(2\ \ \ --\) \(\
--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(---\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\ *) \
\[IndentingNewLine]\[IndentingNewLine]\(Clear[aa, fi, a, aad, aadd, fidas, 
        tas, f, rr, hht, hha];\)\), "\n", 
    \(aa = a[t]; \ fi = f[t];\), "\n", 
    \(\(aad = D[aa, t];\)\), "\n", 
    \(\(aadd = D[aa, {t, 2}];\)\), "\n", 
    \(\(fid = D[fi, t];\)\), "\n", 
    \(\(fidd = D[fi, {t, 2}];\)\n\), "\n", 
    \(ti = 0.0000017; \ t0 = 4;\), "\n", 
    \(\(f0 = 0.11;\)\ \), "\n", 
    \(om0m = 0.3; \ ss = 2;\), "\n", 
    \(\(eq1 = 
        aadd/aa\  \[Equal] \ 
          fid^2\ \  + \ \ ss\ fi\  - \ om0m/\((2\ aa^3)\);\)\), "\n", 
    \(\(eq2 = 
        fidd\ \  + \ \ \ 3\ \ fid\ \((aad/aa)\)\  - \ ss \[Equal] 
          0;\)\), "\n", 
    \(\(eqb1 = f[ti] == f0;\)\), "\n", 
    \(\(eqb2 = \(f'\)[ti] == 0;\)\), "\n", 
    \(\(eqb3 = 
        a[ti] \[Equal] \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((2/3)\);\)\), "\n", 
    \(\(eqb4 = \(a'\)[
            ti] \[Equal] \((2/
                3)\)\ \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((\(-1\)/
                  3)\);\)\), "\n", 
    \(\(sol2 = 
        NDSolve[{eq1, eq2, eqb1, eqb2, eqb3, eqb4}, {aa, fi}, {t, ti, t0}, 
          MaxSteps \[Rule] 10000000];\)\), "\n", 
    \(\(asol = Part[Evaluate[a[t] /. sol2], 1];\)\), "\n", 
    \(\(fsol = 
        Part[Evaluate[f[t] /. sol2], 1];\)\[IndentingNewLine]\), "\n", 
    \(\(dfsol = D[fsol, t];\)\), "\n", 
    \(\(enf = \(-0.5\)\ dfsol^2\  + \ ss\ fsol;\)\), "\n", 
    \(\(as[t1_] := asol\  /. \ t -> t1\ ;\)\), "\n", 
    \(\(tt = Part[FindRoot[as[t] == 1, {t, 0.1}], 1, 2];\)\), "\n", 
    \(\(tas[a_] := 
        Part[FindRoot[as[t] \[Equal] a, {t, 0.3}], 1, 2];\)\), "\n", 
    \(\(hht[t1_] := D[asol, t]/asol\  /. \ t -> t1\ ;\)\), "\n", 
    \(\(hha[a_] := hht[tas[a]];\)\), "\n", 
    \(\(hhz[z_] := hha[1/\((z + 1)\)];\)\), "\n", 
    \(enf\  /. \ t \[Rule] tt\), "\n", 
    \(hhz[0]\), "\[IndentingNewLine]", 
    \(\(hhzt = 
        Sqrt[\((1 - om0m)\) + om0m \((1 + z)\)^3] /. 
          om0m \[Rule] 0.3;\)\), "\[IndentingNewLine]", 
    \(\(Plot[{hhz[z], hhzt}, {z, 0, 1}];\)\), "\[IndentingNewLine]", 
    \(\(enf = \(-0.5\)\ dfsol^2\  + \ ss\ fsol;\)\), "\n", 
    \(\(ppf = \(-0.5\)\ dfsol^2\  - \ ss\ fsol;\)\), "\n", 
    \(\(wft[t1_] := ppf/enf\  /. \ t -> t1\ ;\)\ \), "\n", 
    \(\(wfa[a_] := wft[tas[a]];\)\), "\n", 
    \(\(wfz[z_] := wfa[1/\((z + 1)\)];\)\), "\n", 
    \(\(plw20p = 
        Plot[wfz[z], {z, 0, 2}, Frame \[Rule] True, PlotRange \[Rule] All, 
          FrameLabel \[Rule] {"\<z\>", "\<w(z)\>"}];\)\)}], "Input"],

Cell[BoxData[
    \(0.6909920915040378`\)], "Output"],

Cell[BoxData[
    \(1.00291790801312`\)], "Output"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.75907 0.773785 [
[.21429 .00222 -10.7813 -17.8125 ]
[.21429 .00222 10.7813 0 ]
[.40476 .00222 -10.7813 -17.8125 ]
[.40476 .00222 10.7813 0 ]
[.59524 .00222 -10.7813 -17.8125 ]
[.59524 .00222 10.7813 0 ]
[.78571 .00222 -10.7813 -17.8125 ]
[.78571 .00222 10.7813 0 ]
[.97619 .00222 -5.53125 -17.8125 ]
[.97619 .00222 5.53125 0 ]
[.01131 .09209 -21.5625 -8.90625 ]
[.01131 .09209 0 8.90625 ]
[.01131 .16947 -21.5625 -8.90625 ]
[.01131 .16947 0 8.90625 ]
[.01131 .24685 -21.5625 -8.90625 ]
[.01131 .24685 0 8.90625 ]
[.01131 .32423 -21.5625 -8.90625 ]
[.01131 .32423 0 8.90625 ]
[.01131 .40161 -21.5625 -8.90625 ]
[.01131 .40161 0 8.90625 ]
[.01131 .47899 -21.5625 -8.90625 ]
[.01131 .47899 0 8.90625 ]
[.01131 .55636 -21.5625 -8.90625 ]
[.01131 .55636 0 8.90625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
gsave
.21429 .00222 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 .01472 m
.40476 .02097 L
s
gsave
.40476 .00222 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 .01472 m
.59524 .02097 L
s
gsave
.59524 .00222 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 .01472 m
.78571 .02097 L
s
gsave
.78571 .00222 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 .01472 m
.97619 .02097 L
s
gsave
.97619 .00222 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .09209 m
.03006 .09209 L
s
gsave
.01131 .09209 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
1.000 setlinewidth
grestore
.02381 .16947 m
.03006 .16947 L
s
gsave
.01131 .16947 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
.02381 .24685 m
.03006 .24685 L
s
gsave
.01131 .24685 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
1.000 setlinewidth
grestore
.02381 .32423 m
.03006 .32423 L
s
gsave
.01131 .32423 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
.02381 .40161 m
.03006 .40161 L
s
gsave
.01131 .40161 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.02381 .47899 m
.03006 .47899 L
s
gsave
.01131 .47899 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
1.000 setlinewidth
grestore
.02381 .55636 m
.03006 .55636 L
s
gsave
.01131 .55636 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .03019 m
.02756 .03019 L
s
.02381 .04567 m
.02756 .04567 L
s
.02381 .06114 m
.02756 .06114 L
s
.02381 .07662 m
.02756 .07662 L
s
.02381 .10757 m
.02756 .10757 L
s
.02381 .12304 m
.02756 .12304 L
s
.02381 .13852 m
.02756 .13852 L
s
.02381 .154 m
.02756 .154 L
s
.02381 .18495 m
.02756 .18495 L
s
.02381 .20042 m
.02756 .20042 L
s
.02381 .2159 m
.02756 .2159 L
s
.02381 .23137 m
.02756 .23137 L
s
.02381 .26233 m
.02756 .26233 L
s
.02381 .2778 m
.02756 .2778 L
s
.02381 .29328 m
.02756 .29328 L
s
.02381 .30875 m
.02756 .30875 L
s
.02381 .3397 m
.02756 .3397 L
s
.02381 .35518 m
.02756 .35518 L
s
.02381 .37066 m
.02756 .37066 L
s
.02381 .38613 m
.02756 .38613 L
s
.02381 .41708 m
.02756 .41708 L
s
.02381 .43256 m
.02756 .43256 L
s
.02381 .44803 m
.02756 .44803 L
s
.02381 .46351 m
.02756 .46351 L
s
.02381 .49446 m
.02756 .49446 L
s
.02381 .50994 m
.02756 .50994 L
s
.02381 .52541 m
.02756 .52541 L
s
.02381 .54089 m
.02756 .54089 L
s
.02381 .57184 m
.02756 .57184 L
s
.02381 .58732 m
.02756 .58732 L
s
.02381 .60279 m
.02756 .60279 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01697 m
.02605 .01694 L
.02729 .01693 L
.02846 .01692 L
.02954 .01691 L
.03072 .01691 L
.0318 .0169 L
.03279 .0169 L
.03396 .0169 L
.03506 .0169 L
.03626 .01691 L
.03756 .01691 L
.03891 .01693 L
.0402 .01694 L
.04262 .01697 L
.045 .01701 L
.04753 .01706 L
.0521 .01718 L
.05752 .01737 L
.06244 .01758 L
.07287 .01815 L
.08414 .01897 L
.10458 .02095 L
.12452 .02352 L
.14558 .02689 L
.18355 .03465 L
.22398 .04519 L
.26289 .05746 L
.30425 .07265 L
.34409 .08923 L
.38242 .10689 L
.42321 .12736 L
.46247 .14862 L
.50022 .17037 L
.54043 .19486 L
.57911 .21962 L
.62025 .24714 L
.65988 .27474 L
.69799 .30221 L
.73855 .3324 L
.77759 .36232 L
.81909 .395 L
.85907 .42728 L
.89754 .45904 L
.93846 .49354 L
.97619 .52598 L
s
.02381 .01472 m
.06244 .02928 L
.10458 .04618 L
.14415 .063 L
.18221 .08004 L
.22272 .09908 L
.26171 .1183 L
.30316 .13965 L
.34309 .1611 L
.3815 .18255 L
.42237 .20622 L
.46172 .22982 L
.49955 .25324 L
.53984 .27895 L
.57861 .30443 L
.61984 .33229 L
.65954 .35985 L
.69774 .38703 L
.73838 .41664 L
.77751 .4458 L
.81909 .47749 L
.85916 .50867 L
.89771 .53928 L
.93871 .57245 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{425.625, 263.063},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006Y00011b000`400?l00000o`00003oo`3ooonZ
0?ooo`00o`3ooonZ0?ooo`00o`3ooonZ0?ooo`00o`3ooonZ0?ooo`00o`3ooonZ0?ooo`00o`3ooonZ
0?ooo`00I03oool3000000<0oooo00@000000?ooo`3oool0oooo1@00000m0?ooo`<000000`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo03/0oooo0`0000030?ooo`030000003oool0
oooo0080oooo0`00000n0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`<00000@`3oool3
000000h0oooo001S0?ooo`050000003oool0oooo0?ooo`0000001`3oool010000000oooo0?ooo`00
000l0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0j0?ooo`050000
003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000003`0oooo00D000000?oo
o`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`000000@`3oool00`000000oooo0?oo
o`0=0?ooo`00H`3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0?03o
ool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0>P3oool01@000000oooo
0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo0000000l0?ooo`050000003oool0oooo
0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000004<0oooo00<000000?ooo`3oool03@3o
ool006<0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo03/0oooo00D0
00000?ooo`3oool0oooo000000050?ooo`H00000>`3oool01@000000oooo0?ooo`3oool0000000H0
oooo00D000000?ooo`3oool0oooo0000000l0?ooo`050000003oool0oooo0?ooo`0000001P3oool0
1@000000oooo0?ooo`3oool0000004<0oooo00<000000?ooo`3oool03@3oool006<0oooo00D00000
0?ooo`3oool0oooo000000090?ooo`030000003oool0oooo03/0oooo00D000000?ooo`3oool0oooo
000000050?ooo`050000003oool0oooo0?ooo`000000?03oool01@000000oooo0?ooo`3oool00000
00H0oooo00D000000?ooo`3oool0oooo0000000l0?ooo`050000003oool0oooo0?ooo`0000001`3o
ool00`000000oooo000000140?ooo`030000003oool0oooo00d0oooo001S0?ooo`050000003oool0
oooo0?ooo`0000002P3oool00`000000oooo0?ooo`0j0?ooo`050000003oool0oooo0?ooo`000000
1P3oool010000000oooo0?ooo`00000l0?ooo`050000003oool0oooo0?ooo`0000001P3oool20000
0080oooo00<000000?ooo`3oool0>P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0=0?ooo`00H`3oool01@000000oooo0?ooo`3oool0
000000X0oooo00<000000?ooo`3oool0>P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<0
00000?ooo`000000?03oool01@000000oooo0?ooo`3oool0000000H0oooo00@000000?ooo`000000
0000?@3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`000000A03oool00`00
0000oooo0?ooo`0=0?ooo`00H`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?oo
o`3oool0>P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`000000?03oool0
1@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0?@3oool01@000000oooo0?oo
o`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000130?ooo`030000003oool0oooo00d0
oooo001S0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool00000
03`0oooo00D000000?ooo`3oool0oooo000000080?ooo`800000?03oool01@000000oooo0?ooo`3o
ool0000000P0oooo00<000000?ooo`3oool0?03oool01@000000oooo0?ooo`3oool0000000H0oooo
00D000000?ooo`3oool0oooo000000120?ooo`8000003`3oool006@0oooo0`0000080?ooo`<00000
?P3oool3000000X0oooo00<000000?ooo`3oool0>`3oool3000000X0oooo0P00000m0?ooo`<00000
203oool3000004@0oooo00<000000?ooo`3oool03@3oool00?l0ooooZP3oool001l0oooo00<00000
0?ooo`3oool0o`3ooon80?ooo`007`3oool00`000000oooo0?ooo`3o0?ooohP0oooo000O0?ooo`03
0000003oool0oooo0?l0ooooR03oool001l0oooo00<000000?ooo`3oool0o`3ooon80?ooo`007`3o
ool00`000000oooo0?ooo`3o0?ooohP0oooo000O0?ooo`030000003oool0oooo0?l0ooooR03oool0
01H0ooooo`00002?000000D0oooo000O0?oooa80000000<0oooo0000003oool04@3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0=0?ooo`007`3oool010000000oooo0?ooo`3oool3000000/0oooo2`0000090?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo00@0oooo0`00000C0?ooo`P00000
9`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003o
ool0oooo00L0oooo0P00000I0?ooo`P00000o`3ooomN0?ooo`007`3oool00`000000oooo0?ooo`09
0?ooo`<000007P3oool700000?l0ooooE`3oool001l0oooo0`00000<0?ooo`<000008P3oool50000
0?l0ooooDP3oool001l0oooo00<000000?ooo`3oool03`3oool2000002D0oooo1@00003o0?ooodd0
oooo000O0?ooo`030000003oool0oooo0140oooo0`00000W0?ooo`@00000o`3ooom90?ooo`007`3o
ool00`000000oooo0?ooo`0D0?ooo`800000:@3oool400000?l0ooooA@3oool001l0oooo00<00000
0?ooo`3oool05P3oool2000002/0oooo1000003o0?oood40oooo000O0?ooo`030000003oool0oooo
01P0oooo0`00000/0?ooo`@00000o`3ooolm0?ooo`007`3oool3000001/0oooo0P00000^0?ooo`@0
0000o`3oooli0?ooo`007`3oool00`000000oooo0?ooo`0M0?ooo`<00000;`3oool300000?l0oooo
=P3oool001l0oooo00<000000?ooo`3oool0803oool200000300oooo0`00003o0?oooc<0oooo000O
0?ooo`030000003oool0oooo0280oooo0`00000`0?ooo`<00000o`3oool`0?ooo`007`3oool00`00
0000oooo0?ooo`0U0?ooo`800000<@3oool300000?l0oooo;@3oool001l0oooo00<000000?ooo`3o
ool09`3oool300000340oooo0`00003o0?ooobX0oooo000O0?ooo`030000003oool0oooo02X0oooo
0P00000b0?ooo`<00000o`3ooolW0?ooo`007`3oool3000002`0oooo0`00000b0?ooo`<00000o`3o
oolT0?ooo`007`3oool00`000000oooo0?ooo`0_0?ooo`800000<`3oool200000?l0oooo8P3oool0
01l0oooo00<000000?ooo`3oool0<@3oool2000003<0oooo0`00003o0?oooal0oooo000O0?ooo`03
0000003oool0oooo03<0oooo0P00000d0?ooo`<00000o`3ooolL0?ooo`007`3oool00`000000oooo
0?ooo`0e0?ooo`800000=@3oool300000?l0oooo6@3oool001l0oooo00<000000?ooo`3oool0=`3o
ool2000003H0oooo0P00003o0?oooaL0oooo000O0?ooo`<00000>@3oool2000003H0oooo0P00003o
0?oooaD0oooo000O0?ooo`030000003oool0oooo03/0oooo0P00000f0?ooo`800000o`3ooolC0?oo
o`002@3oool3000000<0oooo00<000000?ooo`3oool00P3oool3000000P0oooo00<000000?ooo`3o
ool0?@3oool2000003H0oooo0`00003o0?oooa00oooo000:0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0o0?ooo`800000=`3oool200000?l0oooo
3P3oool000X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0440oooo0P00000g0?ooo`800000o`3oool<0?ooo`002P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0@`3oool2000003L0oooo0`00003o
0?ooo`T0oooo000:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool40000
04@0oooo0P00000h0?ooo`800000o`3oool70?ooo`002P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0A`3oool2000003P0oooo0P00003o0?ooo`D0
oooo000:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`190?ooo`800000>03oool200000?l0oooo0`3oool000X0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04/0oooo0`00000g0?ooo`800000o`3o
ool10?ooo`002@3oool2000000T0oooo0P0000090?ooo`030000003oool0oooo04h0oooo0P00000g
0?ooo`800000oP3oool000X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0500oooo0P00000g0?ooo`800000o03oool001l0oooo0`00001B0?ooo`80
0000=`3oool200000?X0oooo000O0?ooo`030000003oool0oooo05@0oooo0`00000f0?ooo`800000
n03oool001l0oooo00<000000?ooo`3oool0E`3oool2000003H0oooo0P00003f0?ooo`007`3oool0
0`000000oooo0?ooo`1I0?ooo`800000=P3oool200000?@0oooo000O0?ooo`030000003oool0oooo
05/0oooo0P00000f0?ooo`800000lP3oool001l0oooo00<000000?ooo`3oool0G@3oool2000003H0
oooo0P00003`0?ooo`007`3oool3000005l0oooo0P00000f0?ooo`800000kP3oool001l0oooo00<0
00000?ooo`3oool0H@3oool2000003H0oooo0P00003/0?ooo`007`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo03D0oooo0P00003Z0?ooo`007`3oool00`000000oooo0?ooo`1T0?oo
o`800000=`3oool200000>P0oooo000O0?ooo`030000003oool0oooo06H0oooo0P00000g0?ooo`80
0000iP3oool001l0oooo00<000000?ooo`3oool0J03oool2000003L0oooo0P00003T0?ooo`007`3o
ool3000006X0oooo0P00000g0?ooo`800000hP3oool001l0oooo00<000000?ooo`3oool0K03oool0
0`000000oooo0?ooo`0f0?ooo`800000h03oool001l0oooo00<000000?ooo`3oool0K@3oool20000
03P0oooo0P00003N0?ooo`007`3oool00`000000oooo0?ooo`1_0?ooo`800000>03oool200000=`0
oooo000O0?ooo`030000003oool0oooo0740oooo0P00000h0?ooo`030000003oool0oooo0=T0oooo
000O0?ooo`030000003oool0oooo07<0oooo0P00000g0?ooo`800000f@3oool001l0oooo0`00001e
0?ooo`800000=`3oool200000=L0oooo000O0?ooo`030000003oool0oooo07L0oooo0P00000g0?oo
o`030000003oool0oooo0=@0oooo000O0?ooo`030000003oool0oooo07T0oooo0P00000f0?ooo`80
0000e03oool000T0oooo0`0000030?ooo`040000003oool0oooo0?ooo`D000001`3oool00`000000
oooo0?ooo`1k0?ooo`800000=P3oool200000=80oooo000:0?ooo`030000003oool0oooo00L0oooo
00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`1m0?ooo`800000=P3oool00`000000
oooo0?ooo`3?0?ooo`002P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0O`3oool2000003D0oooo0P00003?0?ooo`002P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?oo
o`0d0?ooo`800000c@3oool000X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`06
0?ooo`@00000P@3oool2000003H0oooo00<000000?ooo`3oool0bP3oool000X0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08@0oooo0P00000e0?oo
o`800000bP3oool000X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`370?ooo`00
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
Q`3oool2000003D0oooo0P0000370?ooo`002@3oool2000000P0oooo00D000000?ooo`3oool0oooo
000000070?ooo`030000003oool0oooo08T0oooo0P00000e0?ooo`800000a@3oool000X0oooo00<0
00000?ooo`3oool01`3oool3000000P0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo0<80oooo000O0?ooo`<00000S03oool2000003D0oooo0P000032
0?ooo`007`3oool00`000000oooo0?ooo`2>0?ooo`800000=@3oool00`000000oooo0?ooo`2o0?oo
o`007`3oool00`000000oooo0?ooo`2@0?ooo`800000=03oool200000;l0oooo000O0?ooo`030000
003oool0oooo0980oooo0P00000d0?ooo`800000_@3oool001l0oooo00<000000?ooo`3oool0U03o
ool2000003@0oooo00<000000?ooo`3oool0^P3oool001l0oooo00<000000?ooo`3oool0UP3oool2
000003<0oooo0P00002j0?ooo`007`3oool3000009P0oooo0P00000c0?ooo`800000^03oool001l0
oooo00<000000?ooo`3oool0VP3oool2000003<0oooo0P00002f0?ooo`007`3oool00`000000oooo
0?ooo`2L0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/`3oool001l0oooo00<0
00000?ooo`3oool0W@3oool2000003<0oooo0P00002c0?ooo`007`3oool00`000000oooo0?ooo`2O
0?ooo`030000003oool0oooo0380oooo0P00002a0?ooo`007`3oool00`000000oooo0?ooo`2P0?oo
o`800000=03oool200000:l0oooo000O0?ooo`<00000XP3oool00`000000oooo0?ooo`0c0?ooo`80
0000[@3oool001l0oooo00<000000?ooo`3oool0X`3oool2000003D0oooo00<000000?ooo`3oool0
ZP3oool001l0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0c0?ooo`800000ZP3o
ool001l0oooo00<000000?ooo`3oool0YP3oool2000003D0oooo00<000000?ooo`3oool0Y`3oool0
01l0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0c0?ooo`800000Y`3oool001l0
oooo00<000000?ooo`3oool0Z@3oool2000003D0oooo00<000000?ooo`3oool0Y03oool001l0oooo
0`00002[0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0X`3oool001l0oooo00<0
00000?ooo`3oool0[03oool2000003@0oooo0P00002S0?ooo`007`3oool00`000000oooo0?ooo`2^
0?ooo`800000=03oool00`000000oooo0?ooo`2P0?ooo`002@3oool3000000<0oooo00@000000?oo
o`3oool0oooo100000080?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0<P3oool2
00000:00oooo000:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`2a0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`002P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0/`3oool2000003<0
oooo0P00002M0?ooo`002P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo
1000002d0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0VP3oool000X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0;H0oooo0P00
000c0?ooo`800000VP3oool000X0oooo00<000000?ooo`3oool0203oool2000000P0oooo00<00000
0?ooo`3oool0^03oool2000003<0oooo00<000000?ooo`3oool0U`3oool000X0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0;X0oooo00<000000?oo
o`3oool0<@3oool2000009L0oooo000:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`2k0?ooo`800000<`3oool00`000000oooo0?ooo`2D0?ooo`00
2@3oool2000000P0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo0;d0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2C0?ooo`002P3oool00`000000oooo
0?ooo`070?ooo`<00000203oool300000;h0oooo0P00000b0?ooo`800000T`3oool001l0oooo00<0
00000?ooo`3oool0`03oool200000380oooo00<000000?ooo`3oool0T03oool001l0oooo00<00000
0?ooo`3oool0`P3oool00`000000oooo0?ooo`0`0?ooo`800000T03oool001l0oooo00<000000?oo
o`3oool0``3oool200000380oooo00<000000?ooo`3oool0S@3oool001l0oooo00<000000?ooo`3o
ool0a@3oool00`000000oooo0?ooo`0`0?ooo`800000S@3oool001l0oooo00<000000?ooo`3oool0
aP3oool200000380oooo00<000000?ooo`3oool0RP3oool001l0oooo00<000000?ooo`3oool0b03o
ool200000340oooo0P00002:0?ooo`007`3oool300000<X0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`270?ooo`007`3oool00`000000oooo0?ooo`3;0?ooo`800000<@3oool00`00
0000oooo0?ooo`260?ooo`007`3oool00`000000oooo0?ooo`3=0?ooo`030000003oool0oooo02l0
oooo0P0000260?ooo`007`3oool00`000000oooo0?ooo`3>0?ooo`800000<@3oool00`000000oooo
0?ooo`230?ooo`007`3oool00`000000oooo0?ooo`3@0?ooo`800000<03oool00`000000oooo0?oo
o`220?ooo`007`3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo02h0oooo0P000022
0?ooo`007`3oool300000=<0oooo0P00000`0?ooo`030000003oool0oooo07l0oooo000O0?ooo`03
0000003oool0oooo0=D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`1n0?ooo`00
7`3oool00`000000oooo0?ooo`3F0?ooo`800000;`3oool2000007h0oooo000O0?ooo`030000003o
ool0oooo0=P0oooo0P00000_0?ooo`030000003oool0oooo07/0oooo000O0?ooo`030000003oool0
oooo0=X0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1j0?ooo`007`3oool00`00
0000oooo0?ooo`3K0?ooo`800000;P3oool2000007X0oooo000O0?ooo`<00000g@3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo07L0oooo000O0?ooo`030000003oool0oooo0=h0oooo
0P00000^0?ooo`030000003oool0oooo07H0oooo00090?ooo`<000000`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0h03oool00`000000oooo0?oo
o`0/0?ooo`800000MP3oool000X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0>40oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1c
0?ooo`002P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0hP3oool2000002h0oooo00<000000?ooo`3oool0LP3oool000X0oooo00<000000?ooo`3o
ool01@3oool6000000L0oooo00<000000?ooo`3oool0i03oool00`000000oooo0?ooo`0/0?ooo`80
0000LP3oool000X0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000P0
oooo1000003T0?ooo`800000;P3oool00`000000oooo0?ooo`1_0?ooo`002P3oool00`000000oooo
0?ooo`060?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0i`3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo06h0oooo000:0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`000000203oool00`000000oooo0?ooo`3X0?ooo`800000;@3oool2000006h0oooo
000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000203oool00`000000oooo0?oo
o`3Z0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0J`3oool000T0oooo0P00000:
0?ooo`800000203oool00`000000oooo0?ooo`3[0?ooo`800000;@3oool00`000000oooo0?ooo`1Z
0?ooo`002P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0k@3oool00`000000oooo0?ooo`0[0?ooo`800000JP3oool001l0oooo0`00003^0?ooo`80
0000;@3oool00`000000oooo0?ooo`1W0?ooo`007`3oool00`000000oooo0?ooo`3`0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool0IP3oool001l0oooo00<000000?ooo`3oool0l@3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo06D0oooo000O0?ooo`030000003oool0
oooo0?80oooo0P00000/0?ooo`800000I@3oool001l0oooo00<000000?ooo`3oool0m03oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo0680oooo000O0?ooo`030000003oool0oooo0?D0
oooo0P00000/0?ooo`030000003oool0oooo0640oooo000O0?ooo`<00000m`3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo0600oooo000O0?ooo`030000003oool0oooo0?P0oooo0P00
000[0?ooo`800000H03oool001l0oooo00<000000?ooo`3oool0nP3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo05d0oooo000O0?ooo`030000003oool0oooo0?/0oooo0P00000[0?oo
o`030000003oool0oooo05`0oooo000O0?ooo`030000003oool0oooo0?d0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`1K0?ooo`007`3oool00`000000oooo0?ooo`3n0?ooo`030000
003oool0oooo02T0oooo0P00001K0?ooo`007`3oool300000?l0oooo0P00000[0?ooo`030000003o
ool0oooo05P0oooo000O0?ooo`030000003oool0oooo0?l0oooo0P3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo05L0oooo000O0?ooo`030000003oool0oooo0?l0oooo0`3oool00`00
0000oooo0?ooo`0Y0?ooo`800000E`3oool001l0oooo00<000000?ooo`3oool0o`3oool40?ooo`80
0000:`3oool00`000000oooo0?ooo`1D0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooo`H0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1C0?ooo`007`3oool00`000000oooo0?oo
o`3o0?ooo`L0oooo00<000000?ooo`3oool0:@3oool2000005<0oooo000O0?ooo`030000003oool0
oooo0?l0oooo203oool2000002/0oooo00<000000?ooo`3oool0D03oool001l0oooo0`00003o0?oo
o`X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1?0?ooo`007`3oool00`000000
oooo0?ooo`3o0?ooo`/0oooo00<000000?ooo`3oool0:@3oool2000004l0oooo00090?ooo`<00000
0`3oool010000000oooo0?ooo`3oool3000000T0oooo00<000000?ooo`3oool0o`3oool<0?ooo`80
0000:`3oool00`000000oooo0?ooo`1<0?ooo`002P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0o`3oool>0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0B`3oool000X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0?l0oooo3`3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo04X0oooo000:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`3o0?oooa00oooo0P00000Z0?ooo`800000BP3oool000X0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`050?ooo`@00000o`3ooolA0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0A`3oool000X0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo4`3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo04H0oooo000:0?ooo`030000003oool0oooo00H0oooo0`0000090?ooo`030000
003oool0oooo0?l0oooo503oool2000002X0oooo00<000000?ooo`3oool0A@3oool000X0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo5P3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo04@0oooo00090?ooo`8000002@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo5`3oool00`000000oooo0?ooo`0X
0?ooo`800000A03oool000X0oooo00<000000?ooo`3oool01`3oool4000000L0oooo00<000000?oo
o`3oool0o`3ooolH0?ooo`800000:P3oool00`000000oooo0?ooo`110?ooo`007`3oool300000?l0
oooo6P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0400oooo000O0?ooo`030000
003oool0oooo0?l0oooo6`3oool2000002T0oooo00<000000?ooo`3oool0?`3oool001l0oooo00<0
00000?ooo`3oool0o`3ooolM0?ooo`030000003oool0oooo02L0oooo0P00000o0?ooo`007`3oool0
0`000000oooo0?ooo`3o0?oooah0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0l
0?ooo`007`3oool00`000000oooo0?ooo`3o0?oooal0oooo0P00000Y0?ooo`030000003oool0oooo
03/0oooo000O0?ooo`030000003oool0oooo0?l0oooo8@3oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo03X0oooo000O0?ooo`<00000o`3ooolR0?ooo`030000003oool0oooo02L0oooo
0P00000j0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooob<0oooo0P00000Y0?ooo`030000003o
ool0oooo03L0oooo000O0?ooo`030000003oool0oooo0?l0oooo9@3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo03H0oooo000O0?ooo`030000003oool0oooo0?l0oooo9P3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo03D0oooo000O0?ooo`030000003oool0oooo0?l0
oooo9`3oool2000002P0oooo0P00000e0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooobT0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0b0?ooo`007`3oool300000?l0oooo:P3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0340oooo000O0?ooo`030000003oool0
oooo0?l0oooo:`3oool2000002P0oooo00<000000?ooo`3oool0<03oool001l0oooo00<000000?oo
o`3oool0o`3oool]0?ooo`030000003oool0oooo02H0oooo0P00000`0?ooo`007`3oool00`000000
oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0]0?ooo`00
7`3oool00`000000oooo0?ooo`3o0?ooobl0oooo0P00000X0?ooo`030000003oool0oooo02`0oooo
000O0?ooo`030000003oool0oooo0?l0oooo<@3oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo02/0oooo000O0?ooo`<00000o`3ooolb0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0:P3oool001l0oooo00<000000?ooo`3oool0o`3ooolc0?ooo`8000009`3oool00`00
0000oooo0?ooo`0Y0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooocD0oooo00<000000?ooo`3o
ool09@3oool2000002T0oooo00090?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`<00000
203oool00`000000oooo0?ooo`3o0?ooocH0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`0V0?ooo`002P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000
1`3oool00`000000oooo0?ooo`3o0?ooocL0oooo0P00000W0?ooo`030000003oool0oooo02D0oooo
000:0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000
003oool0oooo0?l0oooo>@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02@0oooo
000:0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000070?ooo`@00000
o`3oooli0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool08`3oool000X0oooo00<0
00000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0
o`3ooolk0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool08P3oool000X0oooo00<0
00000?ooo`3oool01P3oool200000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`3o0?oooc`0oooo0P00000V0?ooo`030000003oool0oooo0240oooo000:0?ooo`030000003oool0
oooo00H0oooo00@000000?ooo`0000000000203oool00`000000oooo0?ooo`3o0?oooch0oooo00<0
00000?ooo`3oool0903oool200000240oooo000:0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooocl0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0N0?ooo`002@3oool2000000X0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`3o0?oood00oooo0P00000V0?ooo`030000003oool0oooo01d0oooo000:0?ooo`03
0000003oool0oooo00T0oooo0P0000070?ooo`<00000o`3ooom20?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool0703oool001l0oooo00<000000?ooo`3oool0o`3ooom30?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool06`3oool001l0oooo00<000000?ooo`3oool0o`3o
oom40?ooo`8000009@3oool00`000000oooo0?ooo`0J0?ooo`007`3oool00`000000oooo0?ooo`3o
0?ooodH0oooo00<000000?ooo`3oool08`3oool2000001X0oooo000O0?ooo`030000003oool0oooo
0?l0ooooA`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01L0oooo000O0?ooo`03
0000003oool0oooo0?l0ooooB03oool2000002D0oooo00<000000?ooo`3oool05P3oool001l0oooo
00<000000?ooo`3oool0o`3ooom:0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
5@3oool001l0oooo0`00003o0?oood/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0D0?ooo`007`3oool00`000000oooo0?ooo`3o0?oood`0oooo0P00000T0?ooo`030000003oool0
oooo01<0oooo000O0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo0180oooo000O0?ooo`030000003oool0oooo0?l0ooooC`3oool00`000000
oooo0?ooo`0R0?ooo`8000004P3oool001l0oooo00<000000?ooo`3oool0o`3ooom@0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool03`3oool001l0oooo00<000000?ooo`3oool0o`3o
oomA0?ooo`800000903oool00`000000oooo0?ooo`0>0?ooo`007`3oool300000?l0ooooD`3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo
0?l0ooooE03oool00`000000oooo0?ooo`0a0?ooo`007`3oool00`000000oooo0?ooo`3o0?oooeD0
oooo00<000000?ooo`3oool0<03oool001l0oooo00<000000?ooo`3oool0o`3ooomF0?ooo`800000
<03oool001l0oooo00<000000?ooo`3oool0o`3ooomH0?ooo`030000003oool0oooo02d0oooo000O
0?ooo`030000003oool0oooo0?l0ooooF@3oool00`000000oooo0?ooo`0/0?ooo`007`3oool30000
0?l0ooooFP3oool00`000000oooo0?ooo`0[0?ooo`007`3oool00`000000oooo0?ooo`3o0?oooe/0
oooo0P00000[0?ooo`002@3oool3000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0?l0ooooG@3oool00`000000oooo0?ooo`0X0?ooo`002P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3o
oomN0?ooo`030000003oool0oooo02L0oooo000:0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oooel0oooo00<000000?ooo`3oool09P3oool0
00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0?l0ooooH03oool00`000000oooo0?ooo`0U0?ooo`002P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00L0oooo1000003o0?ooof00oooo0P00000U0?ooo`002P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooomS0?ooo`030000
003oool0oooo0280oooo000:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`3o0?ooof@0oooo00<000000?ooo`3oool08@3oool000X0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0ooooI@3oool0
0`000000oooo0?ooo`0P0?ooo`002@3oool2000000L0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooIP3oool200000200oooo000:0?ooo`03
0000003oool0oooo00H0oooo1@0000070?ooo`030000003oool0oooo0?l0ooooJ03oool00`000000
oooo0?ooo`0M0?ooo`007`3oool300000?l0ooooJ@3oool00`000000oooo0?ooo`0L0?ooo`007`3o
ool00`000000oooo0?ooo`3o0?ooofX0oooo00<000000?ooo`3oool06`3oool001l0oooo00<00000
0?ooo`3oool0o`3ooom[0?ooo`030000003oool0oooo01X0oooo000O0?ooo`030000003oool0oooo
0?l0ooooK03oool2000001X0oooo000O0?ooo`030000003oool0oooo0?l0ooooKP3oool00`000000
oooo0?ooo`0G0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooofl0oooo00<000000?ooo`3oool0
5P3oool001l0oooo0`00003o0?ooog00oooo00<000000?ooo`3oool05@3oool001l0oooo00<00000
0?ooo`3oool0o`3oooma0?ooo`030000003oool0oooo01@0oooo000O0?ooo`030000003oool0oooo
0?l0ooooLP3oool00`000000oooo0?ooo`0C0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooog<0
oooo00<000000?ooo`3oool04P3oool001l0oooo00<000000?ooo`3oool0o`3ooomd0?ooo`800000
4P3oool001l0oooo00<000000?ooo`3oool0o`3ooomf0?ooo`030000003oool0oooo00l0oooo000O
0?ooo`<00000o`3ooomg0?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo
0?l0ooooN03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`3o0?ooohP0
oooo000O0?ooo`030000003oool0oooo0?l0ooooR03oool001l0oooo00<000000?ooo`3oool0o`3o
oon80?ooo`007`3oool00`000000oooo0?ooo`3o0?ooohP0oooo000O0?ooo`030000003oool0oooo
0?l0ooooR03oool00001\
\>"],
  ImageRangeCache->{{{0, 424.625}, {262.063, 0}} -> {-0.0846619, 0.925809, \
0.00264732, 0.00325834}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.476191 2.30413 1.55047 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.2619 -0.0125 -10.7813 -17.8125 ]
[.2619 -0.0125 10.7813 0 ]
[.5 -0.0125 -5.53125 -17.8125 ]
[.5 -0.0125 5.53125 0 ]
[.7381 -0.0125 -10.7813 -17.8125 ]
[.7381 -0.0125 10.7813 0 ]
[.97619 -0.0125 -5.53125 -17.8125 ]
[.97619 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.125 -35.625 ]
[.5 -0.0125 5.125 -17.8125 ]
[-0.0125 .05595 -38.3125 -8.90625 ]
[-0.0125 .05595 0 8.90625 ]
[-0.0125 .13347 -31.25 -8.90625 ]
[-0.0125 .13347 0 8.90625 ]
[-0.0125 .21099 -38.3125 -8.90625 ]
[-0.0125 .21099 0 8.90625 ]
[-0.0125 .28852 -31.25 -8.90625 ]
[-0.0125 .28852 0 8.90625 ]
[-0.0125 .36604 -38.3125 -8.90625 ]
[-0.0125 .36604 0 8.90625 ]
[-0.0125 .44357 -31.25 -8.90625 ]
[-0.0125 .44357 0 8.90625 ]
[-0.0125 .52109 -38.3125 -8.90625 ]
[-0.0125 .52109 0 8.90625 ]
[-0.0125 .59861 -31.25 -8.90625 ]
[-0.0125 .59861 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -56.125 -14.7188 ]
[-0.01875 .30902 -38.3125 14.7188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.125 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .05595 m
.00625 .05595 L
s
gsave
-0.0125 .05595 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.45) show
1.000 setlinewidth
grestore
0 .13347 m
.00625 .13347 L
s
gsave
-0.0125 .13347 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
0 .21099 m
.00625 .21099 L
s
gsave
-0.0125 .21099 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.35) show
1.000 setlinewidth
grestore
0 .28852 m
.00625 .28852 L
s
gsave
-0.0125 .28852 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
1.000 setlinewidth
grestore
0 .36604 m
.00625 .36604 L
s
gsave
-0.0125 .36604 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
1.000 setlinewidth
grestore
0 .44357 m
.00625 .44357 L
s
gsave
-0.0125 .44357 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
0 .52109 m
.00625 .52109 L
s
gsave
-0.0125 .52109 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
1.000 setlinewidth
grestore
0 .59861 m
.00625 .59861 L
s
gsave
-0.0125 .59861 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .07145 m
.00375 .07145 L
s
0 .08696 m
.00375 .08696 L
s
0 .10246 m
.00375 .10246 L
s
0 .11797 m
.00375 .11797 L
s
0 .14898 m
.00375 .14898 L
s
0 .16448 m
.00375 .16448 L
s
0 .17998 m
.00375 .17998 L
s
0 .19549 m
.00375 .19549 L
s
0 .2265 m
.00375 .2265 L
s
0 .242 m
.00375 .242 L
s
0 .25751 m
.00375 .25751 L
s
0 .27301 m
.00375 .27301 L
s
0 .30402 m
.00375 .30402 L
s
0 .31953 m
.00375 .31953 L
s
0 .33503 m
.00375 .33503 L
s
0 .35054 m
.00375 .35054 L
s
0 .38155 m
.00375 .38155 L
s
0 .39705 m
.00375 .39705 L
s
0 .41256 m
.00375 .41256 L
s
0 .42806 m
.00375 .42806 L
s
0 .45907 m
.00375 .45907 L
s
0 .47457 m
.00375 .47457 L
s
0 .49008 m
.00375 .49008 L
s
0 .50558 m
.00375 .50558 L
s
0 .53659 m
.00375 .53659 L
s
0 .5521 m
.00375 .5521 L
s
0 .5676 m
.00375 .5676 L
s
0 .58311 m
.00375 .58311 L
s
0 .04044 m
.00375 .04044 L
s
0 .02494 m
.00375 .02494 L
s
0 .00943 m
.00375 .00943 L
s
0 .61412 m
.00375 .61412 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -122.938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.7188 12.9063 translate
90 rotate
-75.7188 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.063 17.500 moveto
(H) show
77.625 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.875 17.500 moveto
(L) show
88.438 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .05595 m
1 .05595 L
s
.99375 .13347 m
1 .13347 L
s
.99375 .21099 m
1 .21099 L
s
.99375 .28852 m
1 .28852 L
s
.99375 .36604 m
1 .36604 L
s
.99375 .44357 m
1 .44357 L
s
.99375 .52109 m
1 .52109 L
s
.99375 .59861 m
1 .59861 L
s
.125 Mabswid
.99625 .07145 m
1 .07145 L
s
.99625 .08696 m
1 .08696 L
s
.99625 .10246 m
1 .10246 L
s
.99625 .11797 m
1 .11797 L
s
.99625 .14898 m
1 .14898 L
s
.99625 .16448 m
1 .16448 L
s
.99625 .17998 m
1 .17998 L
s
.99625 .19549 m
1 .19549 L
s
.99625 .2265 m
1 .2265 L
s
.99625 .242 m
1 .242 L
s
.99625 .25751 m
1 .25751 L
s
.99625 .27301 m
1 .27301 L
s
.99625 .30402 m
1 .30402 L
s
.99625 .31953 m
1 .31953 L
s
.99625 .33503 m
1 .33503 L
s
.99625 .35054 m
1 .35054 L
s
.99625 .38155 m
1 .38155 L
s
.99625 .39705 m
1 .39705 L
s
.99625 .41256 m
1 .41256 L
s
.99625 .42806 m
1 .42806 L
s
.99625 .45907 m
1 .45907 L
s
.99625 .47457 m
1 .47457 L
s
.99625 .49008 m
1 .49008 L
s
.99625 .50558 m
1 .50558 L
s
.99625 .53659 m
1 .53659 L
s
.99625 .5521 m
1 .5521 L
s
.99625 .5676 m
1 .5676 L
s
.99625 .58311 m
1 .58311 L
s
.99625 .04044 m
1 .04044 L
s
.99625 .02494 m
1 .02494 L
s
.99625 .00943 m
1 .00943 L
s
.99625 .61412 m
1 .61412 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .03 m
.03279 .0253 L
.04262 .02115 L
.04758 .01945 L
.05288 .01793 L
.05785 .01678 L
.06244 .01595 L
.06503 .01557 L
.06788 .01524 L
.07075 .01499 L
.07232 .01488 L
.07379 .01481 L
.07445 .01478 L
.07517 .01476 L
.07648 .01473 L
.07776 .01472 L
.07895 .01472 L
.07968 .01472 L
.08036 .01474 L
.08164 .01477 L
.08236 .0148 L
.08302 .01483 L
.08451 .01491 L
.08691 .01509 L
.08916 .0153 L
.09427 .01597 L
.09924 .01685 L
.10458 .01803 L
.11475 .02097 L
.12582 .02512 L
.14594 .03502 L
.18672 .06278 L
.22599 .09659 L
.26374 .13308 L
.30394 .17401 L
.34263 .21377 L
.38377 .25519 L
.42339 .29342 L
.4615 .32818 L
.50206 .36277 L
.54111 .39362 L
.58261 .42377 L
.62259 .45035 L
.66106 .47375 L
.70197 .49647 L
.74138 .51638 L
.77926 .53385 L
.8196 .55081 L
.85843 .56568 L
.8997 .58006 L
Mistroke
.93947 .59267 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{425.625, 263.063},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006Y00011b000`400?l00000o`00003oo`3ooonZ
0?ooo`00o`3ooonZ0?ooo`00o`3ooonZ0?ooo`00o`3ooonZ0?ooo`00o`3ooonZ0?ooo`00o`3ooonZ
0?ooo`00l03oool600000;<0oooo003a0?ooo`050000003oool0oooo0?ooo`000000/`3oool00?80
oooo00<000000?ooo`3oool0]03oool00?80oooo00<000000?ooo`3oool0]03oool00?<0oooo00<0
00000?ooo`3oool0/`3oool00?00oooo00D000000?ooo`3oool0oooo0000002d0?ooo`00l03oool6
00000;<0oooo003o0?ooojX0oooo003o0?ooojX0oooo003o0?ooojX0oooo003o0?ooojX0oooo003o
0?ooojX0oooo003o0?ooojX0oooo003o0?ooojX0oooo003o0?ooojX0oooo003o0?ooojX0oooo003o
0?ooojX0oooo003o0?ooojX0oooo00180?ooo`<00000C@3oool3000000<0oooo00@000000?ooo`3o
ool0oooo0`00001=0?ooo`<00000C03oool3000000<0oooo00@000000?ooo`3oool0oooo0`00001<
0?ooo`D000002P3oool004L0oooo00D000000?ooo`3oool0oooo0000001;0?ooo`050000003oool0
oooo0?ooo`0000002@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04`0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`1:0?ooo`040000003oool0oooo000000X0oooo
00170?ooo`050000003oool0oooo0?ooo`000000B`3oool01@000000oooo0?ooo`3oool0000000X0
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0:0?ooo`00A`3oool01@000000oooo
0?ooo`3oool0000004/0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo
04X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool02@3oool004L0oooo00D000000?ooo`3oool0oooo0000001;0?oo
o`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo04`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0
oooo00T0oooo00170?ooo`050000003oool0oooo0?ooo`000000B`3oool01@000000oooo0?ooo`3o
ool0000000T0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1<0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`080?ooo`00A`3oool0
1@000000oooo0?ooo`3oool0000004/0oooo00D000000?ooo`3oool0oooo000000060?ooo`<00000
CP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00H0oooo0`00001@0?ooo`030000
003oool0oooo00P0oooo00170?ooo`050000003oool0oooo0?ooo`000000B`3oool01@000000oooo
0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1<0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`080?ooo`00
A`3oool01@000000oooo0?ooo`3oool0000004/0oooo00D000000?ooo`3oool0oooo000000070?oo
o`030000003oool0oooo04`0oooo0P00001=0?ooo`8000002@3oool00`000000oooo0?ooo`1;0?oo
o`050000003oool0oooo0?ooo`0000002P3oool004P0oooo0`00001=0?ooo`<00000203oool40000
04`0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`070?ooo`@00000B`3oool30000
00/0oooo003o0?ooojX0oooo003o0?ooojX0oooo003o0?ooojX0oooo003o0?ooojX0oooo003o0?oo
ojX0oooo003o0?ooojX0oooo003o0?ooojX0oooo00110?ooool00000IP0000030?ooo`00@@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00110?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo
0580oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0040oooo00110?ooo`<00000o`3ooomQ0?ooo`8000000`3oool00440oooo00<000000?ooo`3oool0
o`3ooomR0?ooo`030000003oool0oooo0040oooo00110?ooo`030000003oool0oooo0180oooo3P00
003o0?oood80oooo00<000000?ooo`3oool00@3oool00440oooo00<000000?ooo`3oool03P3oool4
000000h0oooo1000003o0?oooch0oooo00<000000?ooo`3oool00@3oool00440oooo00<000000?oo
o`3oool0303oool2000001H0oooo1000003o0?ooocX0oooo00<000000?ooo`3oool00@3oool00440
oooo0`00000:0?ooo`800000703oool300000?l0oooo=P3oool2000000<0oooo00110?ooo`030000
003oool0oooo00P0oooo0P00000Q0?ooo`800000o`3ooole0?ooo`030000003oool0oooo0040oooo
00110?ooo`030000003oool0oooo00H0oooo0P00000U0?ooo`800000o`3ooolc0?ooo`030000003o
ool0oooo0040oooo00110?ooo`030000003oool0oooo02l0oooo0P00003o0?oooc40oooo00<00000
0?ooo`3oool00@3oool00440oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`3o0?oo
obh0oooo00<000000?ooo`3oool00@3oool00440oooo00<000000?ooo`3oool0<P3oool200000?l0
oooo;P3oool00`000000oooo0?ooo`010?ooo`00@@3oool3000003@0oooo00<000000?ooo`3oool0
o`3ooolZ0?ooo`8000000`3oool00440oooo00<000000?ooo`3oool0=@3oool200000?l0oooo:`3o
ool00`000000oooo0?ooo`010?ooo`00903oool3000000<0oooo00<000000?ooo`3oool0103oool0
10000000oooo0?ooo`3oool3000000T0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`3o0?ooobP0oooo00<000000?ooo`3oool00@3oool002D0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0>03oool2
00000?l0oooo:03oool00`000000oooo0?ooo`010?ooo`009@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0j0?oo
o`030000003oool0oooo0?l0oooo9@3oool00`000000oooo0?ooo`010?ooo`006@3oool7000000D0
oooo00<000000?ooo`3oool01@3oool6000000H0oooo00<000000?ooo`3oool01@3oool3000003/0
oooo0P00003o0?ooob<0oooo0`0000030?ooo`009@3oool00`000000oooo0?ooo`050?ooo`050000
003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool0o`3ooolR0?ooo`030000003oool0oooo0040oooo000U0?ooo`030000
003oool0oooo00H0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo03h0oooo0P00003o0?ooob80oooo00<000000?ooo`3oool00@3oool002D0oooo
00<000000?ooo`3oool01`3oool00`000000oooo000000030?ooo`<000002@3oool00`000000oooo
0?ooo`100?ooo`030000003oool0oooo0?l0oooo7`3oool00`000000oooo0?ooo`010?ooo`009@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0?l0oooo7P3oool00`000000oooo0?oo
o`010?ooo`00903oool2000000X0oooo0P0000040?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`3o0?oooad0oooo00<000000?ooo`3oool00@3oool0
02D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`@000001`3oool30000
04<0oooo0P00003o0?oooa`0oooo0P0000030?ooo`00@@3oool00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo0?l0oooo6P3oool00`000000oooo0?ooo`010?ooo`00@@3oool00`000000oooo
0?ooo`160?ooo`030000003oool0oooo0?l0oooo6@3oool00`000000oooo0?ooo`010?ooo`00@@3o
ool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0?l0oooo603oool00`000000oooo0?oo
o`010?ooo`00@@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0?l0oooo5`3oool0
0`000000oooo0?ooo`010?ooo`00@@3oool3000004T0oooo00<000000?ooo`3oool0o`3ooolE0?oo
o`8000000`3oool00440oooo00<000000?ooo`3oool0BP3oool200000?l0oooo5P3oool00`000000
oooo0?ooo`010?ooo`00@@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0?l0oooo
4`3oool00`000000oooo0?ooo`010?ooo`00@@3oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo0?l0oooo4P3oool00`000000oooo0?ooo`010?ooo`00@@3oool00`000000oooo0?ooo`1>
0?ooo`030000003oool0oooo0?l0oooo4@3oool00`000000oooo0?ooo`010?ooo`00@@3oool00`00
0000oooo0?ooo`1?0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`010?oo
o`00@@3oool300000500oooo00<000000?ooo`3oool0o`3oool>0?ooo`8000000`3oool00440oooo
00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`3o0?ooo`h0oooo00<000000?ooo`3oool0
0@3oool00440oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`3o0?ooo`d0oooo00<0
00000?ooo`3oool00@3oool00440oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`3o
0?ooo``0oooo00<000000?ooo`3oool00@3oool00440oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`3o0?ooo`/0oooo00<000000?ooo`3oool00@3oool00440oooo00<000000?ooo`3o
ool0E@3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool00@3oool00440oooo
0`00001F0?ooo`030000003oool0oooo0?l0oooo203oool2000000<0oooo000[0?ooo`<000000`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`3o0?ooo`P0oooo00<000000?ooo`3oool00@3oool002`0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0o`3oool70?ooo`030000003oool0oooo0040oooo000/0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo
0?l0oooo1P3oool00`000000oooo0?ooo`010?ooo`008@3oool7000000@0oooo00<000000?ooo`3o
ool01@3oool6000000L0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`3o0?ooo`D0
oooo00<000000?ooo`3oool00@3oool002`0oooo00<000000?ooo`3oool01@3oool01@000000oooo
0?ooo`3oool0000000P0oooo0`00001K0?ooo`030000003oool0oooo0?l0oooo0P3oool3000000<0
oooo000/0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool00000203oool00`000000
oooo0?ooo`1L0?ooo`030000003oool0oooo0?l0oooo0`3oool00`000000oooo0?ooo`010?ooo`00
;03oool00`000000oooo0?ooo`070?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool0
G@3oool00`000000oooo0?ooo`3o0?ooo`80oooo00<000000?ooo`3oool00@3oool002`0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo000000080?ooo`030000003oool0oooo05h0oooo00<0
00000?ooo`3oool0o`3oool10?ooo`030000003oool0oooo0040oooo000[0?ooo`8000002P3oool2
000000P0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`3o0?ooo`030000003oool0
oooo0040oooo000/0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`1P0?ooo`030000003oool0oooo0?h0oooo00<000000?ooo`3oool00@3oool00440
oooo0`00001Q0?ooo`030000003oool0oooo0?`0oooo0P0000030?ooo`00@@3oool00`000000oooo
0?ooo`1R0?ooo`030000003oool0oooo0?`0oooo00<000000?ooo`3oool00@3oool00440oooo00<0
00000?ooo`3oool0H`3oool00`000000oooo0?ooo`3k0?ooo`030000003oool0oooo0040oooo0011
0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0nP3oool00`000000oooo0?ooo`01
0?ooo`00@@3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0?T0oooo00<000000?oo
o`3oool00@3oool00440oooo0`00001V0?ooo`030000003oool0oooo0?L0oooo0P0000030?ooo`00
@@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0?L0oooo00<000000?ooo`3oool0
0@3oool00440oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`3f0?ooo`030000003o
ool0oooo0040oooo00110?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0m@3oool0
0`000000oooo0?ooo`010?ooo`00@@3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo
0?@0oooo00<000000?ooo`3oool00@3oool00440oooo00<000000?ooo`3oool0J`3oool00`000000
oooo0?ooo`3c0?ooo`030000003oool0oooo0040oooo00110?ooo`<00000K03oool00`000000oooo
0?ooo`3a0?ooo`8000000`3oool00440oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?oo
o`3a0?ooo`030000003oool0oooo0040oooo00110?ooo`030000003oool0oooo06h0oooo00<00000
0?ooo`3oool0l03oool00`000000oooo0?ooo`010?ooo`00@@3oool00`000000oooo0?ooo`1_0?oo
o`030000003oool0oooo0>l0oooo00<000000?ooo`3oool00@3oool00440oooo00<000000?ooo`3o
ool0L03oool00`000000oooo0?ooo`3^0?ooo`030000003oool0oooo0040oooo00110?ooo`<00000
L03oool00`000000oooo0?ooo`3]0?ooo`8000000`3oool00440oooo00<000000?ooo`3oool0L@3o
ool00`000000oooo0?ooo`3]0?ooo`030000003oool0oooo0040oooo000T0?ooo`<000000`3oool0
10000000oooo0?ooo`3oool4000000<0oooo0`0000090?ooo`030000003oool0oooo0780oooo00<0
00000?ooo`3oool0k03oool00`000000oooo0?ooo`010?ooo`009@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1c
0?ooo`030000003oool0oooo0>/0oooo00<000000?ooo`3oool00@3oool002D0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`3Z0?ooo`030000003oool0oooo0040oooo000I0?ooo`L0
00001@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo0>T0oooo00<000000?ooo`3o
ool00@3oool002D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo0`00001f0?ooo`030000003oool0oooo0>H0oooo0`0000030?ooo`009@3o
ool00`000000oooo0?ooo`080?ooo`8000001P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo07L0oooo00<000000?ooo`3oool0i`3oool00`000000oooo0?ooo`010?ooo`009@3oool0
0`000000oooo0?ooo`090?ooo`040000003oool0oooo0?ooo`<000002@3oool00`000000oooo0?oo
o`1h0?ooo`030000003oool0oooo0>H0oooo00<000000?ooo`3oool00@3oool002D0oooo00<00000
0?ooo`3oool02P3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`3oool0i@3oool00`000000oooo0?ooo`010?ooo`00903oool2000000P0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0NP3o
ool00`000000oooo0?ooo`3T0?ooo`030000003oool0oooo0040oooo000U0?ooo`030000003oool0
oooo00L0oooo0`0000040?ooo`@000001`3oool3000007/0oooo00<000000?ooo`3oool0hP3oool2
000000<0oooo00110?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0hP3oool00`00
0000oooo0?ooo`010?ooo`00@@3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0>40
oooo00<000000?ooo`3oool00@3oool00440oooo00<000000?ooo`3oool0OP3oool200000>40oooo
00<000000?ooo`3oool00@3oool00440oooo00<000000?ooo`3oool0P03oool00`000000oooo0?oo
o`3N0?ooo`030000003oool0oooo0040oooo00110?ooo`030000003oool0oooo0840oooo00<00000
0?ooo`3oool0g@3oool00`000000oooo0?ooo`010?ooo`00@@3oool300000880oooo00<000000?oo
o`3oool0f`3oool2000000<0oooo00110?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3o
ool0f`3oool00`000000oooo0?ooo`010?ooo`00@@3oool00`000000oooo0?ooo`240?ooo`030000
003oool0oooo0=X0oooo00<000000?ooo`3oool00@3oool00440oooo00<000000?ooo`3oool0Q@3o
ool00`000000oooo0?ooo`3I0?ooo`030000003oool0oooo0040oooo00110?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`010?ooo`00@@3oool30000
08L0oooo00<000000?ooo`3oool0eP3oool2000000<0oooo00110?ooo`030000003oool0oooo08P0
oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`010?ooo`00@@3oool00`000000oooo
0?ooo`290?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00@3oool00440oooo00<0
00000?ooo`3oool0RP3oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo0040oooo0011
0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`01
0?ooo`00@@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0=80oooo00<000000?oo
o`3oool00@3oool00440oooo0`00002=0?ooo`030000003oool0oooo0=00oooo0P0000030?ooo`00
2@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
d03oool00`000000oooo0?ooo`010?ooo`002@3oool3000001l0oooo0`0000030?ooo`040000003o
ool0oooo0?ooo`@00000203oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0<l0oooo
00<000000?ooo`3oool00@3oool000T0oooo00<000000?ooo`3oool00`00000M0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2@0?ooo`030000003o
ool0oooo0<h0oooo00<000000?ooo`3oool00@3oool000h0oooo0P00000L0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0
oooo0<d0oooo00<000000?ooo`3oool00@3oool000T0oooo00<000000?ooo`3oool00P00000C0?oo
o`L00000103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo0`00002B0?oo
o`030000003oool0oooo0<X0oooo0`0000030?ooo`002@3oool300000200oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3o
ool0b`3oool00`000000oooo0?ooo`010?ooo`002@3oool00`000000oooo0?ooo`03000001d0oooo
00<000000?ooo`3oool0203oool2000000P0oooo00<000000?ooo`3oool0U03oool00`000000oooo
0?ooo`3:0?ooo`030000003oool0oooo0040oooo000>0?ooo`800000703oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?oo
o`390?ooo`030000003oool0oooo0040oooo00090?ooo`030000003oool0oooo008000007P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0UP3oool0
0`000000oooo0?ooo`380?ooo`030000003oool0oooo0040oooo00090?ooo`<000007`3oool20000
00P0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo09L0oooo00<00000
0?ooo`3oool0a`3oool00`000000oooo0?ooo`010?ooo`002@3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo00L0oooo0`0000080?ooo`<00000V03oool00`000000oooo0?ooo`350?oo
o`8000000`3oool000P0oooo2@00000`0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool0a@3oool00`000000oooo0?ooo`010?ooo`001`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool0VP3oool200000<D0oooo00<000000?ooo`3oool0
0@3oool000H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo09`0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`010?ooo`002@3oool2
000000@0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0
oooo0<40oooo00<000000?ooo`3oool00@3oool000T0oooo00<000000?ooo`3oool00P3oool20000
0340oooo0`00002N0?ooo`030000003oool0oooo0;l0oooo0P0000030?ooo`002@3oool00`000000
oooo0?ooo`02000000030?ooo`000000oooo0300oooo00<000000?ooo`3oool0W`3oool00`000000
oooo0?ooo`2o0?ooo`030000003oool0oooo0040oooo00090?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo0;h0oooo
00<000000?ooo`3oool00@3oool000T0oooo0P0000040?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool0X@3oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo0040oooo0009
0?ooo`030000003oool0oooo0080oooo0P00000a0?ooo`030000003oool0oooo0:80oooo00<00000
0?ooo`3oool0_03oool00`000000oooo0?ooo`010?ooo`00@@3oool00`000000oooo0?ooo`2S0?oo
o`030000003oool0oooo0;/0oooo00<000000?ooo`3oool00@3oool000H0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0/0?ooo`<00000Y03oool200000;X0oooo0P0000030?ooo`00
1`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
YP3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo0040oooo00080?ooo`T00000<03o
ool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool00@3o
ool00440oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`2f0?ooo`030000003oool0
oooo0040oooo00110?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0]@3oool00`00
0000oooo0?ooo`010?ooo`00@@3oool300000:X0oooo00<000000?ooo`3oool0/`3oool2000000<0
oooo00110?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0/`3oool00`000000oooo
0?ooo`010?ooo`00903oool3000000<0oooo00@000000?ooo`3oool0oooo1@0000020?ooo`<00000
2@3oool00`000000oooo0?ooo`2/0?ooo`800000/`3oool00`000000oooo0?ooo`010?ooo`009@3o
ool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0
0@3oool002D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`2_0?ooo`030000003o
ool0oooo0040oooo000I0?ooo`L000001@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0
oooo0:h0oooo00<000000?ooo`3oool00@3oool002D0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo0`00002a0?ooo`030000003oool0oooo
0:/0oooo0`0000030?ooo`009@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2b0?ooo`800000[@3oool00`000000
oooo0?ooo`010?ooo`009@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<00000
2@3oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0
0@3oool002D0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`00000;0?ooo`030000
003oool0oooo0;D0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`010?ooo`00903o
ool2000000P0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0040oooo
000U0?ooo`030000003oool0oooo00L0oooo0`0000040?ooo`@000001`3oool300000;L0oooo0P00
002W0?ooo`8000000`3oool00440oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`2U
0?ooo`030000003oool0oooo0040oooo00110?ooo`030000003oool0oooo0;X0oooo00<000000?oo
o`3oool0Y03oool00`000000oooo0?ooo`010?ooo`00@@3oool00`000000oooo0?ooo`2k0?ooo`80
0000Y03oool00`000000oooo0?ooo`010?ooo`00@@3oool00`000000oooo0?ooo`2m0?ooo`030000
003oool0oooo0:40oooo00<000000?ooo`3oool00@3oool00440oooo00<000000?ooo`3oool0_P3o
ool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo0040oooo00110?ooo`<00000_`3oool2
000009l0oooo0P0000030?ooo`00@@3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo
09d0oooo00<000000?ooo`3oool00@3oool00440oooo00<000000?ooo`3oool0`P3oool2000009d0
oooo00<000000?ooo`3oool00@3oool00440oooo00<000000?ooo`3oool0a03oool00`000000oooo
0?ooo`2J0?ooo`030000003oool0oooo0040oooo00110?ooo`030000003oool0oooo0<D0oooo0P00
002J0?ooo`030000003oool0oooo0040oooo00110?ooo`<00000a`3oool00`000000oooo0?ooo`2F
0?ooo`8000000`3oool00440oooo00<000000?ooo`3oool0b03oool2000009L0oooo00<000000?oo
o`3oool00@3oool00440oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`2D0?ooo`03
0000003oool0oooo0040oooo00110?ooo`030000003oool0oooo0</0oooo0P00002D0?ooo`030000
003oool0oooo0040oooo00110?ooo`030000003oool0oooo0<d0oooo00<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`010?ooo`00@@3oool00`000000oooo0?ooo`3>0?ooo`800000T@3oool0
0`000000oooo0?ooo`010?ooo`00@@3oool300000=00oooo00<000000?ooo`3oool0S@3oool20000
00<0oooo00110?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`010?ooo`00:`3oool3000000<0oooo00@000000?ooo`3oool0oooo1@0000070?ooo`03
0000003oool0oooo0=80oooo0P00002=0?ooo`030000003oool0oooo0040oooo000/0?ooo`030000
003oool0oooo00L0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`3D0?ooo`03
0000003oool0oooo08X0oooo00<000000?ooo`3oool00@3oool002`0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0=D0oooo0P00002:0?ooo`030000
003oool0oooo0040oooo000Q0?ooo`L00000103oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00H0oooo0`00003G0?ooo`030000003oool0oooo08D0oooo0`0000030?ooo`00;03oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0f03oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo0040oooo000/0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3I0?ooo`800000QP3oool00`00
0000oooo0?ooo`010?ooo`00;03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0f`3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo0040
oooo000/0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`3L0?ooo`800000P`3oool00`000000oooo0?ooo`010?ooo`00:`3oool2000000P0oooo00D0
00000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo0=h0oooo0P0000210?ooo`030000
003oool0oooo0040oooo000/0?ooo`030000003oool0oooo00L0oooo0`0000080?ooo`<00000h03o
ool00`000000oooo0?ooo`1m0?ooo`8000000`3oool00440oooo00<000000?ooo`3oool0h@3oool2
000007h0oooo00<000000?ooo`3oool00@3oool00440oooo00<000000?ooo`3oool0h`3oool00`00
0000oooo0?ooo`1k0?ooo`030000003oool0oooo0040oooo00110?ooo`030000003oool0oooo0>@0
oooo0P00001k0?ooo`030000003oool0oooo0040oooo00110?ooo`030000003oool0oooo0>H0oooo
0P00001i0?ooo`030000003oool0oooo0040oooo00110?ooo`<00000j03oool00`000000oooo0?oo
o`1e0?ooo`8000000`3oool00440oooo00<000000?ooo`3oool0j@3oool2000007H0oooo00<00000
0?ooo`3oool00@3oool00440oooo00<000000?ooo`3oool0j`3oool2000007@0oooo00<000000?oo
o`3oool00@3oool00440oooo00<000000?ooo`3oool0k@3oool200000780oooo00<000000?ooo`3o
ool00@3oool00440oooo00<000000?ooo`3oool0k`3oool200000700oooo00<000000?ooo`3oool0
0@3oool00440oooo00<000000?ooo`3oool0l@3oool2000006h0oooo00<000000?ooo`3oool00@3o
ool00440oooo0`00003c0?ooo`800000J`3oool2000000<0oooo00110?ooo`030000003oool0oooo
0?D0oooo0P00001Z0?ooo`030000003oool0oooo0040oooo00110?ooo`030000003oool0oooo0?L0
oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`010?ooo`00@@3oool00`000000oooo
0?ooo`3h0?ooo`800000I`3oool00`000000oooo0?ooo`010?ooo`00@@3oool00`000000oooo0?oo
o`3j0?ooo`800000I@3oool00`000000oooo0?ooo`010?ooo`00@@3oool300000?`0oooo0P00001R
0?ooo`8000000`3oool00440oooo00<000000?ooo`3oool0oP3oool200000640oooo00<000000?oo
o`3oool00@3oool002@0oooo0`0000030?ooo`030000003oool0oooo0080oooo0`0000030?ooo`<0
00002@3oool00`000000oooo0?ooo`3o0?ooo`40oooo0P00001O0?ooo`030000003oool0oooo0040
oooo000U0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0?l0oooo0`3oool2000005d0oooo00<000000?ooo`3oool0
0@3oool002D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0o`3oool50?ooo`800000F`3oool00`000000oooo0?oo
o`010?ooo`006@3oool7000000D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3oool70?ooo`800000F@3oool0
0`000000oooo0?ooo`010?ooo`009@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01@3oool300000?l0oooo2@3oool2000005D0oooo0`0000030?oo
o`009@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`3o0?ooo`/0oooo0P00001E0?ooo`030000003oool0oooo0040
oooo000U0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool3000000T0oooo
00<000000?ooo`3oool0o`3oool=0?ooo`800000D`3oool00`000000oooo0?ooo`010?ooo`009@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`3o0?ooo`l0oooo0P00001A0?ooo`030000003oool0oooo0040oooo000T
0?ooo`8000002@3oool2000000D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o
0?oooa40oooo0P00001?0?ooo`030000003oool0oooo0040oooo000U0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00`3oool4000000L0oooo00<000000?ooo`3oool0o`3ooolC0?oo
o`<00000C03oool00`000000oooo0?ooo`010?ooo`00@@3oool300000?l0oooo5P3oool2000004T0
oooo0P0000030?ooo`00@@3oool00`000000oooo0?ooo`3o0?oooaP0oooo0P0000180?ooo`030000
003oool0oooo0040oooo00110?ooo`030000003oool0oooo0?l0oooo6P3oool3000004D0oooo00<0
00000?ooo`3oool00@3oool00440oooo00<000000?ooo`3oool0o`3ooolM0?ooo`800000@`3oool0
0`000000oooo0?ooo`010?ooo`00@@3oool00`000000oooo0?ooo`3o0?oooal0oooo0P0000110?oo
o`030000003oool0oooo0040oooo00110?ooo`<00000o`3ooolQ0?ooo`<00000?@3oool2000000<0
oooo00110?ooo`030000003oool0oooo0?l0oooo903oool3000003/0oooo00<000000?ooo`3oool0
0@3oool00440oooo00<000000?ooo`3oool0o`3ooolW0?ooo`800000>@3oool00`000000oooo0?oo
o`010?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooobT0oooo0`00000f0?ooo`030000003oool0
oooo0040oooo00110?ooo`030000003oool0oooo0?l0oooo;03oool3000003<0oooo00<000000?oo
o`3oool00@3oool00440oooo00<000000?ooo`3oool0o`3oool_0?ooo`<00000<03oool00`000000
oooo0?ooo`010?ooo`00@@3oool300000?l0oooo<P3oool3000002`0oooo0P0000030?ooo`00@@3o
ool00`000000oooo0?ooo`3o0?ooocD0oooo0P00000[0?ooo`030000003oool0oooo0040oooo0011
0?ooo`030000003oool0oooo0?l0oooo=`3oool3000002P0oooo00<000000?ooo`3oool00@3oool0
0440oooo00<000000?ooo`3oool0o`3ooolj0?ooo`<000009@3oool00`000000oooo0?ooo`010?oo
o`00@@3oool00`000000oooo0?ooo`3o0?ooocd0oooo0`00000R0?ooo`030000003oool0oooo0040
oooo00110?ooo`<00000o`3ooom00?ooo`@000007@3oool2000000<0oooo00110?ooo`030000003o
ool0oooo0?l0ooooA03oool4000001X0oooo00<000000?ooo`3oool00@3oool002/0oooo0`000003
0?ooo`030000003oool0oooo0080oooo0`0000080?ooo`030000003oool0oooo0?l0ooooB03oool4
000001H0oooo00<000000?ooo`3oool00@3oool002`0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooC03oool3000001<0oooo00<000000?oo
o`3oool00@3oool002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0?l0ooooC`3oool300000100oooo00<000000?ooo`3oool00@3oool00240oooo
1`0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`3o0?oooe80oooo1000000<0?ooo`030000003oool0oooo0040oooo000/0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01`3oool300000?l0ooooEP3oool3000000L0oooo0`00
00030?ooo`00;03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0o`3ooomI0?ooo`8000001`3oool00`000000oooo0?ooo`010?ooo`00;03oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooomR0?oo
o`030000003oool0oooo0040oooo000/0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`3o0?ooof80oooo00<000000?ooo`3oool00@3oool002/0oooo
0P0000090?ooo`8000002@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0540oooo
00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0580oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00;03oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00L0oooo0`0000060?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`8000000`3oool00440oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00@@3ooooo000006H000000`3oool00?l0
ooooZP3oool00001\
\>"],
  ImageRangeCache->{{{0, 424.625}, {262.063, 0}} -> {-0.437431, -1.5587, \
0.00589958, 0.00181192}}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[{
    \( (*\ 
      Find\ chi\ square\ for\ given\ H \((z)\)\ \ *) \[IndentingNewLine]\(f[
          z_] := 1/hhz[z];\)\), "\n", 
    \(\(rr[zz_] := NIntegrate[f[z], {z, 0, zz}];\)\), "\n", 
    \(\(qq = Table[rr[zz[i]], {i, 1, ndat}];\)\)}], "Input"],

Cell[BoxData[{
    \( (*\ Construct\ marginalization\ coefficients\ \((see\ astro - 
              ph/0401556\  .. )\)\ *) \[IndentingNewLine]Clear[chi2fa, 
      chi2fb, chi2fc]\), "\n", 
    \(\(chi2fa = 
        Sum[\((ld[i] - 5\ Log[10, qq[\([i]\)]*\((1 + zz[i])\)])\)^2/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\n", 
    \(\(chi2fb = 
        Sum[\((ld[i] - 
                5\ Log[10, qq[\([i]\)]*\((1 + zz[i])\)])\)/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\n", 
    \(\(chi2fc = Sum[1/\((sld[i]^2)\), {i, 1, ndat}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ Construct\ function\ after\ marginalization, \ 
      find\ same\ result\ as\ with\ mb\ minimization\ *) \
\[IndentingNewLine]chi2fm = 
      chi2fa - chi2fb^2/chi2fc\), "\[IndentingNewLine]", 
    \(dchi2p20 = chi2fm - chi2l\)}], "Input"],

Cell[BoxData[
    \(186.0897764414549`\)], "Output"],

Cell[BoxData[
    \(8.96240500640124`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ \(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(\
--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(-\(---\)\)\)\)\)\)\)\)\)\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)*) \[IndentingNewLine]\[IndentingNewLine] \
(*\ Find\ H \((z)\)\ for\ given\ slope\ s\ of\ the\ linear\ potential . \ 
            Present\ time\  = \ \(tt\ \((corresponds\ to\ a = 1)\) . \ 
              Run\ trials\ for\ initial\ condition\ for\ field\ fi\ \((f0)\)\ \
and\ initial\ time\ ti\ until\ we\ get\ field\ energy\ enf\  = \ \(0.7\ and\ \
H \((z = 0)\)\  = 
            1\ at\ present\ time\ \(\(tt\)\(.\)\)\)\)\ *) \[IndentingNewLine]\
\[IndentingNewLine] (*\ \(--\(--\(--\(--\ \ s\)\)\)\)\  = \ \(2.35\ \ \ --\) \
\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(---\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\ *) \
\[IndentingNewLine]\[IndentingNewLine]\(Clear[aa, fi, a, aad, aadd, fidas, 
        tas, f, rr, hht, hha];\)\), "\n", 
    \(aa = a[t]; \ fi = f[t];\), "\n", 
    \(\(aad = D[aa, t];\)\), "\n", 
    \(\(aadd = D[aa, {t, 2}];\)\), "\n", 
    \(\(fid = D[fi, t];\)\), "\n", 
    \(\(fidd = D[fi, {t, 2}];\)\n\), "\n", 
    \(ti = 0.0000017; \ t0 = 4;\), "\n", 
    \(\(f0 = 0.000002;\)\ \), "\n", 
    \(om0m = 0.3; \ ss = 2.35;\), "\n", 
    \(\(eq1 = 
        aadd/aa\  \[Equal] \ 
          fid^2\ \  + \ \ ss\ fi\  - \ om0m/\((2\ aa^3)\);\)\), "\n", 
    \(\(eq2 = 
        fidd\ \  + \ \ \ 3\ \ fid\ \((aad/aa)\)\  - \ ss \[Equal] 
          0;\)\), "\n", 
    \(\(eqb1 = f[ti] == f0;\)\), "\n", 
    \(\(eqb2 = \(f'\)[ti] == 0;\)\), "\n", 
    \(\(eqb3 = 
        a[ti] \[Equal] \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((2/3)\);\)\), "\n", 
    \(\(eqb4 = \(a'\)[
            ti] \[Equal] \((2/
                3)\)\ \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((\(-1\)/
                  3)\);\)\), "\n", 
    \(\(sol2 = 
        NDSolve[{eq1, eq2, eqb1, eqb2, eqb3, eqb4}, {aa, fi}, {t, ti, t0}, 
          MaxSteps \[Rule] 10000000];\)\), "\n", 
    \(\(asol = Part[Evaluate[a[t] /. sol2], 1];\)\), "\n", 
    \(\(fsol = 
        Part[Evaluate[f[t] /. sol2], 1];\)\[IndentingNewLine]\), "\n", 
    \(\(dfsol = D[fsol, t];\)\), "\n", 
    \(\(enf = \(-0.5\)\ dfsol^2\  + \ ss\ fsol;\)\), "\n", 
    \(\(as[t1_] := asol\  /. \ t -> t1\ ;\)\), "\n", 
    \(\(tt = Part[FindRoot[as[t] == 1, {t, 0.1}], 1, 2];\)\), "\n", 
    \(\(tas[a_] := 
        Part[FindRoot[as[t] \[Equal] a, {t, 0.3}], 1, 2];\)\), "\n", 
    \(\(hht[t1_] := D[asol, t]/asol\  /. \ t -> t1\ ;\)\), "\n", 
    \(\(hha[a_] := hht[tas[a]];\)\), "\n", 
    \(\(hhz[z_] := hha[1/\((z + 1)\)];\)\), "\n", 
    \(enf\  /. \ t \[Rule] tt\), "\n", 
    \(hhz[0]\), "\[IndentingNewLine]", 
    \(\(hhzt = 
        Sqrt[\((1 - om0m)\) + om0m \((1 + z)\)^3] /. 
          om0m \[Rule] 0.3;\)\), "\[IndentingNewLine]", 
    \(\(Plot[{hhz[z], hhzt}, {z, 0, 1}];\)\), "\[IndentingNewLine]", 
    \(\(enf = \(-0.5\)\ dfsol^2\  + \ ss\ fsol;\)\), "\n", 
    \(\(ppf = \(-0.5\)\ dfsol^2\  - \ ss\ fsol;\)\), "\n", 
    \(\(wft[t1_] := ppf/enf\  /. \ t -> t1\ ;\)\ \), "\n", 
    \(\(wfa[a_] := wft[tas[a]];\)\), "\n", 
    \(\(wfz[z_] := wfa[1/\((z + 1)\)];\)\), "\n", 
    \(\(plw235p = 
        Plot[wfz[z], {z, 0, 2}, Frame \[Rule] True, PlotRange \[Rule] All, 
          FrameLabel \[Rule] {"\<z\>", "\<w(z)\>"}];\)\)}], "Input"],

Cell[BoxData[
    \(0.6957445165340244`\)], "Output"],

Cell[BoxData[
    \(1.0052840592651324`\)], "Output"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.744453 0.765483 [
[.21429 .00853 -10.7813 -17.8125 ]
[.21429 .00853 10.7813 0 ]
[.40476 .00853 -10.7813 -17.8125 ]
[.40476 .00853 10.7813 0 ]
[.59524 .00853 -10.7813 -17.8125 ]
[.59524 .00853 10.7813 0 ]
[.78571 .00853 -10.7813 -17.8125 ]
[.78571 .00853 10.7813 0 ]
[.97619 .00853 -5.53125 -17.8125 ]
[.97619 .00853 5.53125 0 ]
[.01131 .17413 -21.5625 -8.90625 ]
[.01131 .17413 0 8.90625 ]
[.01131 .32722 -21.5625 -8.90625 ]
[.01131 .32722 0 8.90625 ]
[.01131 .48032 -21.5625 -8.90625 ]
[.01131 .48032 0 8.90625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .02103 m
.21429 .02728 L
s
gsave
.21429 .00853 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 .02103 m
.40476 .02728 L
s
gsave
.40476 .00853 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 .02103 m
.59524 .02728 L
s
gsave
.59524 .00853 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 .02103 m
.78571 .02728 L
s
gsave
.78571 .00853 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 .02103 m
.97619 .02728 L
s
gsave
.97619 .00853 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .02103 m
.07143 .02478 L
s
.11905 .02103 m
.11905 .02478 L
s
.16667 .02103 m
.16667 .02478 L
s
.2619 .02103 m
.2619 .02478 L
s
.30952 .02103 m
.30952 .02478 L
s
.35714 .02103 m
.35714 .02478 L
s
.45238 .02103 m
.45238 .02478 L
s
.5 .02103 m
.5 .02478 L
s
.54762 .02103 m
.54762 .02478 L
s
.64286 .02103 m
.64286 .02478 L
s
.69048 .02103 m
.69048 .02478 L
s
.7381 .02103 m
.7381 .02478 L
s
.83333 .02103 m
.83333 .02478 L
s
.88095 .02103 m
.88095 .02478 L
s
.92857 .02103 m
.92857 .02478 L
s
.25 Mabswid
0 .02103 m
1 .02103 L
s
.02381 .17413 m
.03006 .17413 L
s
gsave
.01131 .17413 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
.02381 .32722 m
.03006 .32722 L
s
gsave
.01131 .32722 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
.02381 .48032 m
.03006 .48032 L
s
gsave
.01131 .48032 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .0593 m
.02756 .0593 L
s
.02381 .09758 m
.02756 .09758 L
s
.02381 .13585 m
.02756 .13585 L
s
.02381 .2124 m
.02756 .2124 L
s
.02381 .25067 m
.02756 .25067 L
s
.02381 .28895 m
.02756 .28895 L
s
.02381 .3655 m
.02756 .3655 L
s
.02381 .40377 m
.02756 .40377 L
s
.02381 .44205 m
.02756 .44205 L
s
.02381 .51859 m
.02756 .51859 L
s
.02381 .55687 m
.02756 .55687 L
s
.02381 .59514 m
.02756 .59514 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .02507 m
.04262 .02173 L
.06244 .0189 L
.08255 .01676 L
.09396 .01589 L
.09905 .01557 L
.10458 .01529 L
.11004 .01506 L
.11508 .01491 L
.11756 .01485 L
.11989 .0148 L
.12232 .01476 L
.12361 .01475 L
.125 .01473 L
.12623 .01472 L
.12737 .01472 L
.12863 .01472 L
.12933 .01472 L
.12997 .01472 L
.13114 .01472 L
.1324 .01472 L
.1336 .01473 L
.1347 .01474 L
.13675 .01477 L
.13901 .0148 L
.14357 .0149 L
.14881 .01506 L
.15378 .01527 L
.16308 .01577 L
.1731 .01648 L
.184 .01747 L
.20377 .01982 L
.22478 .02307 L
.26253 .03085 L
.30273 .04174 L
.34142 .05463 L
.38256 .07074 L
.42218 .08843 L
.46029 .1073 L
.50085 .12922 L
.5399 .15196 L
.5814 .17773 L
.62138 .20399 L
.65985 .23046 L
.70076 .25982 L
.74017 .28916 L
.77805 .31827 L
.81839 .35019 L
.85722 .38173 L
.89849 .41608 L
Mistroke
.93826 .44992 L
.97619 .48286 L
Mfstroke
.02381 .02103 m
.06244 .03544 L
.10458 .05216 L
.14415 .0688 L
.18221 .08565 L
.22272 .10449 L
.26171 .1235 L
.30316 .14462 L
.34309 .16585 L
.3815 .18707 L
.42237 .21048 L
.46172 .23383 L
.49955 .257 L
.53984 .28243 L
.57861 .30764 L
.61984 .3352 L
.65954 .36246 L
.69774 .38935 L
.73838 .41864 L
.77751 .44749 L
.81909 .47884 L
.85916 .50969 L
.89771 .53996 L
.93871 .57278 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{424.188, 262.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006X00011R000`400?l00000o`00003oo`3ooonY
0?ooo`00o`3ooonY0?ooo`00o`3ooonY0?ooo`00o`3ooonY0?ooo`00o`3ooonY0?ooo`00o`3ooonY
0?ooo`00H`3oool3000000<0oooo00@000000?ooo`3oool0oooo1@00000m0?ooo`<000000`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo0`0000030?ooo`030000003oool0
oooo0080oooo0`00000n0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`<00000@`3oool3
000000d0oooo001R0?ooo`050000003oool0oooo0?ooo`0000001`3oool010000000oooo0?ooo`00
000l0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0k0?ooo`050000
003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000003`0oooo00D000000?oo
o`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`000000@`3oool00`000000oooo0?oo
o`0<0?ooo`00HP3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0?03o
ool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0>`3oool01@000000oooo
0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo0000000l0?ooo`050000003oool0oooo
0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000004<0oooo00<000000?ooo`3oool0303o
ool00680oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo03/0oooo00D0
00000?ooo`3oool0oooo000000050?ooo`H00000?03oool01@000000oooo0?ooo`3oool0000000H0
oooo00D000000?ooo`3oool0oooo0000000l0?ooo`050000003oool0oooo0?ooo`0000001P3oool0
1@000000oooo0?ooo`3oool0000004<0oooo00<000000?ooo`3oool0303oool00680oooo00D00000
0?ooo`3oool0oooo000000090?ooo`030000003oool0oooo03/0oooo00D000000?ooo`3oool0oooo
000000050?ooo`050000003oool0oooo0?ooo`000000?@3oool01@000000oooo0?ooo`3oool00000
00H0oooo00D000000?ooo`3oool0oooo0000000l0?ooo`050000003oool0oooo0?ooo`0000001`3o
ool00`000000oooo000000140?ooo`030000003oool0oooo00`0oooo001R0?ooo`050000003oool0
oooo0?ooo`0000002P3oool00`000000oooo0?ooo`0j0?ooo`050000003oool0oooo0?ooo`000000
1P3oool010000000oooo0?ooo`00000m0?ooo`050000003oool0oooo0?ooo`0000001P3oool20000
0080oooo00<000000?ooo`3oool0>P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0<0?ooo`00HP3oool01@000000oooo0?ooo`3oool0
000000X0oooo00<000000?ooo`3oool0>P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<0
00000?ooo`000000?@3oool01@000000oooo0?ooo`3oool0000000H0oooo00@000000?ooo`000000
0000?@3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`000000A03oool00`00
0000oooo0?ooo`0<0?ooo`00HP3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?oo
o`3oool0>P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`000000?@3oool0
1@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0?@3oool01@000000oooo0?oo
o`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000130?ooo`030000003oool0oooo00`0
oooo001R0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool00000
03`0oooo00D000000?ooo`3oool0oooo000000080?ooo`800000?@3oool01@000000oooo0?ooo`3o
ool0000000P0oooo00<000000?ooo`3oool0?03oool01@000000oooo0?ooo`3oool0000000H0oooo
00D000000?ooo`3oool0oooo000000120?ooo`8000003P3oool001d0oooo00<000000?ooo`3oool0
@`3oool3000000P0oooo0`00000n0?ooo`<000002P3oool00`000000oooo0?ooo`0l0?ooo`<00000
2P3oool2000003d0oooo0`0000080?ooo`<00000A03oool00`000000oooo0?ooo`0<0?ooo`007@3o
ool00`000000oooo0?ooo`3o0?ooohT0oooo000M0?ooo`030000003oool0oooo0?l0ooooR@3oool0
01d0oooo00<000000?ooo`3oool0o`3ooon90?ooo`007@3oool00`000000oooo0?ooo`3o0?ooohT0
oooo000M0?ooo`030000003oool0oooo0?l0ooooR@3oool001d0oooo00<000000?ooo`3oool04P3o
oolY00000?l0ooooCP3oool001d0oooo00<000000?ooo`3oool02P3oool8000002T0oooo1P00003o
0?ooodP0oooo000D0?ooool00000T@0000040?ooo`007@3oool00`000000oooo00000004000000`0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100
oooo1`00000<0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00/0oooo000M0?ooo`<0000000@0oooo000000000000
0000303oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`040?ooo`D000001`3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0;0?ooo`00
7@3oool00`000000oooo0?ooo`040?ooo`<00000@`3oool00`000000oooo0?ooo`090?ooo`D00000
>`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`070?ooo`800000DP3o
ool400000?l0oooo:P3oool001d0oooo00<000000?ooo`3oool02@3oool3000005<0oooo1000003o
0?ooobH0oooo000M0?ooo`030000003oool0oooo00`0oooo0`00001D0?ooo`@00000o`3ooolR0?oo
o`007@3oool00`000000oooo0?ooo`0?0?ooo`800000EP3oool400000?l0oooo7P3oool001d0oooo
00<000000?ooo`3oool04@3oool3000005L0oooo1000003o0?oooaX0oooo000M0?ooo`030000003o
ool0oooo01@0oooo0P00001I0?ooo`800000o`3ooolH0?ooo`007@3oool00`000000oooo0?ooo`0F
0?ooo`800000F@3oool300000?l0oooo5@3oool001d0oooo00<000000?ooo`3oool0603oool30000
05T0oooo0P00003o0?oooa<0oooo000M0?ooo`030000003oool0oooo01/0oooo0P00001I0?ooo`<0
0000o`3oool@0?ooo`007@3oool00`000000oooo0?ooo`0M0?ooo`<00000F@3oool200000?l0oooo
3P3oool001d0oooo00<000000?ooo`3oool0803oool2000005T0oooo0`00003o0?ooo`/0oooo000M
0?ooo`<000008P3oool3000005T0oooo0`00003o0?ooo`P0oooo000M0?ooo`030000003oool0oooo
02D0oooo0`00001I0?ooo`<00000o`3oool50?ooo`007@3oool00`000000oooo0?ooo`0X0?ooo`80
0000FP3oool200000?l0oooo0`3oool001d0oooo00<000000?ooo`3oool0:P3oool3000005T0oooo
0`00003o0?ooo`007@3oool00`000000oooo0?ooo`0]0?ooo`<00000F@3oool300000?`0oooo000M
0?ooo`030000003oool0oooo0300oooo0P00001J0?ooo`<00000n@3oool001d0oooo00<000000?oo
o`3oool0<P3oool2000005/0oooo0P00003g0?ooo`007@3oool00`000000oooo0?ooo`0d0?ooo`80
0000F`3oool200000?D0oooo000M0?ooo`030000003oool0oooo03H0oooo0P00001K0?ooo`800000
l`3oool001d0oooo00<000000?ooo`3oool0>03oool2000005/0oooo0`00003`0?ooo`007@3oool0
0`000000oooo0?ooo`0j0?ooo`800000G03oool200000>h0oooo000M0?ooo`030000003oool0oooo
03`0oooo0`00001K0?ooo`800000k03oool001d0oooo00<000000?ooo`3oool0?`3oool2000005/0
oooo0P00003Z0?ooo`007@3oool00`000000oooo0?ooo`110?ooo`800000F`3oool200000>P0oooo
000M0?ooo`030000003oool0oooo04<0oooo0P00001K0?ooo`800000iP3oool001d0oooo00<00000
0?ooo`3oool0A@3oool3000005X0oooo0P00003T0?ooo`007@3oool3000004P0oooo0P00001J0?oo
o`800000hP3oool001d0oooo00<000000?ooo`3oool0BP3oool2000005X0oooo0P00003P0?ooo`00
7@3oool00`000000oooo0?ooo`1<0?ooo`800000FP3oool200000=h0oooo000M0?ooo`030000003o
ool0oooo04h0oooo0P00001J0?ooo`800000g03oool001d0oooo00<000000?ooo`3oool0D03oool2
000005X0oooo00<000000?ooo`3oool0f@3oool001d0oooo00<000000?ooo`3oool0DP3oool20000
05T0oooo0P00003I0?ooo`007@3oool00`000000oooo0?ooo`1D0?ooo`800000F@3oool200000=L0
oooo000M0?ooo`030000003oool0oooo05H0oooo0P00001I0?ooo`800000e@3oool001d0oooo00<0
00000?ooo`3oool0F03oool2000005T0oooo0P00003C0?ooo`007@3oool00`000000oooo0?ooo`1J
0?ooo`800000F@3oool200000=40oooo000M0?ooo`030000003oool0oooo05`0oooo0P00001I0?oo
o`800000c`3oool001d0oooo00<000000?ooo`3oool0GP3oool2000005T0oooo0P00003=0?ooo`00
7@3oool00`000000oooo0?ooo`1P0?ooo`800000F@3oool200000</0oooo000M0?ooo`030000003o
ool0oooo0680oooo0P00001I0?ooo`800000b@3oool001d0oooo00<000000?ooo`3oool0I03oool2
000005T0oooo0P0000370?ooo`007@3oool3000006H0oooo0P00001I0?ooo`800000a@3oool001d0
oooo00<000000?ooo`3oool0J03oool2000005T0oooo00<000000?ooo`3oool0`P3oool001d0oooo
00<000000?ooo`3oool0JP3oool2000005P0oooo0P0000320?ooo`007@3oool00`000000oooo0?oo
o`1/0?ooo`800000F03oool200000<00oooo000M0?ooo`030000003oool0oooo06h0oooo0P00001H
0?ooo`800000_P3oool001d0oooo00<000000?ooo`3oool0L03oool2000005P0oooo0P00002l0?oo
o`007@3oool00`000000oooo0?ooo`1b0?ooo`800000F03oool00`000000oooo0?ooo`2i0?ooo`00
7@3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo05H0oooo0P00002i0?ooo`007@3o
ool00`000000oooo0?ooo`1e0?ooo`800000F03oool00`000000oooo0?ooo`2f0?ooo`007@3oool0
0`000000oooo0?ooo`1g0?ooo`800000E`3oool200000;H0oooo000M0?ooo`030000003oool0oooo
07T0oooo0P00001G0?ooo`030000003oool0oooo0;<0oooo000M0?ooo`030000003oool0oooo07/0
oooo0P00001F0?ooo`030000003oool0oooo0;80oooo00070?ooo`<000000`3oool010000000oooo
0?ooo`3oool5000000L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`1D0?ooo`80
0000/P3oool000P0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000070?ooo`03
0000003oool0oooo07h0oooo0P00001F0?ooo`030000003oool0oooo0:l0oooo00080?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`200?ooo`800000
E@3oool200000:l0oooo00080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3o
ool400000840oooo0P00001E0?ooo`030000003oool0oooo0:`0oooo00080?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`240?ooo`800000E03oool2
00000:`0oooo00080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`260?ooo`800000E03oool00`000000oooo0?ooo`2Y0?ooo`00203oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0R03oool2000005<0
oooo0P00002Y0?ooo`00203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0RP3oool2000005<0oooo00<000000?ooo`3oool0YP3oool000L0oooo0P00
00080?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`2<0?ooo`030000
003oool0oooo0540oooo0P00002V0?ooo`00203oool00`000000oooo0?ooo`070?ooo`<00000203o
ool00`000000oooo0?ooo`2=0?ooo`800000D`3oool200000:@0oooo000M0?ooo`030000003oool0
oooo08l0oooo0P00001C0?ooo`030000003oool0oooo0:40oooo000M0?ooo`030000003oool0oooo
0940oooo00<000000?ooo`3oool0D@3oool200000:40oooo000M0?ooo`030000003oool0oooo0980
oooo0P00001C0?ooo`030000003oool0oooo09h0oooo000M0?ooo`030000003oool0oooo09@0oooo
0P00001B0?ooo`800000WP3oool001d0oooo00<000000?ooo`3oool0UP3oool200000580oooo0P00
002L0?ooo`007@3oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0540oooo00<00000
0?ooo`3oool0V@3oool001d0oooo00<000000?ooo`3oool0V@3oool200000580oooo0P00002I0?oo
o`007@3oool00`000000oooo0?ooo`2K0?ooo`800000DP3oool00`000000oooo0?ooo`2F0?ooo`00
7@3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0
U@3oool001d0oooo0`00002N0?ooo`800000D@3oool2000009D0oooo000M0?ooo`030000003oool0
oooo0:00oooo0P00001A0?ooo`030000003oool0oooo0980oooo000M0?ooo`030000003oool0oooo
0:80oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`2A0?ooo`007@3oool00`000000
oooo0?ooo`2S0?ooo`800000D03oool200000940oooo000M0?ooo`030000003oool0oooo0:D0oooo
0P00001@0?ooo`030000003oool0oooo08h0oooo000M0?ooo`030000003oool0oooo0:L0oooo00<0
00000?ooo`3oool0CP3oool00`000000oooo0?ooo`2=0?ooo`007@3oool00`000000oooo0?ooo`2X
0?ooo`800000C`3oool2000008d0oooo000M0?ooo`030000003oool0oooo0:X0oooo0P00001?0?oo
o`030000003oool0oooo08X0oooo000M0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3o
ool0C@3oool2000008X0oooo000M0?ooo`030000003oool0oooo0:d0oooo0P00001?0?ooo`030000
003oool0oooo08L0oooo000M0?ooo`030000003oool0oooo0:l0oooo0P00001>0?ooo`800000Q`3o
ool001d0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0
oooo08@0oooo000M0?ooo`030000003oool0oooo0;80oooo0P00001>0?ooo`800000Q03oool001d0
oooo00<000000?ooo`3oool0]03oool2000004h0oooo0P0000220?ooo`007@3oool00`000000oooo
0?ooo`2f0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0O`3oool001d0oooo0`00
002g0?ooo`800000CP3oool2000007l0oooo000M0?ooo`030000003oool0oooo0;T0oooo0P00001>
0?ooo`030000003oool0oooo07`0oooo000M0?ooo`030000003oool0oooo0;/0oooo00<000000?oo
o`3oool0C03oool2000007`0oooo000M0?ooo`030000003oool0oooo0;`0oooo0P00001>0?ooo`03
0000003oool0oooo07T0oooo000M0?ooo`030000003oool0oooo0;h0oooo0P00001=0?ooo`030000
003oool0oooo07P0oooo000M0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0B`3o
ool2000007P0oooo000M0?ooo`030000003oool0oooo0<40oooo0P00001=0?ooo`030000003oool0
oooo07D0oooo000M0?ooo`030000003oool0oooo0<<0oooo0P00001<0?ooo`030000003oool0oooo
07@0oooo000M0?ooo`030000003oool0oooo0<D0oooo0P00001;0?ooo`800000M03oool001d0oooo
00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0740oooo
000M0?ooo`030000003oool0oooo0<P0oooo0P00001;0?ooo`030000003oool0oooo0700oooo000M
0?ooo`030000003oool0oooo0<X0oooo0P00001:0?ooo`800000L03oool001d0oooo00<000000?oo
o`3oool0c03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo06d0oooo000M0?ooo`03
0000003oool0oooo0<d0oooo0P00001:0?ooo`030000003oool0oooo06`0oooo000M0?ooo`030000
003oool0oooo0<l0oooo00<000000?ooo`3oool0B03oool2000006`0oooo000M0?ooo`<00000d03o
ool00`000000oooo0?ooo`190?ooo`030000003oool0oooo06T0oooo000M0?ooo`030000003oool0
oooo0=40oooo0P00001:0?ooo`030000003oool0oooo06P0oooo000M0?ooo`030000003oool0oooo
0=<0oooo00<000000?ooo`3oool0B03oool2000006P0oooo000M0?ooo`030000003oool0oooo0=@0
oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`1U0?ooo`007@3oool00`000000oooo
0?ooo`3E0?ooo`800000BP3oool00`000000oooo0?ooo`1T0?ooo`007@3oool00`000000oooo0?oo
o`3G0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0H`3oool001d0oooo00<00000
0?ooo`3oool0f03oool00`000000oooo0?ooo`180?ooo`800000H`3oool001d0oooo00<000000?oo
o`3oool0f@3oool2000004X0oooo00<000000?ooo`3oool0H03oool001d0oooo00<000000?ooo`3o
ool0f`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo05l0oooo000M0?ooo`030000
003oool0oooo0=`0oooo0P0000190?ooo`030000003oool0oooo05h0oooo000M0?ooo`030000003o
ool0oooo0=h0oooo00<000000?ooo`3oool0A`3oool2000005h0oooo000M0?ooo`030000003oool0
oooo0=l0oooo0P0000190?ooo`030000003oool0oooo05/0oooo00070?ooo`<000000`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0h@3oool00`00
0000oooo0?ooo`170?ooo`030000003oool0oooo05X0oooo00080?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3R0?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool0F@3oool000P0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0><0oooo0P0000180?ooo`800000F@3oool000P0oooo00<0
00000?ooo`3oool01@3oool6000000L0oooo1000003T0?ooo`030000003oool0oooo04L0oooo00<0
00000?ooo`3oool0EP3oool000P0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3o
ool0000000P0oooo00<000000?ooo`3oool0iP3oool2000004P0oooo00<000000?ooo`3oool0E@3o
ool000P0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000080?ooo`030000003o
ool0oooo0>P0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`1D0?ooo`00203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool0j@3oool2
000004L0oooo00<000000?ooo`3oool0D`3oool000P0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo000000080?ooo`030000003oool0oooo0>/0oooo00<000000?ooo`3oool0A@3oool20000
05<0oooo00070?ooo`8000002P3oool2000000P0oooo00<000000?ooo`3oool0k03oool2000004L0
oooo00<000000?ooo`3oool0D03oool000P0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0>h0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`1?0?ooo`007@3oool00`000000oooo0?ooo`3_0?ooo`800000AP3oool00`000000oooo0?oo
o`1>0?ooo`007@3oool00`000000oooo0?ooo`3a0?ooo`800000A@3oool2000004h0oooo000M0?oo
o`030000003oool0oooo0?<0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1;0?oo
o`007@3oool00`000000oooo0?ooo`3d0?ooo`800000A@3oool00`000000oooo0?ooo`1:0?ooo`00
7@3oool00`000000oooo0?ooo`3f0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0
B@3oool001d0oooo00<000000?ooo`3oool0m`3oool2000004@0oooo0P0000190?ooo`007@3oool0
0`000000oooo0?ooo`3i0?ooo`800000A03oool00`000000oooo0?ooo`160?ooo`007@3oool00`00
0000oooo0?ooo`3k0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0A@3oool001d0
oooo00<000000?ooo`3oool0o03oool2000004<0oooo00<000000?ooo`3oool0A03oool001d0oooo
0`00003n0?ooo`030000003oool0oooo0440oooo0P0000140?ooo`007@3oool00`000000oooo0?oo
o`3o0?ooo`800000@`3oool00`000000oooo0?ooo`110?ooo`007@3oool00`000000oooo0?ooo`3o
0?ooo`80oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`100?ooo`007@3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0o0?oo
o`007@3oool00`000000oooo0?ooo`3o0?ooo`@0oooo0P0000120?ooo`800000?`3oool001d0oooo
00<000000?ooo`3oool0o`3oool60?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
?03oool001d0oooo00<000000?ooo`3oool0o`3oool70?ooo`800000@P3oool00`000000oooo0?oo
o`0k0?ooo`007@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0j0?ooo`007@3oool00`000000oooo0?ooo`3o0?ooo`X0oooo0P0000110?oo
o`800000>P3oool001d0oooo00<000000?ooo`3oool0o`3oool<0?ooo`030000003oool0oooo0400
oooo00<000000?ooo`3oool0=`3oool001d0oooo00<000000?ooo`3oool0o`3oool=0?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool0=P3oool001d0oooo00<000000?ooo`3oool0o`3o
ool>0?ooo`800000@@3oool00`000000oooo0?ooo`0e0?ooo`007@3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0d0?ooo`007@3oool00`00
0000oooo0?ooo`3o0?oooa40oooo00<000000?ooo`3oool0?`3oool2000003@0oooo000M0?ooo`03
0000003oool0oooo0?l0oooo4P3oool200000440oooo00<000000?ooo`3oool0<@3oool001d0oooo
0`00003o0?oooa@0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0`0?ooo`007@3o
ool00`000000oooo0?ooo`3o0?oooaD0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`0_0?ooo`007@3oool00`000000oooo0?ooo`3o0?oooaH0oooo0P0000100?ooo`030000003oool0
oooo02h0oooo000M0?ooo`030000003oool0oooo0?l0oooo603oool00`000000oooo0?ooo`0n0?oo
o`800000;P3oool001d0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030000003oool0oooo03l0
oooo00<000000?ooo`3oool0:`3oool001d0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`800000
@03oool00`000000oooo0?ooo`0Z0?ooo`007@3oool00`000000oooo0?ooo`3o0?oooa`0oooo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`0Y0?ooo`007@3oool00`000000oooo0?ooo`3o
0?oooad0oooo0P00000o0?ooo`800000:@3oool001d0oooo00<000000?ooo`3oool0o`3ooolO0?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool09P3oool001d0oooo00<000000?ooo`3o
ool0o`3ooolP0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool09@3oool001d0oooo
00<000000?ooo`3oool0o`3ooolQ0?ooo`800000?`3oool00`000000oooo0?ooo`0T0?ooo`007@3o
ool00`000000oooo0?ooo`3o0?ooob<0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?oo
o`0S0?ooo`007@3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool0?@3oool2
000002<0oooo000M0?ooo`030000003oool0oooo0?l0oooo9@3oool2000003l0oooo00<000000?oo
o`3oool0803oool001d0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool07`3oool001d0oooo0`00003o0?ooobP0oooo00<000000?ooo`3oool0
?@3oool00`000000oooo0?ooo`0N0?ooo`007@3oool00`000000oooo0?ooo`3o0?ooobT0oooo0P00
000n0?ooo`8000007P3oool001d0oooo00<000000?ooo`3oool0o`3oool[0?ooo`030000003oool0
oooo03d0oooo00<000000?ooo`3oool06`3oool001d0oooo00<000000?ooo`3oool0o`3oool/0?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool06P3oool001d0oooo00<000000?ooo`3o
ool0o`3oool]0?ooo`800000?P3oool00`000000oooo0?ooo`0I0?ooo`007@3oool00`000000oooo
0?ooo`3o0?ooobl0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0H0?ooo`007@3o
ool00`000000oooo0?ooo`3o0?oooc00oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`0G0?ooo`007@3oool00`000000oooo0?ooo`3o0?oooc40oooo0P00000m0?ooo`030000003oool0
oooo01H0oooo000M0?ooo`030000003oool0oooo0?l0oooo<`3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo01D0oooo000M0?ooo`030000003oool0oooo0?l0oooo=03oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo01@0oooo000M0?ooo`030000003oool0oooo0?l0oooo
=@3oool2000003`0oooo0P00000D0?ooo`007@3oool00`000000oooo0?ooo`3o0?ooocL0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0A0?ooo`001`3oool3000000<0oooo00<00000
0?ooo`3oool00P3oool3000000P0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0403oool000P0oooo00<000000?ooo`3oool01P3oool01@00
0000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0o`3oooli0?ooo`800000?03oool0
0`000000oooo0?ooo`0?0?ooo`00203oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo
0?ooo`0000001`3oool00`000000oooo0?ooo`3o0?oooc/0oooo00<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`0>0?ooo`00203oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo
0?ooo`0000001`3oool00`000000oooo0?ooo`3o0?oooc`0oooo00<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`0=0?ooo`00203oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo
0?ooo`0000001`3oool400000?l0oooo?03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo00`0oooo00080?ooo`030000003oool0oooo00H0oooo0P0000020?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0o`3oooln0?ooo`800000>`3oool00`000000oooo0?ooo`0;0?oo
o`00203oool00`000000oooo0?ooo`060?ooo`040000003oool00000000000P0oooo00<000000?oo
o`3oool0o`3ooom00?ooo`030000003oool0oooo04H0oooo00080?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?oood40oooo00<000000?ooo`3o
ool0A@3oool000L0oooo0P00000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
o`3ooom20?ooo`800000A@3oool000P0oooo00<000000?ooo`3oool02@3oool2000000L0oooo00<0
00000?ooo`3oool0o`3ooom40?ooo`030000003oool0oooo0480oooo000M0?ooo`030000003oool0
oooo0?l0ooooA@3oool00`000000oooo0?ooo`110?ooo`007@3oool00`000000oooo0?ooo`3o0?oo
odH0oooo0P0000110?ooo`007@3oool00`000000oooo0?ooo`3o0?ooodP0oooo00<000000?ooo`3o
ool0?P3oool001d0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo03d0oooo
000M0?ooo`030000003oool0oooo0?l0ooooBP3oool2000003d0oooo000M0?ooo`030000003oool0
oooo0?l0ooooC03oool00`000000oooo0?ooo`0j0?ooo`007@3oool00`000000oooo0?ooo`3o0?oo
odd0oooo00<000000?ooo`3oool0>@3oool001d0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`80
0000>@3oool001d0oooo00<000000?ooo`3oool0o`3ooom@0?ooo`030000003oool0oooo03H0oooo
000M0?ooo`<00000o`3ooomA0?ooo`030000003oool0oooo03D0oooo000M0?ooo`030000003oool0
oooo0?l0ooooDP3oool00`000000oooo0?ooo`0d0?ooo`007@3oool00`000000oooo0?ooo`3o0?oo
oe<0oooo0P00000d0?ooo`007@3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3o
ool0<@3oool001d0oooo00<000000?ooo`3oool0o`3ooomF0?ooo`030000003oool0oooo0300oooo
000M0?ooo`030000003oool0oooo0?l0ooooE`3oool00`000000oooo0?ooo`0_0?ooo`007@3oool0
0`000000oooo0?ooo`3o0?oooeP0oooo0P00000_0?ooo`007@3oool00`000000oooo0?ooo`3o0?oo
oeX0oooo00<000000?ooo`3oool0;03oool001d0oooo00<000000?ooo`3oool0o`3ooomK0?ooo`03
0000003oool0oooo02/0oooo000M0?ooo`030000003oool0oooo0?l0ooooG03oool00`000000oooo
0?ooo`0Z0?ooo`007@3oool00`000000oooo0?ooo`3o0?oooed0oooo0P00000Z0?ooo`007@3oool0
0`000000oooo0?ooo`3o0?oooel0oooo00<000000?ooo`3oool09`3oool001d0oooo00<000000?oo
o`3oool0o`3ooomP0?ooo`030000003oool0oooo02H0oooo000M0?ooo`030000003oool0oooo0?l0
ooooH@3oool2000002H0oooo000M0?ooo`030000003oool0oooo0?l0ooooH`3oool00`000000oooo
0?ooo`0S0?ooo`007@3oool300000?l0ooooI03oool00`000000oooo0?ooo`0R0?ooo`007@3oool0
0`000000oooo0?ooo`3o0?ooofD0oooo0P00000R0?ooo`007@3oool00`000000oooo0?ooo`3o0?oo
ofL0oooo00<000000?ooo`3oool07`3oool001d0oooo00<000000?ooo`3oool0o`3ooomX0?ooo`03
0000003oool0oooo01h0oooo000M0?ooo`030000003oool0oooo0?l0ooooJ@3oool2000001h0oooo
000M0?ooo`030000003oool0oooo0?l0ooooJ`3oool00`000000oooo0?ooo`0K0?ooo`007@3oool0
0`000000oooo0?ooo`3o0?ooof`0oooo00<000000?ooo`3oool06P3oool001d0oooo00<000000?oo
o`3oool0o`3ooom]0?ooo`030000003oool0oooo01T0oooo000M0?ooo`030000003oool0oooo0?l0
ooooKP3oool00`000000oooo0?ooo`0H0?ooo`007@3oool00`000000oooo0?ooo`3o0?ooofl0oooo
0P00000H0?ooo`007@3oool00`000000oooo0?ooo`3o0?ooog40oooo00<000000?ooo`3oool05@3o
ool001d0oooo00<000000?ooo`3oool0o`3ooomb0?ooo`030000003oool0oooo01@0oooo000M0?oo
o`030000003oool0oooo0?l0ooooL`3oool00`000000oooo0?ooo`0C0?ooo`007@3oool00`000000
oooo0?ooo`3o0?ooog@0oooo00<000000?ooo`3oool04P3oool001d0oooo00<000000?ooo`3oool0
o`3ooome0?ooo`030000003oool0oooo0140oooo000M0?ooo`<00000o`3ooomf0?ooo`030000003o
ool0oooo0100oooo000M0?ooo`030000003oool0oooo0?l0ooooM`3oool200000100oooo000M0?oo
o`030000003oool0oooo0?l0ooooN@3oool00`000000oooo0?ooo`0=0?ooo`007@3oool00`000000
oooo0?ooo`3o0?ooogX0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0
o`3ooomk0?ooo`030000003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo0?l0ooooR@3o
ool001d0oooo00<000000?ooo`3oool0o`3ooon90?ooo`007@3oool00`000000oooo0?ooo`3o0?oo
ohT0oooo000M0?ooo`030000003oool0oooo0?l0ooooR@3oool001d0oooo00<000000?ooo`3oool0
o`3ooon90?ooo`00\
\>"],
  ImageRangeCache->{{{0, 423.188}, {261.188, 0}} -> {-0.0788218, 0.92539, \
0.00262961, 0.00327165}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.476191 3.72717 1.86053 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.2619 -0.0125 -10.7813 -17.8125 ]
[.2619 -0.0125 10.7813 0 ]
[.5 -0.0125 -5.53125 -17.8125 ]
[.5 -0.0125 5.53125 0 ]
[.7381 -0.0125 -10.7813 -17.8125 ]
[.7381 -0.0125 10.7813 0 ]
[.97619 -0.0125 -5.53125 -17.8125 ]
[.97619 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.125 -35.625 ]
[.5 -0.0125 5.125 -17.8125 ]
[-0.0125 .0061 -20.75 -8.90625 ]
[-0.0125 .0061 0 8.90625 ]
[-0.0125 .09913 -38.3125 -8.90625 ]
[-0.0125 .09913 0 8.90625 ]
[-0.0125 .19216 -31.25 -8.90625 ]
[-0.0125 .19216 0 8.90625 ]
[-0.0125 .28518 -38.3125 -8.90625 ]
[-0.0125 .28518 0 8.90625 ]
[-0.0125 .37821 -31.25 -8.90625 ]
[-0.0125 .37821 0 8.90625 ]
[-0.0125 .47124 -38.3125 -8.90625 ]
[-0.0125 .47124 0 8.90625 ]
[-0.0125 .56426 -31.25 -8.90625 ]
[-0.0125 .56426 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -56.125 -14.7188 ]
[-0.01875 .30902 -38.3125 14.7188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.125 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0061 m
.00625 .0061 L
s
gsave
-0.0125 .0061 -81.75 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .09913 m
.00625 .09913 L
s
gsave
-0.0125 .09913 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.95) show
1.000 setlinewidth
grestore
0 .19216 m
.00625 .19216 L
s
gsave
-0.0125 .19216 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
1.000 setlinewidth
grestore
0 .28518 m
.00625 .28518 L
s
gsave
-0.0125 .28518 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.85) show
1.000 setlinewidth
grestore
0 .37821 m
.00625 .37821 L
s
gsave
-0.0125 .37821 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
1.000 setlinewidth
grestore
0 .47124 m
.00625 .47124 L
s
gsave
-0.0125 .47124 -99.3125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
1.000 setlinewidth
grestore
0 .56426 m
.00625 .56426 L
s
gsave
-0.0125 .56426 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .02471 m
.00375 .02471 L
s
0 .04332 m
.00375 .04332 L
s
0 .06192 m
.00375 .06192 L
s
0 .08053 m
.00375 .08053 L
s
0 .11774 m
.00375 .11774 L
s
0 .13634 m
.00375 .13634 L
s
0 .15495 m
.00375 .15495 L
s
0 .17355 m
.00375 .17355 L
s
0 .21076 m
.00375 .21076 L
s
0 .22937 m
.00375 .22937 L
s
0 .24797 m
.00375 .24797 L
s
0 .26658 m
.00375 .26658 L
s
0 .30379 m
.00375 .30379 L
s
0 .3224 m
.00375 .3224 L
s
0 .341 m
.00375 .341 L
s
0 .35961 m
.00375 .35961 L
s
0 .39682 m
.00375 .39682 L
s
0 .41542 m
.00375 .41542 L
s
0 .43403 m
.00375 .43403 L
s
0 .45263 m
.00375 .45263 L
s
0 .48984 m
.00375 .48984 L
s
0 .50845 m
.00375 .50845 L
s
0 .52705 m
.00375 .52705 L
s
0 .54566 m
.00375 .54566 L
s
0 .58287 m
.00375 .58287 L
s
0 .60147 m
.00375 .60147 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -122.938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.7188 12.9063 translate
90 rotate
-75.7188 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.063 17.500 moveto
(H) show
77.625 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.875 17.500 moveto
(L) show
88.438 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0061 m
1 .0061 L
s
.99375 .09913 m
1 .09913 L
s
.99375 .19216 m
1 .19216 L
s
.99375 .28518 m
1 .28518 L
s
.99375 .37821 m
1 .37821 L
s
.99375 .47124 m
1 .47124 L
s
.99375 .56426 m
1 .56426 L
s
.125 Mabswid
.99625 .02471 m
1 .02471 L
s
.99625 .04332 m
1 .04332 L
s
.99625 .06192 m
1 .06192 L
s
.99625 .08053 m
1 .08053 L
s
.99625 .11774 m
1 .11774 L
s
.99625 .13634 m
1 .13634 L
s
.99625 .15495 m
1 .15495 L
s
.99625 .17355 m
1 .17355 L
s
.99625 .21076 m
1 .21076 L
s
.99625 .22937 m
1 .22937 L
s
.99625 .24797 m
1 .24797 L
s
.99625 .26658 m
1 .26658 L
s
.99625 .30379 m
1 .30379 L
s
.99625 .3224 m
1 .3224 L
s
.99625 .341 m
1 .341 L
s
.99625 .35961 m
1 .35961 L
s
.99625 .39682 m
1 .39682 L
s
.99625 .41542 m
1 .41542 L
s
.99625 .43403 m
1 .43403 L
s
.99625 .45263 m
1 .45263 L
s
.99625 .48984 m
1 .48984 L
s
.99625 .50845 m
1 .50845 L
s
.99625 .52705 m
1 .52705 L
s
.99625 .54566 m
1 .54566 L
s
.99625 .58287 m
1 .58287 L
s
.99625 .60147 m
1 .60147 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .60332 m
.06244 .48398 L
.10458 .373 L
.14415 .28842 L
.18221 .2241 L
.22272 .17151 L
.26171 .13343 L
.30316 .10337 L
.34309 .08199 L
.3815 .06661 L
.42237 .05435 L
.46172 .04547 L
.49955 .03892 L
.53984 .03354 L
.57861 .02952 L
.61984 .02618 L
.65954 .02364 L
.69774 .02168 L
.73838 .02 L
.77751 .01868 L
.81909 .01754 L
.85916 .01662 L
.89771 .01589 L
.93871 .01523 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{424.188, 262.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006X00011R000`400?l00000o`00003oo`3ooonY
0?ooo`00o`3ooonY0?ooo`00o`3ooonY0?ooo`00o`3ooonY0?ooo`00o`3ooonY0?ooo`00o`3ooonY
0?ooo`00k`3oool600000;<0oooo003`0?ooo`050000003oool0oooo0?ooo`000000/`3oool00?40
oooo00<000000?ooo`3oool0]03oool00?40oooo00<000000?ooo`3oool0]03oool00?80oooo00<0
00000?ooo`3oool0/`3oool00>l0oooo00D000000?ooo`3oool0oooo0000002d0?ooo`00k`3oool6
00000;<0oooo003o0?ooojT0oooo003o0?ooojT0oooo003o0?ooojT0oooo003o0?ooojT0oooo003o
0?ooojT0oooo003o0?ooojT0oooo003o0?ooojT0oooo003o0?ooojT0oooo003o0?ooojT0oooo003o
0?ooojT0oooo00170?ooo`<00000C03oool3000000<0oooo00@000000?ooo`3oool0oooo0`00001>
0?ooo`<00000C@3oool3000000<0oooo00@000000?ooo`3oool0oooo0`00001<0?ooo`D000002@3o
ool004H0oooo00D000000?ooo`3oool0oooo0000001:0?ooo`050000003oool0oooo0?ooo`000000
2@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`1:0?ooo`040000003oool0oooo000000T0oooo00160?ooo`050000
003oool0oooo0?ooo`000000BP3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`090?ooo`00AP3oool01@000000oooo0?ooo`3oool00000
04X0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool0C@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool0203oool004H0oooo00D000000?ooo`3oool0oooo0000001:0?ooo`050000003oool0
oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04d0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00P0oooo0016
0?ooo`050000003oool0oooo0?ooo`000000BP3oool01@000000oooo0?ooo`3oool0000000T0oooo
00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`070?ooo`00AP3oool01@000000oooo0?oo
o`3oool0000004X0oooo00D000000?ooo`3oool0oooo000000060?ooo`<00000C`3oool00`000000
oooo0?ooo`1=0?ooo`030000003oool0oooo00H0oooo0`00001@0?ooo`030000003oool0oooo00L0
oooo00160?ooo`050000003oool0oooo0?ooo`000000BP3oool01@000000oooo0?ooo`3oool00000
00H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`00AP3oool01@000000
oooo0?ooo`3oool0000004X0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0
oooo04d0oooo0P00001>0?ooo`8000002@3oool00`000000oooo0?ooo`1;0?ooo`050000003oool0
oooo0?ooo`0000002@3oool004L0oooo0`00001<0?ooo`<00000203oool4000004d0oooo00<00000
0?ooo`3oool0C@3oool00`000000oooo0?ooo`070?ooo`@00000B`3oool3000000X0oooo003o0?oo
ojT0oooo003o0?ooojT0oooo003o0?ooojT0oooo003o0?ooojT0oooo003o0?ooojT0oooo003o0?oo
ojT0oooo000c0?ooo`D00000o`3oooma0?ooo`00=03oool010000000oooo0?ooo`0000080?ooool0
0000I`0000020?ooo`00=@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo
0@0000010?ooo`40oooo000Y0?ooo`L000001P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00D0oooo0@0000010?ooo`40oooo000f0?ooo`030000003oool0oooo00L0oooo0`000005
0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`1C
0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool00`3oool300000080oooo000g0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooomS0?ooo`4000000@3oool10?oo
o`00=`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0ooooH`3oool100000040
oooo0@3oool003L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooob/0oooo
<@0000070?ooo`4000000@3oool10?ooo`00<`3oool01@000000oooo0?ooo`3oool0000000P0oooo
00<000000?ooo`3oool0o`3oool>0?oooad00000>03oool100000040oooo0@3oool003@0oooo0`00
00090?ooo`030000003oool0oooo0?00oooo7@00001E0?ooo`4000000@3oool10?ooo`00@03oool2
00000><0oooo3P00001a0?ooo`8000000P3oool00400oooo00<000000?ooo`3oool0e03oool>0000
0800oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo0<H0oooo3P00002>0?ooo`40
00000@3oool10?ooo`00@03oool00`000000oooo0?ooo`2k0?ooo`/00000W03oool100000040oooo
0@3oool00400oooo00<000000?ooo`3oool0/`3oool800000:L0oooo0@0000010?ooo`40oooo0010
0?ooo`030000003oool0oooo0:d0oooo1P00002_0?ooo`4000000@3oool10?ooo`00@03oool00`00
0000oooo0?ooo`2Y0?ooo`@00000]@3oool100000040oooo0@3oool00400oooo0P00002V0?ooo`@0
0000^03oool200000080oooo00100?ooo`030000003oool0oooo0:00oooo1@00002m0?ooo`400000
0@3oool10?ooo`00@03oool00`000000oooo0?ooo`2L0?ooo`@00000`P3oool100000040oooo0@3o
ool00400oooo00<000000?ooo`3oool0U`3oool500000<H0oooo0@0000010?ooo`40oooo00100?oo
o`030000003oool0oooo09<0oooo1000003;0?ooo`4000000@3oool10?ooo`00@03oool00`000000
oooo0?ooo`2?0?ooo`@00000c`3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0
R`3oool400000=<0oooo0@0000010?ooo`40oooo00100?ooo`800000R03oool400000=H0oooo0P00
00020?ooo`00@03oool00`000000oooo0?ooo`240?ooo`<00000f`3oool100000040oooo0@3oool0
0400oooo00<000000?ooo`3oool0PP3oool200000=h0oooo0@0000010?ooo`40oooo00100?ooo`03
0000003oool0oooo0800oooo0P00003P0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo
0?ooo`1m0?ooo`<00000hP3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0N`3o
ool200000>D0oooo0@0000010?ooo`40oooo00100?ooo`800000NP3oool200000>H0oooo0P000002
0?ooo`00@03oool00`000000oooo0?ooo`1g0?ooo`800000j@3oool100000040oooo0@3oool00400
oooo00<000000?ooo`3oool0M@3oool200000>/0oooo0@0000010?ooo`40oooo000S0?ooo`<00000
0`3oool010000000oooo0?ooo`3oool2000000D0oooo0`0000090?ooo`030000003oool0oooo07<0
oooo0P00003]0?ooo`4000000@3oool10?ooo`00903oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1a0?ooo`800000
k`3oool100000040oooo0@3oool002@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0K`3oool200000?40oooo0@00
00010?ooo`40oooo000H0?ooo`L000001@3oool00`000000oooo0?ooo`070?ooo`@000001P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo06d0oooo0P00003c0?ooo`4000000@3oool1
0?ooo`00903oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000001P3oool0
0`000000oooo0?ooo`050?ooo`<00000J`3oool200000?<0oooo0`0000020?ooo`00903oool00`00
0000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo06T0oooo0P00003g0?ooo`4000000@3oool10?ooo`00903oool00`00
0000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000P3oool3000000T0oooo00<00000
0?ooo`3oool0I`3oool200000?T0oooo0@0000010?ooo`40oooo000T0?ooo`030000003oool0oooo
00H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0IP3oool00`000000oooo0?ooo`3i0?ooo`4000000@3oool10?ooo`008`3oool20000
00P0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0I@3oool00`000000oooo0?ooo`3j0?ooo`4000000@3oool10?ooo`00903oool00`00
0000oooo0?ooo`070?ooo`<00000103oool4000000L0oooo00<000000?ooo`3oool0H`3oool20000
0?d0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo0680oooo00<000000?ooo`3o
ool0o@3oool100000040oooo0@3oool00400oooo0P00001R0?ooo`030000003oool0oooo0?d0oooo
0P0000020?ooo`00@03oool00`000000oooo0?ooo`1O0?ooo`800000o`3oool20?ooo`4000000@3o
ool10?ooo`00@03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0?l0oooo0P3oool1
00000040oooo0@3oool00400oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`3o0?oo
o`<0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo05/0oooo0P00003o0?ooo`H0
oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0
o`3oool60?ooo`4000000@3oool10?ooo`00@03oool2000005X0oooo00<000000?ooo`3oool0o`3o
ool60?ooo`8000000P3oool00400oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3o
0?ooo`P0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool0o`3oool90?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo0?l0oooo2P3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0
E@3oool00`000000oooo0?ooo`3o0?ooo`/0oooo0@0000010?ooo`40oooo00100?ooo`030000003o
ool0oooo05@0oooo00<000000?ooo`3oool0o`3oool<0?ooo`4000000@3oool10?ooo`00@03oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0?l0oooo3@3oool100000040oooo0@3oool0
0400oooo0P00001C0?ooo`030000003oool0oooo0?l0oooo3@3oool200000080oooo00100?ooo`03
0000003oool0oooo0540oooo00<000000?ooo`3oool0o`3oool?0?ooo`4000000@3oool10?ooo`00
@03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0?l0oooo403oool100000040oooo
0@3oool00400oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`3o0?oooa40oooo0@00
00010?ooo`40oooo00100?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0o`3ooolB
0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
0?l0oooo4`3oool100000040oooo0@3oool00400oooo0P00001=0?ooo`030000003oool0oooo0?l0
oooo4`3oool200000080oooo00100?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
o`3ooolE0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo0?l0oooo5@3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`3o0?oooaH0oooo0@0000010?ooo`40oooo000Z0?ooo`<000000`3oool01000
0000oooo0?ooo`3oool2000000X0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3o
0?oooaL0oooo0@0000010?ooo`40oooo000[0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0?l0oooo603oool10000
0040oooo0@3oool002/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool0o`3ooolH0?ooo`4000000@3oool10?ooo`00
7`3oool7000000D0oooo00<000000?ooo`3oool01`3oool4000000L0oooo0`0000170?ooo`030000
003oool0oooo0?l0oooo5`3oool300000080oooo000[0?ooo`030000003oool0oooo00H0oooo00D0
00000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
o`3ooolJ0?ooo`4000000@3oool10?ooo`00:`3oool00`000000oooo0?ooo`060?ooo`050000003o
ool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0?l0oooo
6`3oool100000040oooo0@3oool002/0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?oo
o`3oool0000000L0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`3o0?oooa/0oooo
0@0000010?ooo`40oooo000[0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo
000000070?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`400000
0@3oool10?ooo`00:P3oool2000000P0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000
003oool0oooo04<0oooo00<000000?ooo`3oool0o`3ooolM0?ooo`4000000@3oool10?ooo`00:`3o
ool00`000000oooo0?ooo`070?ooo`<00000203oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo0?l0oooo7P3oool100000040oooo0@3oool00400oooo0P0000130?ooo`030000003oool0
oooo0?l0oooo7@3oool200000080oooo00100?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0o`3ooolO0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo0?l0oooo803oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`3o0?ooob40oooo0@0000010?ooo`40oooo00100?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`4000000@3oool10?ooo`00@03oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0?l0oooo8P3oool100000040oooo0@3oool0
0400oooo0P00000n0?ooo`030000003oool0oooo0?l0oooo8P3oool200000080oooo00100?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`4000000@3oool10?ooo`00
@03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0?l0oooo903oool100000040oooo
0@3oool00400oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`3o0?ooob@0oooo0@00
00010?ooo`40oooo00100?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooolU
0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo
0?l0oooo9P3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`3o0?ooobH0oooo0@0000010?ooo`40oooo00100?ooo`800000>P3oool00`000000oooo
0?ooo`3o0?ooobH0oooo0P0000020?ooo`00@03oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo0?l0oooo9`3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`3o0?ooobP0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0o`3ooolY0?ooo`4000000@3oool10?ooo`00@03oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo0?l0oooo:@3oool100000040oooo0@3oool00400oooo
00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`3o0?ooobX0oooo0@0000010?ooo`40oooo
00100?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0o`3oool[0?ooo`4000000@3o
ool10?ooo`00@03oool2000003H0oooo00<000000?ooo`3oool0o`3ooolZ0?ooo`8000000P3oool0
0400oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`3o0?ooob`0oooo0@0000010?oo
o`40oooo00100?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0o`3oool/0?ooo`40
00000@3oool10?ooo`001`3oool00`000000oooo0?ooo`0I0?ooo`<000000`3oool00`000000oooo
0?ooo`020?ooo`<000000`3oool3000000T0oooo00<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`3o0?ooobd0oooo0@0000010?ooo`40oooo00070?ooo`<000006P3oool00`000000oooo0?oo
o`060?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool0o`3oool^0?ooo`4000000@3oool10?ooo`001`3o
ool00`000000oooo0?ooo`03000001L0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?oo
o`3oool0000000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo0?l0oooo;P3oool100000040oooo0@3oool000`0oooo0P00000:0?ooo`L000001@3o
ool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo
0?ooo`050?ooo`<00000<@3oool00`000000oooo0?ooo`3o0?ooobd0oooo0`0000020?ooo`001`3o
ool00`000000oooo0?ooo`02000001P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000
00070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`3o0?ooobl0oooo0@0000010?ooo`40oooo00070?ooo`<000006P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo0?l0oooo<03oool100000040oooo0@3oool000L0oooo00<000000?oo
o`3oool00`00000G0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000000`3oool30000
00T0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`3o0?oooc00oooo0@0000010?oo
o`40oooo000<0?ooo`8000005P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool0o`3ooola0?ooo`4000000@3oool10?ooo`001`3oool00`000000oooo0?ooo`02000001L0
oooo0P0000080?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo02l0oooo00<000000?ooo`3oool0o`3ooola0?ooo`4000000@3oool10?oo
o`001`3oool3000001X0oooo00<000000?ooo`3oool01`3oool3000000@0oooo100000070?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool0o`3ooolb0?ooo`4000000@3oool10?ooo`00
1`3oool00`000000oooo0?ooo`0f0?ooo`800000;`3oool00`000000oooo0?ooo`3o0?oooc40oooo
0P0000020?ooo`001P3oool900000340oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`3o0?oooc<0oooo0@0000010?ooo`40oooo00050?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0oooo<`3oool1
00000040oooo0@3oool000@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0o`3ooold0?ooo`4000000@3oool10?oo
o`00@03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0?l0oooo=03oool100000040
oooo0@3oool000L0oooo0P0000040?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`3o0?ooocD0oooo0@0000010?ooo`40oooo00070?ooo`030000003o
ool0oooo0080oooo0P00000b0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0o`3o
oole0?ooo`4000000@3oool10?ooo`001`3oool00`000000oooo0?ooo`02000000030?ooo`000000
oooo0340oooo0P00000[0?ooo`030000003oool0oooo0?l0oooo=@3oool200000080oooo00070?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo0?l0oooo=P3oool100000040oooo0@3oool000L0oooo0P0000040?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?ooocL0
oooo0@0000010?ooo`40oooo00070?ooo`030000003oool0oooo0080oooo0P00000b0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0o`3ooolg0?ooo`4000000@3oool10?ooo`00103o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`3o0?ooocL0oooo0@0000010?ooo`40oooo00050?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo0?l0oooo>03oool100000040oooo0@3oool000H0oooo2@00000a0?ooo`800000:@3oool00`00
0000oooo0?ooo`3o0?ooocL0oooo0P0000020?ooo`00@03oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo0?l0oooo>@3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`3o0?ooocT0oooo0@0000010?ooo`40oooo00100?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool0o`3ooolj0?ooo`4000000@3oool10?ooo`00@03oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0?l0oooo>P3oool100000040oooo0@3oool0
0400oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3o0?oooc/0oooo0@0000010?oo
o`40oooo00100?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0o`3ooolk0?ooo`40
00000@3oool10?ooo`00@03oool2000002D0oooo00<000000?ooo`3oool0o`3ooolk0?ooo`800000
0P3oool00400oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`3o0?oooc`0oooo0@00
00010?ooo`40oooo00100?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0o`3ooolm
0?ooo`4000000@3oool10?ooo`00:P3oool3000000<0oooo00<000000?ooo`3oool00P3oool30000
00P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`3o0?ooocd0oooo0@0000010?oo
o`40oooo000[0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000070?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool0o`3oooln0?ooo`4000000@3oool10?oo
o`00:`3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000001`3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo0?l0oooo?P3oool100000040oooo0@3oool001l0
oooo1`0000050?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000070?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool0o`3oooln0?ooo`4000000@3oool10?oo
o`00:`3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000P0oooo0`00000Q0?ooo`03
0000003oool0oooo0?l0oooo?@3oool300000080oooo000[0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0oooo
?`3oool100000040oooo0@3oool002/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000
00080?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0o`3ooom00?ooo`4000000@3o
ool10?ooo`00:`3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000001`3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0?l0oooo@03oool100000040oooo0@3o
ool002X0oooo0P0000080?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo0?l0oooo@03oool100000040oooo0@3oool002/0oooo00<00000
0?ooo`3oool01`3oool3000000P0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3o
0?oood40oooo0@0000010?ooo`40oooo00100?ooo`800000803oool00`000000oooo0?ooo`3o0?oo
od00oooo0P0000020?ooo`00@03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0
oooo@@3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`3o0?oood80oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0o`3ooom20?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo0?l0oooo@`3oool100000040oooo0@3oool00400oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`3o0?oood<0oooo0@0000010?ooo`40oooo00100?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0o`3ooom30?ooo`4000000@3oool10?ooo`00
@03oool2000001d0oooo00<000000?ooo`3oool0o`3ooom30?ooo`8000000P3oool00400oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`3o0?oood@0oooo0@0000010?ooo`40oooo0010
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0o`3ooom40?ooo`4000000@3oool1
0?ooo`00@03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0?l0ooooA@3oool10000
0040oooo0@3oool00400oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`3o0?ooodD0
oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
o`3ooom60?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo0?l0ooooAP3oool100000040oooo0@3oool00400oooo0P00000K0?ooo`030000003oool0
oooo0?l0ooooA@3oool200000080oooo00100?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0o`3ooom70?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo0?l0ooooA`3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`3o0?ooodL0oooo0@0000010?ooo`40oooo00100?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0o`3ooom80?ooo`4000000@3oool10?ooo`00@03oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0?l0ooooB03oool100000040oooo0@3oool0
0400oooo0P00000H0?ooo`030000003oool0oooo0?l0ooooB03oool200000080oooo00100?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0o`3ooom90?ooo`4000000@3oool10?ooo`00
@03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0?l0ooooB@3oool100000040oooo
0@3oool002<0oooo0`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool3000000T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3o0?ooodX0oooo0@00
00010?ooo`40oooo000T0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0o`3ooom:
0?ooo`4000000@3oool10?ooo`00903oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
0?l0ooooBP3oool100000040oooo0@3oool001P0oooo1`0000050?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0o`3ooom;0?ooo`4000000@3oool10?ooo`00903oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool3000001D0oooo
00<000000?ooo`3oool0o`3ooom90?ooo`<000000P3oool002@0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`3o0?oood`0oooo0@0000010?ooo`40oooo000T0?ooo`030000003oool0
oooo00T0oooo00@000000?ooo`3oool0oooo0`0000090?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0o`3ooom<0?ooo`4000000@3oool10?ooo`00903oool00`000000oooo0?ooo`09
0?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo0?l0ooooC03oool100000040oooo0@3oool002<0oooo0P0000070?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0o`3ooom=0?ooo`4000000@3oool10?ooo`00903oool00`000000oooo0?ooo`06
0?ooo`D000000`3oool4000000L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3o
0?ooodd0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0o`3ooom=0?ooo`4000000@3oool10?ooo`00@03oool2000001<0oooo00<000000?ooo`3o
ool0o`3ooom=0?ooo`8000000P3oool00400oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0o`3ooom>0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0?l0ooooC`3oool100000040oooo0@3oool00400oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`3o0?ooodl0oooo0@0000010?ooo`40oooo00100?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0o`3ooom?0?ooo`4000000@3oool10?ooo`00
@03oool200000140oooo00<000000?ooo`3oool0o`3ooom?0?ooo`8000000P3oool00400oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?oooe00oooo0@0000010?ooo`40oooo0010
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0o`3ooom@0?ooo`4000000@3oool1
0?ooo`00@03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooD@3oool10000
0040oooo0@3oool00400oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?oooe40
oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
o`3ooomA0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0?l0ooooDP3oool100000040oooo0@3oool00400oooo0P00000?0?ooo`030000003oool0
oooo0?l0ooooD@3oool200000080oooo00100?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0o`3ooomB0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0?l0ooooD`3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`3o0?oooe<0oooo0@0000010?ooo`40oooo00100?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0o`3ooomC0?ooo`4000000@3oool10?ooo`00@03oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooE03oool100000040oooo0@3oool0
0400oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?oooe@0oooo0@0000010?oo
o`40oooo00100?ooo`8000003@3oool00`000000oooo0?ooo`3o0?oooe<0oooo0P0000020?ooo`00
@03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooE@3oool100000040oooo
0@3oool00400oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?oooeD0oooo0@00
00010?ooo`40oooo000Z0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?oooeD0oooo0@000001
0?ooo`40oooo000[0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooEP3oool100000040oooo0@3oool002/0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0o`3ooomF0?ooo`4000000@3oool10?ooo`007`3oool7000000D0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`<000002P3oool00`000000oooo
0?ooo`3o0?oooe@0oooo0`0000020?ooo`00:`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?oooeL0oooo0@00
00010?ooo`40oooo000[0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0ooooE`3oool100000040oooo0@3oool0
02/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`4000000@3oool10?ooo`00:`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`3o0?oooeP0oooo0@0000010?ooo`40oooo000Z0?ooo`8000001`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`3o0?oooeP0oooo0@0000010?ooo`40oooo000[0?ooo`030000003oool0oooo00H0oooo1@00
00070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooomH0?ooo`4000000@3o
ool10?ooo`00@03oool2000000P0oooo00<000000?ooo`3oool0o`3ooomH0?ooo`8000000P3oool0
0400oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oooeT0oooo0@0000010?oo
o`40oooo00100?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooomI0?ooo`40
00000@3oool10?ooo`00@03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo
FP3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`3o0?oooeX0oooo0@0000010?ooo`40oooo00100?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0o`3ooomJ0?ooo`4000000@3oool10?ooo`00@03oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0?l0ooooF`3oool100000040oooo0@3oool00400oooo0P0000060?ooo`03
0000003oool0oooo0?l0ooooFP3oool200000080oooo00100?ooo`030000003oool0oooo0?l0oooo
H`3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool0o`3ooomS0?ooo`4000000@3o
ool10?ooo`00@03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0580oooo00<00000
0?ooo`3oool0DP3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0580oooo00<00000
0?ooo`3oool01@3oool100000040oooo0@3oool00400oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool10000
0040oooo0@3oool00400ooooo`00001W00000080oooo0000\
\>"],
  ImageRangeCache->{{{0, 423.188}, {261.188, 0}} -> {-0.426181, -2.06353, \
0.00587032, 0.00150247}}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[{
    \( (*\ 
      Find\ chi\ square\ for\ given\ H \((z)\)\ \ *) \[IndentingNewLine]\(f[
          z_] := 1/hhz[z];\)\), "\n", 
    \(\(rr[zz_] := NIntegrate[f[z], {z, 0, zz}];\)\), "\n", 
    \(\(qq = Table[rr[zz[i]], {i, 1, ndat}];\)\)}], "Input"],

Cell[BoxData[{
    \( (*\ Construct\ marginalization\ coefficients\ \((see\ astro - 
              ph/0401556\  .. )\)\ *) \[IndentingNewLine]Clear[chi2fa, 
      chi2fb, chi2fc]\), "\n", 
    \(\(chi2fa = 
        Sum[\((ld[i] - 5\ Log[10, qq[\([i]\)]*\((1 + zz[i])\)])\)^2/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\n", 
    \(\(chi2fb = 
        Sum[\((ld[i] - 
                5\ Log[10, qq[\([i]\)]*\((1 + zz[i])\)])\)/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\n", 
    \(\(chi2fc = Sum[1/\((sld[i]^2)\), {i, 1, ndat}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ Construct\ function\ after\ marginalization, \ 
      find\ same\ result\ as\ with\ mb\ minimization\ *) \
\[IndentingNewLine]chi2fm = 
      chi2fa - chi2fb^2/chi2fc\), "\[IndentingNewLine]", 
    \(dchi2p23 = chi2fm - chi2l\)}], "Input"],

Cell[BoxData[
    \(202.80352906975895`\)], "Output"],

Cell[BoxData[
    \(25.676157634705305`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ \ Construct\ Plot\ for\ chi^2\ vs\ the\ slope\ ss\ \ \ *) \)\(\
\[IndentingNewLine]\)\(chi2alp = 
      Table[{{0, 0}, {0.2, dchi2p02}, {0.5, dchi2p05}, {0.7, dchi2p07}, {1, 
            dchi2p10}, {1.5, dchi2p15}, {2, dchi2p20}, {2.35, 
            dchi2p23}}]\)\)\)], "Input"],

Cell[BoxData[
    \({{0, 
        0}, {0.2`, \(-0.019113908521831036`\)}, {0.5`, \
\(-0.14523190073668957`\)}, {0.7`, \(-0.20727176778018475`\)}, {1, \
\(-0.036296041682362556`\)}, {1.5`, 1.46034980379045`}, {2, 
        8.96240500640124`}, {2.35`, 25.676157634705305`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(plch2p = 
      ListPlot[chi2alp, PlotJoined \[Rule] True, Frame \[Rule] True, 
        PlotRange \[Rule] All, 
        FrameLabel \[Rule] {"\<s\>", \
\*"\"\<\!\(\[CapitalDelta]\[Chi]\^2\)\>\""}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.405268 0.0194286 0.0227406 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.22644 -0.0125 -10.7813 -17.8125 ]
[.22644 -0.0125 10.7813 0 ]
[.42908 -0.0125 -5.53125 -17.8125 ]
[.42908 -0.0125 5.53125 0 ]
[.63171 -0.0125 -10.7813 -17.8125 ]
[.63171 -0.0125 10.7813 0 ]
[.83435 -0.0125 -5.53125 -17.8125 ]
[.83435 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -4.75 -35.625 ]
[.5 -0.0125 4.75 -17.8125 ]
[-0.0125 .01943 -11.0625 -8.90625 ]
[-0.0125 .01943 0 8.90625 ]
[-0.0125 .13313 -11.0625 -8.90625 ]
[-0.0125 .13313 0 8.90625 ]
[-0.0125 .24683 -18.125 -8.90625 ]
[-0.0125 .24683 0 8.90625 ]
[-0.0125 .36054 -18.125 -8.90625 ]
[-0.0125 .36054 0 8.90625 ]
[-0.0125 .47424 -18.125 -8.90625 ]
[-0.0125 .47424 0 8.90625 ]
[-0.0125 .58794 -18.125 -8.90625 ]
[-0.0125 .58794 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -35.9375 -13.0938 ]
[-0.01875 .30902 -18.125 13.0938 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.22644 0 m
.22644 .00625 L
s
gsave
.22644 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.42908 0 m
.42908 .00625 L
s
gsave
.42908 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.63171 0 m
.63171 .00625 L
s
gsave
.63171 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.83435 0 m
.83435 .00625 L
s
gsave
.83435 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.06434 0 m
.06434 .00375 L
s
.10486 0 m
.10486 .00375 L
s
.14539 0 m
.14539 .00375 L
s
.18592 0 m
.18592 .00375 L
s
.26697 0 m
.26697 .00375 L
s
.3075 0 m
.3075 .00375 L
s
.34802 0 m
.34802 .00375 L
s
.38855 0 m
.38855 .00375 L
s
.4696 0 m
.4696 .00375 L
s
.51013 0 m
.51013 .00375 L
s
.55066 0 m
.55066 .00375 L
s
.59119 0 m
.59119 .00375 L
s
.67224 0 m
.67224 .00375 L
s
.71277 0 m
.71277 .00375 L
s
.75329 0 m
.75329 .00375 L
s
.79382 0 m
.79382 .00375 L
s
.87487 0 m
.87487 .00375 L
s
.9154 0 m
.9154 .00375 L
s
.95593 0 m
.95593 .00375 L
s
.99645 0 m
.99645 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -65.75 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
68.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01943 m
.00625 .01943 L
s
gsave
-0.0125 .01943 -72.0625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13313 m
.00625 .13313 L
s
gsave
-0.0125 .13313 -72.0625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .24683 m
.00625 .24683 L
s
gsave
-0.0125 .24683 -79.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .36054 m
.00625 .36054 L
s
gsave
-0.0125 .36054 -79.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
0 .47424 m
.00625 .47424 L
s
gsave
-0.0125 .47424 -79.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .58794 m
.00625 .58794 L
s
gsave
-0.0125 .58794 -79.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04217 m
.00375 .04217 L
s
0 .06491 m
.00375 .06491 L
s
0 .08765 m
.00375 .08765 L
s
0 .11039 m
.00375 .11039 L
s
0 .15587 m
.00375 .15587 L
s
0 .17861 m
.00375 .17861 L
s
0 .20135 m
.00375 .20135 L
s
0 .22409 m
.00375 .22409 L
s
0 .26957 m
.00375 .26957 L
s
0 .29232 m
.00375 .29232 L
s
0 .31506 m
.00375 .31506 L
s
0 .3378 m
.00375 .3378 L
s
0 .38328 m
.00375 .38328 L
s
0 .40602 m
.00375 .40602 L
s
0 .42876 m
.00375 .42876 L
s
0 .4515 m
.00375 .4515 L
s
0 .49698 m
.00375 .49698 L
s
0 .51972 m
.00375 .51972 L
s
0 .54246 m
.00375 .54246 L
s
0 .5652 m
.00375 .5652 L
s
0 .61068 m
.00375 .61068 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -101.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
74.0938 12.9063 translate
90 rotate
-74.0938 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Dc) show
79.688 11.875 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
85.188 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.22644 .61178 m
.22644 .61803 L
s
.42908 .61178 m
.42908 .61803 L
s
.63171 .61178 m
.63171 .61803 L
s
.83435 .61178 m
.83435 .61803 L
s
.125 Mabswid
.06434 .61428 m
.06434 .61803 L
s
.10486 .61428 m
.10486 .61803 L
s
.14539 .61428 m
.14539 .61803 L
s
.18592 .61428 m
.18592 .61803 L
s
.26697 .61428 m
.26697 .61803 L
s
.3075 .61428 m
.3075 .61803 L
s
.34802 .61428 m
.34802 .61803 L
s
.38855 .61428 m
.38855 .61803 L
s
.4696 .61428 m
.4696 .61803 L
s
.51013 .61428 m
.51013 .61803 L
s
.55066 .61428 m
.55066 .61803 L
s
.59119 .61428 m
.59119 .61803 L
s
.67224 .61428 m
.67224 .61803 L
s
.71277 .61428 m
.71277 .61803 L
s
.75329 .61428 m
.75329 .61803 L
s
.79382 .61428 m
.79382 .61803 L
s
.87487 .61428 m
.87487 .61803 L
s
.9154 .61428 m
.9154 .61803 L
s
.95593 .61428 m
.95593 .61803 L
s
.99645 .61428 m
.99645 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01943 m
1 .01943 L
s
.99375 .13313 m
1 .13313 L
s
.99375 .24683 m
1 .24683 L
s
.99375 .36054 m
1 .36054 L
s
.99375 .47424 m
1 .47424 L
s
.99375 .58794 m
1 .58794 L
s
.125 Mabswid
.99625 .04217 m
1 .04217 L
s
.99625 .06491 m
1 .06491 L
s
.99625 .08765 m
1 .08765 L
s
.99625 .11039 m
1 .11039 L
s
.99625 .15587 m
1 .15587 L
s
.99625 .17861 m
1 .17861 L
s
.99625 .20135 m
1 .20135 L
s
.99625 .22409 m
1 .22409 L
s
.99625 .26957 m
1 .26957 L
s
.99625 .29232 m
1 .29232 L
s
.99625 .31506 m
1 .31506 L
s
.99625 .3378 m
1 .3378 L
s
.99625 .38328 m
1 .38328 L
s
.99625 .40602 m
1 .40602 L
s
.99625 .42876 m
1 .42876 L
s
.99625 .4515 m
1 .4515 L
s
.99625 .49698 m
1 .49698 L
s
.99625 .51972 m
1 .51972 L
s
.99625 .54246 m
1 .54246 L
s
.99625 .5652 m
1 .5652 L
s
.99625 .61068 m
1 .61068 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01943 m
.10486 .01899 L
.22644 .01613 L
.3075 .01472 L
.42908 .0186 L
.63171 .05264 L
.83435 .22324 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{777.625, 480.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<90001h2000`400?l00000o`00003oo`3ooooo
0?ooool0oooo303oool00?l0ooooo`3ooooo0?ooo``0oooo003o0?ooool0ooooo`3oool<0?ooo`00
o`3ooooo0?ooool0oooo303oool00?l0ooooo`3ooooo0?ooo``0oooo003o0?oooi`0oooo0`00003o
0?ooof`0oooo003o0?oooi`0oooo00@000000?ooo`3oool00000o`3ooom[0?ooo`00o`3ooonO0?oo
o`030000003oool0oooo0?l0ooooJ@3oool00?l0ooooW@3oool200000?l0ooooK03oool00?l0oooo
W03oool00`000000oooo0?ooo`3o0?ooof`0oooo003o0?oooi`0oooo00@000000?ooo`3oool00000
o`3ooom[0?ooo`00o`3ooonM0?ooo`<00000o`3ooom[0?ooo`00o`3ooooo0?ooool0oooo303oool0
0?l0ooooo`3ooooo0?ooo``0oooo003o0?ooool0ooooo`3oool<0?ooo`00o`3ooooo0?ooool0oooo
303oool00?l0ooooo`3ooooo0?ooo``0oooo003o0?ooool0ooooo`3oool<0?ooo`00o`3ooooo0?oo
ool0oooo303oool00?l0ooooo`3ooooo0?ooo``0oooo003o0?ooool0ooooo`3oool<0?ooo`00o`3o
oooo0?ooool0oooo303oool00?l0ooooo`3ooooo0?ooo``0oooo001;0?ooo`<00000Q`3oool30000
00<0oooo00@000000?ooo`3oool0oooo0`0000270?ooo`<00000QP3oool3000000<0oooo00@00000
0?ooo`3oool0oooo0`0000260?ooo`D00000O`3oool004X0oooo00D000000?ooo`3oool0oooo0000
00250?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`250?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`240?ooo`040000
003oool0oooo000007l0oooo001:0?ooo`050000003oool0oooo0?ooo`000000Q@3oool01@000000
oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`1o0?oo
o`00BP3oool01@000000oooo0?ooo`3oool0000008D0oooo00D000000?ooo`3oool0oooo0000000:
0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0OP3oool004X0oooo00D000000?oo
o`3oool0oooo000000250?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?oo
o`240?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`250?ooo`030000003oool0oooo07h0oooo001:0?ooo`050000003oool0oooo0?ooo`000000Q@3o
ool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo
0?ooo`260?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo
0?ooo`1m0?ooo`00BP3oool01@000000oooo0?ooo`3oool0000008D0oooo00D000000?ooo`3oool0
oooo000000060?ooo`<00000R03oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00H0
oooo0`00002:0?ooo`030000003oool0oooo07d0oooo001:0?ooo`050000003oool0oooo0?ooo`00
0000Q@3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0R03oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0RP3oool00`00
0000oooo0?ooo`1m0?ooo`00BP3oool01@000000oooo0?ooo`3oool0000008D0oooo00D000000?oo
o`3oool0oooo000000070?ooo`030000003oool0oooo08H0oooo0P0000270?ooo`8000002@3oool0
0`000000oooo0?ooo`250?ooo`050000003oool0oooo0?ooo`000000O`3oool004/0oooo0`000027
0?ooo`<00000203oool4000008H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`07
0?ooo`@00000Q@3oool300000800oooo003o0?ooool0ooooo`3oool<0?ooo`00o`3ooooo0?ooool0
oooo303oool00?l0ooooo`3ooooo0?ooo``0oooo003o0?ooool0ooooo`3oool<0?ooo`00o`3ooooo
0?ooool0oooo303oool00?l0ooooo`3ooooo0?ooo``0oooo003o0?ooool0ooooo`3oool<0?ooo`00
o`3ooooo0?ooool0oooo303oool00?l0ooooo`3ooooo0?ooo``0oooo003o0?ooool0ooooo`3oool<
0?ooo`00o`3ooooo0?ooool0oooo303oool003`0ooooo`00003o00000<<00000303oool003`0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0000000<0?ooo`00?03oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0000000`0oooo000l0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`000000303oool003`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`2<0?oo
o`030000003oool0oooo08/0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2<0?oo
o`030000003oool0oooo0740oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3o
ool0S03oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3o
ool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oookl0oooo00<000000?ooo`3oool0
2P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oookl0oooo00<000000?ooo`3oool02P3o
ool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oookl0oooo00<000000?ooo`3oool02P3oool0
03`0oooo00<000000?ooo`3oool0o`3ooooo0?oookl0oooo00<000000?ooo`3oool02P3oool002`0
oooo0`00000=0?ooo`030000003oool0oooo0?l0ooooo`3ooono0?ooo`030000003oool0oooo00X0
oooo000[0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`2j0?oooc80
0000o`3ooooB0?ooo`030000003oool0oooo00X0oooo000[0?ooo`050000003oool0oooo0?ooo`00
0000303oool00`000000oooo0?ooo`280?oooc800000<P3ooolZ00000?l0ooooZ03oool00`000000
oooo0?ooo`0:0?ooo`00:`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3o
ool0G@3oool[000008h0oooo6000003o0?oooi00oooo00<000000?ooo`3oool02P3oool002/0oooo
00D000000?ooo`3oool0oooo0000000<0?ooo`H000002`3ooom?00000=40oooo1P00003o0?ooohH0
oooo1@00000<0?ooo`00:`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3o
ool0o`3ooole0?ooo`H00000o`3ooon40?ooo`030000003oool0oooo00X0oooo000[0?ooo`050000
003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`3o0?oooc/0oooo1P00003o0?ooogh0
oooo00<000000?ooo`3oool02P3oool002/0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`03
0000003oool0oooo0?l0oooo@@3oool600000?l0ooooN03oool00`000000oooo0?ooo`0:0?ooo`00
:`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0o`3ooom70?ooo`H0
0000o`3ooomb0?ooo`030000003oool0oooo00X0oooo000/0?ooo`<000003@3oool00`000000oooo
0?ooo`3o0?ooodd0oooo1P00003o0?ooof`0oooo00<000000?ooo`3oool02P3oool003`0oooo00<0
00000?ooo`3oool0o`3ooomC0?ooo`H00000o`3ooomV0?ooo`030000003oool0oooo00X0oooo000l
0?ooo`030000003oool0oooo0?l0ooooF@3oool600000?l0ooooH03oool00`000000oooo0?ooo`0:
0?ooo`00?03oool00`000000oooo0?ooo`3o0?oooel0oooo1P00003o0?oooeX0oooo00<000000?oo
o`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooomU0?ooo`H00000o`3ooomD0?ooo`03
0000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooJ`3oool600000?l0oooo
CP3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooog40oooo1P00
003o0?ooodP0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooomg
0?ooo`H00000o`3ooom20?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo
0?l0ooooO@3oool600000?l0oooo?03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000
oooo0?ooo`3o0?oooh<0oooo1P00003o0?ooocH0oooo00<000000?ooo`3oool02P3oool003`0oooo
00<000000?ooo`3oool0o`3ooon90?ooo`H00000o`3oool`0?ooo`030000003oool0oooo00X0oooo
000l0?ooo`@00000o`3ooon>0?ooo`H00000o`3ooolX0?ooo`<00000303oool003`0oooo00<00000
0?ooo`3oool0o`3ooonE0?ooo`H00000o`3ooolT0?ooo`030000003oool0oooo00X0oooo000l0?oo
o`030000003oool0oooo0?l0ooooV`3oool600000?l0oooo7P3oool00`000000oooo0?ooo`0:0?oo
o`00?03oool00`000000oooo0?ooo`3o0?oooj40oooo1P00003o0?oooaP0oooo00<000000?ooo`3o
ool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooonW0?ooo`H00000o`3ooolB0?ooo`030000
003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0oooo[@3oool600000?l0oooo303o
ool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oook<0oooo1P00003o
0?ooo`H0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3oooni0?oo
o`<00000o`3oool30?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0
oooo_03oool00`000000oooo0?ooo`3o0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000
003oool0oooo0?l0oooo_@3oool00`000000oooo0?ooo`3n0?ooo`030000003oool0oooo00X0oooo
000l0?ooo`030000003oool0oooo0?l0oooo_P3oool200000?h0oooo00<000000?ooo`3oool02P3o
ool003`0oooo00<000000?ooo`3oool0o`3oooo00?ooo`030000003oool0oooo0?/0oooo00<00000
0?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3oooo10?ooo`030000003oool0oooo
0?X0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3oooo20?ooo`03
0000003oool0oooo0?T0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0
o`3oooo30?ooo`030000003oool0oooo0?P0oooo00<000000?ooo`3oool02P3oool003`0oooo00<0
00000?ooo`3oool0o`3oooo40?ooo`800000n03oool00`000000oooo0?ooo`0:0?ooo`00?03oool4
00000?l0ooooa@3oool00`000000oooo0?ooo`3c0?ooo`<00000303oool003`0oooo00<000000?oo
o`3oool0o`3oooo70?ooo`030000003oool0oooo0?@0oooo00<000000?ooo`3oool02P3oool003`0
oooo00<000000?ooo`3oool0o`3oooo80?ooo`030000003oool0oooo0?<0oooo00<000000?ooo`3o
ool02P3oool003`0oooo00<000000?ooo`3oool0o`3oooo90?ooo`030000003oool0oooo0?80oooo
00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3oooo:0?ooo`800000lP3o
ool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oool`0oooo00<00000
0?ooo`3oool0k`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oo
old0oooo00<000000?ooo`3oool0kP3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000
oooo0?ooo`3o0?ooolh0oooo00<000000?ooo`3oool0k@3oool00`000000oooo0?ooo`0:0?ooo`00
?03oool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool0k03oool00`000000oooo
0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooom00oooo0P00003/0?ooo`030000003o
ool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0oooodP3oool00`000000oooo0?ooo`3Y
0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooood`3oool00`00
0000oooo0?ooo`3X0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0
ooooe03oool00`000000oooo0?ooo`3W0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000
003oool0oooo0?l0ooooe@3oool00`000000oooo0?ooo`3V0?ooo`030000003oool0oooo00X0oooo
000l0?ooo`030000003oool0oooo0?l0ooooeP3oool200000>H0oooo00<000000?ooo`3oool02P3o
ool003`0oooo00<000000?ooo`3oool0o`3ooooH0?ooo`030000003oool0oooo0><0oooo00<00000
0?ooo`3oool02P3oool003`0oooo1000003o0?ooomP0oooo00<000000?ooo`3oool0h03oool30000
00`0oooo000l0?ooo`030000003oool0oooo0?l0oooofP3oool00`000000oooo0?ooo`3Q0?ooo`03
0000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0oooof`3oool00`000000oooo
0?ooo`3P0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0oooog03o
ool00`000000oooo0?ooo`3O0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0
oooo0?l0oooog@3oool200000=l0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?oo
o`3oool0o`3ooooO0?ooo`030000003oool0oooo0=`0oooo00<000000?ooo`3oool02P3oool003`0
oooo00<000000?ooo`3oool0o`3ooooP0?ooo`030000003oool0oooo0=/0oooo00<000000?ooo`3o
ool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooQ0?ooo`030000003oool0oooo0=X0oooo
00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooR0?ooo`030000003o
ool0oooo0=T0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooS
0?ooo`800000f@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oo
onD0oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000
oooo0?ooo`3o0?ooonH0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`0:0?ooo`00
?03oool00`000000oooo0?ooo`3o0?ooonL0oooo00<000000?ooo`3oool0e03oool00`000000oooo
0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooonP0oooo00<000000?ooo`3oool0d`3o
ool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooonT0oooo0P00003C
0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooj`3oool00`00
0000oooo0?ooo`3@0?ooo`030000003oool0oooo00X0oooo000l0?ooo`@00000o`3oooo[0?ooo`03
0000003oool0oooo0<d0oooo0`00000<0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooond0oooo
00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?oo
o`3o0?ooonh0oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool0
0`000000oooo0?ooo`3o0?ooonl0oooo0P00003=0?ooo`030000003oool0oooo00X0oooo000l0?oo
o`030000003oool0oooo0?l0ooool@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
00X0oooo000l0?ooo`030000003oool0oooo0?l0oooolP3oool00`000000oooo0?ooo`390?ooo`03
0000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooool`3oool00`000000oooo
0?ooo`380?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0oooom03o
ool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0
oooo0?l0oooom@3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00X0oooo000l0?oo
o`030000003oool0oooo0?l0oooomP3oool200000<H0oooo00<000000?ooo`3oool02P3oool003`0
oooo00<000000?ooo`3oool0o`3ooooh0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3o
ool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooi0?ooo`030000003oool0oooo0<80oooo
00<000000?ooo`3oool02P3oool002/0oooo0`00000>0?ooo`030000003oool0oooo0?l0oooonP3o
ool00`000000oooo0?ooo`310?ooo`030000003oool0oooo00X0oooo000^0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0o`3ooook0?ooo`030000003oool0oooo0<00oooo00<00000
0?ooo`3oool02P3oool002l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?oo
oo`0oooo0P0000300?ooo`030000003oool0oooo00X0oooo000_0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0o`3oooon0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3o
ool02P3oool002l0oooo00<000000?ooo`3oool02P3oool600000?l0ooooo03oool00`000000oooo
0?ooo`2h0?ooo`D00000303oool002h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`3o0?ooool0oooo0@3oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo00X0oooo000[
0?ooo`<000003P3oool00`000000oooo0?ooo`3o0?ooool0oooo0P3oool00`000000oooo0?ooo`2j
0?ooo`030000003oool0oooo00X0oooo000[0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0o`3ooooo0?ooo`<0oooo0P00002j0?ooo`030000003oool0oooo00X0oooo000/0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`D0oooo00<000000?ooo`3o
ool0]`3oool00`000000oooo0?ooo`0:0?ooo`00;03oool4000000`0oooo00<000000?ooo`3oool0
o`3ooooo0?ooo`H0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0:0?ooo`00?03o
ool00`000000oooo0?ooo`3o0?ooool0oooo1`3oool00`000000oooo0?ooo`2e0?ooo`030000003o
ool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3oool80?ooo`030000003oool0
oooo0;@0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oo
o`T0oooo0P00002d0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0
ooooo`3oool;0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool02P3oool003`0oooo
00<000000?ooo`3oool0o`3ooooo0?ooo``0oooo00<000000?ooo`3oool0/03oool00`000000oooo
0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo3@3oool00`000000oooo0?oo
o`2_0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3oool>
0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?oo
o`3oool0o`3ooooo0?ooo`l0oooo0P00002^0?ooo`030000003oool0oooo00X0oooo000l0?ooo`03
0000003oool0oooo0?l0ooooo`3ooolA0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3o
ool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooa80oooo00<000000?ooo`3oool0
ZP3oool00`000000oooo0?ooo`0:0?ooo`00?03oool400000?l0ooooo`3ooolB0?ooo`030000003o
ool0oooo0:L0oooo0`00000<0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo503oool0
0`000000oooo0?ooo`2X0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo
0?l0ooooo`3ooolE0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool02P3oool003`0
oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo0P00002W0?ooo`030000003oool0oooo00X0
oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooolH0?ooo`030000003oool0oooo0:@0oooo
00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooaT0oooo00<0
00000?ooo`3oool0X`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o
0?ooool0oooo6P3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo00X0oooo000l0?oo
o`030000003oool0oooo0?l0ooooo`3ooolK0?ooo`030000003oool0oooo0:40oooo00<000000?oo
o`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooa`0oooo0P00002Q0?ooo`03
0000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooolN0?ooo`030000
003oool0oooo09h0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3o
oooo0?oooal0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool0
0`000000oooo0?ooo`3o0?ooool0oooo803oool00`000000oooo0?ooo`2L0?ooo`030000003oool0
oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`030000003oool0oooo
09/0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooob80
oooo0P00002K0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0oooo
o`3ooolT0?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool02P3oool003`0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooobD0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?oo
o`0:0?ooo`00?03oool400000?l0ooooo`3ooolU0?ooo`030000003oool0oooo09@0oooo0`00000<
0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo9`3oool00`000000oooo0?ooo`2E0?oo
o`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooolX0?ooo`80
0000U@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo
:P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003o
ool0oooo0?l0ooooo`3oool[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool02P3o
ool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooob`0oooo00<000000?ooo`3oool0T03oool0
0`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo;@3oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0
ooooo`3oool^0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool02P3oool003`0oooo
00<000000?ooo`3oool0o`3ooooo0?ooobl0oooo0P00002>0?ooo`030000003oool0oooo00X0oooo
000l0?ooo`030000003oool0oooo0?l0ooooo`3ooola0?ooo`030000003oool0oooo08/0oooo00<0
00000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooc80oooo00<00000
0?ooo`3oool0RP3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oo
ool0oooo<`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo00X0oooo000l0?ooo`03
0000003oool0oooo0?l0ooooo`3ooold0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3o
ool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooocD0oooo0P0000280?ooo`030000
003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooolg0?ooo`030000003o
ool0oooo08D0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo
0?ooocP0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`0:0?ooo`00?03oool40000
0?l0ooooo`3ooolh0?ooo`030000003oool0oooo0840oooo0`00000<0?ooo`00?03oool00`000000
oooo0?ooo`3o0?ooool0oooo>P3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo00X0
oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooolk0?ooo`800000PP3oool00`000000oooo
0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo?@3oool00`000000oooo0?oo
o`1o0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3oooln
0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?oo
o`3oool0o`3ooooo0?ooocl0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0:0?oo
o`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo@03oool00`000000oooo0?ooo`1l0?ooo`03
0000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooom10?ooo`800000
O03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo@`3o
ool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0
oooo0?l0ooooo`3ooom40?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool02P3oool0
03`0oooo00<000000?ooo`3oool0o`3ooooo0?ooodD0oooo00<000000?ooo`3oool0M`3oool00`00
0000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooAP3oool00`000000
oooo0?ooo`1f0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0oooo
o`3ooom70?ooo`800000MP3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?oo
o`3o0?ooool0ooooB@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00X0oooo000l
0?ooo`030000003oool0oooo0?l0ooooo`3ooom:0?ooo`030000003oool0oooo0780oooo00<00000
0?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oood/0oooo00<000000?oo
o`3oool0L@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool400000?l0ooooo`3ooom:0?ooo`03
0000003oool0oooo06l0oooo0`00000<0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo
C03oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003o
ool0oooo0?l0ooooo`3ooom<0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool02P3o
ool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oood`0oooo00<000000?ooo`3oool0L03oool0
0`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooC@3oool00`00
0000oooo0?ooo`1_0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0
ooooo`3ooom=0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool02P3oool003`0oooo
00<000000?ooo`3oool0o`3ooooo0?ooodh0oooo00<000000?ooo`3oool0KP3oool00`000000oooo
0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooCP3oool00`000000oooo0?oo
o`1^0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooom>
0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?oo
o`3oool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0:0?oo
o`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?ooo`1]0?ooo`03
0000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooom?0?ooo`030000
003oool0oooo06d0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3o
oooo0?oooe00oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0:0?ooo`009@3oool3
000000@0oooo0`00000=0?ooo`030000003oool0oooo0?l0ooooo`3ooom@0?ooo`030000003oool0
oooo06`0oooo00<000000?ooo`3oool02P3oool002H0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<00000
0?ooo`3oool0J`3oool00`000000oooo0?ooo`0:0?ooo`009P3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool0
0`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00X0oooo000V0?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo0000000<0?ooo`H00000o`3ooooo0?ooodh0oooo00<00000
0?ooo`3oool0I`3oool5000000`0oooo000V0?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo0000000<0?ooo`030000003oool0oooo0?l0ooooo`3ooomB0?ooo`030000003oool0
oooo06X0oooo00<000000?ooo`3oool02P3oool002H0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0o`3ooooo0?oooe80oooo00<00000
0?ooo`3oool0JP3oool00`000000oooo0?ooo`0:0?ooo`009P3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`3o0?ooool0ooooDP3oool0
0`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo00X0oooo000V0?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo0?l0ooooo`3ooomC
0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool02P3oool002D0oooo0P0000040?oo
o`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`3o0?ooool0ooooD`3oool0
0`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo00X0oooo000V0?ooo`030000003oool0oooo
00<0oooo0`00000=0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`030000003oool0oooo
06P0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0
oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo
0?ooo`3o0?ooool0ooooE03oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00X0oooo
000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomE0?ooo`030000003oool0oooo06L0oooo00<0
00000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooeD0oooo00<00000
0?ooo`3oool0I`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oo
ool0ooooE@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00X0oooo000l0?ooo`03
0000003oool0oooo0?l0ooooo`3ooomF0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3o
ool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooeH0oooo00<000000?ooo`3oool0
IP3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooE`3o
ool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0
oooo0?l0ooooo`3ooomG0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool02P3oool0
03`0oooo1000003o0?ooool0ooooEP3oool00`000000oooo0?ooo`1S0?ooo`<00000303oool003`0
oooo00<000000?ooo`3oool0o`3ooooo0?oooeP0oooo00<000000?ooo`3oool0I03oool00`000000
oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooF03oool00`000000oooo
0?ooo`1T0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3o
oomH0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool02P3oool003`0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooeT0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0:
0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooF@3oool00`000000oooo0?ooo`1S0?oo
o`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomJ0?ooo`03
0000003oool0oooo0680oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0
o`3ooooo0?oooeX0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0:0?ooo`00?03o
ool00`000000oooo0?ooo`3o0?ooool0ooooFP3oool00`000000oooo0?ooo`1R0?ooo`030000003o
ool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomK0?ooo`030000003oool0
oooo0640oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oe/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000
oooo0?ooo`3o0?ooool0ooooF`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00X0
oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomL0?ooo`030000003oool0oooo0600oooo
00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooe`0oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o
0?ooool0ooooG@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00X0oooo000l0?oo
o`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`030000003oool0oooo05l0oooo00<000000?oo
o`3oool02P3oool003`0oooo1000003o0?ooool0ooooG03oool00`000000oooo0?ooo`1M0?ooo`<0
0000303oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooeh0oooo00<000000?ooo`3oool0
GP3oool00`000000oooo0?ooo`0:0?ooo`00603oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo0?l0ooooo`3ooomN0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool02P3o
ool001D0oooo1000000S0?ooo`030000003oool0oooo0?l0ooooo`3ooomN0?ooo`030000003oool0
oooo05h0oooo00<000000?ooo`3oool02P3oool001<0oooo0P0000030?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool0o`3ooooo0?oooel0oooo00<000000?ooo`3oool0G@3oool00`00
0000oooo0?ooo`0:0?ooo`00403oool3000000D0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`3o0?ooool0ooooG`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo00X0
oooo000?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`3o0?ooool0ooooH03oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00X0oooo
000@0?ooo`<000001@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0ooooo`3o
oomP0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool02P3oool001<0oooo0P000003
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0o`3ooooo0?ooof00oooo00<00000
0?ooo`3oool0G03oool00`000000oooo0?ooo`0:0?ooo`005@3oool4000002<0oooo00<000000?oo
o`3oool0o`3ooooo0?ooof40oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0:0?oo
o`00603oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0ooooo`3ooomQ0?ooo`03
0000003oool0oooo05/0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`3o0?ooool0ooooH@3oool00`000000oooo0?ooo`1K0?ooo`030000
003oool0oooo00X0oooo000I0?ooo`8000008@3oool00`000000oooo0?ooo`3o0?ooool0ooooHP3o
ool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00X0oooo000B0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3o0?ooool0ooooHP3oool0
0`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00X0oooo000B0?ooo`<000000P3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo0?l0ooooo`3ooomS0?ooo`030000003oool0oooo
05T0oooo00<000000?ooo`3oool02P3oool001D0oooo1`00000P0?ooo`030000003oool0oooo0?l0
ooooo`3ooomS0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool02P3oool001D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`@00000o`3ooooo0?ooof80oooo
00<000000?ooo`3oool0E`3oool3000000`0oooo000D0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`3o0?ooool0ooooI03oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo00<0oooo0P00000X
0?ooo`030000003oool0oooo0?l0ooooo`3ooomT0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool02P3oool000`0oooo00<000000?ooo`3oool00P3oool2000002T0oooo00<000000?oo
o`3oool0o`3ooooo0?ooof@0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0:0?oo
o`00303oool01`000000oooo0?ooo`3oool000000?ooo`000000:@3oool00`000000oooo0?ooo`3o
0?ooool0ooooI@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo00X0oooo000=0?oo
o`<0000000<0oooo000000000000:@3oool00`000000oooo0?ooo`3o0?ooool0ooooI@3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0
ooooo`3ooomU0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool02P3oool003`0oooo
00<000000?ooo`3oool0o`3ooooo0?ooofH0oooo00<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooIP3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomW
0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?oo
o`3oool0o`3ooooo0?ooofL0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0:0?oo
o`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooI`3oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomX0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3o
oooo0?ooofP0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0:0?ooo`00?03oool0
0`000000oooo0?ooo`3o0?ooool0ooooJ03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomY0?ooo`030000003oool0oooo
05<0oooo00<000000?ooo`3oool02P3oool003`0oooo1000003o0?ooool0ooooJ03oool00`000000
oooo0?ooo`1A0?ooo`<00000303oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooofX0oooo
00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?oo
o`3o0?ooool0ooooJP3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo00X0oooo000l
0?ooo`030000003oool0oooo0?l0ooooo`3ooomZ0?ooo`030000003oool0oooo0580oooo00<00000
0?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooof/0oooo00<000000?oo
o`3oool0D@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0
ooooJ`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000
003oool0oooo0?l0ooooo`3ooom[0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0
2P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooof`0oooo00<000000?ooo`3oool0D03o
ool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooK03oool0
0`000000oooo0?ooo`1@0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo
0?l0ooooo`3ooom]0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool02P3oool003`0
oooo00<000000?ooo`3oool0o`3ooooo0?ooofd0oooo00<000000?ooo`3oool0C`3oool00`000000
oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooK@3oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3o
oom^0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool02P3oool002D0oooo0`000003
0?ooo`<000003P3oool00`000000oooo0?ooo`3o0?ooool0ooooKP3oool00`000000oooo0?ooo`1>
0?ooo`030000003oool0oooo00X0oooo000V0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`3o0?ooool0ooooKP3oool00`000000oooo0?ooo`1>0?oo
o`030000003oool0oooo00X0oooo000V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`3o0?ooool0ooooK`3oool00`000000oooo0?ooo`1=0?ooo`03
0000003oool0oooo00X0oooo000V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
2P3oool600000?l0ooooo`3ooom/0?ooo`030000003oool0oooo04T0oooo1@00000<0?ooo`009P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3o
oooo0?ooog00oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0:0?ooo`009P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooooo
0?ooog00oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0:0?ooo`009P3oool00`00
0000oooo0?ooo`020?ooo`<000003P3oool00`000000oooo0?ooo`3o0?ooool0ooooL03oool00`00
0000oooo0?ooo`1<0?ooo`030000003oool0oooo00X0oooo000V0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?ooool0ooooL@3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo00X0oooo000U0?ooo`8000001@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooo`3oooma0?ooo`030000003oool0oooo04/0oooo
00<000000?ooo`3oool02P3oool002H0oooo00<000000?ooo`3oool00`3oool4000000`0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooog40oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?oo
o`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooLP3oool00`000000oooo0?ooo`1:
0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomb0?oo
o`030000003oool0oooo04X0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooog<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0:0?ooo`00
?03oool00`000000oooo0?ooo`3o0?ooool0ooooL`3oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomc0?ooo`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo
0?ooog@0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`00
0000oooo0?ooo`3o0?ooool0ooooM03oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo
00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooogD0oooo
00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool400000?l0ooooo`3o
oomd0?ooo`030000003oool0oooo04D0oooo0`00000<0?ooo`00?03oool00`000000oooo0?ooo`3o
0?ooool0ooooMP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00X0oooo000l0?oo
o`030000003oool0oooo0?l0ooooo`3ooomf0?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooogH0oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo
M`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003o
ool0oooo0?l0ooooo`3ooomg0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool02P3o
ool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooogL0oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooN03oool00`00
0000oooo0?ooo`140?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0
ooooo`3ooomh0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool02P3oool003`0oooo
00<000000?ooo`3oool0o`3ooooo0?ooogT0oooo00<000000?ooo`3oool0@`3oool00`000000oooo
0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooN@3oool00`000000oooo0?oo
o`130?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomi
0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?oo
o`3oool0o`3ooooo0?ooogX0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0:0?oo
o`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooNP3oool00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomj0?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3o
oooo0?ooog/0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool4
00000?l0ooooo`3ooomj0?ooo`030000003oool0oooo03l0oooo0`00000<0?ooo`00?03oool00`00
0000oooo0?ooo`3o0?ooool0ooooO03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3oooml0?ooo`030000003oool0oooo0400
oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooog`0oooo
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?oo
o`3o0?ooool0ooooO@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00X0oooo000l
0?ooo`030000003oool0oooo0?l0ooooo`3ooomm0?ooo`030000003oool0oooo03l0oooo00<00000
0?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooogd0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0
ooooOP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000
003oool0oooo0?l0ooooo`3ooomn0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
2P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooogh0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooO`3oool0
0`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo
0?l0ooooo`3ooomo0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool02P3oool003`0
oooo00<000000?ooo`3oool0o`3ooooo0?oooh00oooo00<000000?ooo`3oool0?03oool00`000000
oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooP03oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3o
oon00?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool02P3oool003`0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooh40oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0:
0?ooo`00?03oool400000?l0ooooo`3ooon00?ooo`030000003oool0oooo03T0oooo0`00000<0?oo
o`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooP@3oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooon20?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3o
oooo0?oooh80oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool0
0`000000oooo0?ooo`3o0?ooool0ooooP`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooon30?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooh<0
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo
0?ooo`3o0?ooool0ooooQ03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00X0oooo
000l0?ooo`030000003oool0oooo0?l0ooooo`3ooon40?ooo`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooh@0oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oo
ool0ooooQ@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00X0oooo000l0?ooo`03
0000003oool0oooo0?l0ooooo`3ooon50?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooohH0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooQP3o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0
oooo0?l0ooooo`3ooon60?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02P3oool0
03`0oooo00<000000?ooo`3oool0o`3ooooo0?ooohL0oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`0:0?ooo`00?03oool400000?l0ooooo`3ooon60?ooo`030000003oool0oooo03<0
oooo0`00000<0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooQ`3oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3o
oon80?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02P3oool003`0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooohP0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0:
0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooR@3oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooon90?ooo`03
0000003oool0oooo03<0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0
o`3ooooo0?ooohT0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0:0?ooo`00?03o
ool00`000000oooo0?ooo`3o0?ooool0ooooRP3oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooon:0?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ohX0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000
oooo0?ooo`3o0?ooool0ooooR`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00X0
oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooon;0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooh`0oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`00903oool5000000<0oooo0`00000=
0?ooo`030000003oool0oooo0?l0ooooo`3ooon<0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool02P3oool002D0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3o
ool0000000`0oooo00<000000?ooo`3oool0o`3ooooo0?oooh`0oooo00<000000?ooo`3oool0<03o
ool00`000000oooo0?ooo`0:0?ooo`009P3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`000000303oool00`000000oooo0?ooo`3o0?ooool0ooooS@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo00X0oooo000W0?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`0:0?ooo`H00000o`3ooooo0?ooohX0oooo00<000000?ooo`3oool0:`3o
ool5000000`0oooo000W0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0?l0ooooo`3ooon=0?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool02P3oool002P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0?l0ooooo`3ooon>0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool02P3oool002P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0?l0ooooo`3ooon>0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool02P3oool002P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0?l0ooooo`3ooon?0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool02P3oool002@0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003o
ool0oooo0?ooo`000000303oool00`000000oooo0?ooo`3o0?ooool0ooooS`3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000U0?ooo`<00000103oool3000000d0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooohl0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooT03oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooon@0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooi00oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`00
?03oool00`000000oooo0?ooo`3o0?ooool0ooooT@3oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonA0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo
0?oooi80oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`00
0000oooo0?ooo`3o0?ooool0ooooTP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonB0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooi<0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool400000?l0ooooo`3o
oonB0?ooo`030000003oool0oooo02L0oooo0`00000<0?ooo`00?03oool00`000000oooo0?ooo`3o
0?ooool0ooooT`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00X0oooo000l0?oo
o`030000003oool0oooo0?l0ooooo`3ooonD0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooi@0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo
U@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003o
ool0oooo0?l0ooooo`3ooonE0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02P3o
ool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooiD0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooUP3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0
ooooo`3ooonF0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool02P3oool003`0oooo
00<000000?ooo`3oool0o`3ooooo0?oooiH0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooU`3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonG
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?oo
o`3oool0o`3ooooo0?oooiL0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0:0?oo
o`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooV03oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonH0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3o
oooo0?oooiT0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool4
00000?l0ooooo`3ooonH0?ooo`030000003oool0oooo0240oooo0`00000<0?ooo`00?03oool00`00
0000oooo0?ooo`3o0?ooool0ooooV@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonJ0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooiX0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?oo
o`3o0?ooool0ooooVP3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00X0oooo000l
0?ooo`030000003oool0oooo0?l0ooooo`3ooonK0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooi/0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0
ooooW03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000
003oool0oooo0?l0ooooo`3ooonL0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
2P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooi`0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooW@3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo
0?l0ooooo`3ooonM0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool02P3oool003`0
oooo00<000000?ooo`3oool0o`3ooooo0?oooid0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooWP3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3o
oonN0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool02P3oool003`0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooil0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0:
0?ooo`00?03oool400000?l0ooooo`3ooonN0?ooo`030000003oool0oooo01/0oooo0`00000<0?oo
o`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooW`3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonP0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3o
oooo0?oooj00oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0:0?ooo`00?03oool0
0`000000oooo0?ooo`3o0?ooool0ooooX03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonQ0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooj40
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo
0?ooo`3o0?ooool0ooooXP3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00X0oooo
000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonR0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooj80oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?oo
ool0ooooX`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00X0oooo000l0?ooo`03
0000003oool0oooo0?l0ooooo`3ooonS0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooj<0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooY03o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0
oooo0?l0ooooo`3ooonT0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool02P3oool0
03`0oooo00<000000?ooo`3oool0o`3ooooo0?ooojD0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0:0?ooo`00?03oool400000?l0ooooo`3ooonT0?ooo`030000003oool0oooo01D0
oooo0`00000<0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooY@3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3o
oonV0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02P3oool003`0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooojH0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0:
0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooYP3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonW0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0
o`3ooooo0?ooojL0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0:0?ooo`00?03o
ool00`000000oooo0?ooo`3o0?ooool0ooooZ03oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00X0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonX0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ojP0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000
oooo0?ooo`3o0?ooool0ooooZ@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00X0
oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonY0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooojT0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0:0?ooo`00903oool500000080oooo0`00000>
0?ooo`030000003oool0oooo0?l0ooooo`3ooonZ0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool02P3oool002D0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0?l0ooooo`3ooonZ0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool02P3oool002H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo0?l0ooooo`3ooon[0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool02P3oool002L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`H0
0000o`3ooooo0?ooojP0oooo00<000000?ooo`3oool03@3oool5000000`0oooo000W0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?ooool0oooo
Z`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000X0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?ooool0oooo[03o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00X0oooo000X0?ooo`030000003oool0
oooo00<000003P3oool00`000000oooo0?ooo`3o0?ooool0oooo[03oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00X0oooo000X0?ooo`040000003oool0oooo00000100oooo00<00000
0?ooo`3oool0o`3ooooo0?oooj`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0:
0?ooo`00903oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`3o0?ooool0oooo[@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00X0oooo000U0?ooo`<00000103oool4000000`0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ojd0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000
oooo0?ooo`3o0?ooool0oooo[P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00X0
oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooon^0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooojh0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`00?03oool00`000000oooo0?ooo`3o
0?ooool0oooo[`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo000l0?oo
o`030000003oool0oooo0?l0ooooo`3ooon_0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oookl0oooo00<000000?ooo`3o
ool02P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oookl0oooo00<000000?ooo`3oool0
2P3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oookl0oooo00<000000?ooo`3oool02P3o
ool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oookl0oooo00<000000?ooo`3oool02P3oool0
03`0oooo1000003o0?ooool0oooo_03oool3000000`0oooo000l0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo08`0
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00X0
oooo000l0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0S03oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0S03oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`000000303oool003`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0000000<
0?ooo`00?03ooooo00000?l00000``00000<0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 776.625}, {479.625, 0}} -> {-0.27159, -3.62892, \
0.00350417, 0.062449}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Show[plch2p, 
      Graphics[{\[IndentingNewLine]{Dashing[{0.01, 0.01}], 
            Line[{{0, 1}, {1.33, 1}}]}, \[IndentingNewLine]{Dashing[{0.01, 
                0.01}], 
            Line[{{1.33, 1}, {1.33, 0}}]}, \[IndentingNewLine]{Dashing[{0.01, 
                0.01}], 
            Line[{{0, 4}, {1.66, 4}}]}, \[IndentingNewLine]{Dashing[{0.01, 
                0.01}], 
            Line[{{1.66, 4}, {1.66, 0}}]}, \[IndentingNewLine]{Dashing[{0.01, 
                0.01}], 
            Line[{{0, 6.63}, {1.87, 
                  6.63}}]}, \[IndentingNewLine]{Dashing[{0.01, 0.01}], 
            Line[{{1.87, 6.63}, {1.87, 
                  0}}]}\[IndentingNewLine]}], \[IndentingNewLine]Epilog \
\[Rule] {Text["\<68.3%\>", {1.42, 0.4}], Text["\<95.4%\>", {1.75, 2}], 
          Text["\<99.0%\>", {1.95, 0.52}], 
          Text["\<Phantom Models\>", {1, 
              17}]}\[IndentingNewLine]]\)\(\[IndentingNewLine]\)\(\
\[IndentingNewLine]\)\( (*\ \
\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\ \ \
Fig\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\) . \ \
\(\(\(\(\(\(\(\(\(\(\(\(\(\(\(\(\(\(\(\(\(\(\(2\ --\)--\)--\)--\)--\)--\)--\)\
--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)\ \ \ *) \)\)\
\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.405268 0.0194286 0.0227406 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.22644 -0.0125 -10.7813 -17.8125 ]
[.22644 -0.0125 10.7813 0 ]
[.42908 -0.0125 -5.53125 -17.8125 ]
[.42908 -0.0125 5.53125 0 ]
[.63171 -0.0125 -10.7813 -17.8125 ]
[.63171 -0.0125 10.7813 0 ]
[.83435 -0.0125 -5.53125 -17.8125 ]
[.83435 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -4.75 -35.625 ]
[.5 -0.0125 4.75 -17.8125 ]
[-0.0125 .01943 -11.0625 -8.90625 ]
[-0.0125 .01943 0 8.90625 ]
[-0.0125 .13313 -11.0625 -8.90625 ]
[-0.0125 .13313 0 8.90625 ]
[-0.0125 .24683 -18.125 -8.90625 ]
[-0.0125 .24683 0 8.90625 ]
[-0.0125 .36054 -18.125 -8.90625 ]
[-0.0125 .36054 0 8.90625 ]
[-0.0125 .47424 -18.125 -8.90625 ]
[-0.0125 .47424 0 8.90625 ]
[-0.0125 .58794 -18.125 -8.90625 ]
[-0.0125 .58794 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -35.9375 -13.0938 ]
[-0.01875 .30902 -18.125 13.0938 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.59929 .02852 -20.125 -8.90625 ]
[.59929 .02852 20.125 8.90625 ]
[.73303 .06491 -20.125 -8.90625 ]
[.73303 .06491 20.125 8.90625 ]
[.81408 .03125 -20.125 -8.90625 ]
[.81408 .03125 20.125 8.90625 ]
[.42908 .40602 -49.8125 -8.90625 ]
[.42908 .40602 49.8125 8.90625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.22644 0 m
.22644 .00625 L
s
gsave
.22644 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.42908 0 m
.42908 .00625 L
s
gsave
.42908 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.63171 0 m
.63171 .00625 L
s
gsave
.63171 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.83435 0 m
.83435 .00625 L
s
gsave
.83435 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.06434 0 m
.06434 .00375 L
s
.10486 0 m
.10486 .00375 L
s
.14539 0 m
.14539 .00375 L
s
.18592 0 m
.18592 .00375 L
s
.26697 0 m
.26697 .00375 L
s
.3075 0 m
.3075 .00375 L
s
.34802 0 m
.34802 .00375 L
s
.38855 0 m
.38855 .00375 L
s
.4696 0 m
.4696 .00375 L
s
.51013 0 m
.51013 .00375 L
s
.55066 0 m
.55066 .00375 L
s
.59119 0 m
.59119 .00375 L
s
.67224 0 m
.67224 .00375 L
s
.71277 0 m
.71277 .00375 L
s
.75329 0 m
.75329 .00375 L
s
.79382 0 m
.79382 .00375 L
s
.87487 0 m
.87487 .00375 L
s
.9154 0 m
.9154 .00375 L
s
.95593 0 m
.95593 .00375 L
s
.99645 0 m
.99645 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -65.75 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
68.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01943 m
.00625 .01943 L
s
gsave
-0.0125 .01943 -72.0625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13313 m
.00625 .13313 L
s
gsave
-0.0125 .13313 -72.0625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .24683 m
.00625 .24683 L
s
gsave
-0.0125 .24683 -79.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .36054 m
.00625 .36054 L
s
gsave
-0.0125 .36054 -79.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
0 .47424 m
.00625 .47424 L
s
gsave
-0.0125 .47424 -79.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .58794 m
.00625 .58794 L
s
gsave
-0.0125 .58794 -79.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04217 m
.00375 .04217 L
s
0 .06491 m
.00375 .06491 L
s
0 .08765 m
.00375 .08765 L
s
0 .11039 m
.00375 .11039 L
s
0 .15587 m
.00375 .15587 L
s
0 .17861 m
.00375 .17861 L
s
0 .20135 m
.00375 .20135 L
s
0 .22409 m
.00375 .22409 L
s
0 .26957 m
.00375 .26957 L
s
0 .29232 m
.00375 .29232 L
s
0 .31506 m
.00375 .31506 L
s
0 .3378 m
.00375 .3378 L
s
0 .38328 m
.00375 .38328 L
s
0 .40602 m
.00375 .40602 L
s
0 .42876 m
.00375 .42876 L
s
0 .4515 m
.00375 .4515 L
s
0 .49698 m
.00375 .49698 L
s
0 .51972 m
.00375 .51972 L
s
0 .54246 m
.00375 .54246 L
s
0 .5652 m
.00375 .5652 L
s
0 .61068 m
.00375 .61068 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -101.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
74.0938 12.9063 translate
90 rotate
-74.0938 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Dc) show
79.688 11.875 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
85.188 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.22644 .61178 m
.22644 .61803 L
s
.42908 .61178 m
.42908 .61803 L
s
.63171 .61178 m
.63171 .61803 L
s
.83435 .61178 m
.83435 .61803 L
s
.125 Mabswid
.06434 .61428 m
.06434 .61803 L
s
.10486 .61428 m
.10486 .61803 L
s
.14539 .61428 m
.14539 .61803 L
s
.18592 .61428 m
.18592 .61803 L
s
.26697 .61428 m
.26697 .61803 L
s
.3075 .61428 m
.3075 .61803 L
s
.34802 .61428 m
.34802 .61803 L
s
.38855 .61428 m
.38855 .61803 L
s
.4696 .61428 m
.4696 .61803 L
s
.51013 .61428 m
.51013 .61803 L
s
.55066 .61428 m
.55066 .61803 L
s
.59119 .61428 m
.59119 .61803 L
s
.67224 .61428 m
.67224 .61803 L
s
.71277 .61428 m
.71277 .61803 L
s
.75329 .61428 m
.75329 .61803 L
s
.79382 .61428 m
.79382 .61803 L
s
.87487 .61428 m
.87487 .61803 L
s
.9154 .61428 m
.9154 .61803 L
s
.95593 .61428 m
.95593 .61803 L
s
.99645 .61428 m
.99645 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01943 m
1 .01943 L
s
.99375 .13313 m
1 .13313 L
s
.99375 .24683 m
1 .24683 L
s
.99375 .36054 m
1 .36054 L
s
.99375 .47424 m
1 .47424 L
s
.99375 .58794 m
1 .58794 L
s
.125 Mabswid
.99625 .04217 m
1 .04217 L
s
.99625 .06491 m
1 .06491 L
s
.99625 .08765 m
1 .08765 L
s
.99625 .11039 m
1 .11039 L
s
.99625 .15587 m
1 .15587 L
s
.99625 .17861 m
1 .17861 L
s
.99625 .20135 m
1 .20135 L
s
.99625 .22409 m
1 .22409 L
s
.99625 .26957 m
1 .26957 L
s
.99625 .29232 m
1 .29232 L
s
.99625 .31506 m
1 .31506 L
s
.99625 .3378 m
1 .3378 L
s
.99625 .38328 m
1 .38328 L
s
.99625 .40602 m
1 .40602 L
s
.99625 .42876 m
1 .42876 L
s
.99625 .4515 m
1 .4515 L
s
.99625 .49698 m
1 .49698 L
s
.99625 .51972 m
1 .51972 L
s
.99625 .54246 m
1 .54246 L
s
.99625 .5652 m
1 .5652 L
s
.99625 .61068 m
1 .61068 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01943 m
.10486 .01899 L
.22644 .01613 L
.3075 .01472 L
.42908 .0186 L
.63171 .05264 L
.83435 .22324 L
.97619 .60332 L
s
[ .01 .01 ] 0 setdash
.02381 .04217 m
.56282 .04217 L
s
.56282 .04217 m
.56282 .01943 L
s
.02381 .11039 m
.69656 .11039 L
s
.69656 .11039 m
.69656 .01943 L
s
.02381 .1702 m
.78166 .1702 L
s
.78166 .1702 m
.78166 .01943 L
s
gsave
.59929 .02852 -81.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(68.3) show
87.625 17.500 moveto
(%) show
99.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.73303 .06491 -81.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(95.4) show
87.625 17.500 moveto
(%) show
99.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.81408 .03125 -81.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(99.0) show
87.625 17.500 moveto
(%) show
99.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.42908 .40602 -110.813 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Phantom) show
116.313 17.500 moveto
(Models) show
158.625 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{776.75, 480.063},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<80001h2000`400?l00000o`00003oo`3ooooo
0?ooool0oooo2`3oool00?l0ooooo`3ooooo0?ooo`/0oooo003o0?ooool0ooooo`3oool;0?ooo`00
o`3ooooo0?ooool0oooo2`3oool00?l0ooooo`3ooooo0?ooo`/0oooo003o0?ooool0ooooo`3oool;
0?ooo`00o`3ooonK0?ooo`<00000o`3ooom/0?ooo`00o`3ooonK0?ooo`040000003oool0oooo0000
0?l0ooooJ`3oool00?l0ooooWP3oool00`000000oooo0?ooo`3o0?ooofT0oooo003o0?oooi`0oooo
0P00003o0?ooof`0oooo003o0?oooi/0oooo00<000000?ooo`3oool0o`3ooom/0?ooo`00o`3ooonK
0?ooo`040000003oool0oooo00000?l0ooooJ`3oool00?l0ooooW03oool300000?l0ooooJ`3oool0
0?l0ooooo`3ooooo0?ooo`/0oooo003o0?ooool0ooooo`3oool;0?ooo`00o`3ooooo0?ooool0oooo
2`3oool00?l0ooooo`3ooooo0?ooo`/0oooo003o0?ooool0ooooo`3oool;0?ooo`00o`3ooooo0?oo
ool0oooo2`3oool00?l0ooooo`3ooooo0?ooo`/0oooo003o0?ooool0ooooo`3oool;0?ooo`00o`3o
oooo0?ooool0oooo2`3oool00?l0ooooo`3ooooo0?ooo`/0oooo003o0?ooool0ooooo`3oool;0?oo
o`00B`3oool3000008L0oooo0`0000030?ooo`040000003oool0oooo0?ooo`<00000QP3oool30000
08L0oooo0`0000030?ooo`040000003oool0oooo0?ooo`<00000Q@3oool5000007l0oooo001:0?oo
o`050000003oool0oooo0?ooo`000000Q@3oool01@000000oooo0?ooo`3oool0000000T0oooo00<0
00000?ooo`3oool0Q03oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0P`3oool010000000oooo0?ooo`00001o0?ooo`00BP3oool01@000000oooo0?oo
o`3oool0000008D0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo08<0
oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo08<0
oooo00<000000?ooo`3oool0O`3oool004X0oooo00D000000?ooo`3oool0oooo000000250?ooo`05
0000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo
08L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo
07h0oooo001:0?ooo`050000003oool0oooo0?ooo`000000Q@3oool01@000000oooo0?ooo`3oool0
000000X0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`270?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`1n0?ooo`00BP3oool01@00
0000oooo0?ooo`3oool0000008D0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003o
ool0oooo08@0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0O@3oool004X0oooo00D000000?ooo`3oool0oooo0000
00250?ooo`050000003oool0oooo0?ooo`0000001P3oool3000008L0oooo00<000000?ooo`3oool0
Q`3oool00`000000oooo0?ooo`060?ooo`<00000R@3oool00`000000oooo0?ooo`1m0?ooo`00BP3o
ool01@000000oooo0?ooo`3oool0000008D0oooo00D000000?ooo`3oool0oooo000000060?ooo`03
0000003oool0oooo08L0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo08T0oooo00<000000?ooo`3oool0O@3oool004X0oooo00D000000?ooo`3oool0
oooo000000250?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`250?oo
o`800000R03oool2000000T0oooo00<000000?ooo`3oool0Q03oool01@000000oooo0?ooo`3oool0
000007l0oooo001;0?ooo`<00000Q`3oool3000000P0oooo100000250?ooo`030000003oool0oooo
08L0oooo00<000000?ooo`3oool01`3oool4000008@0oooo0`0000200?ooo`00o`3ooooo0?ooool0
oooo2`3oool00?l0ooooo`3ooooo0?ooo`/0oooo003o0?ooool0ooooo`3oool;0?ooo`00o`3ooooo
0?ooool0oooo2`3oool00?l0ooooo`3ooooo0?ooo`/0oooo003o0?ooool0ooooo`3oool;0?ooo`00
o`3ooooo0?ooool0oooo2`3oool00?l0ooooo`3ooooo0?ooo`/0oooo003o0?ooool0ooooo`3oool;
0?ooo`00o`3ooooo0?ooool0oooo2`3oool00?l0ooooo`3ooooo0?ooo`/0oooo000l0?ooool00000
o`000033000000/0oooo000l0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00@000000?ooo`3oool00000
2`3oool003`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`00000;0?ooo`00?03o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0S03o
ool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0LP3o
ool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo08/0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo08/0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`090?ooo`00?03oool00`00
0000oooo0?ooo`3o0?ooool0oooo_`3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000
oooo0?ooo`3o0?ooool0oooo_`3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo
0?ooo`3o0?ooool0oooo_`3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?oo
o`3o0?ooool0oooo_`3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o
0?ooool0oooo_`3oool00`000000oooo0?ooo`090?ooo`00;03oool3000000d0oooo00<000000?oo
o`3oool0^@3oool[00000?l0oooofP3oool00`000000oooo0?ooo`090?ooo`00:`3oool01@000000
oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0Q`3ooolb000002/0oooo7000003o0?oo
okh0oooo00<000000?ooo`3oool02@3oool002/0oooo00D000000?ooo`3oool0oooo0000000<0?oo
o`030000003oool0oooo05d0oooo:P00001i0?oooad00000o`3ooonQ0?ooo`030000003oool0oooo
00T0oooo000[0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`0[0?oo
oc800000`03ooolA00000?l0ooooT03oool00`000000oooo0?ooo`090?ooo`00:`3oool01@000000
oooo0?ooo`3oool0000000`0oooo1P00000;0?oooad00000o`3oool40?ooo`H00000E@3oool00`00
0000oooo0?ooo`1K0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0TP3oool60000
00/0oooo000[0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`3o0?oo
ocD0oooo1P00001?0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`2G0?ooo`030000003oool0oooo00T0oooo000[0?ooo`050000003oool0oooo0?oo
o`000000303oool00`000000oooo0?ooo`3o0?oooc/0oooo1P00001C0?ooo`<00000103oool30000
00<0oooo00@000000?ooo`3oool0oooo100000030?ooo`030000003oool0oooo00<0oooo0P00000d
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`09
0?ooo`00:`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0o`3ooom1
0?ooo`H00000C03oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo
0000000:0?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000<`3oool00`00
0000oooo0?ooo`0i0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool02@3oool002/0
oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo0?l0ooooA`3oool60000
04H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000002P3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool00000<`3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`8000001@3oool00`000000
oooo0?ooo`020?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`800000L`3oool00`000000
oooo0?ooo`090?ooo`00;03oool3000000d0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`H00000
@03oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000:0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool00000LP3oool00`000000oooo0?ooo`090?ooo`00?03o
ool00`000000oooo0?ooo`3o0?oooe<0oooo1P00000j0?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0000000;0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
oooo0P00000d0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0
oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooF@3oool6000003@0oooo0P0000020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool200000080oooo0P0000020?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`040?oo
o`@000000`3oool4000000H0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`090?ooo`00?03oool0
0`000000oooo0?ooo`3o0?oooel0oooo1P00000^0?ooo`040000003oool00000000000@0oooo00<0
00000?ooo`0000002P3oool00`000000oooo000000020?ooo`040000003oool0oooo000007T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool0oooo0P00001c0?ooo`030000003o
ool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooI@3oool6000001l0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000002P3o
ool200000080oooo00D000000?ooo`3oool0oooo0000001h0?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000000H0oooo00H000000?ooo`3oool0oooo0000003o
ool200000080oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`090?ooo`00?03oool0
0`000000oooo0?ooo`3o0?ooof/0oooo1P00000I0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000H0oooo00@000000?ooo`3oool0oooo
0P0000020?ooo`050000003oool0oooo0?ooo`000000N03oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000060?ooo`040000003oool0oooo0?ooo`8000000P3o
ool010000000oooo0?ooo`00001f0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003o
ool0oooo0?l0ooooL@3oool6000001<0oooo00<000000?ooo`3oool02@3oool2000000<0oooo0`00
00080?ooo`<000000P3oool2000000D0oooo00<000000?ooo`3oool0M@3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`3oool0oooo000000060?ooo`040000003oool0oooo0?oo
o`8000000P3oool01@000000oooo0?ooo`3oool0000007D0oooo00<000000?ooo`3oool02@3oool0
03`0oooo00<000000?ooo`3oool0o`3ooomg0?ooo`H000003@3oool00`000000oooo0?ooo`2M0?oo
o`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000H0oooo00@0
00000?ooo`3oool0oooo0P0000020?ooo`050000003oool0oooo0?ooo`000000M@3oool00`000000
oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooogd0oooo1P0000070?ooo`030000
003oool0oooo09h0oooo0`0000040?ooo`<00000203oool300000080oooo0P0000050?ooo`030000
003oool0oooo0780oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3o
oon30?ooo`H0000000<0oooo0000003oool0G03oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo09L0oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooon9
0?ooo`H00000F@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo09L0oooo00<00000
0?ooo`3oool02@3oool003`0oooo1000000=0?ooo`P000001P3oool8000000H0oooo200000060?oo
o`P000001P3oool8000000H0oooo200000060?ooo`P000001P3oool8000000H0oooo200000070?oo
o`P000001P3oool8000000H0oooo200000060?ooo`P000001P3oool8000000H0oooo200000060?oo
o`P000001P3oool8000000H0oooo200000060?ooo`P000001P3oool8000000H0oooo200000060?oo
o`P000001P3oool8000000H0oooo200000070?ooo`P000001P3oool8000000H0oooo200000050?oo
o`030000003oool0oooo0080oooo1P00001C0?ooo`030000003oool0oooo03T0oooo00<000000?oo
o`3oool0U03oool4000000/0oooo000l0?ooo`030000003oool0oooo0?l0ooooU@3oool6000004d0
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo00T0
oooo000l0?ooo`030000003oool0oooo0?l0ooooV`3oool6000004L0oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003o
ool0oooo0?l0ooooX@3oool600000440oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`2G0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooY`3oool6
000003/0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0
oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0oooo[@3oool6000003D0oooo00<000000?oo
o`3oool0>@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo00T0oooo000l0?ooo`03
0000003oool0oooo0?l0oooo/`3oool600000?l0oooo1P3oool00`000000oooo0?ooo`090?ooo`00
?03oool00`000000oooo0?ooo`3o0?oookT0oooo0`00003o0?ooo`<0oooo00<000000?ooo`3oool0
2@3oool003`0oooo00<000000?ooo`3oool0o`3ooonl0?ooo`030000003oool0oooo0?l0oooo00<0
00000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooonm0?ooo`030000003oool0
oooo0?h0oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooonn0?oo
o`800000oP3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?oool00
oooo00<000000?ooo`3oool0n`3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo
0?ooo`3o0?oool40oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`060?ooo`800000
1@3oool3000000@0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000D0
oooo0P00000B0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool02@3oool003`0oooo
00<000000?ooo`3oool0o`3oooo20?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0
oooo000000040?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0U`3oool00`00
0000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?oool<0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool02@3oool003`0
oooo00<000000?ooo`3oool0o`3oooo40?ooo`8000008P3oool00`000000oooo0?ooo`070?ooo`@0
00001P3oool00`000000oooo0?ooo`030?ooo`H00000103oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`090?oo
o`00?03oool400000?l0ooooa@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00H0
oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo000000050?ooo`040000003oool0oooo0?ooo`8000004P3oool00`000000oooo0?oo
o`2D0?ooo`@000002`3oool003`0oooo00<000000?ooo`3oool0o`3oooo70?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<0
00000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`8000000P3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool02@3oool003`0oooo00<0
00000?ooo`3oool0o`3oooo80?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3o
ool01@000000oooo0?ooo`3oool000000080oooo0`0000090?ooo`050000003oool000000?ooo`00
00000P3oool010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo09L0oooo00<000000?oo
o`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3oooo90?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool02@3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo0000
000D0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool02@3oool003`0oooo00<00000
0?ooo`3oool0o`3oooo:0?ooo`030000003oool0oooo02@0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo00T0oooo0P0000001@3oool000000?ooo`3oool0000000<0oooo
00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?oo
o`3o0?oool/0oooo0P00000U0?ooo`<00000103oool4000000T0oooo00<000000?ooo`3oool00P00
00050?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool02@3oool003`0oooo00<00000
0?ooo`3oool0o`3oooo=0?ooo`030000003oool0oooo0>h0oooo00<000000?ooo`3oool02@3oool0
03`0oooo00<000000?ooo`3oool0o`3oooo>0?ooo`030000003oool0oooo0>d0oooo00<000000?oo
o`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo0>`0
oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3oooo@0?ooo`030000
003oool0oooo0>/0oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3o
oooA0?ooo`8000005@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo09L0oooo00<0
00000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooC0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0
oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooe03oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`090?oo
o`00?03oool00`000000oooo0?ooo`3o0?ooomD0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool02@3oool003`0oooo
00<000000?ooo`3oool0o`3ooooF0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo00T0oooo000l0?ooo`@00000o`3o
oooF0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`2D0?ooo`@000002`3oool003`0oooo00<000000?ooo`3oool0o`3ooooH0?ooo`8000003P3oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool02@3oool0
03`0oooo00<000000?ooo`3oool0o`3ooooJ0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0>@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo00T0oooo000l0?ooo`03
0000003oool0oooo0?l0oooof`3oool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo00T0
oooo000l0?ooo`030000003oool0oooo0?l0oooog03oool00`000000oooo0?ooo`3O0?ooo`030000
003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0oooog@3oool00`000000oooo0?oo
o`3N0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0oooogP3oool2
00000=h0oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooP0?oo
o`030000003oool0oooo0=/0oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3o
ool0o`3ooooQ0?ooo`030000003oool0oooo0=X0oooo00<000000?ooo`3oool02@3oool003`0oooo
00<000000?ooo`3oool0o`3ooooR0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003o
ool0oooo0?l0ooooh`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0U`3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o
0?ooon@0oooo0P0000020?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0U`3oool0
0`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooonH0oooo00<000000?oo
o`000000>`3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo00T0oooo000l0?ooo`03
0000003oool0oooo0?l0ooooi`3oool2000003/0oooo00<000000?ooo`3oool0U`3oool00`000000
oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooonP0oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003o
ool0oooo0?l0ooooj03oool2000003X0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?oo
o`090?ooo`00?03oool4000000d0oooo200000060?ooo`P000001P3oool8000000H0oooo20000006
0?ooo`P000001P3oool8000000H0oooo200000060?ooo`P000001P3oool8000000L0oooo20000006
0?ooo`P000001P3oool8000000H0oooo200000060?ooo`P000001P3oool8000000H0oooo20000006
0?ooo`P000001P3oool8000000H0oooo200000060?ooo`P000001P3oool8000000H0oooo20000006
0?ooo`P000001P3oool8000000L0oooo200000060?ooo`P000001P3oool8000000H0oooo20000006
0?ooo`P000001P3oool8000000H0oooo200000060?ooo`P000001P3oool8000000H0oooo20000000
103oool000000?ooo`00000i0?ooo`030000003oool0oooo09@0oooo1000000;0?ooo`00?03oool0
0`000000oooo0?ooo`3o0?ooon/0oooo0P00003A0?ooo`030000003oool0oooo00T0oooo000l0?oo
o`030000003oool0oooo0?l0ooook@3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo
00T0oooo000l0?ooo`030000003oool0oooo0?l0ooookP3oool00`000000oooo0?ooo`3=0?ooo`03
0000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooook`3oool00`000000oooo
0?ooo`3<0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooool03o
ool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0
oooo0?l0ooool@3oool200000</0oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?oo
o`3oool0o`3ooooc0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0U`3oool00`00
0000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?oooo@0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000
003oool0oooo0?l0oooom@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo09L0oooo
00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3oooof0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`090?ooo`00?03oool0
0`000000oooo0?ooo`3o0?ooooL0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`2G
0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0oooon03oool20000
02X0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`090?ooo`00:`3oool3000000h0
oooo00<000000?ooo`3oool0o`3ooooj0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool0U`3oool00`000000oooo0?ooo`090?ooo`00;P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo0?l0oooon`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo09L0oooo
00<000000?ooo`3oool02@3oool002l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`3o0?oooo`0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`090?ooo`00;`3oool0
0`000000oooo0?ooo`0:0?ooo`H00000o`3ooooj0?ooo`030000003oool0oooo0;T0oooo1P00000;
0?ooo`00;`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0oooooP3oool20000
0;h0oooo00<000000?ooo`3oool02@3oool002h0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`3o0?ooool0oooo0@3oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo00T0
oooo000[0?ooo`<000003P3oool00`000000oooo0?ooo`3o0?ooool0oooo0P3oool00`000000oooo
0?ooo`2j0?ooo`030000003oool0oooo00T0oooo000[0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooo`<0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?oo
o`090?ooo`00;03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooo`3oool4
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`09
0?ooo`00;03oool4000000`0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`D0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo00T0oooo000l0?ooo`03
0000003oool0oooo0?l0ooooo`3oool60?ooo`8000007@3oool00`000000oooo0?ooo`2G0?ooo`03
0000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3oool80?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`090?ooo`00?03o
ool00`000000oooo0?ooo`3o0?ooool0oooo2@3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo09L0oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo
0?ooo`X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`2G0?ooo`030000003oool0
oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3oool;0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000
oooo0?ooo`3o0?ooool0oooo303oool2000001L0oooo00<000000?ooo`3oool0U`3oool00`000000
oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo3P3oool00`000000oooo
0?ooo`2^0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3o
ool?0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool02@3oool003`0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooa00oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`09
0?ooo`00?03oool400000?l0ooooo`3oool@0?ooo`030000003oool0oooo0:P0oooo1000000;0?oo
o`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo4P3oool00`000000oooo0?ooo`2Z0?ooo`03
0000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooolC0?ooo`800000
ZP3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo5@3o
ool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0
oooo0?l0ooooo`3ooolF0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0U`3oool0
0`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool02@3oool003`0
oooo00<000000?ooo`3oool0o`3ooooo0?oooaP0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`2G0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0oooo
o`3ooolI0?ooo`8000002P3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo00T0oooo
000l0?ooo`030000003oool0oooo0?l0ooooo`3ooolK0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0U`3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o
0?ooool0oooo703oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo09L0oooo00<00000
0?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooad0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo00T0oooo000l0?ooo`03
0000003oool0oooo00h0oooo200000060?ooo`P000001P3oool8000000H0oooo200000060?ooo`P0
00001P3oool8000000H0oooo200000060?ooo`P000001P3oool8000000L0oooo200000060?ooo`P0
00001P3oool8000000H0oooo200000060?ooo`P000001P3oool8000000H0oooo200000060?ooo`P0
00001P3oool8000000H0oooo200000060?ooo`P000001P3oool8000000H0oooo200000060?ooo`P0
00001P3oool8000000L0oooo200000060?ooo`P000001P3oool8000000H0oooo200000060?ooo`P0
00001P3oool8000000H0oooo200000060?ooo`P000001P3oool8000000H0oooo200000060?ooo`P0
00001P3oool8000000H0oooo200000060?ooo`P000001@3oool00`000000oooo0?ooo`2G0?ooo`03
0000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooolO0?ooo`030000
003oool0oooo09d0oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3o
oooo0?ooob00oooo0P00002M0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0
oooo0?l0ooooo`3ooolR0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool02@3oool0
03`0oooo00<000000?ooo`3oool0o`3ooooo0?ooob<0oooo00<000000?ooo`3oool0V@3oool00`00
0000oooo0?ooo`090?ooo`00?03oool400000?l0ooooo`3ooolS0?ooo`030000003oool0oooo09D0
oooo1000000;0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo9@3oool00`000000oooo
0?ooo`2G0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3o
oolV0?ooo`800000U`3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o
0?ooool0oooo:03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo00T0oooo000l0?oo
o`030000003oool0oooo0?l0ooooo`3ooolY0?ooo`030000003oool0oooo09<0oooo00<000000?oo
o`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooobX0oooo00<000000?ooo`3o
ool0TP3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo
:`3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003o
ool0oooo0?l0ooooo`3oool/0?ooo`800000T@3oool00`000000oooo0?ooo`090?ooo`00?03oool0
0`000000oooo0?ooo`3o0?ooool0oooo;P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3oool_0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooc00
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo
0?ooo`3o0?ooool0oooo<@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00T0oooo
000l0?ooo`030000003oool0oooo0?l0ooooo`3ooolb0?ooo`030000003oool0oooo08X0oooo00<0
00000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooc<0oooo0P00002:
0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooole0?oo
o`030000003oool0oooo08L0oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooocH0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`090?ooo`00
?03oool400000?l0ooooo`3ooolf0?ooo`030000003oool0oooo0880oooo1000000;0?ooo`00?03o
ool00`000000oooo0?ooo`3o0?ooool0oooo>03oool00`000000oooo0?ooo`240?ooo`030000003o
ool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3oooli0?ooo`800000Q03oool0
0`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo>`3oool00`00
0000oooo0?ooo`210?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0
ooooo`3oooll0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool02@3oool003`0oooo
00<000000?ooo`3oool0o`3ooooo0?ooocd0oooo00<000000?ooo`3oool0O`3oool00`000000oooo
0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo?P3oool00`000000oooo0?oo
o`1n0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooolo
0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?oo
o`3oool0o`3ooooo0?oood00oooo0P00001m0?ooo`030000003oool0oooo00T0oooo000l0?ooo`03
0000003oool0oooo0?l0ooooo`3ooom20?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3o
ool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oood<0oooo00<000000?ooo`3oool0
N@3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooA03o
ool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0
oooo0?l0ooooo`3ooom50?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool02@3oool0
03`0oooo00<000000?ooo`3oool0o`3ooooo0?ooodH0oooo0P00001g0?ooo`030000003oool0oooo
00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooom80?ooo`030000003oool0oooo07@0
oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooodT0oooo
00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`090?ooo`00?03oool400000?l0ooooo`3o
oom90?ooo`030000003oool0oooo06l0oooo1000000;0?ooo`00?03oool00`000000oooo0?ooo`3o
0?ooool0ooooBP3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo00T0oooo000l0?oo
o`030000003oool0oooo0?l0ooooo`3ooom;0?ooo`030000003oool0oooo0740oooo00<000000?oo
o`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oood/0oooo00<000000?ooo`3o
ool0L@3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo
B`3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003o
ool0oooo0?l0ooooo`3ooom<0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool02@3o
ool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oood`0oooo00<000000?ooo`3oool0L03oool0
0`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooC@3oool00`00
0000oooo0?ooo`1_0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0
ooooo`3ooom=0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool02@3oool003`0oooo
00<000000?ooo`3oool0o`3ooooo0?ooodd0oooo00<000000?ooo`3oool0K`3oool00`000000oooo
0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooCP3oool00`000000oooo0?oo
o`1^0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooom>
0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?oo
o`3oool0o`3ooooo0?ooodh0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`090?oo
o`009@3oool3000000@0oooo0`00000=0?ooo`030000003oool0oooo0?l0ooooo`3ooom?0?ooo`03
0000003oool0oooo06d0oooo00<000000?ooo`3oool02@3oool002H0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0o`3ooooo0?ooodl0
oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`090?ooo`009P3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`3o0?ooool0
ooooD03oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo00T0oooo000V0?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000<0?ooo`H00000o`3ooooo0?ooodd0
oooo00<000000?ooo`3oool0I`3oool6000000/0oooo000V0?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo0?l0ooooo`3ooom@0?ooo`03
0000003oool0oooo06`0oooo00<000000?ooo`3oool02@3oool002H0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0o`3ooooo0?oooe40
oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`090?ooo`009P3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`3o0?ooool0
ooooD@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00T0oooo000V0?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo0?l0
ooooo`3ooomA0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool02@3oool002D0oooo
0P0000040?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`3o0?ooool0
ooooDP3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo00T0oooo000V0?ooo`030000
003oool0oooo00<0oooo0`00000=0?ooo`030000003oool0oooo0?l0ooooo`3ooomB0?ooo`030000
003oool0oooo06X0oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3o
oooo0?oooe<0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`090?ooo`00?03oool0
0`000000oooo0?ooo`3o0?ooool0ooooD`3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0
oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomC0?ooo`030000003oool0oooo
06T0oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0
oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo
0?ooo`3o0?ooool0ooooE03oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00T0oooo
000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`030000003oool0oooo06P0oooo00<0
00000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooeD0oooo00<00000
0?ooo`3oool0I`3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?oo
ool0ooooE@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00T0oooo000l0?ooo`03
0000003oool0oooo0?l0ooooo`3ooomF0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3o
ool02@3oool003`0oooo1000003o0?ooool0ooooE@3oool00`000000oooo0?ooo`1S0?ooo`@00000
2`3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooeH0oooo00<000000?ooo`3oool0IP3o
ool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooE`3oool0
0`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo
0?l0ooooo`3ooomG0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool02@3oool003`0
oooo00<000000?ooo`3oool0o`3ooooo0?oooeL0oooo00<000000?ooo`3oool0I@3oool00`000000
oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooF03oool00`000000oooo
0?ooo`1T0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3o
oomH0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool02@3oool003`0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooeT0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`09
0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooF@3oool00`000000oooo0?ooo`1S0?oo
o`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomI0?ooo`03
0000003oool0oooo06<0oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0
o`3ooooo0?oooeX0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`090?ooo`00?03o
ool00`000000oooo0?ooo`3o0?ooool0ooooFP3oool00`000000oooo0?ooo`1R0?ooo`030000003o
ool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomJ0?ooo`030000003oool0
oooo0680oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oe/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000
oooo0?ooo`3o0?ooool0ooooF`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00T0
oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomL0?ooo`030000003oool0oooo0600oooo
00<000000?ooo`3oool02@3oool003`0oooo1000003o0?ooool0ooooF`3oool00`000000oooo0?oo
o`1M0?ooo`@000002`3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooe`0oooo00<00000
0?ooo`3oool0H03oool00`000000oooo0?ooo`090?ooo`00603oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`030000003oool0oooo05l0oooo00<000000?oo
o`3oool02@3oool001D0oooo1000000S0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`03
0000003oool0oooo05l0oooo00<000000?ooo`3oool02@3oool001<0oooo0P0000030?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo00<000000?ooo`3oool0
G`3oool00`000000oooo0?ooo`090?ooo`00403oool3000000D0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`3o0?ooool0ooooGP3oool00`000000oooo0?ooo`1N0?ooo`030000003o
ool0oooo00T0oooo000?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`3o0?ooool0ooooGP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0
oooo00T0oooo000@0?ooo`<000001@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
0?l0ooooo`3ooomO0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool02@3oool001<0
oooo0P0000030?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0o`3ooooo0?oooel0
oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`090?ooo`005@3oool4000002<0oooo
00<000000?ooo`3oool0o`3ooooo0?oooel0oooo00<000000?ooo`3oool0G@3oool00`000000oooo
0?ooo`090?ooo`00603oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0ooooo`3o
oomP0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool02@3oool001/0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`3o0?ooool0ooooH03oool00`000000oooo0?ooo`1L
0?ooo`030000003oool0oooo00T0oooo000I0?ooo`8000008@3oool00`000000oooo0?ooo`3o0?oo
ool0ooooH03oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00T0oooo000B0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3o0?ooool0
ooooH@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00T0oooo000B0?ooo`<00000
0P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0?l0ooooo`3ooomQ0?ooo`030000
003oool0oooo05/0oooo00<000000?ooo`3oool02@3oool001D0oooo1`00000P0?ooo`030000003o
ool0oooo0?l0ooooo`3ooomR0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool02@3o
ool001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`@00000o`3ooooo
0?ooof40oooo00<000000?ooo`3oool0E`3oool4000000/0oooo000D0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3o0?ooool0ooooHP3oool00`00
0000oooo0?ooo`1J0?ooo`030000003oool0oooo00T0oooo000C0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0o`3ooooo0?ooof<0oooo00<000000?ooo`3oool0F@3oool00`000000
oooo0?ooo`090?ooo`00303oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool0o`3ooooo0?ooof<0oooo00<000000?ooo`3oool0F@3oool00`000000oooo
0?ooo`090?ooo`00303oool00`000000oooo0?ooo`020?ooo`800000:@3oool00`000000oooo0?oo
o`3o0?ooool0ooooH`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo00T0oooo000<
0?ooo`070000003oool0oooo0?ooo`000000oooo0000000Y0?ooo`030000003oool0oooo0?l0oooo
o`3ooomT0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool02@3oool000d0oooo0`00
00000`3oool000000000000Y0?ooo`030000003oool0oooo0?l0ooooo`3ooomT0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo
0?ooofD0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`090?ooo`00?03oool00`00
0000oooo0?ooo`3o0?ooool0ooooI@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomU0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooofH0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?oo
o`3o0?ooool0ooooIP3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00T0oooo000l
0?ooo`030000003oool0oooo0?l0ooooo`3ooomV0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooofL0oooo00<000000?oo
o`3oool0E@3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0
ooooI`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000
003oool0oooo0?l0ooooo`3ooomX0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
2@3oool003`0oooo1000003o0?ooool0ooooI`3oool00`000000oooo0?ooo`1A0?ooo`@000002`3o
ool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooofP0oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooJ@3oool00`00
0000oooo0?ooo`1C0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0
ooooo`3ooomY0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool02@3oool003`0oooo
00<000000?ooo`3oool0o`3ooooo0?ooofT0oooo00<000000?ooo`3oool0D`3oool00`000000oooo
0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooJP3oool00`000000oooo0?oo
o`1B0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomZ
0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?oo
o`3oool0o`3ooooo0?ooof/0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`090?oo
o`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooJ`3oool00`000000oooo0?ooo`1A0?ooo`03
0000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooom[0?ooo`030000
003oool0oooo0540oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3o
oooo0?ooof`0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`090?ooo`00?03oool0
0`000000oooo0?ooo`3o0?ooool0ooooK03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0
oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooom/0?ooo`030000003oool0oooo
0500oooo00<000000?ooo`3oool02@3oool002D0oooo0`0000030?ooo`<000003P3oool00`000000
oooo0?ooo`3o0?ooool0ooooK@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00T0
oooo000V0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`3o0?ooool0ooooK@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00T0oooo
000V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`3o0?ooool0ooooKP3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00T0oooo000V
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool600000?l0ooooo`3ooom[
0?ooo`030000003oool0oooo04T0oooo1P00000;0?ooo`009P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooooo0?ooofh0oooo00<000000?oo
o`3oool0CP3oool00`000000oooo0?ooo`090?ooo`009P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooooo0?ooofl0oooo00<000000?ooo`3o
ool0C@3oool00`000000oooo0?ooo`090?ooo`009P3oool00`000000oooo0?ooo`020?ooo`<00000
3P3oool00`000000oooo0?ooo`3o0?ooool0ooooK`3oool00`000000oooo0?ooo`1=0?ooo`030000
003oool0oooo00T0oooo000V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`3o0?ooool0ooooK`3oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo00T0oooo000U0?ooo`8000001@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0?l0ooooo`3ooom`0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool02@3oool0
02H0oooo00<000000?ooo`3oool00`3oool4000000`0oooo00<000000?ooo`3oool0o`3ooooo0?oo
og00oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000
oooo0?ooo`3o0?ooool0ooooL@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00T0
oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3oooma0?ooo`030000003oool0oooo04/0oooo
00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooog40oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o
0?ooool0ooooLP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00T0oooo000l0?oo
o`030000003oool0oooo0?l0ooooo`3ooomb0?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooog80oooo00<000000?ooo`3o
ool0BP3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo
L`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003o
ool0oooo0?l0ooooo`3ooomc0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool02@3o
ool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`090?ooo`00?03oool400000?l0ooooo`3ooomc0?ooo`030000003oool0oooo
04D0oooo1000000;0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0oooo
o`3ooome0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool02@3oool003`0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooogD0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooM@3oool00`000000oooo0?ooo`17
0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomf0?oo
o`030000003oool0oooo04H0oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooogH0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`090?ooo`00
?03oool00`000000oooo0?ooo`3o0?ooool0ooooM`3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomg0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo
0?ooogL0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`090?ooo`00?03oool00`00
0000oooo0?ooo`3o0?ooool0ooooN03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo
00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomh0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooogP0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?oo
o`3k0?ooo`<000001@3oool3000000050?ooo`00000000000000003oool0200000001@3oool00000
000000000000oooo008000000`3oool300000080oooo0`0000001@3oool00000000000000000oooo
00<000000`3oool3000000<0oooo00<000000?ooo`3oool00`0000020?ooo`<00000103oool20000
00030?ooo`000000oooo0080oooo0`0000001@3oool00000000000000000oooo00<00000o`3ooolQ
0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?oo
o`3oool0o03oool00`000000oooo0?ooo`050?ooo`070000003oool0oooo0?ooo`000000oooo0000
00030?ooo`040000003oool0oooo000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo
000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000D0oooo
00@000000?ooo`3oool0oooo0P0000030?ooo`040000003oool0oooo000000<0oooo00@000000?oo
o`3oool000000P3oool3000000030?ooo`000000oooo0080oooo00<000000?ooo`0000000P3oool0
10000000oooo0?ooo`00003o0?ooob00oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?oo
o`090?ooo`00?03oool00`000000oooo0?ooo`3l0?ooo`030000003oool0oooo00D0oooo00L00000
0?ooo`3oool0oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool010000000
oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool00`3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000P3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo7`3o
ool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00T0oooo000l0?ooo`@00000n`3oool0
0`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000000P3oool400000080oooo00D0
00000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000
oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000001@3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
0?ooo`800000o`3ooolR0?ooo`030000003oool0oooo03l0oooo1000000;0?ooo`00?03oool00`00
0000oooo0?ooo`3l0?ooo`D000000`3oool01@000000oooo0?ooo`3oool0000000D0oooo00@00000
0?ooo`3oool000000`3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool5000000050?ooo`000000oooo0?oo
o`000000o`3ooolT0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool02@3oool003`0
oooo00<000000?ooo`3oool0o03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
00000P3oool00`000000oooo000000030?ooo`030000003oool00000008000000P3oool010000000
oooo0?ooo`0000030?ooo`060000003oool0oooo0?ooo`000000oooo0`0000020?ooo`8000000P3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`000000
0P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P0000020?ooo`07
0000003oool0oooo0?ooo`000000oooo000000020?ooo`040000003oool0oooo00000?l0oooo8P3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0
oooo0?`0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`000000oooo008000000`3o
ool3000000<0oooo00@000000?ooo`00000000000P3oool3000000<0oooo0`0000030?ooo`040000
003oool0000000000080oooo0P0000060?ooo`030000003oool0000000@0oooo00<000000?ooo`00
00000`3oool3000000@0oooo0P0000000`3oool000000?ooo`020?ooo`<000000P3oool010000000
oooo0?ooo`3oool300000?l0oooo8P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
00T0oooo000l0?ooo`030000003oool0oooo0?`0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`00000C0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`000000103oool00`00
0000oooo0000000=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooolV0?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3o
ool0o03oool00`000000oooo0?ooo`020?ooo`040000003oool00000000001<0oooo00<000000?oo
o`3oool05P3oool2000000H0oooo0P00000<0?ooo`8000001`3oool200000?l0oooo:@3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?/0
oooo1P0000030?ooo`030000003oool0oooo02T0oooo0`0000060?ooo`<00000303oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo9`3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomm0?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3o
oooo0?ooogd0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`090?ooo`00?03oool0
0`000000oooo0?ooo`3o0?ooool0ooooO@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0
oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomn0?ooo`030000003oool0oooo
03h0oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooogh0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo
0?ooo`3o0?ooool0ooooOP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00T0oooo
000l0?ooo`030000003oool0oooo0?l0ooooo`3ooomo0?ooo`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooogl0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?oo
ool0ooooP03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00T0oooo000l0?ooo`@0
0000o`3ooooo0?ooogl0oooo00<000000?ooo`3oool0>@3oool4000000/0oooo000l0?ooo`030000
003oool0oooo0?l0ooooo`3ooon00?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
2@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooh40oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooP@3oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo
0?l0ooooo`3ooon10?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool02@3oool003`0
oooo00<000000?ooo`3oool0o`3ooooo0?oooh80oooo00<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooPP3oool00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3o
oon30?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool02@3oool003`0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooh<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`09
0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooP`3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooon40?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0
o`3ooooo0?oooh@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`090?ooo`00?03o
ool00`000000oooo0?ooo`3o0?ooool0ooooQ03oool00`000000oooo0?ooo`0h0?ooo`030000003o
ool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooon50?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ohD0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000
oooo0?ooo`3o0?ooool0ooooQP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00T0
oooo000l0?ooo`@00000o`3ooooo0?ooohD0oooo00<000000?ooo`3oool0<`3oool4000000/0oooo
000l0?ooo`030000003oool0oooo0?l0ooooo`3ooon60?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooohL0oooo00<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?oo
ool0ooooQ`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00T0oooo000l0?ooo`03
0000003oool0oooo0?l0ooooo`3ooon70?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooohP0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooR03o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0
oooo0?l0ooooo`3ooon90?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02@3oool0
03`0oooo00<000000?ooo`3oool0o`3ooooo0?ooohT0oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooR@3oool00`000000
oooo0?ooo`0c0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0oooo
o`3ooon:0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool02@3oool003`0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooohX0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?oo
o`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooRP3oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo00T0oooo000T0?ooo`D000000`3oool3000000d0oooo00<000000?oo
o`3oool0o`3ooooo0?oooh/0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`090?oo
o`009@3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`000000303oool0
0`000000oooo0?ooo`3o0?ooool0ooooR`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo00T0oooo000V0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000<
0?ooo`030000003oool0oooo0?l0ooooo`3ooon<0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool02@3oool002L0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
oooo00X0oooo1P00003o0?ooool0ooooR@3oool00`000000oooo0?ooo`0[0?ooo`H000002`3oool0
02L0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooh`0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`09
0?ooo`00:03oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooohd0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`09
0?ooo`00:03oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooohd0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`09
0?ooo`00:03oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooohd0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`09
0?ooo`00903oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000
000<0?ooo`030000003oool0oooo0?l0ooooo`3ooon>0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool02@3oool002D0oooo0`0000040?ooo`<000003@3oool00`000000oooo0?ooo`3o
0?ooool0ooooSP3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00T0oooo000l0?oo
o`030000003oool0oooo0?l0ooooo`3ooon?0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooohl0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo
S`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003o
ool0oooo0?l0ooooo`3ooon@0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3o
ool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooi00oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooT03oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0
ooooo`3ooonA0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool003`0oooo
00<000000?ooo`3oool0o`3ooooo0?oooi40oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooTP3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo00T0oooo000l0?ooo`@00000o`3ooooo0?oooi40oooo00<00000
0?ooo`3oool09`3oool4000000/0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonB0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooi<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`00
?03oool00`000000oooo0?ooo`3o0?ooool0ooooT`3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonC0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo
0?oooi@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`00?03oool00`00
0000oooo0?ooo`3o0?ooool0ooooU03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonE0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooiD0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?oo
o`3o0?ooool0ooooU@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000l
0?ooo`030000003oool0oooo0?l0ooooo`3ooonF0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooiH0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0
ooooUP3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000
003oool0oooo0?l0ooooo`3ooonG0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
2@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooiL0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooV03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00T0oooo000l0?ooo`@00000o`3ooooo0?oo
oiL0oooo00<000000?ooo`3oool08@3oool4000000/0oooo000l0?ooo`030000003oool0oooo0?l0
ooooo`3ooonH0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool02@3oool003`0oooo
00<000000?ooo`3oool0o`3ooooo0?oooiT0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooV@3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonI
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?oo
o`3oool0o`3ooooo0?oooiX0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`090?oo
o`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooVP3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonK0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3o
oooo0?oooi/0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`090?ooo`00?03oool0
0`000000oooo0?ooo`3o0?ooool0ooooV`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonL0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooi`0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo
0?ooo`3o0?ooool0ooooW03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00T0oooo
000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonM0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooid0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?oo
ool0ooooWP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00T0oooo000l0?ooo`@0
0000o`3ooooo0?oooid0oooo00<000000?ooo`3oool06`3oool4000000/0oooo000l0?ooo`030000
003oool0oooo0?l0ooooo`3ooonN0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
2@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooil0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooW`3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo
0?l0ooooo`3ooonO0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool02@3oool003`0
oooo00<000000?ooo`3oool0o`3ooooo0?oooj00oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooX03oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3o
oonQ0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool02@3oool003`0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooj40oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`09
0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooX@3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonR0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0
o`3ooooo0?oooj80oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`090?ooo`00?03o
ool00`000000oooo0?ooo`3o0?ooool0ooooXP3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonS0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oj<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000
oooo0?ooo`3o0?ooool0ooooY03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00T0
oooo000l0?ooo`@00000o`3ooooo0?oooj<0oooo00<000000?ooo`3oool05@3oool4000000/0oooo
000l0?ooo`030000003oool0oooo0?l0ooooo`3ooonT0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooojD0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?oo
ool0ooooY@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00T0oooo000l0?ooo`03
0000003oool0oooo0?l0ooooo`3ooonU0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool02@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooojH0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooYP3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0
oooo0?l0ooooo`3ooonW0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02@3oool0
03`0oooo00<000000?ooo`3oool0o`3ooooo0?ooojL0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooY`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0oooo
o`3ooonX0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02@3oool003`0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooojP0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooZ03oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00T0oooo000T0?ooo`D000000P3oool3000000h0oooo00<000000?oo
o`3oool0o`3ooooo0?ooojT0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`090?oo
o`009@3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0o`3ooooo0?ooojT0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`090?oo
o`009P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooojX0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`090?ooo`00
9`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo1P00003o0?ooool0oooo
Y`3oool00`000000oooo0?ooo`0=0?ooo`H000002`3oool002L0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooo`3ooonZ0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool02@3oool002P0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooo`3ooon[0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool02@3oool002P0oooo00<000000?ooo`3oool00`00000>0?oo
o`030000003oool0oooo0?l0ooooo`3ooon[0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool02@3oool002P0oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`3o0?oo
ool0ooooZ`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00T0oooo000T0?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0?l0ooooo`3ooon/0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02@3oool002D0
oooo0`0000040?ooo`@00000303oool00`000000oooo0?ooo`3o0?ooool0oooo[03oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0oooo
o`3ooon]0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02@3oool003`0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooojd0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`090?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0oooo[@3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooon^0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooojh0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`00
?03oool00`000000oooo0?ooo`3o0?ooool0oooo_`3oool00`000000oooo0?ooo`090?ooo`00?03o
ool00`000000oooo0?ooo`3o0?ooool0oooo_`3oool00`000000oooo0?ooo`090?ooo`00?03oool0
0`000000oooo0?ooo`3o0?ooool0oooo_`3oool00`000000oooo0?ooo`090?ooo`00?03oool00`00
0000oooo0?ooo`3o0?ooool0oooo_`3oool00`000000oooo0?ooo`090?ooo`00?03oool400000?l0
ooooo`3ooonk0?ooo`@000002`3oool003`0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0S03oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool02@3oool003`0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo08`0oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo0780oooo00<0
00000?ooo`3oool02@3oool003`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`00
000;0?ooo`00?03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`040000003oool0oooo000000/0oooo000l
0?ooool00000o`000033000000/0oooo0000\
\>"],
  ImageRangeCache->{{{0, 775.75}, {479.063, 0}} -> {-0.27186, -3.63174, \
0.00350861, 0.0625282}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(plwp = 
      Show[{plw02p, plw10p, plw15p, plw20p}, 
        Epilog \[Rule] {Text["\<s=2\>", {0.1, \(-1.465\)}], 
            Text["\<s=1.5\>", {0.1, \(-1.22\)}], 
            Text["\<s=1.0\>", {0.1, \(-1.084\)}], 
            Text["\<s=0.2\>", {0.1, \(-0.998\)}]}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.476191 1.83962 1.23589 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.2619 -0.0125 -10.7813 -17.8125 ]
[.2619 -0.0125 10.7813 0 ]
[.5 -0.0125 -5.53125 -17.8125 ]
[.5 -0.0125 5.53125 0 ]
[.7381 -0.0125 -10.7813 -17.8125 ]
[.7381 -0.0125 10.7813 0 ]
[.97619 -0.0125 -5.53125 -17.8125 ]
[.97619 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.125 -35.625 ]
[.5 -0.0125 5.125 -17.8125 ]
[-0.0125 .10938 -31.25 -8.90625 ]
[-0.0125 .10938 0 8.90625 ]
[-0.0125 .23296 -31.25 -8.90625 ]
[-0.0125 .23296 0 8.90625 ]
[-0.0125 .35655 -31.25 -8.90625 ]
[-0.0125 .35655 0 8.90625 ]
[-0.0125 .48014 -31.25 -8.90625 ]
[-0.0125 .48014 0 8.90625 ]
[-0.0125 .60373 -20.75 -8.90625 ]
[-0.0125 .60373 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -49.0625 -14.7188 ]
[-0.01875 .30902 -31.25 14.7188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.07143 .02904 -12.7813 -8.90625 ]
[.07143 .02904 12.7813 8.90625 ]
[.07143 .33184 -18.0313 -8.90625 ]
[.07143 .33184 18.0313 8.90625 ]
[.07143 .49992 -18.0313 -8.90625 ]
[.07143 .49992 18.0313 8.90625 ]
[.07143 .6062 -18.0313 -8.90625 ]
[.07143 .6062 18.0313 8.90625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.125 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10938 m
.00625 .10938 L
s
gsave
-0.0125 .10938 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
0 .23296 m
.00625 .23296 L
s
gsave
-0.0125 .23296 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
1.000 setlinewidth
grestore
0 .35655 m
.00625 .35655 L
s
gsave
-0.0125 .35655 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
0 .48014 m
.00625 .48014 L
s
gsave
-0.0125 .48014 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
1.000 setlinewidth
grestore
0 .60373 m
.00625 .60373 L
s
gsave
-0.0125 .60373 -81.75 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .13409 m
.00375 .13409 L
s
0 .15881 m
.00375 .15881 L
s
0 .18353 m
.00375 .18353 L
s
0 .20825 m
.00375 .20825 L
s
0 .25768 m
.00375 .25768 L
s
0 .2824 m
.00375 .2824 L
s
0 .30712 m
.00375 .30712 L
s
0 .33184 m
.00375 .33184 L
s
0 .38127 m
.00375 .38127 L
s
0 .40599 m
.00375 .40599 L
s
0 .43071 m
.00375 .43071 L
s
0 .45542 m
.00375 .45542 L
s
0 .50486 m
.00375 .50486 L
s
0 .52958 m
.00375 .52958 L
s
0 .5543 m
.00375 .5543 L
s
0 .57901 m
.00375 .57901 L
s
0 .08466 m
.00375 .08466 L
s
0 .05994 m
.00375 .05994 L
s
0 .03522 m
.00375 .03522 L
s
0 .0105 m
.00375 .0105 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -115.875 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.7188 12.9063 translate
90 rotate
-75.7188 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.063 17.500 moveto
(H) show
77.625 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.875 17.500 moveto
(L) show
88.438 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .10938 m
1 .10938 L
s
.99375 .23296 m
1 .23296 L
s
.99375 .35655 m
1 .35655 L
s
.99375 .48014 m
1 .48014 L
s
.99375 .60373 m
1 .60373 L
s
.125 Mabswid
.99625 .13409 m
1 .13409 L
s
.99625 .15881 m
1 .15881 L
s
.99625 .18353 m
1 .18353 L
s
.99625 .20825 m
1 .20825 L
s
.99625 .25768 m
1 .25768 L
s
.99625 .2824 m
1 .2824 L
s
.99625 .30712 m
1 .30712 L
s
.99625 .33184 m
1 .33184 L
s
.99625 .38127 m
1 .38127 L
s
.99625 .40599 m
1 .40599 L
s
.99625 .43071 m
1 .43071 L
s
.99625 .45542 m
1 .45542 L
s
.99625 .50486 m
1 .50486 L
s
.99625 .52958 m
1 .52958 L
s
.99625 .5543 m
1 .5543 L
s
.99625 .57901 m
1 .57901 L
s
.99625 .08466 m
1 .08466 L
s
.99625 .05994 m
1 .05994 L
s
.99625 .03522 m
1 .03522 L
s
.99625 .0105 m
1 .0105 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .10938 m
1 .10938 L
s
.5 Mabswid
.02381 .59857 m
.06244 .59914 L
.10458 .5997 L
.14415 .60017 L
.18221 .60056 L
.22272 .60094 L
.26171 .60125 L
.30316 .60155 L
.34309 .60179 L
.3815 .602 L
.42237 .60219 L
.46172 .60235 L
.49955 .60248 L
.53984 .60261 L
.57861 .60272 L
.61984 .60282 L
.65954 .6029 L
.69774 .60298 L
.73838 .60304 L
.77751 .6031 L
.81909 .60316 L
.85916 .60321 L
.89771 .60325 L
.93871 .60329 L
.97619 .60332 L
s
.02381 .47623 m
.06244 .48699 L
.10458 .49867 L
.14415 .50916 L
.18221 .51858 L
.22272 .52777 L
.26171 .53575 L
.30316 .54332 L
.34309 .54979 L
.3815 .5553 L
.42237 .56047 L
.46172 .56485 L
.49955 .56858 L
.53984 .57209 L
.57861 .57507 L
.61984 .57787 L
.65954 .58025 L
.69774 .58229 L
.73838 .58422 L
.77751 .58587 L
.81909 .58744 L
.85916 .58878 L
.89771 .58995 L
.93871 .59106 L
.97619 .59198 L
s
.02381 .30198 m
.06244 .31618 L
.10458 .33549 L
.14415 .35559 L
.18221 .37547 L
.22272 .39629 L
.26171 .41538 L
.30316 .43427 L
.34309 .45092 L
.3815 .46546 L
.42237 .47938 L
.46172 .49137 L
.49955 .5017 L
.53984 .51151 L
.57861 .51993 L
.61984 .52789 L
.65954 .53471 L
.69774 .54057 L
.73838 .54614 L
.77751 .55094 L
.81909 .5555 L
.85916 .55943 L
.89771 .56284 L
.93871 .5661 L
.97619 .5688 L
s
.02381 .0269 m
.03279 .02315 L
.04262 .01985 L
.04758 .01849 L
.05288 .01728 L
.05785 .01636 L
.06244 .0157 L
.06503 .0154 L
.06788 .01513 L
.07075 .01493 L
.07232 .01485 L
.07379 .01479 L
.07445 .01477 L
.07517 .01475 L
.07648 .01473 L
.07776 .01472 L
.07895 .01472 L
.07968 .01472 L
.08036 .01473 L
.08164 .01476 L
.08236 .01478 L
.08302 .01481 L
.08451 .01487 L
.08691 .01501 L
.08916 .01518 L
.09427 .01572 L
.09924 .01641 L
.10458 .01736 L
.11475 .0197 L
.12582 .02301 L
.14594 .0309 L
.18672 .05303 L
.22599 .07998 L
.26374 .10907 L
.30394 .14169 L
.34263 .17338 L
.38377 .2064 L
.42339 .23687 L
.4615 .26458 L
.50206 .29215 L
.54111 .31674 L
.58261 .34078 L
.62259 .36196 L
.66106 .38062 L
.70197 .39872 L
.74138 .41459 L
.77926 .42852 L
.8196 .44204 L
.85843 .45389 L
.8997 .46536 L
Mistroke
.93947 .4754 L
.97619 .48389 L
Mfstroke
gsave
.07143 .02904 -73.7813 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
68.500 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
84.563 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.07143 .33184 -79.0313 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
68.500 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
95.063 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.07143 .49992 -79.0313 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
68.500 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.0) show
95.063 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.07143 .6062 -79.0313 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
68.500 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
95.063 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{787.063, 486.438},
  ImageMargins->{{44, 0}, {0, 2}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<C0001iR000`400?l00000o`00003oo`3ooooo
0?ooool0oooo5P3oool00?l0ooooo`3ooooo0?oooaH0oooo003o0?ooool0ooooo`3ooolF0?ooo`00
o`3ooooo0?ooool0oooo5P3oool00?l0ooooo`3ooooo0?oooaH0oooo003o0?ooojH0oooo1P00003o
0?ooofT0oooo003o0?ooojL0oooo00D000000?ooo`3oool0oooo0000003o0?ooofT0oooo003o0?oo
ojP0oooo00<000000?ooo`3oool0o`3ooomZ0?ooo`00o`3ooonX0?ooo`030000003oool0oooo0?l0
ooooJP3oool00?l0ooooZ@3oool00`000000oooo0?ooo`3o0?ooofT0oooo003o0?ooojH0oooo00D0
00000?ooo`3oool0oooo0000003o0?ooofX0oooo003o0?ooojH0oooo1P00003o0?ooofT0oooo003o
0?ooool0ooooo`3ooolF0?ooo`00o`3ooooo0?ooool0oooo5P3oool00?l0ooooo`3ooooo0?oooaH0
oooo003o0?ooool0ooooo`3ooolF0?ooo`00o`3ooooo0?ooool0oooo5P3oool00?l0ooooo`3ooooo
0?oooaH0oooo003o0?ooool0ooooo`3ooolF0?ooo`00o`3ooooo0?ooool0oooo5P3oool00?l0oooo
o`3ooooo0?oooaH0oooo003o0?ooool0ooooo`3ooolF0?ooo`00o`3ooooo0?ooool0oooo5P3oool0
05<0oooo0`00002Q0?ooo`<000000`3oool010000000oooo0?ooo`3oool300000:80oooo0`00002R
0?ooo`<000000`3oool010000000oooo0?ooo`3oool300000:00oooo1@00000F0?ooo`00DP3oool0
1@000000oooo0?ooo`3oool0000009l0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000
003oool0oooo0:00oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo09h0oooo00@000000?ooo`3oool000005P3oool00580oooo00D000000?ooo`3oool0
oooo0000002O0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`2O0?oo
o`030000003oool0oooo0:80oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2N0?oo
o`030000003oool0oooo01H0oooo001B0?ooo`050000003oool0oooo0?ooo`000000W`3oool01@00
0000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`2R
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0E
0?ooo`00DP3oool01@000000oooo0?ooo`3oool0000009l0oooo00D000000?ooo`3oool0oooo0000
000:0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool05@3oool00580oooo00D00000
0?ooo`3oool0oooo0000002O0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo
0?ooo`2P0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`2Q0?ooo`030000003oool0oooo01@0oooo001B0?ooo`050000003oool0oooo0?ooo`000000
W`3oool01@000000oooo0?ooo`3oool0000000H0oooo0`00002S0?ooo`030000003oool0oooo0:80
oooo00<000000?ooo`3oool01P3oool300000:@0oooo00<000000?ooo`3oool0503oool00580oooo
00D000000?ooo`3oool0oooo0000002O0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`00
0000oooo0?ooo`2S0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo01@0oooo001B0?ooo`050000003oool0oooo0?oo
o`000000W`3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0X@3oool2
00000:<0oooo0P0000090?ooo`030000003oool0oooo09l0oooo00D000000?ooo`3oool0oooo0000
000F0?ooo`00D`3oool300000:40oooo0`0000080?ooo`@00000X@3oool00`000000oooo0?ooo`2R
0?ooo`030000003oool0oooo00L0oooo1000002O0?ooo`<000005`3oool00?l0ooooo`3ooooo0?oo
oaH0oooo003o0?ooool0ooooo`3ooolF0?ooo`00o`3ooooo0?ooool0oooo5P3oool00?l0ooooo`3o
oooo0?oooaH0oooo003o0?ooool0ooooo`3ooolF0?ooo`00o`3ooooo0?ooool0oooo5P3oool00?l0
ooooo`3ooooo0?oooaH0oooo003o0?ooool0ooooo`3ooolF0?ooo`00o`3ooooo0?ooool0oooo5P3o
ool00?l0ooooo`3ooooo0?oooaH0oooo003o0?ooool0ooooo`3ooolF0?ooo`00o`3ooooo0?ooool0
oooo5P3oool004<0ooooo`00003o00000<`000001P3oool004<0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00@0oooo00130?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0Y`3oool00`00
0000oooo0?ooo`2W0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0Y`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo0:H0
oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0
oooo00130?ooo`030000003oool0oooo0?l0ooooo`3oooo80?ooo`030000003oool0oooo00@0oooo
00130?ooo`030000003oool0oooo0?l0ooooo`3oooo80?ooo`030000003oool0oooo00@0oooo0013
0?ooo`@00000o`3ooooo0?oool@0oooo100000060?ooo`00@`3oool00`000000oooo0?ooo`3o0?oo
ool0oooob03oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooool0
oooob03oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`0^0?oooa400000
o`3ooooo0?ooohT0oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool09P3o
ool800000140oooo1`00003o0?ooool0ooooPP3oool00`000000oooo0?ooo`040?ooo`00@`3oool0
0`000000oooo0?ooo`0R0?ooo`@00000803oool400000?l0ooooo`3ooomn0?ooo`030000003oool0
oooo00@0oooo00130?ooo`030000003oool0oooo01h0oooo1000000X0?ooo`@00000o`3ooooo0?oo
ogX0oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool06`3oool300000300
oooo0`00003o0?ooool0ooooM`3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo
0?ooo`0G0?ooo`@00000=P3oool400000?l0ooooo`3ooomc0?ooo`030000003oool0oooo00@0oooo
00130?ooo`030000003oool0oooo01@0oooo0`00000n0?ooo`@00000o`3ooooo0?ooofl0oooo00<0
00000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool04P3oool200000180oooo0`00000<
0?ooo`D000007`3oool200000?l0ooooo`3ooom]0?ooo`030000003oool0oooo00@0oooo00130?oo
o`030000003oool0oooo0100oooo0P00000D0?ooo`040000003oool0oooo00000080oooo1`000003
0?ooo`040000003oool0oooo00000240oooo0P00003o0?ooool0ooooJ`3oool00`000000oooo0?oo
o`040?ooo`00@`3oool00`000000oooo0?ooo`0>0?ooo`8000006@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo02<0oooo0`00003o0?ooool0ooooJ03oool00`000000oooo0?ooo`04
0?ooo`00@`3oool00`000000oooo0?ooo`0W0?ooo`8000003`3oool00`000000oooo0?ooo`0U0?oo
o`800000o`3ooooo0?ooofH0oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`030?ooo`L000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000o`3ooooo0?ooof@0oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0
9P3oool010000000oooo0?ooo`00000?0?ooo`030000003oool0oooo02P0oooo0P00003o0?ooool0
ooooHP3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`0W0?ooo`<00000
3`3oool00`000000oooo0?ooo`0Z0?ooo`800000o`3ooooo0?ooof00oooo00<000000?ooo`3oool0
103oool004<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0/0?ooo`800000o`3o
oooo0?oooeh0oooo00<000000?ooo`3oool0103oool004<0oooo1000000d0?ooo`050000003oool0
oooo0?ooo`000000<03oool200000?l0ooooo`3ooomI0?ooo`@000001P3oool004<0oooo00<00000
0?ooo`3oool0=P3oool3000003<0oooo0P00003o0?ooool0ooooFP3oool00`000000oooo0?ooo`04
0?ooo`00@`3oool00`000000oooo0?ooo`1^0?ooo`800000o`3ooooo0?oooeP0oooo00<000000?oo
o`3oool0103oool004<0oooo00<000000?ooo`3oool0L03oool200000?l0ooooo`3ooomF0?ooo`03
0000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0780oooo0P00003o0?ooool0oooo
E03oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`1d0?ooo`800000o`3o
oooo0?oooe80oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0MP3oool2
00000?l0ooooo`3ooom@0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo
07P0oooo0P00003o0?ooool0ooooCP3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000
oooo0?ooo`1j0?ooo`800000o`3ooooo0?oood`0oooo00<000000?ooo`3oool0103oool004<0oooo
00<000000?ooo`3oool0O03oool200000?l0ooooo`3ooom:0?ooo`030000003oool0oooo00@0oooo
00130?ooo`030000003oool0oooo07h0oooo0P00003o0?ooool0ooooB03oool00`000000oooo0?oo
o`040?ooo`00@`3oool00`000000oooo0?ooo`200?ooo`800000o`3ooooo0?ooodH0oooo00<00000
0?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`3o0?oo
ool0oooo@`3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`230?ooo`80
0000o`3ooooo0?oood<0oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0
Q@3oool00`000000oooo0?ooo`3o0?ooool0oooo@03oool00`000000oooo0?ooo`040?ooo`00@`3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0?l0ooooo`3ooolo0?ooo`030000003o
ool0oooo00@0oooo00130?ooo`030000003oool0oooo08L0oooo0P00003o0?ooool0oooo?`3oool0
0`000000oooo0?ooo`040?ooo`00@`3oool4000008P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ocT0oooo100000060?ooo`00@`3oool00`000000oooo0?ooo`2:0?ooo`800000o`3ooooo0?oooc`0
oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0S03oool00`000000oooo
0?ooo`3o0?ooool0oooo>@3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo0?l0ooooo`3ooolh0?ooo`030000003oool0oooo00@0oooo0013
0?ooo`030000003oool0oooo08h0oooo0P00003o0?ooool0oooo>03oool00`000000oooo0?ooo`04
0?ooo`00@`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0?l0ooooo`3ooole0?oo
o`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0940oooo0P00003o0?ooool0
oooo=@3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`2C0?ooo`030000
003oool0oooo0?l0ooooo`3ooolb0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003o
ool0oooo09@0oooo00<000000?ooo`3oool0o`3ooooo0?oooc40oooo00<000000?ooo`3oool0103o
ool004<0oooo00<000000?ooo`3oool0U@3oool200000?l0ooooo`3ooola0?ooo`030000003oool0
oooo00@0oooo00130?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0o`3ooooo0?oo
obh0oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0V03oool200000?l0
ooooo`3oool^0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo09X0oooo
00<000000?ooo`3oool0o`3ooooo0?ooob/0oooo00<000000?ooo`3oool0103oool004<0oooo00<0
00000?ooo`3oool0V`3oool00`000000oooo0?ooo`3o0?ooool0oooo:P3oool00`000000oooo0?oo
o`040?ooo`00@`3oool00`000000oooo0?ooo`2L0?ooo`800000o`3ooooo0?ooobX0oooo00<00000
0?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`3o0?oo
ool0oooo9`3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`2O0?ooo`80
0000o`3ooooo0?ooobL0oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0
X@3oool00`000000oooo0?ooo`3o0?ooool0oooo903oool00`000000oooo0?ooo`040?ooo`00@`3o
ool400000:40oooo00<000000?ooo`3oool0o`3ooooo0?ooob00oooo100000060?ooo`00@`3oool0
0`000000oooo0?ooo`2S0?ooo`800000o`3ooooo0?ooob<0oooo00<000000?ooo`3oool0103oool0
04<0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`3o0?ooool0oooo803oool00`00
0000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0
ooooo`3ooolO0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0:L0oooo
0P00003o0?ooool0oooo7`3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?oo
o`2Y0?ooo`030000003oool0oooo0?l0ooooo`3ooolL0?ooo`030000003oool0oooo00@0oooo0013
0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0o`3ooooo0?oooa/0oooo00<00000
0?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0Z`3oool200000?l0ooooo`3ooolK0?oo
o`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooaP0oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0
[P3oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool00`000000oooo0?ooo`040?ooo`00@`3o
ool00`000000oooo0?ooo`2_0?ooo`800000o`3ooooo0?oooaL0oooo00<000000?ooo`3oool0103o
ool004<0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`3o0?ooool0oooo503oool0
0`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo
0?l0ooooo`3ooolC0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0;<0
oooo0P00003o0?ooool0oooo4`3oool00`000000oooo0?ooo`040?ooo`00:@3oool3000000<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0;D0oooo
00<000000?ooo`3oool0o`3ooooo0?oooa00oooo00<000000?ooo`3oool0103oool002X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0;H0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooo`l0oooo00<000000?ooo`3oool0103oool002X0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0;L0oooo0P00003o
0?ooool0oooo3`3oool00`000000oooo0?ooo`040?ooo`007P3oool7000000D0oooo00<000000?oo
o`3oool01@3oool6000000/0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`3o0?oo
ool0oooo303oool00`000000oooo0?ooo`040?ooo`00:P3oool00`000000oooo0?ooo`050?ooo`05
0000003oool0oooo0?ooo`000000303ooooo00000?l00000c00000060?ooo`00:P3oool00`000000
oooo0?ooo`060?ooo`040000003oool0oooo000000`0oooo00<000000?ooo`3oool0^`3oool20000
0?l0ooooo`3oool;0?ooo`030000003oool0oooo00@0oooo000Z0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo0?l0
ooooo`3oool80?ooo`030000003oool0oooo00@0oooo000Z0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`000000303oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo0?l0oooo
o`3oool70?ooo`030000003oool0oooo00@0oooo000Y0?ooo`8000002P3oool2000000`0oooo00<0
00000?ooo`3oool0_`3oool00`000000oooo0?ooo`3o0?ooool0oooo1P3oool00`000000oooo0?oo
o`040?ooo`00:P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0`03oool00`000000oooo0?ooo`3o0?ooool0oooo1@3oool00`000000oooo0?ooo`04
0?ooo`00@`3oool00`000000oooo0?ooo`310?ooo`800000o`3ooooo0?ooo`D0oooo00<000000?oo
o`3oool0103oool004<0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`3o0?ooool0
oooo0P3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`340?ooo`030000
003oool0oooo0?l0ooooo`3oool10?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003o
ool0oooo0<D0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`030000003oool0oooo00@0oooo0013
0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool0o`3oooon0?ooo`030000003oool0
oooo00@0oooo00130?ooo`030000003oool0oooo0<L0oooo0P00003o0?ooooh0oooo00<000000?oo
o`3oool0103oool004<0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`3o0?oooo/0
oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0bP3oool00`000000oooo
0?ooo`3o0?ooooX0oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0b`3o
ool00`000000oooo0?ooo`3o0?ooooT0oooo00<000000?ooo`3oool0103oool004<0oooo00<00000
0?ooo`3oool0c03oool00`000000oooo0?ooo`3o0?ooooP0oooo00<000000?ooo`3oool0103oool0
04<0oooo00<000000?ooo`3oool0c@3oool200000?l0oooon03oool00`000000oooo0?ooo`040?oo
o`00@`3oool400000<h0oooo00<000000?ooo`3oool0o`3oooob0?ooo`@000001P3oool004<0oooo
00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`3o0?oooo@0oooo00<000000?ooo`3oool0
103oool004<0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`3o0?oooo<0oooo00<0
00000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`3o
0?oooo80oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0d`3oool20000
0?l0oooolP3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`3E0?ooo`03
0000003oool0oooo0?l0ooook`3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo
0?ooo`3F0?ooo`030000003oool0oooo0?l0ooookP3oool00`000000oooo0?ooo`040?ooo`00@`3o
ool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo0?l0ooook@3oool00`000000oooo0?oo
o`040?ooo`00@`3oool00`000000oooo0?ooo`3H0?ooo`800000o`3oooo]0?ooo`030000003oool0
oooo00@0oooo00130?ooo`030000003oool0oooo0=X0oooo00<000000?ooo`3oool0o`3ooooZ0?oo
o`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0=/0oooo00<000000?ooo`3o
ool0o`3ooooY0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0=`0oooo
00<000000?ooo`3oool0o`3ooooX0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003o
ool0oooo0=d0oooo0P00003o0?ooonP0oooo00<000000?ooo`3oool0103oool004<0oooo00<00000
0?ooo`3oool0g`3oool00`000000oooo0?ooo`3o0?ooonD0oooo00<000000?ooo`3oool0103oool0
04<0oooo00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`3o0?ooon@0oooo00<000000?oo
o`3oool0103oool004<0oooo00<000000?ooo`3oool0h@3oool200000?l0ooooi03oool00`000000
oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`3S0?ooo`030000003oool0oooo0?l0oooo
h@3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`3T0?ooo`030000003o
ool0oooo0?l0ooooh03oool00`000000oooo0?ooo`040?ooo`00@`3oool400000>@0oooo00<00000
0?ooo`3oool0o`3ooooL0?ooo`@000001P3oool004<0oooo00<000000?ooo`3oool0iP3oool20000
0?l0oooog`3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`3X0?ooo`03
0000003oool0oooo0?l0oooog03oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo
0?ooo`3Y0?ooo`030000003oool0oooo0?l0oooof`3oool00`000000oooo0?ooo`040?ooo`00@`3o
ool00`000000oooo0?ooo`3Z0?ooo`030000003oool0oooo0?l0oooofP3oool00`000000oooo0?oo
o`040?ooo`00@`3oool00`000000oooo0?ooo`3[0?ooo`800000o`3ooooJ0?ooo`030000003oool0
oooo00@0oooo00130?ooo`030000003oool0oooo0>d0oooo00<000000?ooo`3oool0o`3ooooG0?oo
o`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0>h0oooo00<000000?ooo`3o
ool0o`3ooooF0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0>l0oooo
0P00003o0?ooomH0oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0l@3o
ool00`000000oooo0?ooo`3o0?ooom<0oooo00<000000?ooo`3oool0103oool004<0oooo00<00000
0?ooo`3oool0lP3oool00`000000oooo0?ooo`3o0?ooom80oooo00<000000?ooo`3oool0103oool0
04<0oooo00<000000?ooo`3oool0l`3oool00`000000oooo0?ooo`3o0?ooom40oooo00<000000?oo
o`3oool0103oool004<0oooo00<000000?ooo`3oool0m03oool200000?l0ooood@3oool00`000000
oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`3f0?ooo`030000003oool0oooo0?l0oooo
cP3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`3g0?ooo`030000003o
ool0oooo0?l0ooooc@3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`3h
0?ooo`030000003oool0oooo0?l0ooooc03oool00`000000oooo0?ooo`040?ooo`00@`3oool00`00
0000oooo0?ooo`3i0?ooo`030000003oool0oooo0?l0oooob`3oool00`000000oooo0?ooo`040?oo
o`00@`3oool400000?T0oooo0P00003o0?ooolP0oooo100000060?ooo`00@`3oool00`000000oooo
0?ooo`3l0?ooo`030000003oool0oooo0?l0oooob03oool00`000000oooo0?ooo`040?ooo`00@`3o
ool00`000000oooo0?ooo`3m0?ooo`030000003oool0oooo0?l0ooooa`3oool00`000000oooo0?oo
o`040?ooo`00@`3oool00`000000oooo0?ooo`3n0?ooo`030000003oool0oooo0?l0ooooaP3oool0
0`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooo`030000003oool0oooo
0?l0ooooa@3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooo`40
oooo0P00003o0?ooolD0oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0
o`3oool30?ooo`030000003oool0oooo0?l0oooo`P3oool00`000000oooo0?ooo`040?ooo`00@`3o
ool00`000000oooo0?ooo`3o0?ooo`@0oooo00<000000?ooo`3oool0o`3oooo10?ooo`030000003o
ool0oooo00@0oooo00130?ooo`030000003oool0oooo0?l0oooo1@3oool00`000000oooo0?ooo`3o
0?oool00oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0o`3oool60?oo
o`030000003oool0oooo0?l0oooo_`3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000
oooo0?ooo`3o0?ooo`L0oooo0P00003o0?oookl0oooo00<000000?ooo`3oool0103oool004<0oooo
00<000000?ooo`3oool0o`3oool90?ooo`030000003oool0oooo0?l0oooo_03oool00`000000oooo
0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool0o`3o
oonk0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0?l0oooo2`3oool0
0`000000oooo0?ooo`3o0?oookX0oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?oo
o`3oool0o`3oool<0?ooo`030000003oool0oooo0?l0oooo^@3oool00`000000oooo0?ooo`040?oo
o`00@`3oool00`000000oooo0?ooo`3o0?ooo`d0oooo0P00003o0?oookT0oooo00<000000?ooo`3o
ool0103oool004<0oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003oool0oooo0?l0oooo
]P3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool0o`3ooone0?ooo`030000003oool0oooo00@0oooo00130?ooo`@00000o`3oool@
0?ooo`030000003oool0oooo0?l0oooo/@3oool4000000H0oooo00130?ooo`030000003oool0oooo
0?l0oooo4P3oool200000?l0oooo]03oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000
oooo0?ooo`3o0?oooa@0oooo00<000000?ooo`3oool0o`3ooona0?ooo`030000003oool0oooo00@0
oooo00130?ooo`030000003oool0oooo0?l0oooo5@3oool00`000000oooo0?ooo`3o0?oook00oooo
00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`800000o`3o
oon`0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0?l0oooo603oool0
0`000000oooo0?ooo`3o0?ooojd0oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?oo
o`3oool0o`3ooolI0?ooo`030000003oool0oooo0?l0oooo[03oool00`000000oooo0?ooo`040?oo
o`00@`3oool00`000000oooo0?ooo`3o0?oooaX0oooo0P00003o0?oooj`0oooo00<000000?ooo`3o
ool0103oool004<0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo0?l0oooo
Z@3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`3o0?oooad0oooo00<0
00000?ooo`3oool0o`3ooonX0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0
oooo0?l0oooo7P3oool200000?l0ooooZ03oool00`000000oooo0?ooo`040?ooo`00@`3oool00`00
0000oooo0?ooo`3o0?ooob00oooo00<000000?ooo`3oool0o`3ooonU0?ooo`030000003oool0oooo
00@0oooo00130?ooo`030000003oool0oooo0?l0oooo8@3oool00`000000oooo0?ooo`3o0?oooj@0
oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0o`3ooolR0?ooo`800000
o`3ooonT0?ooo`030000003oool0oooo00@0oooo000Y0?ooo`<000000`3oool010000000oooo0?oo
o`3oool4000000`0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo0?l0oooo
X@3oool00`000000oooo0?ooo`040?ooo`00:P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`030000003oool0oooo0?l0ooooX03o
ool00`000000oooo0?ooo`040?ooo`00:P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`800000o`3ooonP0?ooo`030000003oool0
oooo00@0oooo000N0?ooo`L000001@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`030000003oool0oooo0?l0ooooW@3oool00`00
0000oooo0?ooo`040?ooo`00:P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo1P00003o0?ooobH0oooo00<000000?ooo`3oool0o`3ooonH0?ooo`D000001P3oool002X0oooo
00<000000?ooo`3oool0203oool2000000`0oooo00<000000?ooo`3oool0o`3ooolZ0?ooo`800000
o`3ooonL0?ooo`030000003oool0oooo00@0oooo000Z0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?ooob`0oooo00<000000?ooo`3oool0o`3o
oonI0?ooo`030000003oool0oooo00@0oooo000Z0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooobd0oooo0P00003o0?oooiT0oooo00<00000
0?ooo`3oool0103oool002T0oooo0P0000080?ooo`050000003oool0oooo0?ooo`0000002`3oool0
0`000000oooo0?ooo`3o0?ooobl0oooo00<000000?ooo`3oool0o`3ooonF0?ooo`030000003oool0
oooo00@0oooo000Z0?ooo`030000003oool0oooo00L0oooo0`00000<0?ooo`030000003oool0oooo
0?l0oooo<03oool00`000000oooo0?ooo`3o0?oooiD0oooo00<000000?ooo`3oool0103oool004<0
oooo00<000000?ooo`3oool0o`3ooola0?ooo`800000o`3ooonE0?ooo`030000003oool0oooo00@0
oooo00130?ooo`030000003oool0oooo0?l0oooo<`3oool00`000000oooo0?ooo`3o0?oooi80oooo
00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0o`3ooold0?ooo`030000003o
ool0oooo0?l0ooooT@3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`3o
0?ooocD0oooo0P00003o0?oooi40oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?oo
o`3oool0o`3ooolg0?ooo`030000003oool0oooo0?l0ooooSP3oool00`000000oooo0?ooo`040?oo
o`00@`3oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool0o`3ooon=0?ooo`03
0000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0?l0oooo>@3oool200000?l0oooo
S@3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`3o0?oooc/0oooo00<0
00000?ooo`3oool0o`3ooon:0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0
oooo0?l0oooo?03oool00`000000oooo0?ooo`3o0?ooohT0oooo00<000000?ooo`3oool0103oool0
04<0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`800000o`3ooon90?ooo`030000003oool0oooo
00@0oooo00130?ooo`030000003oool0oooo0?l0oooo?`3oool00`000000oooo0?ooo`3o0?ooohH0
oooo00<000000?ooo`3oool0103oool004<0oooo1000003o0?ooocl0oooo00<000000?ooo`3oool0
o`3ooon20?ooo`@000001P3oool004<0oooo00<000000?ooo`3oool0o`3ooom10?ooo`800000o`3o
oon50?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0?l0oooo@`3oool0
0`000000oooo0?ooo`3o0?oooh80oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?oo
o`3oool0o`3ooom40?ooo`030000003oool0oooo0?l0ooooP@3oool00`000000oooo0?ooo`040?oo
o`00@`3oool00`000000oooo0?ooo`3o0?ooodD0oooo0P00003o0?oooh40oooo00<000000?ooo`3o
ool0103oool004<0oooo00<000000?ooo`3oool0o`3ooom70?ooo`030000003oool0oooo0?l0oooo
OP3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooodP0oooo0P00
003o0?ooogh0oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0o`3ooom:
0?ooo`030000003oool0oooo0?l0ooooN`3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`00
0000oooo0?ooo`3o0?oood/0oooo0P00003o0?ooog/0oooo00<000000?ooo`3oool0103oool004<0
oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo0?l0ooooN03oool00`000000
oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0
o`3ooomg0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0?l0ooooC`3o
ool200000?l0ooooM`3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`3o
0?oooe40oooo00<000000?ooo`3oool0o`3ooomd0?ooo`030000003oool0oooo00@0oooo00130?oo
o`030000003oool0oooo0?l0ooooDP3oool200000?l0ooooM03oool00`000000oooo0?ooo`040?oo
o`00@`3oool00`000000oooo0?ooo`3o0?oooe@0oooo00<000000?ooo`3oool0o`3oooma0?ooo`03
0000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0?l0ooooE@3oool200000?l0oooo
L@3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`3o0?oooeL0oooo00<0
00000?ooo`3oool0o`3ooom^0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0
oooo0?l0ooooF03oool200000?l0ooooKP3oool00`000000oooo0?ooo`040?ooo`00@`3oool40000
0?l0ooooF@3oool00`000000oooo0?ooo`3o0?ooofP0oooo100000060?ooo`00@`3oool00`000000
oooo0?ooo`3o0?oooe/0oooo0P00003o0?ooof/0oooo00<000000?ooo`3oool0103oool004<0oooo
00<000000?ooo`3oool0o`3ooomM0?ooo`030000003oool0oooo0?l0ooooJ03oool00`000000oooo
0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool0o`3o
oomW0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0?l0ooooG`3oool2
00000?l0ooooI`3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`3o0?oo
of40oooo00<000000?ooo`3oool0o`3ooomT0?ooo`030000003oool0oooo00@0oooo00130?ooo`03
0000003oool0oooo0?l0ooooHP3oool200000?l0ooooI03oool00`000000oooo0?ooo`040?ooo`00
303oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0?l0ooooI03oool00`000000oooo
0?ooo`3o0?ooof40oooo00<000000?ooo`3oool0103oool000`0oooo0`00000d0?ooo`030000003o
ool0oooo0?l0ooooI@3oool200000?l0ooooH@3oool00`000000oooo0?ooo`040?ooo`00303oool0
0`000000oooo0?ooo`0300000340oooo00<000000?ooo`3oool0o`3ooomW0?ooo`800000o`3ooomO
0?ooo`030000003oool0oooo00@0oooo000A0?ooo`800000<03oool00`000000oooo0?ooo`3o0?oo
ofT0oooo00<000000?ooo`3oool0o`3ooomL0?ooo`030000003oool0oooo00@0oooo000<0?ooo`03
0000003oool0oooo00800000<P3oool00`000000oooo0?ooo`3o0?ooofX0oooo0P00003o0?oooe`0
oooo00<000000?ooo`3oool0103oool000`0oooo0`00000d0?ooo`030000003oool0oooo0?l0oooo
K03oool200000?l0ooooFP3oool00`000000oooo0?ooo`040?ooo`00303oool00`000000oooo0?oo
o`0300000340oooo00<000000?ooo`3oool0o`3ooom^0?ooo`030000003oool0oooo0?l0ooooE`3o
ool00`000000oooo0?ooo`040?ooo`004@3oool200000300oooo00<000000?ooo`3oool03P3oool2
00000?l0ooooG`3oool200000?l0ooooE`3oool00`000000oooo0?ooo`040?ooo`00303oool00`00
0000oooo0?ooo`0200000380oooo00<000000?ooo`3oool0403oool300000?l0ooooGP3oool00`00
0000oooo0?ooo`3o0?oooe@0oooo00<000000?ooo`3oool0103oool000`0oooo0`00000d0?ooo`03
0000003oool0oooo01<0oooo0P00003o0?oooed0oooo0P00003o0?oooe@0oooo00<000000?ooo`3o
ool0103oool000`0oooo00<000000?ooo`3oool0=03oool4000001@0oooo0`00003o0?oooe`0oooo
0P00003o0?ooodl0oooo100000060?ooo`002`3oool9000002l0oooo00<000000?ooo`3oool0603o
ool300000?l0ooooF`3oool00`000000oooo0?ooo`3o0?ooodl0oooo00<000000?ooo`3oool0103o
ool000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo01/0oooo0`00003o0?oooeT0oooo0P00003o0?ooodl0oooo00<000000?ooo`3oool0103oool0
00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
01h0oooo0`00003o0?oooeP0oooo0P00003o0?ooodd0oooo00<000000?ooo`3oool0103oool004<0
oooo00<000000?ooo`3oool08@3oool200000?l0ooooF03oool00`000000oooo0?ooo`3o0?ooodX0
oooo00<000000?ooo`3oool0103oool000`0oooo0P0000040?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool08`3oool300000?l0ooooEP3oool200000?l0ooooBP3oool00`000000oooo
0?ooo`040?ooo`00303oool00`000000oooo0?ooo`020?ooo`800000<03oool00`000000oooo0?oo
o`0V0?ooo`<00000o`3ooomE0?ooo`800000o`3ooom80?ooo`030000003oool0oooo00@0oooo000<
0?ooo`030000003oool0oooo0080000000<0oooo0000003oool0;`3oool00`000000oooo0?ooo`0Y
0?ooo`<00000o`3ooomD0?ooo`030000003oool0oooo0?l0ooooA@3oool00`000000oooo0?ooo`04
0?ooo`00303oool00`000000oooo000000030?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool0;03oool200000?l0ooooD`3oool200000?l0ooooA@3oool00`000000oooo0?ooo`040?oo
o`00303oool2000000@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0^0?ooo`80
0000o`3ooomC0?ooo`800000o`3ooom30?ooo`030000003oool0oooo00@0oooo000<0?ooo`030000
003oool0oooo0080oooo0P00000`0?ooo`030000003oool0oooo0300oooo0P00003o0?oooe<0oooo
0P00003o0?oood40oooo00<000000?ooo`3oool0103oool000T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0380oooo0P00003o0?oooe<0oooo00<0
00000?ooo`3oool0o`3oooln0?ooo`030000003oool0oooo00@0oooo000:0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0d0?ooo`800000o`3ooomB
0?ooo`800000o`3oooln0?ooo`030000003oool0oooo00@0oooo000;0?ooo`T00000;`3oool00`00
0000oooo0?ooo`0f0?ooo`800000o`3ooomB0?ooo`800000o`3oooll0?ooo`030000003oool0oooo
00@0oooo00130?ooo`030000003oool0oooo0240oooo0`00000=0?ooo`<000000`3oool700000?l0
ooooCP3oool200000?l0oooo>P3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo
0?ooo`0Q0?ooo`040000003oool0oooo00000080oooo1`0000040?ooo`030000003oool0oooo00H0
oooo0P0000000`3oool000000?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0o`3ooolg0?ooo`03
0000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`080?ooo`<00000o`3ooom?0?ooo`800000o`3ooolg0?ooo`030000
003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0280oooo0P00000>0?ooo`030000003o
ool0oooo00X0oooo0P00003o0?oooe00oooo0P00003o0?ooocD0oooo00<000000?ooo`3oool0103o
ool004<0oooo1000000P0?ooo`030000003oool0oooo00<0oooo1`0000040?ooo`030000003oool0
oooo00X0oooo00@000000?ooo`0000000000o`3ooom@0?ooo`800000o`3oool`0?ooo`@000001P3o
ool004<0oooo00<000000?ooo`3oool08@3oool010000000oooo0?ooo`00000=0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00P3oool200000?l0ooooD03oool200000?l0oooo<@3o
ool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`0R0?ooo`<000003@3oool0
0`000000oooo0?ooo`060?ooo`<000001`3oool200000?l0ooooD03oool00`000000oooo0?ooo`3o
0?ooobh0oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo0P00003o0?ooodl0oooo0P00003o0?oo
obh0oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0<@3oool2000000T0
oooo00<000000?ooo`3oool02P3oool200000?l0ooooC`3oool200000?l0oooo;03oool00`000000
oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00L0oooo
1000000;0?ooo`800000o`3ooom?0?ooo`800000o`3ooolZ0?ooo`030000003oool0oooo00@0oooo
00130?ooo`030000003oool0oooo04d0oooo0P00003o0?ooodl0oooo00<000000?ooo`3oool0o`3o
oolW0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo04l0oooo0P00003o
0?ooodh0oooo0P00003o0?ooobL0oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?oo
o`3oool0D@3oool200000?l0ooooCP3oool200000?l0oooo9@3oool00`000000oooo0?ooo`040?oo
o`00@`3oool00`000000oooo0?ooo`1C0?ooo`800000o`3ooom>0?ooo`800000o`3ooolS0?ooo`03
0000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo05D0oooo0P00003o0?ooodh0oooo
00<000000?ooo`3oool0o`3ooolP0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003o
ool0oooo05L0oooo0P00003o0?ooodd0oooo0P00003o0?ooob00oooo00<000000?ooo`3oool0103o
ool004<0oooo00<000000?ooo`3oool0F@3oool200000?l0ooooC@3oool200000?l0oooo7P3oool0
0`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`1K0?ooo`800000o`3ooom=0?oo
o`800000o`3ooolL0?ooo`030000003oool0oooo00@0oooo000Y0?ooo`<000000`3oool010000000
oooo0?ooo`3oool5000000/0oooo00<000000?ooo`3oool0G@3oool200000?l0ooooC@3oool00`00
0000oooo0?ooo`3o0?oooaT0oooo00<000000?ooo`3oool0103oool002X0oooo00<000000?ooo`3o
ool01`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo05l0oooo0P00003o0?oo
od`0oooo0P00003o0?oooaT0oooo00<000000?ooo`3oool0103oool002X0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0640oooo0P00003o0?oood`0
oooo0P00003o0?oooaL0oooo00<000000?ooo`3oool0103oool001h0oooo1`0000050?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1S0?ooo`800000
o`3ooom<0?ooo`800000o`3ooolE0?ooo`030000003oool0oooo00@0oooo000Z0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02P3oool600000680oooo0P00003o0?oood`0oooo00<0
00000?ooo`3oool0o`3oool>0?ooo`D000001P3oool002X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo06L0oooo0P00003o0?oood/0oooo0P00003o
0?oooa80oooo00<000000?ooo`3oool0103oool002X0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo06T0oooo0P00003o0?oood/0oooo0P00003o0?oo
oa00oooo00<000000?ooo`3oool0103oool002X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo06/0oooo0P00003o0?oood/0oooo0P00003o0?ooo`h0
oooo00<000000?ooo`3oool0103oool002T0oooo0P0000080?ooo`050000003oool0oooo0?ooo`00
00002`3oool00`000000oooo0?ooo`1]0?ooo`800000o`3ooom;0?ooo`800000o`3oool<0?ooo`03
0000003oool0oooo00@0oooo000Z0?ooo`030000003oool0oooo00L0oooo0`00000<0?ooo`030000
003oool0oooo06l0oooo0P00003o0?oood/0oooo0P00003o0?ooo`X0oooo00<000000?ooo`3oool0
103oool004<0oooo00<000000?ooo`3oool0L@3oool200000?l0ooooB`3oool200000?l0oooo203o
ool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`1c0?ooo`800000o`3ooom;
0?ooo`800000o`3oool60?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo
07D0oooo0P00003o0?oood/0oooo0P00003o0?ooo`@0oooo00<000000?ooo`3oool0103oool004<0
oooo00<000000?ooo`3oool0M`3oool200000?l0ooooB`3oool200000?l0oooo0P3oool00`000000
oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`1i0?ooo`800000o`3ooom;0?ooo`800000
o`3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`1k0?ooo`800000o`3o
oom;0?ooo`800000o@3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`1m
0?ooo`800000o`3ooom;0?ooo`800000n`3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`00
0000oooo0?ooo`1o0?ooo`030000003oool0oooo0?l0ooooBP3oool200000?T0oooo00<000000?oo
o`3oool0103oool004<0oooo00<000000?ooo`3oool0P03oool200000?l0ooooC03oool200000?L0
oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0PP3oool200000?l0oooo
C03oool200000?D0oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0Q03o
ool200000?l0ooooC03oool200000?<0oooo00<000000?ooo`3oool0103oool004<0oooo10000025
0?ooo`800000o`3ooom<0?ooo`<00000k@3oool4000000H0oooo00130?ooo`030000003oool0oooo
08P0oooo0P00003o0?ooodd0oooo0P00003^0?ooo`030000003oool0oooo00@0oooo00130?ooo`03
0000003oool0oooo08X0oooo0P00003o0?ooodd0oooo0P00003/0?ooo`030000003oool0oooo00@0
oooo00130?ooo`030000003oool0oooo08`0oooo0P00003o0?ooodd0oooo0`00003Y0?ooo`030000
003oool0oooo00@0oooo00130?ooo`030000003oool0oooo08h0oooo0P00003o0?ooodh0oooo0P00
003W0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0900oooo0P00003o
0?ooodh0oooo0P00003U0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo
0980oooo0P00003o0?ooodh0oooo0P00003S0?ooo`030000003oool0oooo00@0oooo00130?ooo`03
0000003oool0oooo09@0oooo0P00003o0?ooodh0oooo0`00003P0?ooo`030000003oool0oooo00@0
oooo00130?ooo`030000003oool0oooo09H0oooo0P00003o0?ooodl0oooo0P00003N0?ooo`030000
003oool0oooo00@0oooo00130?ooo`030000003oool0oooo09P0oooo0P00003o0?ooodl0oooo0P00
003L0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo09X0oooo0P00003o
0?ooodl0oooo0`00003I0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo
09`0oooo00<000000?ooo`3oool0o`3ooom?0?ooo`800000e`3oool00`000000oooo0?ooo`040?oo
o`00@`3oool00`000000oooo0?ooo`2M0?ooo`800000o`3ooomA0?ooo`800000e@3oool00`000000
oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`2O0?ooo`800000o`3ooomA0?ooo`<00000
dP3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`2Q0?ooo`800000o`3o
oomB0?ooo`800000d03oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`2S
0?ooo`800000o`3ooomB0?ooo`<00000c@3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`00
0000oooo0?ooo`2U0?ooo`800000o`3ooomC0?ooo`800000b`3oool00`000000oooo0?ooo`040?oo
o`00@`3oool00`000000oooo0?ooo`2W0?ooo`800000o`3ooomC0?ooo`<00000b03oool00`000000
oooo0?ooo`040?ooo`00@`3oool400000:P0oooo0P00003o0?oooe@0oooo0P0000330?ooo`@00000
1P3oool004<0oooo00<000000?ooo`3oool0Z`3oool200000?l0ooooE03oool300000<<0oooo00<0
00000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0[@3oool200000?l0ooooE@3oool3
00000<00oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0[`3oool20000
0?l0ooooEP3oool200000;h0oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3o
ool0/@3oool200000?l0ooooEP3oool300000;/0oooo00<000000?ooo`3oool0103oool004<0oooo
00<000000?ooo`3oool0/`3oool200000?l0ooooE`3oool200000;T0oooo00<000000?ooo`3oool0
103oool004<0oooo00<000000?ooo`3oool0]@3oool200000?l0ooooE`3oool300000;H0oooo00<0
00000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0]`3oool300000?l0ooooE`3oool3
00000;<0oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0^P3oool20000
0?l0ooooF03oool200000;40oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3o
ool0_03oool200000?l0ooooF03oool300000:h0oooo00<000000?ooo`3oool0103oool004<0oooo
00<000000?ooo`3oool0_P3oool200000?l0ooooF@3oool300000:/0oooo00<000000?ooo`3oool0
103oool004<0oooo00<000000?ooo`3oool0`03oool300000?l0ooooF@3oool200000:T0oooo00<0
00000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0``3oool200000?l0ooooF@3oool3
00000:H0oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0a@3oool20000
0?l0ooooFP3oool300000:<0oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3o
ool0a`3oool200000?l0ooooF`3oool200000:40oooo00<000000?ooo`3oool0103oool004<0oooo
00<000000?ooo`3oool0b@3oool200000?l0ooooF`3oool3000009h0oooo00<000000?ooo`3oool0
103oool004<0oooo00<000000?ooo`3oool0b`3oool300000?l0ooooF`3oool3000009/0oooo00<0
00000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0cP3oool200000?l0ooooG03oool3
000009P0oooo00<000000?ooo`3oool0103oool004<0oooo1000003?0?ooo`800000o`3ooomM0?oo
o`800000T`3oool4000000H0oooo00130?ooo`030000003oool0oooo0=80oooo0P00003o0?oooed0
oooo0`00002C0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0=@0oooo
0`00003o0?oooed0oooo0`00002@0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003o
ool0oooo0=L0oooo0P00003o0?oooeh0oooo0`00002=0?ooo`030000003oool0oooo00@0oooo0013
0?ooo`030000003oool0oooo0=T0oooo0`00003o0?oooeh0oooo0`00002:0?ooo`030000003oool0
oooo00@0oooo00130?ooo`030000003oool0oooo0=`0oooo0P00003o0?oooel0oooo0P0000280?oo
o`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0=h0oooo0P00003o0?oooel0
oooo0`0000250?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0>00oooo
0`00003o0?oooel0oooo0`0000220?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003o
ool0oooo0><0oooo0P00003o0?ooof00oooo0`00001o0?ooo`030000003oool0oooo00@0oooo0013
0?ooo`030000003oool0oooo0>D0oooo0`00003o0?ooof00oooo1000001k0?ooo`030000003oool0
oooo00@0oooo00130?ooo`030000003oool0oooo0>P0oooo0P00003o0?ooof80oooo0`00001h0?oo
o`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0>X0oooo0P00003o0?ooof<0
oooo1000001d0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0>`0oooo
0`00003o0?ooof@0oooo0`00001a0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003o
ool0oooo0>l0oooo0P00003o0?ooofD0oooo1000001]0?ooo`030000003oool0oooo00@0oooo0013
0?ooo`030000003oool0oooo0?40oooo0`00003o0?ooofH0oooo0`00001Z0?ooo`030000003oool0
oooo00@0oooo00130?ooo`030000003oool0oooo0?@0oooo0`00003o0?ooofH0oooo1000001V0?oo
o`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0?L0oooo0P00003o0?ooofP0
oooo0`00001S0?ooo`030000003oool0oooo00@0oooo00130?ooo`@00000n03oool300000?l0oooo
J03oool4000005`0oooo100000060?ooo`00@`3oool00`000000oooo0?ooo`3l0?ooo`<00000o`3o
oomY0?ooo`@00000F`3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`3o
0?ooo`800000o`3ooom[0?ooo`@00000E`3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`00
0000oooo0?ooo`3o0?ooo`80oooo0`00003o0?ooof`0oooo0`00001D0?ooo`030000003oool0oooo
00@0oooo00130?ooo`030000003oool0oooo0?l0oooo1@3oool300000?l0ooooK03oool400000500
oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0o`3oool80?ooo`800000
o`3ooom^0?ooo`@00000C03oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?oo
o`3o0?ooo`X0oooo0`00003o0?ooofl0oooo100000180?ooo`030000003oool0oooo00@0oooo0013
0?ooo`030000003oool0oooo0?l0oooo3@3oool300000?l0ooooL03oool3000004D0oooo00<00000
0?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0o`3oool@0?ooo`<00000o`3ooom`0?oo
o`@00000@@3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`3o0?oooa<0
oooo0`00003o0?ooog40oooo1000000m0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000
003oool0oooo0?l0oooo5P3oool300000?l0ooooLP3oool4000003T0oooo00<000000?ooo`3oool0
103oool004<0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`<00000o`3ooomc0?ooo`@00000=@3o
ool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`3o0?oooa`0oooo0P00003o
0?ooogD0oooo1000000a0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo
0?l0oooo7P3oool300000?l0ooooMP3oool4000002d0oooo00<000000?ooo`3oool0103oool002T0
oooo0`0000030?ooo`030000003oool0oooo0080oooo0`00000<0?ooo`030000003oool0oooo0?l0
oooo8@3oool300000?l0ooooM`3oool5000002P0oooo00<000000?ooo`3oool0103oool002X0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo
0P00003o0?oooa@0oooo0`00003o0?ooogT0oooo1000000T0?ooo`030000003oool0oooo00@0oooo
000Z0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0@0?ooo`@00000o`3ooolC0?ooo`<00000o`3ooomj0?ooo`@00000803oool00`000000oooo0?oo
o`040?ooo`007P3oool7000000D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo01@0oooo0`00003o0?oooa<0oooo0`00003o0?ooog/0oooo1@00000K
0?ooo`030000003oool0oooo00@0oooo000Z0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool02`3oool6000001@0oooo1000003o0?oooa80oooo0`00003o0?ooogd0oooo1000000C0?oo
o`D000001P3oool002X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo01/0oooo0`00003o0?oooa80oooo0`00003o0?ooogh0oooo1000000C0?ooo`03
0000003oool0oooo00@0oooo000Z0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0N0?ooo`@00000o`3ooolA0?ooo`<00000o`3ooomo0?ooo`<00000
403oool00`000000oooo0?ooo`040?ooo`00:P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool08P3oool300000?l0oooo4@3oool300000?l0ooooS`3o
ool00`000000oooo0?ooo`040?ooo`00:@3oool2000000T0oooo0P00000=0?ooo`030000003oool0
oooo02D0oooo1000003o0?oooa00oooo1000003o0?oooh/0oooo00<000000?ooo`3oool0103oool0
02X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
02T0oooo0`00003o0?oooa40oooo0`00003o0?ooohP0oooo00<000000?ooo`3oool0103oool004<0
oooo00<000000?ooo`3oool0;03oool400000?l0oooo403oool300000?l0ooooQ@3oool00`000000
oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`0`0?ooo`@00000o`3oool?0?ooo`<00000
o`3ooon20?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo03@0oooo1000
003o0?ooo`h0oooo0`00003o0?ooogl0oooo00<000000?ooo`3oool0103oool004<0oooo00<00000
0?ooo`3oool0>03oool300000?l0oooo3P3oool400000?l0ooooN`3oool00`000000oooo0?ooo`04
0?ooo`00@`3oool00`000000oooo0?ooo`0Q0?ooo`<000003@3oool3000000<0oooo00@000000?oo
o`3oool0oooo1000003o0?ooo`h0oooo1000003o0?ooogL0oooo00<000000?ooo`3oool0103oool0
04<0oooo00<000000?ooo`3oool08@3oool010000000oooo0?ooo`0000020?ooo`L00000103oool0
0`000000oooo0?ooo`060?ooo`040000003oool0oooo0?ooo`@00000o`3oool>0?ooo`@00000o`3o
oomc0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000`3o
ool400000?l0oooo3P3oool400000?l0ooooK`3oool00`000000oooo0?ooo`040?ooo`00@`3oool0
0`000000oooo0?ooo`0R0?ooo`8000003P3oool00`000000oooo0?ooo`060?ooo`050000003oool0
oooo0?ooo`0000001`3oool300000?l0oooo3`3oool400000?l0ooooJ`3oool00`000000oooo0?oo
o`040?ooo`00@`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00<0oooo1`000004
0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`@00000o`3o
ool?0?ooo`@00000o`3ooomW0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0
oooo0240oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`060?ooo`050000003o
ool0oooo0?ooo`0000003P3oool400000?l0oooo3`3oool400000?l0ooooH`3oool00`000000oooo
0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`0R0?ooo`<000003@3oool00`000000oooo0?oo
o`060?ooo`050000003oool0oooo0?ooo`0000004P3oool400000?l0oooo3`3oool400000?l0oooo
G`3oool00`000000oooo0?ooo`040?ooo`00@`3oool400000340oooo00<000000?ooo`3oool01P3o
ool01@000000oooo0?ooo`3oool0000001H0oooo1000003o0?ooo`l0oooo1000003o0?oooeP0oooo
100000060?ooo`00@`3oool00`000000oooo0?ooo`0a0?ooo`800000203oool01@000000oooo0?oo
o`3oool0000001X0oooo1000003o0?ooo`l0oooo1000003o0?oooeL0oooo00<000000?ooo`3oool0
103oool004<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`070?ooo`<000007`3o
ool400000?l0oooo3`3oool400000?l0ooooD`3oool00`000000oooo0?ooo`040?ooo`00@`3oool0
0`000000oooo0?ooo`1R0?ooo`@00000o`3oool?0?ooo`@00000o`3ooom?0?ooo`030000003oool0
oooo00@0oooo00130?ooo`030000003oool0oooo06H0oooo1000003o0?ooo`l0oooo1000003o0?oo
od/0oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0JP3oool400000?l0
oooo3`3oool500000?l0ooooAP3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo
0?ooo`1^0?ooo`@00000o`3oool@0?ooo`@00000o`3ooom20?ooo`030000003oool0oooo00@0oooo
00130?ooo`030000003oool0oooo0780oooo1000003o0?oooa00oooo1@00003o0?ooocd0oooo00<0
00000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0MP3oool400000?l0oooo4@3oool5
00000?l0oooo>03oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`1j0?oo
o`@00000o`3ooolB0?ooo`@00000o`3ooold0?ooo`030000003oool0oooo00@0oooo00130?ooo`03
0000003oool0oooo07h0oooo1000003o0?oooa80oooo1@00003o0?ooobl0oooo00<000000?ooo`3o
ool0103oool004<0oooo00<000000?ooo`3oool0PP3oool400000?l0oooo4`3oool500000?l0oooo
:P3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`260?ooo`@00000o`3o
oolD0?ooo`D00000o`3ooolU0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0
oooo08X0oooo1000003o0?oooaD0oooo1@00003o0?ooob00oooo00<000000?ooo`3oool0103oool0
04<0oooo00<000000?ooo`3oool0SP3oool400000?l0oooo5P3oool400000?l0oooo703oool00`00
0000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`2B0?ooo`@00000o`3ooolF0?ooo`D0
0000o`3ooolG0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo09H0oooo
1000003o0?oooaL0oooo1@00003o0?oooa80oooo00<000000?ooo`3oool0103oool004<0oooo00<0
00000?ooo`3oool0VP3oool500000?l0oooo5`3oool500000?l0oooo3@3oool00`000000oooo0?oo
o`040?ooo`00@`3oool4000009h0oooo1P00003o0?oooaH0oooo1P00003o0?ooo`@0oooo10000006
0?ooo`00@`3oool00`000000oooo0?ooo`2U0?ooo`D00000o`3ooolG0?ooo`D00000o`3oool20?oo
o`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0:X0oooo1P00003o0?oooaH0
oooo1P00003k0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0;00oooo
1P00003o0?oooaH0oooo1P00003e0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003o
ool0oooo0;H0oooo1@00003o0?oooaL0oooo1P00003_0?ooo`030000003oool0oooo00@0oooo0013
0?ooo`030000003oool0oooo0;/0oooo1@00003o0?oooaP0oooo1`00003X0?ooo`030000003oool0
oooo00@0oooo00130?ooo`030000003oool0oooo0<00oooo1@00003o0?oooaX0oooo1`00003Q0?oo
o`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0<D0oooo1000003o0?oooad0
oooo1`00003J0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0<T0oooo
1@00003o0?oooal0oooo1`00003C0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003o
ool0oooo0<h0oooo1@00003o0?ooob40oooo1`00003<0?ooo`030000003oool0oooo00@0oooo0013
0?ooo`030000003oool0oooo0=<0oooo1P00003o0?ooob80oooo200000340?ooo`030000003oool0
oooo00@0oooo00130?ooo`030000003oool0oooo0=T0oooo1`00003o0?ooob<0oooo1`00002m0?oo
o`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0>00oooo2000003o0?ooob80
oooo2000002e0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0>P0oooo
1`00003o0?ooob<0oooo2@00002/0?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003o
ool0oooo0>l0oooo1`00003o0?ooobD0oooo2@00002S0?ooo`030000003oool0oooo00@0oooo0013
0?ooo`030000003oool0oooo0?H0oooo1`00003o0?ooobL0oooo2@00002J0?ooo`030000003oool0
oooo00@0oooo00130?ooo`030000003oool0oooo0?d0oooo1P00003o0?ooobX0oooo2P00002@0?oo
o`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0?l0oooo103oool700000?l0
oooo;@3oool:000008H0oooo00<000000?ooo`3oool0103oool004<0oooo1000003o0?ooo`X0oooo
1`00003o0?oooc00oooo2P00001i0?ooo`@000001P3oool004<0oooo00<000000?ooo`3oool0o`3o
oolB0?ooo`L00000o`3ooolc0?ooo`X00000LP3oool00`000000oooo0?ooo`040?ooo`00@`3oool0
0`000000oooo0?ooo`3o0?oooaT0oooo2000003o0?ooocD0oooo2P00001X0?ooo`030000003oool0
oooo00@0oooo00130?ooo`030000003oool0oooo0?l0oooo8@3oool700000?l0oooo>03oool90000
05l0oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`P0
0000o`3oooli0?ooo`T00000EP3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo
0?ooo`3o0?oooc00oooo2@00003o0?ooocT0oooo2@00001=0?ooo`030000003oool0oooo00@0oooo
00130?ooo`030000003oool0oooo0?l0oooo>@3oool:00000?l0oooo>03oool<00000440oooo00<0
00000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0o`3ooom30?ooo`T00000o`3ooolk
0?ooo`h00000<`3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`3o0?oo
od`0oooo2@00003o0?oood00oooo3P00000U0?ooo`030000003oool0oooo00@0oooo00130?ooo`03
0000003oool0oooo0?l0ooooE@3oool900000?l0ooooA@3oool>000001L0oooo00<000000?ooo`3o
ool0103oool004<0oooo00<000000?ooo`3oool0o`3ooomN0?ooo``00000o`3ooom70?ooo`L00000
403oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooofX0oooo3P00
003o0?oooe00oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0o`3ooomh
0?ooo`h00000o`3ooom20?ooo`030000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo
0?l0ooooQP3oool>00000?l0oooo=03oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000
oooo0?ooo`3o0?oooi@0oooo3`00003o0?ooobD0oooo00<000000?ooo`3oool0103oool004<0oooo
00<000000?ooo`3oool0o`3ooonS0?ooo`h00000o`3ooolG0?ooo`030000003oool0oooo00@0oooo
00130?ooo`030000003oool0oooo0?l0oooo/@3oool>00000?l0oooo2@3oool00`000000oooo0?oo
o`040?ooo`00@`3oool400000?l0oooo_P3oool>00000?L0oooo100000060?ooo`00@`3oool00`00
0000oooo0?ooo`3o0?ooold0oooo3P00003/0?ooo`030000003oool0oooo00@0oooo00130?ooo`03
0000003oool0oooo0?l0oooof`3oool>00000=h0oooo00<000000?ooo`3oool0103oool004<0oooo
00<000000?ooo`3oool0o`3ooooY0?oooaH00000b03oool00`000000oooo0?ooo`040?ooo`00@`3o
ool00`000000oooo0?ooo`3o0?ooool0oooo7000002/0?ooo`030000003oool0oooo00@0oooo0013
0?ooo`030000003oool0oooo0?l0ooooo`3ooolL0?oooa`00000T03oool00`000000oooo0?ooo`04
0?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooool0oooo>03ooolN00000780oooo00<000000?oo
o`3oool0103oool004<0oooo00<000000?ooo`3oool0o`3ooooo0?oooeH0oooo7000001F0?ooo`03
0000003oool0oooo00@0oooo00130?ooo`030000003oool0oooo0?l0ooooo`3ooomb0?oooa`00000
>P3oool00`000000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooool0ooooSP3o
oolZ00000100oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0o`3ooooo
0?ooolP0oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0o`3ooooo0?oo
olP0oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0o`3ooooo0?ooolP0
oooo00<000000?ooo`3oool0103oool004<0oooo00<000000?ooo`3oool0o`3ooooo0?ooolP0oooo
00<000000?ooo`3oool0103oool003<0oooo0`00000=0?ooo`030000003oool0oooo00h0oooo3P00
003o0?ooool0oooo[03oool00`000000oooo0?ooo`040?ooo`00=03oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo01`0ooooEP00003o0?ooool0ooooEP3oool00`000000oooo0?ooo`04
0?ooo`00=03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0240oooo0`00000=0?oo
o`<000000`3oool010000000oooo0?ooo`3oool500000380ooooSP00003o0?ooolL0oooo00<00000
0?ooo`3oool0103oool002T0oooo1`0000040?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool08@3oool010000000oooo0?ooo`0000020?ooo`L000000P3oool01@000000oooo0?ooo`3o
ool0000000L0oooo00@000000?ooo`3oool00000`03ooooo000008d00000>P3oool00`000000oooo
0?ooo`040?ooo`00=03oool00`000000oooo0?ooo`0<0?ooo`H000008@3oool00`000000oooo0?oo
o`090?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`3o0?ooool0oooo
CP3ooolZ000000`0oooo1@0000060?ooo`00=03oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo0280oooo0P00000<0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo
0?ooo`3o0?ooool0ooooQ`3oool00`000000oooo0?ooo`040?ooo`00=03oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool00`3oool700000080oooo00D0
00000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo0?l0ooooo`3ooon70?ooo`030000
003oool0oooo00@0oooo000d0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool08@3o
ool010000000oooo0?ooo`00000;0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000
oooo0?ooo`3o0?ooool0ooooQP3oool00`000000oooo0?ooo`040?ooo`00<`3oool2000000h0oooo
00<000000?ooo`3oool08P3oool3000000/0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`03
0000003oool0oooo0?l0ooooo`3ooon60?ooo`030000003oool0oooo00@0oooo000d0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0<03oool01@000000oooo0?ooo`3oool0000000X0
oooo00<000000?ooo`3oool0o`3ooooo0?ooohH0oooo00<000000?ooo`3oool0103oool004<0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0O0?ooo`050000003oool0oooo0?ooo`00
00001P3oool01@000000oooo0?ooo`3oool0000007P0oooo00<000000?ooo`3oool0Y`3oool00`00
0000oooo0?ooo`2V0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`040?ooo`00@`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01l0
oooo100000080?ooo`<000004`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0
oooo00130?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool004<0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`00@`3ooooo00000?l00000c0000006
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 786.063}, {485.438, 0}} -> {-0.249996, -1.53906, \
0.00294684, 0.00113542}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Show[{plwq, plwp}, 
      Epilog \[Rule] {Text["\<s=3\>", {0.5, \(-0.75\)}], 
          Text["\<s=0.2\>", {0.1, \(-0.975\)}], 
          Text["\<s=1.0\>", {0.1, \(-0.895\)}], 
          Text["\<s=1.5\>", {0.1, \(-0.785\)}], 
          Text["\<s=2.\>", {0.1, \(-0.66\)}], 
          Text["\<s=2.5\>", {0.02, \(-0.42\)}], 
          Text["\<s=2\>", {0.1, \(-1.46\)}], 
          Text["\<s=1.5\>", {0.1, \(-1.26\)}], 
          Text["\<s=1.0\>", {0.1, \(-1.11\)}], 
          Text["\<s=0.2\>", {0.1, \(-1.02\)}], 
          Text["\<Quintessence Models (w(z)>-1)\>", {1.2, \(-0.6\)}], 
          Text["\<Phantom Models (w(z)<-1)\>", {1.4, \(-1.3\)}]}]\)\(\
\[IndentingNewLine]\)\(\[IndentingNewLine]\)\( (*\ \(\(--\(--\(--\(--\(--\(\
--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--Fig\)\)\)\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\) . \ \ \(\(\(\(\(\(\(\(\(\(\(\(\(\(\(\(\(\(\(\(\
\(\(\(\(\(\(3\ \ --\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)\
--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)\)\(-\)*) \)\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.476191 0.69942 0.463706 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.2619 -0.0125 -10.7813 -17.8125 ]
[.2619 -0.0125 10.7813 0 ]
[.5 -0.0125 -5.53125 -17.8125 ]
[.5 -0.0125 5.53125 0 ]
[.7381 -0.0125 -10.7813 -17.8125 ]
[.7381 -0.0125 10.7813 0 ]
[.97619 -0.0125 -5.53125 -17.8125 ]
[.97619 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.125 -35.625 ]
[.5 -0.0125 5.125 -17.8125 ]
[-0.0125 .05023 -31.25 -8.90625 ]
[-0.0125 .05023 0 8.90625 ]
[-0.0125 .14297 -31.25 -8.90625 ]
[-0.0125 .14297 0 8.90625 ]
[-0.0125 .23571 -20.75 -8.90625 ]
[-0.0125 .23571 0 8.90625 ]
[-0.0125 .32846 -31.25 -8.90625 ]
[-0.0125 .32846 0 8.90625 ]
[-0.0125 .4212 -31.25 -8.90625 ]
[-0.0125 .4212 0 8.90625 ]
[-0.0125 .51394 -31.25 -8.90625 ]
[-0.0125 .51394 0 8.90625 ]
[-0.0125 .60668 -31.25 -8.90625 ]
[-0.0125 .60668 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -49.0625 -14.7188 ]
[-0.01875 .30902 -31.25 14.7188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.2619 .35164 -12.7813 -8.90625 ]
[.2619 .35164 12.7813 8.90625 ]
[.07143 .24731 -18.0313 -8.90625 ]
[.07143 .24731 18.0313 8.90625 ]
[.07143 .2844 -18.0313 -8.90625 ]
[.07143 .2844 18.0313 8.90625 ]
[.07143 .33541 -18.0313 -8.90625 ]
[.07143 .33541 18.0313 8.90625 ]
[.07143 .39337 -14.5 -8.90625 ]
[.07143 .39337 14.5 8.90625 ]
[.03333 .50466 -18.0313 -8.90625 ]
[.03333 .50466 18.0313 8.90625 ]
[.07143 .02241 -12.7813 -8.90625 ]
[.07143 .02241 12.7813 8.90625 ]
[.07143 .11515 -18.0313 -8.90625 ]
[.07143 .11515 18.0313 8.90625 ]
[.07143 .18471 -18.0313 -8.90625 ]
[.07143 .18471 18.0313 8.90625 ]
[.07143 .22644 -18.0313 -8.90625 ]
[.07143 .22644 18.0313 8.90625 ]
[.59524 .4212 -93.9688 -8.90625 ]
[.59524 .4212 93.9688 8.90625 ]
[.69048 .0966 -81.3438 -8.90625 ]
[.69048 .0966 81.3438 8.90625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.125 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .05023 m
.00625 .05023 L
s
gsave
-0.0125 .05023 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
0 .14297 m
.00625 .14297 L
s
gsave
-0.0125 .14297 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
0 .23571 m
.00625 .23571 L
s
gsave
-0.0125 .23571 -81.75 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .32846 m
.00625 .32846 L
s
gsave
-0.0125 .32846 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .4212 m
.00625 .4212 L
s
gsave
-0.0125 .4212 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .51394 m
.00625 .51394 L
s
gsave
-0.0125 .51394 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .60668 m
.00625 .60668 L
s
gsave
-0.0125 .60668 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .07342 m
.00375 .07342 L
s
0 .0966 m
.00375 .0966 L
s
0 .11979 m
.00375 .11979 L
s
0 .16616 m
.00375 .16616 L
s
0 .18934 m
.00375 .18934 L
s
0 .21253 m
.00375 .21253 L
s
0 .2589 m
.00375 .2589 L
s
0 .28208 m
.00375 .28208 L
s
0 .30527 m
.00375 .30527 L
s
0 .35164 m
.00375 .35164 L
s
0 .37483 m
.00375 .37483 L
s
0 .39801 m
.00375 .39801 L
s
0 .44438 m
.00375 .44438 L
s
0 .46757 m
.00375 .46757 L
s
0 .49075 m
.00375 .49075 L
s
0 .53712 m
.00375 .53712 L
s
0 .56031 m
.00375 .56031 L
s
0 .58349 m
.00375 .58349 L
s
0 .02705 m
.00375 .02705 L
s
0 .00386 m
.00375 .00386 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -115.875 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.7188 12.9063 translate
90 rotate
-75.7188 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.063 17.500 moveto
(H) show
77.625 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.875 17.500 moveto
(L) show
88.438 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .05023 m
1 .05023 L
s
.99375 .14297 m
1 .14297 L
s
.99375 .23571 m
1 .23571 L
s
.99375 .32846 m
1 .32846 L
s
.99375 .4212 m
1 .4212 L
s
.99375 .51394 m
1 .51394 L
s
.99375 .60668 m
1 .60668 L
s
.125 Mabswid
.99625 .07342 m
1 .07342 L
s
.99625 .0966 m
1 .0966 L
s
.99625 .11979 m
1 .11979 L
s
.99625 .16616 m
1 .16616 L
s
.99625 .18934 m
1 .18934 L
s
.99625 .21253 m
1 .21253 L
s
.99625 .2589 m
1 .2589 L
s
.99625 .28208 m
1 .28208 L
s
.99625 .30527 m
1 .30527 L
s
.99625 .35164 m
1 .35164 L
s
.99625 .37483 m
1 .37483 L
s
.99625 .39801 m
1 .39801 L
s
.99625 .44438 m
1 .44438 L
s
.99625 .46757 m
1 .46757 L
s
.99625 .49075 m
1 .49075 L
s
.99625 .53712 m
1 .53712 L
s
.99625 .56031 m
1 .56031 L
s
.99625 .58349 m
1 .58349 L
s
.99625 .02705 m
1 .02705 L
s
.99625 .00386 m
1 .00386 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .23764 m
.06244 .23743 L
.10458 .23722 L
.14415 .23704 L
.18221 .23689 L
.22272 .23675 L
.26171 .23664 L
.30316 .23653 L
.34309 .23644 L
.3815 .23636 L
.42237 .23629 L
.46172 .23623 L
.49955 .23618 L
.53984 .23613 L
.57861 .23609 L
.61984 .23605 L
.65954 .23602 L
.69774 .23599 L
.73838 .23597 L
.77751 .23595 L
.81909 .23593 L
.85916 .23591 L
.89771 .23589 L
.93871 .23588 L
.97619 .23587 L
s
.02381 .28291 m
.06244 .27657 L
.10458 .27081 L
.14415 .26628 L
.18221 .26256 L
.22272 .25918 L
.26171 .2564 L
.30316 .25386 L
.34309 .25177 L
.3815 .25002 L
.42237 .24841 L
.46172 .24707 L
.49955 .24594 L
.53984 .24489 L
.57861 .244 L
.61984 .24318 L
.65954 .24248 L
.69774 .24188 L
.73838 .24132 L
.77751 .24084 L
.81909 .24038 L
.85916 .23999 L
.89771 .23966 L
.93871 .23933 L
.97619 .23907 L
s
.02381 .33835 m
.06244 .32186 L
.10458 .30798 L
.14415 .29765 L
.18221 .28952 L
.22272 .28234 L
.26171 .27656 L
.30316 .27138 L
.34309 .26716 L
.3815 .26368 L
.42237 .26049 L
.46172 .25784 L
.49955 .25563 L
.53984 .25357 L
.57861 .25183 L
.61984 .25022 L
.65954 .24885 L
.69774 .24769 L
.73838 .2466 L
.77751 .24566 L
.81909 .24478 L
.85916 .24402 L
.89771 .24337 L
.93871 .24275 L
.97619 .24223 L
s
.02381 .41245 m
.06244 .37823 L
.10458 .35184 L
.14415 .3334 L
.18221 .3195 L
.22272 .30763 L
.26171 .2983 L
.30316 .2901 L
.34309 .2835 L
.3815 .27811 L
.42237 .27321 L
.46172 .26917 L
.49955 .26579 L
.53984 .26267 L
.57861 .26004 L
.61984 .2576 L
.65954 .25554 L
.69774 .25379 L
.73838 .25214 L
.77751 .25073 L
.81909 .2494 L
.85916 .24826 L
.89771 .24727 L
.93871 .24634 L
.97619 .24556 L
s
.02381 .50134 m
.04262 .46806 L
.06244 .44032 L
.08426 .4159 L
.10458 .39732 L
.14264 .37004 L
.18163 .349 L
.22307 .33171 L
.263 .31849 L
.30142 .30809 L
.34228 .29892 L
.38164 .29153 L
.41947 .28547 L
.45976 .27994 L
.49853 .27536 L
.53975 .27115 L
.57946 .26762 L
.61766 .26465 L
.6583 .26187 L
.69743 .25951 L
.73901 .2573 L
.77908 .25541 L
.81763 .2538 L
.85863 .25226 L
.89812 .25094 L
.93609 .24979 L
.97619 .2487 L
s
.02381 .60332 m
.04262 .54844 L
.06244 .50508 L
.08255 .47114 L
.10458 .44187 L
.14509 .40203 L
.18408 .3745 L
.22553 .35246 L
.26546 .33594 L
.30387 .32311 L
.34474 .3119 L
.38409 .30293 L
.42192 .29562 L
.46221 .28897 L
.50098 .28346 L
.54221 .27841 L
.58192 .27419 L
.62011 .27063 L
.66075 .2673 L
.69988 .26447 L
.74147 .26182 L
.78153 .25955 L
.82008 .25761 L
.86109 .25576 L
.90057 .25417 L
.93855 .25279 L
.97619 .25156 L
s
.02381 .23378 m
.06244 .23399 L
.10458 .2342 L
.14415 .23438 L
.18221 .23453 L
.22272 .23467 L
.26171 .23478 L
.30316 .23489 L
.34309 .23499 L
.3815 .23506 L
.42237 .23513 L
.46172 .23519 L
.49955 .23525 L
.53984 .23529 L
.57861 .23533 L
.61984 .23537 L
.65954 .2354 L
.69774 .23543 L
.73838 .23546 L
.77751 .23548 L
.81909 .2355 L
.85916 .23552 L
.89771 .23553 L
.93871 .23555 L
.97619 .23556 L
s
.02381 .18788 m
.06244 .19191 L
.10458 .19629 L
.14415 .20023 L
.18221 .20376 L
.22272 .20721 L
.26171 .21021 L
.30316 .21305 L
.34309 .21547 L
.3815 .21754 L
.42237 .21948 L
.46172 .22113 L
.49955 .22253 L
.53984 .22384 L
.57861 .22496 L
.61984 .22601 L
.65954 .2269 L
.69774 .22767 L
.73838 .22839 L
.77751 .22901 L
.81909 .2296 L
.85916 .23011 L
.89771 .23054 L
.93871 .23096 L
.97619 .2313 L
s
.02381 .1225 m
.06244 .12782 L
.10458 .13507 L
.14415 .14261 L
.18221 .15007 L
.22272 .15788 L
.26171 .16505 L
.30316 .17213 L
.34309 .17838 L
.3815 .18383 L
.42237 .18906 L
.46172 .19356 L
.49955 .19743 L
.53984 .20111 L
.57861 .20427 L
.61984 .20726 L
.65954 .20982 L
.69774 .21201 L
.73838 .21411 L
.77751 .21591 L
.81909 .21762 L
.85916 .21909 L
.89771 .22037 L
.93871 .22159 L
.97619 .22261 L
s
.02381 .01929 m
.03279 .01788 L
.04262 .01664 L
.04758 .01613 L
.05288 .01568 L
.05785 .01533 L
.06244 .01508 L
.06503 .01497 L
.06788 .01487 L
.07075 .0148 L
.07232 .01477 L
.07379 .01474 L
.07445 .01474 L
.07517 .01473 L
.07648 .01472 L
.07776 .01472 L
.07895 .01472 L
.07968 .01472 L
.08036 .01472 L
.08164 .01473 L
.08236 .01474 L
.08302 .01475 L
.08451 .01477 L
.08691 .01483 L
.08916 .01489 L
.09427 .01509 L
.09924 .01535 L
.10458 .01571 L
.11475 .01658 L
.12582 .01783 L
.14594 .02079 L
.18672 .02909 L
.22599 .0392 L
.26374 .05012 L
.30394 .06235 L
.34263 .07425 L
.38377 .08663 L
.42339 .09807 L
.4615 .10847 L
.50206 .11881 L
.54111 .12803 L
.58261 .13705 L
.62259 .145 L
.66106 .152 L
.70197 .15879 L
.74138 .16475 L
.77926 .16997 L
.8196 .17505 L
.85843 .17949 L
.8997 .1838 L
Mistroke
.93947 .18756 L
.97619 .19075 L
Mfstroke
gsave
.2619 .35164 -73.7813 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
68.500 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
84.563 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.07143 .24731 -79.0313 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
68.500 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
95.063 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.07143 .2844 -79.0313 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
68.500 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.0) show
95.063 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.07143 .33541 -79.0313 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
68.500 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
95.063 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.07143 .39337 -75.5 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
68.500 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
88.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.03333 .50466 -79.0313 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
68.500 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
95.063 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.07143 .02241 -73.7813 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
68.500 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
84.563 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.07143 .11515 -79.0313 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
68.500 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
95.063 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.07143 .18471 -79.0313 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
68.500 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.0) show
95.063 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.07143 .22644 -79.0313 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
68.500 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
95.063 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .4212 -154.969 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Quintessence) show
141.563 17.500 moveto
(Models) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
187.313 17.500 moveto
(H) show
191.875 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.938 17.500 moveto
(H) show
206.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
212.750 17.500 moveto
(L) show
217.313 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(>) show
226.313 17.500 moveto
(-) show
235.313 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
242.375 17.500 moveto
(L) show
246.938 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.69048 .0966 -142.344 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Phantom) show
116.313 17.500 moveto
(Models) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
162.063 17.500 moveto
(H) show
166.625 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
176.688 17.500 moveto
(H) show
181.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
187.500 17.500 moveto
(L) show
192.063 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(<) show
201.063 17.500 moveto
(-) show
210.063 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
217.125 17.500 moveto
(L) show
221.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{873, 539.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=Y00026b000`400?l00000o`00003oo`3ooooo
0?ooool0ooooK03oool00?l0ooooo`3ooooo0?ooof`0oooo003o0?ooool0ooooo`3ooom/0?ooo`00
o`3ooooo0?ooool0ooooK03oool00?l0ooooo`3ooooo0?ooof`0oooo003o0?ooom40oooo1P00003o
0?oooi@0oooo003o0?ooom80oooo00D000000?ooo`3oool0oooo0000003o0?oooi@0oooo003o0?oo
om<0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`00o`3ooooC0?ooo`030000003oool0oooo0?l0
ooooU@3oool00?l0ooooe03oool00`000000oooo0?ooo`3o0?oooi@0oooo003o0?ooom40oooo00D0
00000?ooo`3oool0oooo0000003o0?oooiD0oooo003o0?ooom40oooo1P00003o0?oooi@0oooo003o
0?ooool0ooooo`3ooom/0?ooo`00o`3ooooo0?ooool0ooooK03oool00?l0ooooo`3ooooo0?ooof`0
oooo003o0?ooool0ooooo`3ooom/0?ooo`00o`3ooooo0?ooool0ooooK03oool00?l0ooooo`3ooooo
0?ooof`0oooo003o0?ooool0ooooo`3ooom/0?ooo`00o`3ooooo0?ooool0ooooK03oool00?l0oooo
o`3ooooo0?ooof`0oooo003o0?ooool0ooooo`3ooom/0?ooo`00o`3ooooo0?ooool0ooooK03oool0
05H0oooo0`00002f0?ooo`<000000`3oool010000000oooo0?ooo`3oool300000;H0oooo0`00002f
0?ooo`<000000`3oool010000000oooo0?ooo`3oool300000;D0oooo1@00000G0?ooo`00E@3oool0
1@000000oooo0?ooo`3oool000000;@0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000
003oool0oooo0;@0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0;<0oooo00@000000?ooo`3oool000005`3oool005D0oooo00D000000?ooo`3oool0
oooo0000002d0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`2c0?oo
o`030000003oool0oooo0;H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2c0?oo
o`030000003oool0oooo01L0oooo001E0?ooo`050000003oool0oooo0?ooo`000000]03oool01@00
0000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`2f
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0F
0?ooo`00E@3oool01@000000oooo0?ooo`3oool000000;@0oooo00D000000?ooo`3oool0oooo0000
000:0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool05P3oool005D0oooo00D00000
0?ooo`3oool0oooo0000002d0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo
0?ooo`2d0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`2f0?ooo`030000003oool0oooo01D0oooo001E0?ooo`050000003oool0oooo0?ooo`000000
]03oool01@000000oooo0?ooo`3oool0000000H0oooo0`00002g0?ooo`030000003oool0oooo0;H0
oooo00<000000?ooo`3oool01P3oool300000;T0oooo00<000000?ooo`3oool05@3oool005D0oooo
00D000000?ooo`3oool0oooo0000002d0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`00
0000oooo0?ooo`2g0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`2i0?ooo`030000003oool0oooo01D0oooo001E0?ooo`050000003oool0oooo0?oo
o`000000]03oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0]@3oool2
00000;L0oooo0P0000090?ooo`030000003oool0oooo0;@0oooo00D000000?ooo`3oool0oooo0000
000G0?ooo`00EP3oool300000;H0oooo0`0000080?ooo`@00000]@3oool00`000000oooo0?ooo`2f
0?ooo`030000003oool0oooo00L0oooo1000002d0?ooo`<00000603oool00?l0ooooo`3ooooo0?oo
of`0oooo003o0?ooool0ooooo`3ooom/0?ooo`00o`3ooooo0?ooool0ooooK03oool00?l0ooooo`3o
oooo0?ooof`0oooo003o0?ooool0ooooo`3ooom/0?ooo`00o`3ooooo0?ooool0ooooK03oool00?l0
ooooo`3ooooo0?ooof`0oooo003o0?ooool0ooooo`3ooom/0?ooo`00o`3ooooo0?ooool0ooooK03o
ool00?l0ooooo`3ooooo0?ooof`0oooo003o0?ooool0ooooo`3ooom/0?ooo`00o`3ooooo0?ooool0
ooooK03oool00?l0ooooo`3ooooo0?ooof`0oooo00150?ooool00000o`00003o0000024000001P3o
ool004D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00A@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo00150?ooo`@000003`3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03@3oool4000000H0
oooo00150?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0^`3oool00`000000oooo
0?ooo`2j0?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool0^`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0^`3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo0;/0oooo00<0
00000?ooo`3oool0^`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo0015
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooad0oooo00<000000?ooo`3oool0103oool0
04D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo7@3oool00`000000oooo0?ooo`040?oo
o`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolM0?ooo`030000003oool0oooo00@0
oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooad0oooo00<000000?ooo`3oool0
103oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo7@3oool00`000000oooo0?oo
o`040?ooo`00A@3oool00`000000oooo0?ooo`0`0?oooaH00000o`3ooooo0?ooomH0oooo00<00000
0?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool08P3oool>000001H0oooo3P00003o0?oo
ool0oooob03oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0L0?ooo`H0
0000<P3oool900000?l0ooooo`3ooono0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000
003oool0oooo01@0oooo2000000@0?ooo`<000002`3oool5000001h0oooo2000003o0?ooool0oooo
]`3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0@0?ooo`@00000603o
ool01@000000oooo0?ooo`000000oooo00L000000`3oool010000000oooo0?ooo`00000V0?ooo`P0
0000o`3ooooo0?ooojl0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02h0oooo1`00003o0?ooool0oooo
Z03oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0]0?ooo`8000003P3o
ool00`000000oooo0?ooo`0d0?ooo`D00000o`3ooooo0?oooj<0oooo00<000000?ooo`3oool0103o
ool004D0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`020?ooo`L000001@3oool0
0`000000oooo0?ooo`0i0?ooo`@00000o`3ooooo0?oooil0oooo00<000000?ooo`3oool0103oool0
04D0oooo00<000000?ooo`3oool0;03oool010000000oooo0?ooo`00000>0?ooo`030000003oool0
oooo03`0oooo1@00003o0?ooool0ooooVP3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`00
0000oooo0?ooo`0]0?ooo`<000003P3oool00`000000oooo0?ooo`110?ooo`D00000o`3ooooo0?oo
oiD0oooo00<000000?ooo`3oool0103oool004D0oooo1000000m0?ooo`030000003oool0oooo04H0
oooo1000003o0?ooool0ooooSP3oool4000000H0oooo00150?ooo`030000003oool0oooo03X0oooo
00D000000?ooo`3oool0oooo0000001<0?ooo`D00000o`3ooooo0?oooh`0oooo00<000000?ooo`3o
ool0103oool004D0oooo00<000000?ooo`3oool0>`3oool300000580oooo1000003o0?ooool0oooo
R03oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`2D0?ooo`@00000o`3o
oooo0?oooh@0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0V03oool4
00000?l0ooooo`3ooon00?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo
09`0oooo1000003o0?ooool0ooooO03oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000
oooo0?ooo`2P0?ooo`@00000o`3ooooo0?ooogP0oooo00<000000?ooo`3oool0103oool004D0oooo
00<000000?ooo`3oool0Y03oool400000?l0ooooo`3ooomd0?ooo`030000003oool0oooo00@0oooo
00150?ooo`030000003oool0oooo0:P0oooo1000003o0?ooool0ooooL03oool00`000000oooo0?oo
o`040?ooo`00A@3oool00`000000oooo0?ooo`2/0?ooo`@00000o`3ooooo0?ooof`0oooo00<00000
0?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0/03oool300000?l0ooooo`3ooomY0?oo
o`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo0;<0oooo0`00003o0?ooool0
ooooIP3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`2f0?ooo`@00000
o`3ooooo0?ooof80oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0^P3o
ool300000?l0ooooo`3ooomO0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0
oooo0;d0oooo0`00003o0?ooool0ooooG03oool00`000000oooo0?ooo`040?ooo`00:@3oool30000
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
0<00oooo1000003o0?ooool0ooooF03oool00`000000oooo0?ooo`040?ooo`00:P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0a03oool300000?l0
ooooo`3ooomE0?ooo`030000003oool0oooo00@0oooo000Z0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`370?ooo`<00000o`3ooooo0?oooe80oooo
00<000000?ooo`3oool0103oool001h0oooo1`0000050?ooo`030000003oool0oooo00D0oooo1P00
000=0?ooo`030000003oool0oooo0<X0oooo1000003o0?ooool0ooooCP3oool00`000000oooo0?oo
o`040?ooo`00:P3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000003P3o
ool600000</0oooo0`00003o0?ooool0ooooAP3oool6000000H0oooo000Z0?ooo`030000003oool0
oooo00H0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`3A0?ooo`@00000o`3o
oooo0?ooodL0oooo00<000000?ooo`3oool0103oool002X0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0000000>0?ooo`030000003oool0oooo0=D0oooo0`00003o0?ooool0ooooA03oool0
0`000000oooo0?ooo`040?ooo`00:P3oool00`000000oooo0?ooo`070?ooo`030000003oool00000
00h0oooo00<000000?ooo`3oool0f03oool400000?l0ooooo`3ooom00?ooo`030000003oool0oooo
00@0oooo000Y0?ooo`8000002P3oool2000000h0oooo00<000000?ooo`3oool0g03oool300000?l0
ooooo`3ooolm0?ooo`030000003oool0oooo00@0oooo000Z0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3O0?ooo`@00000o`3ooooo0?ooocT0oooo
00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0h`3oool400000?l0ooooo`3o
oole0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo0>L0oooo0`00003o
0?ooool0oooo<P3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`3Z0?oo
o`@00000o`3ooooo0?ooobh0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3o
ool0kP3oool300000?l0ooooo`3oool[0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000
003oool0oooo0?40oooo0`00003o0?ooool0oooo:03oool00`000000oooo0?ooo`040?ooo`00A@3o
ool00`000000oooo0?ooo`3d0?ooo`<00000o`3ooooo0?ooobD0oooo00<000000?ooo`3oool0103o
ool004D0oooo00<000000?ooo`3oool0m`3oool300000?l0ooooo`3ooolR0?ooo`030000003oool0
oooo00@0oooo00150?ooo`030000003oool0oooo0?X0oooo0`00003o0?ooool0oooo7`3oool00`00
0000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`3m0?ooo`@00000o`3ooooo0?oooa/0
oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0o`3oool20?ooo`<00000
o`3ooooo0?oooaP0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0o`3o
ool50?ooo`<00000o`3ooooo0?oooaD0oooo00<000000?ooo`3oool0103oool004D0oooo00<00000
0?ooo`3oool0o`3oool80?ooo`<00000o`3ooooo0?oooa80oooo00<000000?ooo`3oool0103oool0
04D0oooo1000003o0?ooo`X0oooo0`00003o0?ooool0oooo303oool4000000H0oooo00150?ooo`03
0000003oool0oooo0?l0oooo3P3oool300000?l0ooooo`3oool<0?ooo`030000003oool0oooo00@0
oooo00150?ooo`030000003oool0oooo0?l0oooo4@3oool300000?l0ooooo`3oool90?ooo`030000
003oool0oooo00@0oooo00150?ooo`030000003oool0oooo0?l0oooo503oool400000?l0ooooo`3o
ool50?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo0?l0oooo603oool3
00000?l0ooooo`3oool20?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo
0?l0oooo6`3oool300000?l0oooooP3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000
oooo0?ooo`3o0?oooah0oooo1000003o0?ooooX0oooo00<000000?ooo`3oool0103oool004D0oooo
00<000000?ooo`3oool0o`3ooolR0?ooo`<00000o`3oooog0?ooo`030000003oool0oooo00@0oooo
00150?ooo`030000003oool0oooo0?l0oooo9@3oool300000?l0oooom03oool00`000000oooo0?oo
o`040?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooobP0oooo1000003o0?oooo00oooo00<00000
0?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0o`3oool/0?ooo`<00000o`3oooo]0?oo
o`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo0?l0oooo;`3oool300000?l0
oooojP3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`3o0?oooc80oooo
1000003o0?ooo`H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`040?ooo`00A@3o
ool00`000000oooo0?ooo`3o0?ooocH0oooo0`00003o0?ooo`80oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0Z03o
ool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooocT0oooo1000003l
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?oo
o`3oool0o`3ooolm0?ooo`<00000U@3oool3000000D0oooo0`0000001@3oool00000000000000000
oooo00P0000000D0oooo00000000000000000?ooo`02000000<0oooo0`0000020?ooo`<0000000D0
oooo00000000000000000?ooo`03000000<0oooo0`0000030?ooo`030000003oool0oooo00<00000
0P3oool3000000@0oooo0P0000000`3oool000000?ooo`020?ooo`<0000000D0oooo000000000000
00000?ooo`03000000P0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool01P0000030?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool02P3oool3000000@0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`040?oo
o`00A@3oool00`000000oooo0?ooo`3o0?oood00oooo0`00002C0?ooo`030000003oool0oooo00D0
oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000`3o
ool020000000oooo0?ooo`000000oooo0000003oool000000`3oool010000000oooo0?ooo`000003
0?ooo`050000003oool0oooo0?ooo`0000001@3oool010000000oooo0?ooo`3oool2000000<0oooo
00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000020?ooo`<0000000<0oooo0000
003oool00P3oool00`000000oooo000000020?ooo`040000003oool0oooo000000L0oooo00<00000
0?ooo`3oool00`3oool200000080oooo0P0000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000H0oooo0P00000>0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?oo
o`3o0?oood<0oooo1000002?0?ooo`030000003oool0oooo00D0oooo00L000000?ooo`3oool0oooo
0000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`000003
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool00`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01000
0000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool200000100oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo00@0oooo00150?ooo`03
0000003oool0oooo0?l0ooooA`3oool3000008`0oooo00<000000?ooo`3oool01@3oool01@000000
oooo0?ooo`3oool000000080oooo100000020?ooo`050000003oool0oooo0?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo
0?ooo`3oool0000000D0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool2000000P0oooo00<000000?ooo`3o
ool00`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P0000070?ooo`L00000103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool0103oool0
04D0oooo1000003o0?ooodT0oooo100000280?ooo`D000000`3oool01@000000oooo0?ooo`3oool0
000000D0oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000030?ooo`050000
003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00D0
00000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool500000005
0?ooo`000000oooo0?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo000000050?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool200000100oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2T
0?ooo`@000001P3oool004D0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`<00000Q@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo008000000P3oool00`000000oooo000000030?oo
o`030000003oool00000008000000P3oool010000000oooo0?ooo`0000030?ooo`060000003oool0
oooo0?ooo`000000oooo0`0000020?ooo`8000000P3oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool00P0000020?ooo`070000003oool0oooo0?ooo`000000oooo0000
00020?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool0103oool2000000h0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`2W0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo0?l0
ooooD@3oool400000840oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`000000oooo
008000000`3oool3000000<0oooo00@000000?ooo`00000000000P3oool3000000<0oooo0`000003
0?ooo`040000003oool0000000000080oooo0P0000060?ooo`030000003oool0000000@0oooo00<0
00000?ooo`0000000`3oool3000000@0oooo0P0000000`3oool000000?ooo`020?ooo`<000000P3o
ool010000000oooo0?ooo`3oool3000000L0oooo00@000000?ooo`3oool0oooo0`0000001@3oool0
0000000000000000oooo00@000000P3oool6000000<0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0Y`3oool00`00
0000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`3o0?oooeD0oooo1000001m0?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000004`3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0000000@0oooo00<000000?ooo`0000003@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2W0?oo
o`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo0?l0ooooF@3oool4000007T0
oooo00<000000?ooo`3oool00P3oool010000000oooo00000000000C0?ooo`030000003oool0oooo
01H0oooo0P0000060?ooo`800000303oool2000000L0oooo0P00000>0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0D0?ooo`800000103oool00`00
0000oooo0?ooo`2X0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo0?l0
ooooG@3oool4000007@0oooo1P0000030?ooo`030000003oool0oooo02T0oooo0`0000060?ooo`<0
0000303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01H0oooo00D000000?ooo`3o
ool0oooo0000002[0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo0?l0
ooooH@3oool400000?l0oooo]`3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo
0?ooo`3o0?ooofD0oooo1000003o0?oook<0oooo00<000000?ooo`3oool0103oool004D0oooo00<0
00000?ooo`3oool0o`3ooomY0?ooo`@00000o`3ooon_0?ooo`030000003oool0oooo00@0oooo0015
0?ooo`030000003oool0oooo0?l0ooooK@3oool300000?l0oooo[03oool00`000000oooo0?ooo`04
0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooog00oooo1000003o0?ooojP0oooo00<000000?oo
o`3oool0103oool004D0oooo00<000000?ooo`3oool09`3oool3000000`0oooo0`0000030?ooo`04
0000003oool0oooo0?ooo`<00000o`3ooola0?ooo`@00000o`3ooonT0?ooo`030000003oool0oooo
00@0oooo00150?ooo`030000003oool0oooo02L0oooo00D000000?ooo`3oool000000?ooo`070000
00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?oooc80oooo1000003o0?oo
oj00oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooole0?ooo`@0
0000o`3ooonL0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo02P0oooo
0P00000=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3oooli0?ooo`@00000
o`3ooonH0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool00P3oool7000000@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`3o0?ooocd0oooo1000003o0?oooi@0oooo00<000000?ooo`3oool0103oool004D0oooo00<00000
0?ooo`3oool09`3oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0o`3ooom20?ooo`@00000o`3ooon@0?ooo`030000003oool0oooo00@0oooo0015
0?ooo`030000003oool0oooo02P0oooo0`00000<0?ooo`030000003oool0oooo00H0oooo0`00003o
0?ooodT0oooo1000003o0?oooh`0oooo00<000000?ooo`3oool0103oool004D0oooo1000000f0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`@00000o`3ooon50?oo
o`@000001P3oool004D0oooo00<000000?ooo`3oool0=P3oool2000000T0oooo00<000000?ooo`3o
ool0o`3ooom@0?ooo`@00000o`3ooon40?ooo`030000003oool0oooo00@0oooo00150?ooo`030000
003oool0oooo0100oooo1000000S0?ooo`030000003oool0oooo00L0oooo1000003o0?oooe<0oooo
1000003o0?oooh00oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0503o
ool800000?l0ooooP03oool400000?l0ooooO03oool00`000000oooo0?ooo`040?ooo`00A@3oool0
0`000000oooo0?ooo`0L0?ooo`L00000o`3ooomm0?ooo`@00000o`3ooomh0?ooo`030000003oool0
oooo00@0oooo00150?ooo`030000003oool0oooo02<0oooo2000003o0?ooogT0oooo1000003o0?oo
og@0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0:`3oool600000?l0
ooooM`3oool400000?l0ooooL03oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo
0?ooo`0a0?ooo`H00000o`3ooome0?ooo`@00000o`3ooom/0?ooo`030000003oool0oooo00@0oooo
00150?ooo`030000003oool0oooo03L0oooo1P00003o0?ooog<0oooo1@00003o0?ooofL0oooo00<0
00000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0?@3oool500000?l0ooooL`3oool4
00000?l0ooooH`3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`120?oo
o`H00000o`3oooma0?ooo`D00000o`3ooomN0?ooo`030000003oool0oooo00@0oooo00150?ooo`03
0000003oool0oooo04P0oooo1P00003o0?ooog00oooo1@00003o0?oooeT0oooo00<000000?ooo`3o
ool0103oool004D0oooo00<000000?ooo`3oool0CP3oool500000?l0ooooL03oool400000?l0oooo
E@3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`1C0?ooo`D00000o`3o
oom_0?ooo`D00000o`3ooom@0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0
oooo05P0oooo1P00003o0?ooofh0oooo1@00003o0?oood/0oooo00<000000?ooo`3oool0103oool0
02T0oooo0`0000030?ooo`040000003oool0oooo0?ooo`D000003@3oool00`000000oooo0?ooo`1N
0?ooo`D00000o`3ooom^0?ooo`D00000o`3ooom60?ooo`030000003oool0oooo00@0oooo000Z0?oo
o`030000003oool0oooo00L0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`1S
0?ooo`D00000o`3ooom^0?ooo`H00000o`3ooom00?ooo`030000003oool0oooo00@0oooo000Z0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1X0?oo
o`H00000o`3ooom^0?ooo`D00000o`3ooolk0?ooo`030000003oool0oooo00@0oooo000N0?ooo`L0
00001@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0KP3oool500000?l0ooooKP3oool500000?l0oooo=P3oool00`000000oooo0?ooo`040?ooo`00
:P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo1P00001`0?ooo`D00000
o`3ooom^0?ooo`H00000o`3oool[0?ooo`H000001P3oool002X0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0oooo1@00003o0?ooofl0oooo1@00
003o0?ooob/0oooo00<000000?ooo`3oool0103oool002X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07d0oooo1@00003o0?ooofl0oooo1@00003o
0?ooobH0oooo00<000000?ooo`3oool0103oool002X0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0880oooo1@00003o0?ooofl0oooo1@00003o0?oo
ob40oooo00<000000?ooo`3oool0103oool002T0oooo0P0000080?ooo`050000003oool0oooo0?oo
o`0000003@3oool00`000000oooo0?ooo`270?ooo`D00000o`3ooom_0?ooo`H00000o`3ooolK0?oo
o`030000003oool0oooo00@0oooo000Z0?ooo`030000003oool0oooo00L0oooo0`00000>0?ooo`03
0000003oool0oooo08`0oooo1@00003o0?ooog00oooo1@00003o0?oooaH0oooo00<000000?ooo`3o
ool0103oool004D0oooo00<000000?ooo`3oool0T@3oool500000?l0ooooL03oool500000?l0oooo
4@3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`2F0?ooo`H00000o`3o
oom_0?ooo`H00000o`3oool;0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0
oooo09`0oooo1@00003o0?ooog00oooo1P00003o0?ooo`D0oooo00<000000?ooo`3oool0103oool0
04D0oooo00<000000?ooo`3oool0X@3oool500000?l0ooooL@3oool700000?d0oooo00<000000?oo
o`3oool0103oool004D0oooo00<000000?ooo`3oool0YP3oool600000?l0ooooLP3oool700000?H0
oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0[03oool500000?l0oooo
M03oool600000?00oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0/@3o
ool500000?l0ooooM@3oool700000>T0oooo00<000000?ooo`3oool0103oool004D0oooo00<00000
0?ooo`3oool0]P3oool500000?l0ooooM`3oool600000><0oooo00<000000?ooo`3oool0103oool0
04D0oooo00<000000?ooo`3oool0^`3oool600000?l0ooooM`3oool600000=d0oooo00<000000?oo
o`3oool0103oool004D0oooo00<000000?ooo`3oool0`@3oool500000?l0ooooN03oool600000=L0
oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0aP3oool500000?l0oooo
N@3oool600000=40oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0b`3o
ool500000?l0ooooNP3oool700000<X0oooo00<000000?ooo`3oool0103oool004D0oooo1000003?
0?ooo`H00000o`3ooomk0?ooo`P00000_`3oool4000000H0oooo00150?ooo`030000003oool0oooo
0=H0oooo1@00003o0?ooogh0oooo1`00002k0?ooo`030000003oool0oooo00@0oooo00150?ooo`03
0000003oool0oooo0=/0oooo1P00003o0?ooogl0oooo2000002c0?ooo`030000003oool0oooo00@0
oooo00150?ooo`030000003oool0oooo0>40oooo1@00003o0?oooh80oooo1`00002/0?ooo`030000
003oool0oooo00@0oooo00150?ooo`030000003oool0oooo0>H0oooo1P00003o0?oooh<0oooo2000
002T0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo0>`0oooo1P00003o
0?ooohD0oooo2000002L0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo
0?80oooo1P00003o0?ooohL0oooo2000002D0?ooo`030000003oool0oooo00@0oooo00150?ooo`03
0000003oool0oooo0?P0oooo1P00003o0?ooohT0oooo2000002<0?ooo`030000003oool0oooo00@0
oooo00150?ooo`030000003oool0oooo0?h0oooo1`00003o0?ooohX0oooo200000240?ooo`030000
003oool0oooo00@0oooo00150?ooo`030000003oool0oooo0?l0oooo1P3oool600000?l0ooooS03o
ool8000007`0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0o`3oool<
0?ooo`L00000o`3ooon=0?ooo`P00000M03oool00`000000oooo0?ooo`040?ooo`00A@3oool00`00
0000oooo0?ooo`0W0?ooo`<00000303oool3000000<0oooo00<000000?ooo`3oool00P3oool30000
0<h0oooo2000003o0?ooohd0oooo2@00001[0?ooo`030000003oool0oooo00@0oooo00150?ooo`03
0000003oool0oooo02L0oooo00D000000?ooo`3oool000000?ooo`07000000@0oooo00<000000?oo
o`3oool01P3oool01@000000oooo0?ooo`3oool000000=D0oooo2000003o0?ooohh0oooo2`00001P
0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000g@3oool8
00000?l0ooooT@3oool;000005D0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?oo
o`3oool0:03oool2000000d0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0
00000>D0oooo2000003o0?oooi@0oooo2`00001:0?ooo`030000003oool0oooo00@0oooo00150?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool00P3oool7000000@0oooo00<000000?oo
o`3oool01P3oool01@000000oooo0?ooo`3oool000000>d0oooo2000003o0?oooiL0oooo2P000010
0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo02L0oooo00@000000?oo
o`3oool00000303oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000m@3o
ool800000?l0ooooV@3oool;000003D0oooo00<000000?ooo`3oool0103oool004D0oooo00<00000
0?ooo`3oool0403oool4000001@0oooo0`00000<0?ooo`030000003oool0oooo00H0oooo00D00000
0?ooo`3oool0oooo0000003m0?ooo`P00000o`3ooonL0?ooo`X00000:`3oool00`000000oooo0?oo
o`040?ooo`00A@3oool00`000000oooo0?ooo`0D0?ooo`P000006`3oool00`000000oooo0?ooo`06
0?ooo`050000003oool0oooo0?ooo`000000o`3oool60?ooo`P00000o`3ooonN0?ooo`X000008@3o
ool00`000000oooo0?ooo`040?ooo`00A@3oool4000001/0oooo1`00000C0?ooo`800000203oool0
1@000000oooo0?ooo`3oool000000?l0oooo3P3oool800000?l0ooooX03oool:000001@0oooo1000
00060?ooo`00A@3oool00`000000oooo0?ooo`0S0?ooo`P00000303oool00`000000oooo0?ooo`07
0?ooo`<00000o`3ooolG0?ooo`P00000o`3ooonR0?ooo`D000004P3oool00`000000oooo0?ooo`04
0?ooo`00A@3oool00`000000oooo0?ooo`0[0?ooo`T00000o`3oool_0?ooo`P00000o`3ooona0?oo
o`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo03@0oooo2`00003o0?ooob`0
oooo2000003o0?ooojT0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0
?`3oool<00000?l0oooo:03oool:00000?l0ooooW`3oool00`000000oooo0?ooo`040?ooo`00A@3o
ool00`000000oooo0?ooo`1;0?ooo`/00000o`3ooolW0?ooo`X00000o`3ooonE0?ooo`030000003o
ool0oooo00@0oooo00150?ooo`030000003oool0oooo05H0oooo2P00003o0?ooobL0oooo2`00003o
0?ooohX0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0H03oool;0000
0?l0oooo9`3oool:00000?l0ooooP03oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000
oooo0?ooo`1[0?ooo`X00000o`3ooolW0?ooo`/00000o`3ooome0?ooo`030000003oool0oooo00@0
oooo00150?ooo`030000003oool0oooo07D0oooo2P00003o0?ooobP0oooo3@00003o0?ooofP0oooo
00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0O`3oool:00000?l0oooo:`3o
ool@00000?l0ooooF03oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`29
0?ooo`/00000o`3oool`0?ooo`d00000o`3ooom;0?ooo`030000003oool0oooo00@0oooo00150?oo
o`030000003oool0oooo09@0oooo2P00003o0?oooc<0oooo2`00003o0?oood00oooo00<000000?oo
o`3oool0103oool004D0oooo00<000000?ooo`3oool0WP3oool;00000?l0oooo<`3oool;00000?l0
oooo=@3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`2Y0?ooo`d00000
o`3ooola0?ooo`d00000o`3ooolX0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003o
ool0oooo0;H0oooo4000003o0?ooobh0oooo4000003o0?oooaP0oooo00<000000?ooo`3oool0103o
ool004D0oooo00<000000?ooo`3oool0aP3oool@00000?l0oooo;P3oool@00000?l0oooo203oool0
0`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`3F0?oooa000000o`3oool^0?oo
o`l00000n03oool00`000000oooo0?ooo`040?ooo`00A@3oool400000>D0oooo4000003o0?ooobd0
oooo6000003M0?ooo`@000001P3oool004D0oooo00<000000?ooo`3oool0mP3oool@00000?l0oooo
=@3ooolH00000<P0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0o`3o
ool70?oooa000000o`3ooolm0?oooa000000^03oool00`000000oooo0?ooo`040?ooo`00A@3oool0
0`000000oooo0?ooo`3o0?oooaL0oooo4000003o0?ooocd0oooo6000002P0?ooo`030000003oool0
oooo00@0oooo00150?ooo`030000003oool0oooo0?l0oooo9`3oool@00000?l0ooooA@3ooolP0000
0800oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0o`3ooolg0?oooa00
0000o`3ooomE0?ooob000000H03oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo
0?ooo`3o0?ooodL0oooo6000003o0?oooed0oooo7`0000110?ooo`030000003oool0oooo00@0oooo
00150?ooo`030000003oool0oooo0?l0ooooG`3ooolN00000?l0ooooGP3ooolO00000280oooo00<0
00000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool09`3oool3000000`0oooo0`000003
0?ooo`040000003oool0oooo0?ooo`D00000o`3ooolh0?oooal00000o`3ooomN0?oooa0000004P3o
ool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0W0?ooo`050000003oool0
oooo0000003oool01`0000020?ooo`050000003oool0oooo0?ooo`0000001`3oool010000000oooo
0?ooo`00003o0?oooeL0oooo8000003o0?ooof00oooo00<000000?ooo`3oool0103oool004D0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`00
0000203oool00`000000oooo0?ooo`3o0?ooogL0oooo8000003o0?oood00oooo00<000000?ooo`3o
ool0103oool004D0oooo00<000000?ooo`3oool0:03oool2000000/0oooo00D000000?ooo`3oool0
oooo000000090?ooo`030000003oool0oooo0?l0ooooUP3ooolP00000?l0oooo803oool00`000000
oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0080oooo
1`0000020?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`3o0?oookH0
oooo?`00003P0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo02L0oooo
00@000000?ooo`3oool000002P3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?oo
o`3oool0o`3ooood0?oood000000X03oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000
oooo0?ooo`0X0?ooo`<000002P3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?oo
o`3oool0o`3ooooo0?ooocD0ooooG`0000110?ooo`030000003oool0oooo00@0oooo000d0?ooo`<0
00003P3oool00`000000oooo0?ooo`0e0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`00
0000oooo0?ooo`3o0?ooool0ooooU03oool_00000180oooo00<000000?ooo`3oool0103oool003D0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0e0?ooo`050000003oool0oooo0?oo
o`0000001P3oool01@000000oooo0?ooo`3oool000000?l0ooooo`3ooooG0?ooo`030000003oool0
oooo00@0oooo000e0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403ooom_0000
0?l0ooooo`3ooonM0?ooo`030000003oool0oooo00@0oooo000Y0?ooo`L000001@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo07l0ooooo`00003o000008/000004P3oool00`000000
oooo0?ooo`040?ooo`00=@3oool00`000000oooo0?ooo`0=0?ooo`H00000O@3ooooo00000?l00000
RP00000=0?ooo`H000001P3oool003D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0@0?ooog000000o`3ooooo0?oooi`0oooo00<000000?ooo`3oool0103oool003D0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?ooool0oooog03oool^00000180oooo00<00000
0?ooo`3oool0103oool003D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?oo
ool0ooooO03ooomP00000400oooo00<000000?ooo`3oool0103oool003@0oooo0P00000?0?ooo`03
0000003oool0oooo0?l0ooooo`3ooolM0?oooel00000X03oool00`000000oooo0?ooo`040?ooo`00
=@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02L0oooo0`00000<0?ooo`<00000
0`3oool010000000oooo0?ooo`3oool500000?l0oooo^03ooolO00000;l0oooo;P00000B0?ooo`03
0000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo02L0oooo00D000000?ooo`3oool0
00000?ooo`0700000080oooo00D000000?ooo`3oool0oooo000000070?ooo`040000003oool0oooo
00000?l0ooooM`3ooom1000009l0oooo?`0000100?ooo`030000003oool0oooo00@0oooo00150?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0
000000P0oooo00<000000?ooo`3oool0o`3ooomH0?oooal00000W`3ooom1000005h0oooo3`00000B
0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo02P0oooo0P00000;0?oo
o`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`3o0?ooocP0oooo7`00002N
0?ooob000000P03ooolO00000240oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`020?ooo`L000000P3oool01@000000oooo0?ooo`3oool0
000000T0oooo00<000000?ooo`3oool0o`3ooolI0?oooal00000WP3ooolO00000800oooo80000010
0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo02L0oooo00@000000?oo
o`3oool000002P3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0m`3o
oolP000009h0oooo7`00001W0?ooocP00000?P3oool@00000180oooo00<000000?ooo`3oool0103o
ool004D0oooo00<000000?ooo`3oool0:03oool3000000X0oooo00D000000?ooo`3oool0oooo0000
000:0?ooo`030000003oool0oooo0=L0oooo8000002M0?ooob400000MP3oool@000005L0oooo7`00
000R0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo03D0oooo00D00000
0?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo0<00oooo5`00002U0?oooaP00000O`3o
oolH000004P0oooo7`00000P0?ooo`l000004P3oool00`000000oooo0?ooo`040?ooo`00A@3oool0
0`000000oooo0?ooo`0e0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?oo
o`3oool000000;80oooo4000002/0?oooa000000M`3ooolP00000400oooo8000000Q0?oooah00000
8@3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0f0?ooo`<00000203o
ool300000:80oooo4@00002U0?oooaL00000J03ooolO00000400oooo8000000Z0?oooaL00000?`3o
ool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`3F0?oooa000000WP3ooolH
000006P0oooo5`0000180?oooaL00000>P3oool@000005H0oooo00<000000?ooo`3oool0103oool0
04D0oooo00<000000?ooo`3oool0aP3oool@000009l0oooo3`00001`0?oooa000000C`3oool@0000
03T0oooo6000001V0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo0;H0
oooo4000002P0?ooo`l00000KP3ooolA000004h0oooo4@00000a0?oooaP00000OP3oool00`000000
oooo0?ooo`040?ooo`00A@3oool400000:P0oooo3@00002P0?oooa000000K@3oool@000004l0oooo
4000000b0?oooa000000T`3oool4000000H0oooo00150?ooo`030000003oool0oooo09l0oooo2P00
002P0?ooo`d00000K@3oool@000004L0oooo6000000[0?oooaL00000YP3oool00`000000oooo0?oo
o`040?ooo`00A@3oool00`000000oooo0?ooo`2D0?ooo`/00000W`3oool;000006X0oooo40000012
0?oooaD00000:P3ooolI00000;d0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?oo
o`3oool0RP3oool:000009l0oooo2`00001X0?ooo`d00000A`3oool;000002l0oooo4000003F0?oo
o`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo0800oooo2P00002N0?ooo`/0
0000J@3oool:000004T0oooo2`00000/0?ooo`h00000iP3oool00`000000oooo0?ooo`040?ooo`00
A@3oool00`000000oooo0?ooo`1f0?ooo`X00000WP3oool:000006T0oooo2`0000160?ooo`d00000
;@3oool:00000?@0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0K@3o
ool9000009h0oooo2P00001V0?ooo`d00000@P3oool?00000300oooo2P00003n0?ooo`030000003o
ool0oooo00@0oooo00150?ooo`030000003oool0oooo06D0oooo2000002L0?ooo`/00000H@3oool?
00000480oooo3@00000a0?ooo`h00000o`3oool90?ooo`030000003oool0oooo00@0oooo00150?oo
o`030000003oool0oooo05d0oooo2000002J0?ooo`X00000G`3oool=000004L0oooo2P00000^0?oo
oa000000o`3ooolG0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo05D0
oooo2000002G0?ooo`/00000G`3oool:000004T0oooo2`00000[0?ooo`d00000o`3ooolW0?ooo`03
0000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo04`0oooo2@00002E0?ooo`X00000
H03oool:000004P0oooo2`00000/0?ooo`X00000o`3ooold0?ooo`030000003oool0oooo00@0oooo
00150?ooo`030000003oool0oooo04@0oooo2000002F0?ooo`P00000H03oool:000004L0oooo2`00
000]0?ooo`X00000o`3oooln0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0
oooo03/0oooo2@00002F0?ooo`P00000H03oool8000004H0oooo2`00000_0?ooo`T00000o`3ooom8
0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo03<0oooo2000002G0?oo
o`P00000H03oool8000004D0oooo2@00000b0?ooo`P00000o`3ooomA0?ooo`030000003oool0oooo
00@0oooo00150?ooo`030000003oool0oooo02`0oooo1`00002G0?ooo`P00000H03oool8000004D0
oooo2000000c0?ooo`P00000o`3ooomI0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000
003oool0oooo02H0oooo1P00002H0?ooo`H00000H03oool8000004D0oooo2000000c0?ooo`P00000
o`3ooomQ0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo0200oooo1P00
002H0?ooo`H00000H03oool6000004D0oooo2000000b0?ooo`T00000o`3ooomY0?ooo`030000003o
ool0oooo00@0oooo00150?ooo`030000003oool0oooo01X0oooo1P0000070?ooo`<00000303oool3
000000<0oooo00<000000?ooo`3oool00P3oool3000007@0oooo1P00001P0?ooo`H00000A03oool7
00000380oooo2000003o0?ooog80oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?oo
o`3oool0503oool6000000d0oooo00D000000?ooo`3oool000000?ooo`07000000@0oooo00<00000
0?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000006d0oooo1P00001P0?ooo`H00000@P3o
ool800000340oooo2000003o0?ooogX0oooo00<000000?ooo`3oool0103oool004D0oooo1000000?
0?ooo`@000005P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00D00000
0?ooo`3oool0oooo0000001V0?ooo`L00000H03oool600000400oooo2000000a0?ooo`P00000o`3o
oomo0?ooo`@000001P3oool004D0oooo00<000000?ooo`3oool0:03oool2000000d0oooo00<00000
0?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000600oooo1P00001P0?ooo`L00000?P3o
ool800000340oooo2000003o0?ooohX0oooo00<000000?ooo`3oool0103oool004D0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`020?ooo`L00000103oool00`000000oooo0?ooo`06
0?ooo`050000003oool0oooo0?ooo`000000FP3oool600000600oooo1P00000n0?ooo`L00000<@3o
ool800000?l0ooooTP3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0W
0?ooo`040000003oool0oooo000000`0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?oo
o`3oool0000005<0oooo1`00001P0?ooo`H00000?P3oool600000300oooo2000003o0?oooiX0oooo
00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0:03oool3000000`0oooo00<0
00000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000004d0oooo1P00001P0?ooo`L00000
?P3oool6000002h0oooo2000003o0?oooj80oooo00<000000?ooo`3oool0103oool004D0oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000
A`3oool600000600oooo1P00000o0?ooo`H00000;@3oool700000?l0ooooZP3oool00`000000oooo
0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0f0?ooo`800000203oool01@000000oooo0?oo
o`3oool0000004<0oooo1000001P0?ooo`H00000?`3oool6000002d0oooo1P00003o0?oook40oooo
00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`070?ooo`<00000@03oool4000005h0oooo1P00000o0?ooo`H00000;@3oool600000?l0oooo]`3o
ool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`200?ooo`@00000G@3oool5
00000400oooo1@00000/0?ooo`L00000o`3ooonm0?ooo`030000003oool0oooo00@0oooo000;0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0N`3oool5000005/0oooo1P0000100?oo
o`D00000:`3oool600000?l0ooooa03oool00`000000oooo0?ooo`040?ooo`002`3oool3000003L0
oooo00<000000?ooo`3oool0M`3oool4000005/0oooo1@0000100?ooo`H00000:P3oool600000?l0
oooobP3oool00`000000oooo0?ooo`040?ooo`002`3oool00`000000oooo0?ooo`03000003@0oooo
00<000000?ooo`3oool0L`3oool4000005T0oooo1P0000100?ooo`D00000:`3oool500000?l0oooo
d03oool00`000000oooo0?ooo`040?ooo`00403oool2000003<0oooo00<000000?ooo`3oool0K`3o
ool4000005T0oooo100000110?ooo`D00000:`3oool500000?l0ooooe@3oool00`000000oooo0?oo
o`040?ooo`002`3oool00`000000oooo0?ooo`02000003D0oooo00<000000?ooo`3oool0J`3oool4
000005T0oooo100000100?ooo`D00000:`3oool500000?l0oooofP3oool00`000000oooo0?ooo`04
0?ooo`002`3oool3000003L0oooo00<000000?ooo`3oool0I`3oool4000005T0oooo1000000o0?oo
o`D00000:`3oool500000?l0oooog`3oool00`000000oooo0?ooo`040?ooo`002`3oool00`000000
oooo0?ooo`03000003@0oooo00<000000?ooo`3oool0H`3oool4000005T0oooo1000000o0?ooo`@0
0000:`3oool500000?l0ooooi03oool00`000000oooo0?ooo`040?ooo`00403oool2000003<0oooo
00<000000?ooo`3oool0G`3oool4000005T0oooo1000000n0?ooo`D00000:P3oool500000?l0oooo
j@3oool00`000000oooo0?ooo`040?ooo`002`3oool00`000000oooo0?ooo`02000003D0oooo00<0
00000?ooo`3oool0F`3oool4000005T0oooo1000000m0?ooo`D00000:`3oool400000?l0ooookP3o
ool00`000000oooo0?ooo`040?ooo`002`3oool3000003L0oooo1000001F0?ooo`@00000F@3oool4
000003d0oooo1000000[0?ooo`D00000o`3oooo_0?ooo`@000001P3oool000/0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`1C0?ooo`@00000F@3oool4000003`0oooo1@00000[0?oo
o`@00000o`3oooog0?ooo`030000003oool0oooo00@0oooo000:0?ooo`T00000<P3oool00`000000
oooo0?ooo`1?0?ooo`@00000FP3oool3000003`0oooo1000000/0?ooo`@00000o`3ooook0?ooo`03
0000003oool0oooo00@0oooo00090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`1<0?ooo`<00000FP3oool4000003/0oooo1000000[0?ooo`D00000
o`3ooooo0?ooo`030000003oool0oooo00@0oooo00080?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`190?ooo`<00000FP3oool3000003`0oooo0`00
000[0?ooo`@00000o`3ooooo0?ooo`D0oooo00<000000?ooo`3oool0103oool004D0oooo00<00000
0?ooo`3oool0AP3oool3000005T0oooo1000000k0?ooo`@00000:P3oool400000?l0ooooo`3oool9
0?ooo`030000003oool0oooo00@0oooo000;0?ooo`800000103oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo04<0oooo0`00001I0?ooo`<00000?03oool3000002X0oooo1000003o0?oo
ool0oooo3@3oool00`000000oooo0?ooo`040?ooo`002`3oool00`000000oooo0?ooo`020?ooo`80
0000<`3oool00`000000oooo0?ooo`100?ooo`<00000F03oool4000003`0oooo0`00000Y0?ooo`@0
0000o`3ooooo0?oooa40oooo00<000000?ooo`3oool0103oool000/0oooo00<000000?ooo`3oool0
0P0000000`3oool000000?ooo`0b0?ooo`030000003oool0oooo03`0oooo1000001G0?ooo`@00000
?03oool4000002T0oooo0`00003o0?ooool0oooo5@3oool00`000000oooo0?ooo`040?ooo`002`3o
ool00`000000oooo000000030?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0>@3o
ool3000005P0oooo0`00000m0?ooo`<00000:@3oool400000?l0ooooo`3ooolH0?ooo`030000003o
ool0oooo00@0oooo000;0?ooo`800000103oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo03H0oooo0`00001G0?ooo`@00000?03oool4000002P0oooo1000003o0?ooool0oooo703oool0
0`000000oooo0?ooo`040?ooo`002`3oool00`000000oooo0?ooo`020?ooo`800000<`3oool00`00
0000oooo0?ooo`0c0?ooo`<00000E`3oool3000003d0oooo0`00000Y0?ooo`<00000o`3ooooo0?oo
ob00oooo00<000000?ooo`3oool0103oool000P0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo0300oooo0`00001G0?ooo`<00000?@3oool3000002P0
oooo1000003o0?ooool0oooo8`3oool00`000000oooo0?ooo`040?ooo`002@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0;@3oool3000005P0oooo
0P00000m0?ooo`<000009`3oool400000?l0ooooo`3ooolW0?ooo`030000003oool0oooo00@0oooo
000:0?ooo`T00000<P3oool00`000000oooo0?ooo`0[0?ooo`800000F03oool3000003`0oooo0`00
000W0?ooo`<00000o`3ooooo0?ooob/0oooo00<000000?ooo`3oool0103oool002T0oooo0`000003
0?ooo`030000003oool0oooo0080oooo0`00000>0?ooo`030000003oool0oooo02T0oooo0P00001G
0?ooo`<00000?03oool3000002L0oooo0`00003o0?ooool0oooo;P3oool00`000000oooo0?ooo`04
0?ooo`00:03oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo0000
000=0?ooo`030000003oool0oooo02H0oooo0`00001G0?ooo`800000>`3oool4000002L0oooo0`00
003o0?ooool0oooo<@3oool00`000000oooo0?ooo`040?ooo`00:03oool01@000000oooo0?ooo`3o
ool0000000H0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo02@0oooo
0P00001G0?ooo`<00000>P3oool3000002P0oooo0`00003o0?ooool0oooo=03oool00`000000oooo
0?ooo`040?ooo`007P3oool7000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000
003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`0R0?ooo`800000EP3oool3000003X0
oooo0`00000X0?ooo`<00000o`3ooooo0?ooocL0oooo00<000000?ooo`3oool0103oool002P0oooo
00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0000000h0oooo1P00000M0?ooo`80
0000E@3oool3000003X0oooo0`00000W0?ooo`@00000o`3ooooo0?ooocD0oooo1P0000060?ooo`00
:03oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0M0?ooo`<000001`3oool3000000`0oooo0`0000030?ooo`040000003oool0oooo0?oo
o`<00000<P3oool2000003X0oooo0`00000W0?ooo`<00000o`3ooooo0?oooch0oooo00<000000?oo
o`3oool0103oool002P0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool00000
00h0oooo00<000000?ooo`3oool06`3oool2000000X0oooo00D000000?ooo`3oool000000?ooo`07
000000@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0/0?ooo`<00000>@3oool3
000002L0oooo0`00003o0?ooool0oooo@@3oool00`000000oooo0?ooo`040?ooo`00:03oool01@00
0000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`030000003o
ool0oooo01T0oooo0P00000?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0X0?ooo`<00000>P3oool2000002L0oooo0`00003o0?ooool0ooooA03o
ool00`000000oooo0?ooo`040?ooo`00:03oool01@000000oooo0?ooo`3oool0000000H0oooo00D0
00000?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo01H0oooo0`00000?0?ooo`800000
3@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02H0oooo0P00000k0?ooo`800000
9P3oool300000?l0ooooo`3ooom70?ooo`030000003oool0oooo00@0oooo000Y0?ooo`<00000203o
ool3000000h0oooo00<000000?ooo`3oool0503oool200000140oooo00<000000?ooo`3oool00P3o
ool7000000@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0T0?ooo`800000>P3o
ool3000002D0oooo0`00003o0?ooool0ooooBP3oool00`000000oooo0?ooo`040?ooo`00A@3oool0
0`000000oooo0?ooo`0B0?ooo`8000004`3oool010000000oooo0?ooo`00000<0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool08`3oool2000003X0oooo0P00000V0?ooo`800000o`3o
oooo0?ooodd0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0403oool2
000001H0oooo0`00000<0?ooo`030000003oool0oooo00H0oooo0`00000T0?ooo`800000>P3oool2
000002H0oooo0P00003o0?ooool0ooooC`3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool08P3oool20000
03T0oooo0`00000V0?ooo`800000o`3ooooo0?oooe40oooo00<000000?ooo`3oool0103oool004D0
oooo00<000000?ooo`3oool0=P3oool2000000T0oooo00<000000?ooo`3oool07`3oool2000003T0
oooo0P00000W0?ooo`800000o`3ooooo0?oooe<0oooo00<000000?ooo`3oool0103oool004D0oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`070?ooo`@00000703oool2000003P0oooo
0`00000V0?ooo`<00000o`3ooooo0?oooeD0oooo00<000000?ooo`3oool0103oool004D0oooo00<0
00000?ooo`3oool0GP3oool3000003P0oooo0P00000W0?ooo`800000o`3ooooo0?oooeP0oooo00<0
00000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0G03oool2000003T0oooo0P00000W
0?ooo`800000o`3ooooo0?oooeX0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?oo
o`3oool0FP3oool2000003P0oooo0`00000W0?ooo`800000o`3ooooo0?oooe`0oooo00<000000?oo
o`3oool0103oool004D0oooo00<000000?ooo`3oool0F03oool2000003P0oooo0P00000W0?ooo`<0
00001P3oool3000000/0oooo1000003o0?ooool0ooooAP3oool00`000000oooo0?ooo`040?ooo`00
A@3oool00`000000oooo0?ooo`1F0?ooo`800000>03oool2000002L0oooo0P0000090?ooo`050000
003oool0oooo0000003oool01`0000060?ooo`030000003oool0oooo0?l0ooooo`3ooom30?ooo`03
0000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo05@0oooo0P00000h0?ooo`800000
9`3oool2000000h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooool0oooo
@`3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`1B0?ooo`800000>03o
ool2000002L0oooo0P00000>0?ooo`8000003`3oool00`000000oooo0?ooo`3o0?ooool0oooo@`3o
ool00`000000oooo0?ooo`040?ooo`00A@3oool4000004l0oooo0P00000h0?ooo`8000009`3oool2
000000l0oooo00<000000?ooo`3oool00P3oool7000000H0oooo00<000000?ooo`3oool0o`3ooooo
0?oood00oooo100000060?ooo`00A@3oool00`000000oooo0?ooo`1>0?ooo`800000>03oool20000
02L0oooo0P00000A0?ooo`040000003oool0oooo000000`0oooo0P00003o0?ooool0ooooAP3oool0
0`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`1<0?ooo`800000>03oool20000
02L0oooo0P00000D0?ooo`<000003@3oool00`000000oooo0?ooo`3o0?ooool0ooooA03oool00`00
0000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo03H0
oooo0P00000W0?ooo`8000009`3oool00`000000oooo0?ooo`3o0?ooool0oooo@`3oool00`000000
oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`190?ooo`800000=`3oool2000002L0oooo
0P00000U0?ooo`050000003oool0oooo0?ooo`000000o`3ooooo0?ooodD0oooo00<000000?ooo`3o
ool0103oool004D0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0e0?ooo`800000
9`3oool2000002P0oooo0`00003o0?ooool0ooooAP3oool00`000000oooo0?ooo`040?ooo`00A@3o
ool00`000000oooo0?ooo`160?ooo`800000=`3oool00`000000oooo0?ooo`0U0?ooo`800000o`3o
oooo0?ooog<0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0A03oool2
000003L0oooo0P00000V0?ooo`800000o`3ooooo0?ooogD0oooo00<000000?ooo`3oool0103oool0
04D0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0e0?ooo`8000009P3oool20000
0?l0ooooo`3ooomg0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo0440
oooo0P00000f0?ooo`8000009P3oool200000?l0ooooo`3ooomi0?ooo`030000003oool0oooo00@0
oooo00150?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0=03oool2000002H0oooo
0P00003o0?ooool0ooooN`3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?oo
o`0n0?ooo`800000=@3oool2000002H0oooo0P00003o0?ooool0ooooO@3oool00`000000oooo0?oo
o`040?ooo`00A@3oool00`000000oooo0?ooo`0l0?ooo`800000=@3oool2000002H0oooo0P00003o
0?ooool0ooooO`3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo03<0oooo0P00000V0?ooo`800000o`3ooooo0?oooh40oooo00<000000?oo
o`3oool0103oool004D0oooo00<000000?ooo`3oool0>@3oool2000003@0oooo0P00000V0?ooo`80
0000o`3ooooo0?oooh<0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0
=`3oool2000003D0oooo00<000000?ooo`3oool0903oool200000?l0ooooo`3ooon50?ooo`030000
003oool0oooo00@0oooo00150?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0<`3o
ool2000002D0oooo0P00003o0?ooool0ooooQ`3oool00`000000oooo0?ooo`040?ooo`00A@3oool0
0`000000oooo0?ooo`0d0?ooo`800000=@3oool00`000000oooo0?ooo`0S0?ooo`800000o`3ooooo
0?ooohT0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo0280oooo0P00003o0?ooool0ooooR`3oool00`00
0000oooo0?ooo`040?ooo`00A@3oool400000300oooo0P00000e0?ooo`8000008`3oool200000?l0
ooooo`3ooon:0?ooo`@000001P3oool004D0oooo00<000000?ooo`3oool0;`3oool2000003H0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3o0?ooool0ooooS@3oool00`000000oooo
0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo03@0oooo0P00
000T0?ooo`030000003oool0oooo0?l0ooooo`3ooon>0?ooo`030000003oool0oooo00@0oooo0015
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0R
0?ooo`800000o`3ooooo0?oooi40oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0c0?ooo`800000903oool00`000000oooo0?ooo`3o0?oo
ool0ooooT@3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo03<0oooo00<000000?ooo`3oool08P3oool200000?l0ooooo`3ooonD0?ooo`03
0000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0?l0ooooo`3ooonD0?ooo`030000
003oool0oooo00@0oooo00150?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0<P3o
ool2000002@0oooo00<000000?ooo`3oool0o`3ooooo0?oooiD0oooo00<000000?ooo`3oool0103o
ool004D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo0280oooo0P00003o0?ooool0ooooV03oool00`000000oooo0?ooo`040?ooo`00A@3oool00`00
0000oooo0?ooo`0V0?ooo`800000<`3oool2000002@0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oiP0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`0b0?ooo`030000003oool0oooo0280oooo0P00003o0?ooool0ooooV`3oool00`000000
oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00<0oooo
0`00000<0?ooo`D000000P3oool00`000000oooo0?ooo`0E0?ooo`800000903oool00`000000oooo
0?ooo`3o0?ooool0ooooV`3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000P3oool7000000<0oooo
00@000000?ooo`3oool000006@3oool00`000000oooo0?ooo`0R0?ooo`800000o`3ooooo0?oooih0
oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0?l0ooooo`3ooonN0?ooo`030000003oool0oooo00@0oooo
00150?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool2000000l0oooo00<0
00000?ooo`3oool05@3oool2000002@0oooo00<000000?ooo`3oool0o`3ooooo0?oooil0oooo00<0
00000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00<0oooo1`0000050?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool08P3oool200000?l0ooooo`3ooonR0?ooo`030000003oool0oooo00@0oooo00150?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`00000?
0?ooo`030000003oool0oooo0140oooo0P00000T0?ooo`030000003oool0oooo0?l0ooooo`3ooonR
0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool02P3oool3000000l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0R0?oo
o`800000o`3ooooo0?ooojD0oooo00<000000?ooo`3oool0103oool004D0oooo1000000L0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo0?l0ooooo`3ooonR0?ooo`@000001P3oool004D0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0J0?ooo`050000003oool0oooo0?ooo`000000403oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo0?l0ooooo`3ooonV0?ooo`030000003oool0oooo00@0
oooo00150?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool300000100oooo
00<000000?ooo`3oool08@3oool200000?l0ooooo`3ooonY0?ooo`030000003oool0oooo00@0oooo
00150?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0?l0ooooo`3ooonY0?ooo`030000003oool0oooo00@0oooo0015
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo0?l0ooooo`3ooonZ0?ooo`030000003oool0oooo00@0oooo00150?oo
o`030000003oool0oooo01L0oooo0P00000a0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool0o`3ooooo0?oooj/0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool0o`3ooooo0?oooj`0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0_0?ooo`8000008`3oool00`000000oooo0?ooo`3o0?ooool0oooo
[@3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3o0?ooool0oooo[P3o
ool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3o0?ooool0oooo[`3oool0
0`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3o0?ooool0oooo/03oool00`00
0000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3o0?ooool0oooo/@3oool00`000000
oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02l0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3o0?oooaT0oooo0P00001g0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo0>P0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0?l0oooo6@3oool00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo0>L0oooo00<000000?ooo`3oool0103oool004D0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0?l0oooo6@3oool0
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0>H0oooo00<000000?ooo`3oool0103oool0
02T0oooo0`0000030?ooo`030000003oool0oooo0080oooo0`00000>0?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3o0?oooaP0oooo100000050?oo
o`80000000<0oooo0000003oool01P0000001@3oool00000000000000000oooo008000000`3oool3
00000080oooo0`0000030?ooo`<00000103oool3000000050?ooo`00000000000000003oool00`00
00020?ooo`<00000103oool3000000D0oooo0`0000030?ooo`030000003oool0oooo00<000000P3o
ool3000000@0oooo0P0000000`3oool000000?ooo`020?ooo`<0000000D0oooo0000000000000000
0?ooo`03000000P0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00@000000?ooo`3oool0oooo1P0000020?ooo`050000003oool0oooo0?ooo`0000004P3oool3
000000@0oooo00<000000?ooo`3oool0iP3oool00`000000oooo0?ooo`040?ooo`00:03oool01@00
0000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3o0?oooaP0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo0`0000001@3oool00000
0?ooo`3oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<0
00000?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool2000000<0oooo00@0
00000?ooo`3oool000000`3oool010000000oooo0?ooo`0000020?ooo`<0000000<0oooo0000003o
ool00P3oool00`000000oooo000000020?ooo`040000003oool0oooo000000L0oooo00<000000?oo
o`3oool00P3oool200000080oooo0P0000030?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo0P00000A0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0iP3oool00`000000oooo0?ooo`040?ooo`00:03oool01@00
0000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`030000003o
ool0oooo03d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3o0?oooaP0oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo00000080
oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000203oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo000000D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000P3oool010000000oooo0?ooo`0000030?ooo`040000003oool0
oooo000000<0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?oo
o`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool2000000l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3V0?oo
o`030000003oool0oooo00@0oooo000N0?ooo`L000000`3oool01@000000oooo0?ooo`3oool00000
00H0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`H00000>@3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo0?l0oooo6@3oool00`000000oooo0?ooo`040?ooo`040000003oool0
oooo000000<0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool000000080
oooo00D000000?ooo`3oool0oooo000000060?ooo`800000103oool2000000<0oooo00<000000?oo
o`3oool00`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`070?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P0000080?ooo`030000003oool0
oooo0080oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo0P0000020?ooo`L00000
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0>40oooo1P0000060?ooo`00:03o
ool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3o0?oooaX0
oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo
00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0?ooo`D00000
00<0oooo0000003oool0103oool00`000000oooo0?ooo`030?ooo`D0000000<0oooo0000003oool0
0P3oool010000000oooo0?ooo`0000060?ooo`D000001@3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003o
ool0oooo0?ooo`0000000P3oool5000000050?ooo`000000oooo0?ooo`0000002P3oool01@000000
oooo0?ooo`3oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`8000003`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0>H0oooo00<000000?ooo`3oool0103oool002P0oooo00D00000
0?ooo`3oool0oooo000000060?ooo`8000000P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3o0?oooa/0oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`0000030?ooo`050000003oool000000000003o
ool00`0000020?ooo`040000003oool0oooo000000<0oooo00L000000?ooo`3oool0oooo0000003o
ool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`@0
00000P3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`0000030?ooo`030000003oool000000080oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo008000000P3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000P3oool010000000oooo0?ooo`0000070?ooo`050000003oool0
oooo0?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool200000140oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`3V0?ooo`030000003oool0oooo00@0oooo000X0?ooo`05
0000003oool0oooo0?ooo`0000001P3oool010000000oooo00000000000>0?ooo`030000003oool0
oooo03X0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3o0?oooa`0oooo00<00000
0?ooo`3oool0103oool010000000oooo0000000000020?ooo`8000000P3oool01@000000oooo0?oo
o`000000oooo008000000P3oool3000000<0oooo0`0000030?ooo`<000000`3oool3000000<0oooo
0`0000020?ooo`040000003oool00000000000@0oooo0`0000040?ooo`<000001P3oool00`000000
oooo000000040?ooo`030000003oool0000000<0oooo0`0000040?ooo`80000000<0oooo0000003o
ool00P3oool300000080oooo00@000000?ooo`3oool0oooo0`0000070?ooo`030000003oool0oooo
00<0000000D0oooo00000000000000000?ooo`04000000<0oooo1P0000020?ooo`050000003oool0
oooo0?ooo`0000004`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0>H0oooo00<0
00000?ooo`3oool0103oool002P0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo0?l0oooo7@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo000000040?ooo`030000003oool0000000d0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0iP3oool00`000000oooo0?ooo`040?ooo`00:03oool01@000000oooo0?ooo`3o
ool0000000P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0h0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool0o`3ooolO0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0a0?ooo`8000001P3oool2000000`0oooo0P00
00070?ooo`8000003P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool05@3oool2000000@0oooo00<000000?ooo`3oool0i`3oool00`000000oooo0?oo
o`040?ooo`00:@3oool3000000X0oooo0P00000=0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`3o0?ooob40oooo1000000;0?ooo`030000003oool0
oooo03X0oooo0`0000060?ooo`<00000303oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01L0oooo00D000000?ooo`3oool0oooo0000003Z0?ooo`030000003oool0oooo00@0oooo0015
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3o
0?ooool0oooo_`3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool0o`3ooooo0?oool00oooo00<000000?oo
o`3oool0103oool004D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo0?l0ooooo`3oooo10?ooo`030000003oool0oooo00@0oooo00150?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3o0?ooool0oooo
`P3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool0o`3ooooo0?oool<0oooo00<000000?ooo`3oool0103o
ool004D0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo0?l0ooooo`3oooo40?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`3o0?ooool0ooooa@3oool00`00
0000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool0o`3ooooo0?ooolH0oooo00<000000?ooo`3oool0103oool004D0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0?l0oooo
o`3oooo70?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`3o0?ooool0oooob03oool00`000000oooo0?oo
o`040?ooo`00A@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0o`3ooooo0?ooolT0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0ooooo`3oooo:0?oo
o`030000003oool0oooo00@0oooo00150?ooo`@00000:`3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo0?l0ooooo`3oooo80?ooo`@000001P3oool004D0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0?l0ooooo`3oooo;0?ooo`030000
003oool0oooo00@0oooo00150?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`3o0?ooool0ooooc03oool00`000000oooo0?ooo`040?ooo`00A@3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0o`3ooooo
0?ooold0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0ooooo`3oooo>0?ooo`030000003oool0oooo
00@0oooo00150?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`3o0?ooool0oooocP3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0o`3ooooo0?oooll0oooo
00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo0?l0ooooo`3oooo@0?ooo`030000003oool0oooo00@0oooo0015
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3o
0?ooool0ooood@3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0o`3ooooo0?ooom80oooo00<000000?oo
o`3oool0103oool004D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooB0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3o0?ooool0oooo
d`3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool0o`3ooooo0?ooom@0oooo00<000000?ooo`3oool0103o
ool004D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo0?l0ooooo`3ooooE0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3o0?ooool0ooooeP3oool00`00
0000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0o`3ooooo0?ooomH0oooo00<000000?ooo`3oool0103oool004D0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0?l0oooo
o`3ooooG0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`3o0?ooool0oooof03oool00`000000oooo0?oo
o`040?ooo`00A@3oool4000001l0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3o
0?ooool0ooooeP3oool4000000H0oooo00150?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`3o0?ooool0oooof@3oool00`000000oooo0?ooo`040?oo
o`00A@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooomX0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0?l0ooooo`3ooooK0?ooo`030000
003oool0oooo00@0oooo00150?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`3o0?ooool0oooog03oool00`000000oooo0?ooo`040?ooo`00A@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0o`3ooooo
0?ooom`0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo0?l0ooooo`3ooooM0?ooo`030000003oool0oooo
00@0oooo00150?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`3o0?ooool0oooog@3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0o`3ooooo0?ooomh0oooo
00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo0?l0ooooo`3ooooO0?ooo`030000003oool0oooo00@0oooo0015
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3o
0?ooool0oooog`3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0o`3ooooo0?ooon00oooo00<000000?oo
o`3oool0103oool004D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooP0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3o0?ooool0oooo
h@3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0o`3ooooo0?ooon80oooo00<000000?ooo`3oool0103o
ool004D0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo0?l0ooooo`3ooooR0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3o0?ooool0ooooh`3oool00`00
0000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0o`3ooooo0?ooon<0oooo00<000000?ooo`3oool0103oool004D0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0?l0oooo
o`3ooooT0?ooo`030000003oool0oooo00@0oooo00150?ooo`@00000503oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo0?l0ooooo`3ooooQ0?ooo`@000001P3oool004D0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0?l0ooooo`3ooooU
0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`3o0?ooool0ooooiP3oool00`000000oooo0?ooo`040?oo
o`00A@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooonH0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0?l0ooooo`3ooooW0?ooo`030000
003oool0oooo00@0oooo00150?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`3o0?ooool0ooooi`3oool00`000000oooo0?ooo`040?ooo`00A@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0o`3ooooo
0?ooonP0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0203oool30000
00H0oooo00<000000?ooo`3oool00`3oool500000080oooo00@000000?ooo`3oool0oooo0`00000;
0?ooo`030000003oool0oooo0?l0ooooo`3ooooY0?ooo`030000003oool0oooo00@0oooo00150?oo
o`030000003oool0oooo00P0oooo00@000000?ooo`3oool000000P3oool7000000<0oooo00@00000
0?ooo`3oool000002@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooo`3o
oooY0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooonX0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?oo
o`3oool02@3oool2000000l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0?l0ooooo`3ooooZ0?ooo`030000003oool0oooo00@0oooo00150?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool7000000D0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooo`3oooo[0?ooo`03
0000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool0
00003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooon/0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0
2@3oool3000000l0oooo00<000000?ooo`3oool0103oool3000000P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooon`0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooon`0oooo00<000000?ooo`3oool0103oool002T0oooo0`0000030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0G0?ooo`050000003oool0
oooo0?ooo`0000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0ooooo`3o
ooo]0?ooo`030000003oool0oooo00@0oooo000X0?ooo`050000003oool0oooo0?ooo`0000002@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01P0oooo0`0000080?ooo`@000001@3o
ool00`000000oooo0?ooo`3o0?ooool0ooook@3oool00`000000oooo0?ooo`040?ooo`00:03oool0
1@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo0?l0ooooo`3oooo^0?ooo`030000003oool0oooo00@0oooo000N
0?ooo`L000000`3oool01@000000oooo0?ooo`3oool0000000D0oooo1P00000=0?ooo`H00000:03o
ool00`000000oooo0?ooo`3o0?ooool0ooooj@3oool6000000H0oooo000X0?ooo`050000003oool0
oooo0?ooo`0000001@3oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`3o0?ooool0ooookP3oool00`000000oooo0?ooo`040?ooo`00:03o
ool01@000000oooo0?ooo`3oool0000000H0oooo00@000000?ooo`3oool000003P3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo0?l0ooooo`3oooo_0?ooo`030000003oool0oooo00@0
oooo000X0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0000000>0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0o`3ooooo0?ooonl0oooo00<000000?ooo`3o
ool0103oool002P0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0000000h0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?ooool0ooool03oool00`000000
oooo0?ooo`040?ooo`00:03oool01@000000oooo0?ooo`3oool0000000P0oooo0P00000>0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3ooooo0?oooo00oooo00<000000?ooo`3o
ool0103oool002T0oooo0`00000:0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`3o0?ooool0ooool@3oool00`000000oooo0?ooo`040?ooo`00A@3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0?l0ooooo`3ooooa0?ooo`030000003o
ool0oooo00@0oooo00150?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0o`3ooooo
0?oooo40oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`3o0?ooool0oooolP3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo0?l0ooooo`3oooob0?ooo`030000003oool0oooo00@0
oooo00150?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0o`3ooooo0?oooo<0oooo
00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`3o0?ooool0ooool`3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo0?l0ooooo`3ooood0?ooo`030000003oool0oooo00@0oooo00150?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0o`3ooooo0?oooo@0oooo00<000000?oo
o`3oool0103oool004D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3o0?ooool0
oooom03oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo0?l0ooooo`3ooooe0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0o`3ooooo0?ooooD0oooo00<000000?ooo`3oool0103o
ool004D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`3o0?ooool0oooomP3oool0
0`000000oooo0?ooo`040?ooo`00A@3oool400000280oooo00<000000?ooo`3oool0o`3ooooo0?oo
oo<0oooo100000060?ooo`00A@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0?l0
ooooo`3oooog0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool0o`3ooooo0?ooooL0oooo00<000000?ooo`3oool0103oool004D0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`3o0?ooool0oooom`3oool00`000000oooo0?oo
o`040?ooo`00A@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0ooooo`3ooooh
0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool0o`3ooooo0?ooooP0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`3o0?ooool0oooon@3oool00`000000oooo0?ooo`040?ooo`00
A@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0?l0ooooo`3ooooi0?ooo`030000
003oool0oooo00@0oooo00150?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0o`3o
oooo0?ooooX0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`3o0?ooool0oooonP3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0ooooo`3ooooj0?ooo`030000003oool0oooo
00@0oooo00150?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0o`3ooooo0?oooo/0
oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`3o0?ooool0oooon`3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo0?l0ooooo`3ooook0?ooo`030000003oool0oooo00@0oooo0015
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0o`3ooooo0?oooo`0oooo00<00000
0?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3o0?oo
ool0ooooo03oool00`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo0?l0ooooo`3ooool0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool0o`3ooooo0?ooood0oooo00<000000?ooo`3oool0
103oool004D0oooo1000000K0?ooo`030000003oool0oooo0?l0ooooo`3ooooj0?ooo`@000001P3o
ool004D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`3o0?ooool0ooooo@3oool0
0`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
0?l0ooooo`3oooon0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0o`3ooooo0?ooooh0oooo00<000000?ooo`3oool0103oool004D0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`3o0?ooool0oooooP3oool00`000000oooo
0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool00`000000oooo0?ooo`040?oo
o`00A@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooo`40
oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3oool10?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo0@3oool00`000000oooo0?oo
o`040?ooo`00A@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooo`80oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3oool20?ooo`030000003oool0oooo00@0oooo00150?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo0`3oool00`000000
oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooo`<0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool30?ooo`030000003oool0oooo00@0oooo0015
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo103oool0
0`000000oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?ooo`@0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool40?ooo`030000003oool0oooo00@0
oooo00150?ooo`@00000503oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool20?ooo`@00000
1P3oool004D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
ool50?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0oooo1@3oool00`000000oooo0?ooo`040?ooo`00A@3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooo`H0oooo00<000000?oo
o`3oool0103oool004D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3oool60?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0oooo1P3oool00`000000oooo0?ooo`040?ooo`00A@3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooo`L0oooo00<0
00000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3o
0?ooool0ooooo`3oool70?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo1`3oool00`000000oooo0?ooo`040?oo
o`00A@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooo`P0
oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3oool80?ooo`030000003oool0oooo00@0oooo00150?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo203oool00`000000oooo0?oo
o`040?ooo`00A@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooo`T0oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3oool90?ooo`030000003oool0oooo00@0oooo00150?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo2@3oool00`000000
oooo0?ooo`040?ooo`00:@3oool3000000<0oooo00@000000?ooo`3oool0oooo1@00000=0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo2P3oool00`000000
oooo0?ooo`040?ooo`00:03oool01@000000oooo0?ooo`3oool0000000L0oooo00@000000?ooo`3o
ool000003@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
o`X0oooo00<000000?ooo`3oool0103oool002P0oooo00D000000?ooo`3oool0oooo000000080?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo7@3oool00`00
0000oooo0?ooo`040?ooo`007P3oool7000000<0oooo00D000000?ooo`3oool0oooo000000090?oo
o`030000003oool0oooo00`0oooo1P00003o0?ooool0ooooo`3ooolE0?ooo`H000001P3oool002P0
oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0oooo7@3oool00`000000oooo0?ooo`040?ooo`00:03oool01@000000
oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooolM0?ooo`030000003oool0oooo00@0oooo000X0?ooo`050000003oool0oooo0?oo
o`0000002P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
oad0oooo00<000000?ooo`3oool0103oool002P0oooo00D000000?ooo`3oool0oooo0000000:0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo7@3oool00`00
0000oooo0?ooo`040?ooo`00:03oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?oo
o`3oool0oooo0000000=0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0^`3oool0
0`000000oooo0?ooo`2j0?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool0^`3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000Y0?ooo`<00000203oool30000
00h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo
0;X0oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`040?ooo`00A@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo
00150?ooool00000o`00003o0000024000001P3oool00001\
\>"],
  ImageRangeCache->{{{0, 872}, {538.563, 0}} -> {-0.232002, -1.63161, \
0.00263278, 0.00270367}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[{
    \( (*\ Linder\ Ansatz\ \((LA)\) : \ Transient\ behavior\ of\ w \((z)\) = 
        w1\  + \ w2\ z/\((1 + 
                    z)\) : \ \ Evaluate\ integral\ for\ luminocity\ distance\ \
*) \[IndentingNewLine]\(f[z_, om_, w1_, w2_] := 
        1/Sqrt[om*\((1 + z)\)^3\  + \((1 - 
                    om)\)*\((1 + z)\)^\((3 \((1 + w1\  + \ w2)\))\) 
                Exp[3\ w2\ \((\((1/\((1 + z)\))\) - 1)\)]];\)\), "\n", 
    \(\(rr[zz_, om_, w1_, w2_] := 
        NIntegrate[f[z, om, w1, w2], {z, 0, zz}];\)\)}], "Input"],

Cell[BoxData[{
    \( (*\ Construct\ marginalization\ coefficients\ \((see\ \ astro - 
              ph/0401556\  .. )\)\ *) \[IndentingNewLine]\(Clear[chi2fa, 
        chi2fb, chi2fc, chi2fm];\)\), "\[IndentingNewLine]", 
    \(\(chi2fa[w1_, w2_] := 
        Sum[\((ld[i] - 
                  5\ Log[10, 
                      rr[zz[i], 0.3, w1, w2]*\((1 + zz[i])\)])\)^2/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\[IndentingNewLine]", 
    \(\(chi2fb[w1_, w2_] := 
        Sum[\((ld[i] - 
                5\ Log[10, rr[zz[i], 0.3, w1, w2]*\((1 + zz[i])\)])\)/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\[IndentingNewLine]", 
    \(\(chi2fc = Sum[1/\((sld[i]^2)\), {i, 1, ndat}];\)\)}], "Input"],

Cell[BoxData[
    \(\(\( (*\ 
      Construct\ function\ to\ minimized\ after\ marginalization\ *) \)\(\
\[IndentingNewLine]\)\(chi2fm[w1_, w2_] := 
      chi2fa[w1, w2] - chi2fb[w1, w2]^2/chi2fc\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ 
      Minimize\ with\ respect\ to\ om\ and\ find\ same\ result\ as\ with\ mb\ \
minimization . \ 
          Minimization\ and\ marginalization\ have\ the\ same\ \(effect\ !!\)\
\ *) \)\(\[IndentingNewLine]\)\(chmin2m = 
      FindMinimum[
        chi2fm[w1, w2], {w1, {\(-0.9\), \(-0.95\)}}, {w2, {0.03, 0.04}}, 
        MaxIterations \[Rule] 100]\)\)\)], "Input"],

Cell[BoxData[
    \({173.9281963761896`, {w1 \[Rule] \(-1.5770533170068441`\), 
        w2 \[Rule] 3.294188863742627`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(dchi2lind = 173.928 - 177.127\)], "Input"],

Cell[BoxData[
    \(\(-3.1990000000000123`\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ Construct\ w \((z)\)\ at\ best\ fit\ *) \[IndentingNewLine]\(hh[
          z_, om_, w1_, w2_] := 
        h0\ Sqrt[
            om*\((1 + z)\)^3\  + \((1 - 
                    om)\)*\((1 + z)\)^\((3 \((1 + w1\  + \ w2)\))\) 
                Exp[3\ w2\ \((\((1/\((1 + z)\))\) - 1)\)]];\)\), "\n", 
    \(ww[z_, om_, w1_, 
        w2_] := \((2\ \((1 + z)\)\ D[Log[hh[z, om, w1, w2]], z]/3\  - \ 
            1)\)/\((1 - \((h0/hh[z, om, w1, w2])\)^2\ om\ \((1 + 
                    z)\)^3)\)\), "\n", 
    \(\(ws2 = 
        ww[z, 0.3, w1, w2]\  /. \ Part[chmin2m, 2]\  // 
          FullSimplify;\)\), "\n", 
    \(plwzlind = 
      Plot[ws2, {z, 0, 1.75}, PlotRange \[Rule] {\(-2\), 1}, 
        Frame \[Rule] True, FrameLabel \[Rule] {"\<z\>", "\<w(z)\>"}, 
        PlotStyle -> {Dashing[{0.01, 0.01}]}]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.544218 0.412023 0.206011 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.15986 -0.0125 -14.3125 -17.8125 ]
[.15986 -0.0125 14.3125 0 ]
[.29592 -0.0125 -10.7813 -17.8125 ]
[.29592 -0.0125 10.7813 0 ]
[.43197 -0.0125 -14.3125 -17.8125 ]
[.43197 -0.0125 14.3125 0 ]
[.56803 -0.0125 -5.53125 -17.8125 ]
[.56803 -0.0125 5.53125 0 ]
[.70408 -0.0125 -14.3125 -17.8125 ]
[.70408 -0.0125 14.3125 0 ]
[.84014 -0.0125 -10.7813 -17.8125 ]
[.84014 -0.0125 10.7813 0 ]
[.97619 -0.0125 -14.3125 -17.8125 ]
[.97619 -0.0125 14.3125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.125 -35.625 ]
[.5 -0.0125 5.125 -17.8125 ]
[-0.0125 .10301 -31.25 -8.90625 ]
[-0.0125 .10301 0 8.90625 ]
[-0.0125 .20601 -20.75 -8.90625 ]
[-0.0125 .20601 0 8.90625 ]
[-0.0125 .30902 -31.25 -8.90625 ]
[-0.0125 .30902 0 8.90625 ]
[-0.0125 .41202 -11.0625 -8.90625 ]
[-0.0125 .41202 0 8.90625 ]
[-0.0125 .51503 -21.5625 -8.90625 ]
[-0.0125 .51503 0 8.90625 ]
[-0.0125 .61803 -11.0625 -8.90625 ]
[-0.0125 .61803 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -49.0625 -14.7188 ]
[-0.01875 .30902 -31.25 14.7188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.15986 0 m
.15986 .00625 L
s
gsave
.15986 -0.0125 -75.3125 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.29592 0 m
.29592 .00625 L
s
gsave
.29592 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.43197 0 m
.43197 .00625 L
s
gsave
.43197 -0.0125 -75.3125 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.56803 0 m
.56803 .00625 L
s
gsave
.56803 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.70408 0 m
.70408 .00625 L
s
gsave
.70408 -0.0125 -75.3125 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
1.000 setlinewidth
grestore
.84014 0 m
.84014 .00625 L
s
gsave
.84014 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -75.3125 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
1.000 setlinewidth
grestore
.125 Mabswid
.05102 0 m
.05102 .00375 L
s
.07823 0 m
.07823 .00375 L
s
.10544 0 m
.10544 .00375 L
s
.13265 0 m
.13265 .00375 L
s
.18707 0 m
.18707 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2415 0 m
.2415 .00375 L
s
.26871 0 m
.26871 .00375 L
s
.32313 0 m
.32313 .00375 L
s
.35034 0 m
.35034 .00375 L
s
.37755 0 m
.37755 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45918 0 m
.45918 .00375 L
s
.48639 0 m
.48639 .00375 L
s
.51361 0 m
.51361 .00375 L
s
.54082 0 m
.54082 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62245 0 m
.62245 .00375 L
s
.64966 0 m
.64966 .00375 L
s
.67687 0 m
.67687 .00375 L
s
.73129 0 m
.73129 .00375 L
s
.7585 0 m
.7585 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.81293 0 m
.81293 .00375 L
s
.86735 0 m
.86735 .00375 L
s
.89456 0 m
.89456 .00375 L
s
.92177 0 m
.92177 .00375 L
s
.94898 0 m
.94898 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.125 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
gsave
-0.0125 .10301 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
0 .20601 m
.00625 .20601 L
s
gsave
-0.0125 .20601 -81.75 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .30902 m
.00625 .30902 L
s
gsave
-0.0125 .30902 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .41202 m
.00625 .41202 L
s
gsave
-0.0125 .41202 -72.0625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .51503 m
.00625 .51503 L
s
gsave
-0.0125 .51503 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -72.0625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -115.875 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.7188 12.9063 translate
90 rotate
-75.7188 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.063 17.500 moveto
(H) show
77.625 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.875 17.500 moveto
(L) show
88.438 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.15986 .61178 m
.15986 .61803 L
s
.29592 .61178 m
.29592 .61803 L
s
.43197 .61178 m
.43197 .61803 L
s
.56803 .61178 m
.56803 .61803 L
s
.70408 .61178 m
.70408 .61803 L
s
.84014 .61178 m
.84014 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05102 .61428 m
.05102 .61803 L
s
.07823 .61428 m
.07823 .61803 L
s
.10544 .61428 m
.10544 .61803 L
s
.13265 .61428 m
.13265 .61803 L
s
.18707 .61428 m
.18707 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2415 .61428 m
.2415 .61803 L
s
.26871 .61428 m
.26871 .61803 L
s
.32313 .61428 m
.32313 .61803 L
s
.35034 .61428 m
.35034 .61803 L
s
.37755 .61428 m
.37755 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45918 .61428 m
.45918 .61803 L
s
.48639 .61428 m
.48639 .61803 L
s
.51361 .61428 m
.51361 .61803 L
s
.54082 .61428 m
.54082 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62245 .61428 m
.62245 .61803 L
s
.64966 .61428 m
.64966 .61803 L
s
.67687 .61428 m
.67687 .61803 L
s
.73129 .61428 m
.73129 .61803 L
s
.7585 .61428 m
.7585 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.81293 .61428 m
.81293 .61803 L
s
.86735 .61428 m
.86735 .61803 L
s
.89456 .61428 m
.89456 .61803 L
s
.92177 .61428 m
.92177 .61803 L
s
.94898 .61428 m
.94898 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .10301 m
1 .10301 L
s
.99375 .20601 m
1 .20601 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .41202 m
1 .41202 L
s
.99375 .51503 m
1 .51503 L
s
.125 Mabswid
.99625 .0206 m
1 .0206 L
s
.99625 .0412 m
1 .0412 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .0824 m
1 .0824 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .14421 m
1 .14421 L
s
.99625 .16481 m
1 .16481 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .22661 m
1 .22661 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .26781 m
1 .26781 L
s
.99625 .28842 m
1 .28842 L
s
.99625 .32962 m
1 .32962 L
s
.99625 .35022 m
1 .35022 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .39142 m
1 .39142 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .45322 m
1 .45322 L
s
.99625 .47383 m
1 .47383 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .53563 m
1 .53563 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57683 m
1 .57683 L
s
.99625 .59743 m
1 .59743 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .41202 m
1 .41202 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ .01 .01 ] 0 setdash
.02381 .08713 m
.06244 .13212 L
.10458 .17484 L
.14415 .21002 L
.18221 .24013 L
.22272 .26878 L
.26171 .29356 L
.30316 .31732 L
.34309 .33806 L
.3815 .35628 L
.42237 .37403 L
.46172 .38972 L
.49955 .40367 L
.53984 .41743 L
.57861 .42972 L
.61984 .44187 L
.65954 .45277 L
.69774 .46258 L
.73838 .47237 L
.77751 .48122 L
.81909 .49005 L
.85916 .49806 L
.89771 .50534 L
.93871 .51266 L
.97619 .51899 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.563, 327.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0001Ab000`400?l00000o`00003oo`3ooooo
0?oooa@0oooo003o0?ooool0oooo503oool00?l0ooooo`3ooolD0?ooo`00o`3ooooo0?oooa@0oooo
003o0?ooool0oooo503oool00?l0oooo8@3oool600000>`0oooo003o0?ooob80oooo00D000000?oo
o`3oool0oooo0000003/0?ooo`00o`3ooolS0?ooo`030000003oool0oooo0>d0oooo003o0?ooob<0
oooo00<000000?ooo`3oool0k@3oool00?l0oooo903oool00`000000oooo0?ooo`3/0?ooo`00o`3o
oolQ0?ooo`050000003oool0oooo0?ooo`000000k@3oool00?l0oooo8@3oool600000>`0oooo003o
0?ooool0oooo503oool00?l0ooooo`3ooolD0?ooo`00o`3ooooo0?oooa@0oooo003o0?ooool0oooo
503oool00?l0ooooo`3ooolD0?ooo`00o`3ooooo0?oooa@0oooo003o0?ooool0oooo503oool00?l0
ooooo`3ooolD0?ooo`00o`3ooooo0?oooa@0oooo003o0?ooool0oooo503oool00?l0ooooo`3ooolD
0?ooo`00C03oool300000380oooo0`0000030?ooo`040000003oool0oooo0?ooo`D000000P3oool3
000002`0oooo0`0000030?ooo`040000003oool0oooo0?ooo`<00000;03oool3000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`<00000<P3oool300000340oooo0`00
00030?ooo`040000003oool0oooo0?ooo`D000000P3oool3000002d0oooo0`0000030?ooo`040000
003oool0oooo0?ooo`<00000;03oool3000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`<00000403oool004/0oooo00D000000?ooo`3oool0oooo0000000`0?ooo`05
0000003oool0oooo0?ooo`0000001`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo02P0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo02P0oooo00D0
00000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool03@3oool004/0oooo00D000000?ooo`3oool0oooo0000000`0?ooo`050000003oool0oooo0?oo
o`000000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02L0oooo00D000000?oo
o`3oool0oooo0000000:0?ooo`030000003oool0oooo02L0oooo00D000000?ooo`3oool0oooo0000
00080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool004/0oooo00D00000
0?ooo`3oool0oooo0000000`0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo02L0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`03
0000003oool0oooo02L0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0303oool004/0oooo00D000000?ooo`3oool0oooo0000000`0?oo
o`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo02L0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo02L0oooo00D0
00000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
303oool004/0oooo00D000000?ooo`3oool0oooo0000000`0?ooo`050000003oool0oooo0?ooo`00
00002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00D000000?ooo`3o
ool0oooo000000090?ooo`030000003oool0oooo02P0oooo00D000000?ooo`3oool0oooo00000009
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool004/0oooo00D000000?oo
o`3oool0oooo0000000`0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?oo
o`03000002/0oooo00D000000?ooo`3oool0oooo000000060?ooo`<00000:`3oool01@000000oooo
0?ooo`3oool0000000T0oooo00@000000?ooo`3oool0oooo0`00000c0?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`03000002h0oooo00<000000?oo
o`3oool01P3oool3000002d0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`3oool3
00000100oooo001;0?ooo`050000003oool0oooo0?ooo`000000<03oool01@000000oooo0?ooo`3o
ool0000000X0oooo00@000000?ooo`3oool00000;@3oool01@000000oooo0?ooo`3oool0000000H0
oooo00<000000?ooo`3oool0:`3oool01@000000oooo0?ooo`3oool0000000T0oooo00D000000?oo
o`3oool0oooo0000000e0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool0
10000000oooo0?ooo`00000`0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000004P3oool004/0oooo00D0
00000?ooo`3oool0oooo0000000`0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0:P3oool01@000000oooo0?ooo`3oool0
000000L0oooo00<000000?ooo`3oool0:P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000003<0oooo0P00000b0?ooo`800000
203oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0;03oool2000000T0
oooo00<000000?ooo`3oool0:`3oool2000000L0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool000000140oooo001<0?ooo`<00000<P3oool3000000P0oooo0`0000040?ooo`@0
0000:P3oool3000000P0oooo1000000Z0?ooo`<000001`3oool5000000<0oooo1000000a0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool01`3oool3000000@0oooo1000000/0?ooo`03
0000003oool0oooo00L0oooo1000000[0?ooo`030000003oool0oooo00H0oooo1@0000030?ooo`@0
00003P3oool00?l0ooooo`3ooolD0?ooo`00o`3ooooo0?oooa@0oooo003o0?ooool0oooo503oool0
0?l0ooooo`3ooolD0?ooo`00o`3ooooo0?oooa@0oooo003o0?ooool0oooo503oool00?l0ooooo`3o
oolD0?ooo`00o`3ooooo0?oooa@0oooo00130?ooool00000`P00000>0?ooo`00@`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo
00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo
00130?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?oo
o`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?oo
o`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003oool0oooo0?l0oooo_P3oool0
0`000000oooo0?ooo`0<0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oookh0oooo00<000000?oo
o`3oool0303oool004<0oooo00<000000?ooo`3oool0o`3ooonn0?ooo`030000003oool0oooo00`0
oooo00130?ooo`030000003oool0oooo0?l0oooo_P3oool00`000000oooo0?ooo`0<0?ooo`00@`3o
ool00`000000oooo0?ooo`3o0?oookh0oooo00<000000?ooo`3oool0303oool004<0oooo0`00003o
0?oook`0oooo0`00000>0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oookh0oooo00<000000?oo
o`3oool0303oool004<0oooo00<000000?ooo`3oool0o`3ooonn0?ooo`030000003oool0oooo00`0
oooo00130?ooo`030000003oool0oooo0?l0oooo_P3oool00`000000oooo0?ooo`0<0?ooo`00@`3o
ool00`000000oooo0?ooo`3o0?oookh0oooo00<000000?ooo`3oool0303oool004<0oooo00<00000
0?ooo`3oool0o`3ooonn0?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003oool0oooo
0?l0oooo_P3oool00`000000oooo0?ooo`0<0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oookh0
oooo00<000000?ooo`3oool0303oool004<0oooo00<000000?ooo`3oool0o`3ooonn0?ooo`030000
003oool0oooo00`0oooo00130?ooo`<00000o`3ooonl0?ooo`<000003P3oool004<0oooo00<00000
0?ooo`3oool0o`3ooonn0?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003oool0oooo
0?l0oooo_P3oool00`000000oooo0?ooo`0<0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oookh0
oooo00<000000?ooo`3oool0303oool004<0oooo00<000000?ooo`3oool0o`3ooonn0?ooo`030000
003oool0oooo00`0oooo00130?ooo`030000003oool0oooo0?l0oooo_P3oool00`000000oooo0?oo
o`0<0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oookh0oooo00<000000?ooo`3oool0303oool0
04<0oooo00<000000?ooo`3oool0o`3ooonn0?ooo`030000003oool0oooo00`0oooo00130?ooo`03
0000003oool0oooo0?l0oooo_P3oool00`000000oooo0?ooo`0<0?ooo`00@`3oool300000?l0oooo
_03oool3000000h0oooo00130?ooo`030000003oool0oooo0?l0oooo_P3oool00`000000oooo0?oo
o`0<0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oookh0oooo00<000000?ooo`3oool0303oool0
04<0oooo00<000000?ooo`3oool0o`3ooonn0?ooo`030000003oool0oooo00`0oooo00130?ooo`03
0000003oool0oooo0?l0oooo_P3oool00`000000oooo0?ooo`0<0?ooo`00@`3oool00`000000oooo
0?ooo`3o0?oookh0oooo00<000000?ooo`3oool0303oool004<0oooo00<000000?ooo`3oool0o`3o
oonn0?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003oool0oooo0?l0oooo_P3oool0
0`000000oooo0?ooo`0<0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oookh0oooo00<000000?oo
o`3oool0303oool004<0oooo00<000000?ooo`3oool0o`3ooonn0?ooo`030000003oool0oooo00`0
oooo00130?ooo`<00000o`3ooonl0?ooo`<000003P3oool004<0oooo00<000000?ooo`3oool0o`3o
oonn0?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0o`3ooonc0?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0o`3ooonb0?ooo`030000003oool0oooo00`0oooo00130?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooona0?ooo`030000003oool0oooo00`0
oooo000/0?ooo`<000000`3oool010000000oooo0?ooo`3oool3000000X0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`3o0?oook00oooo00<000000?ooo`3oool0303oool002d0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0oooo
_P3oool00`000000oooo0?ooo`0<0?ooo`00;@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0o`3ooonn0?ooo`030000003oool0oooo00`0oooo000Q
0?ooo`L000001@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0o`3ooonn0?ooo`030000003oool0oooo00`0oooo000]0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool01P3oool4000000d0oooo00<000000?ooo`3oool0o`3ooonZ0?oo
o`@000003P3oool002d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooon/0?ooo`030000003oool0oooo00`0
oooo000]0?ooo`030000003oool0oooo00H0oooo0`00000:0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0o`3ooon[0?ooo`030000003oool0oooo00`0oooo000]0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo0?l0ooooZP3oool00`000000oooo0?ooo`0<0?ooo`00;03oool2000000T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?oookh0oooo00<000000?ooo`3oool0303oool0
02d0oooo00<000000?ooo`3oool01`3oool4000000P0oooo00<000000?ooo`3oool0o`3ooonn0?oo
o`030000003oool0oooo00`0oooo00130?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0o`3ooonW0?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0o`3ooonW0?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0o`3ooonV0?ooo`030000003oool0oooo00`0oooo0013
0?ooo`<000005@3oool00`000000oooo0?ooo`3o0?oooj@0oooo0`00000>0?ooo`00@`3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0ooooY@3oool00`000000oooo0?ooo`0<0?oo
o`00@`3oool00`000000oooo0?ooo`3o0?oookh0oooo00<000000?ooo`3oool0303oool004<0oooo
00<000000?ooo`3oool0o`3ooonn0?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool0o`3ooonR0?ooo`030000003oool0oooo00`0oooo0013
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0o`3ooonQ0?ooo`030000003oool0
oooo00`0oooo00130?ooo`030000003oool0oooo01/0oooo0P00003o0?oooj40oooo00<000000?oo
o`3oool0303oool004<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3o0?oooih0
oooo00<000000?ooo`3oool0303oool004<0oooo00<000000?ooo`3oool0o`3ooonn0?ooo`030000
003oool0oooo00`0oooo00130?ooo`<00000o`3ooonl0?ooo`<000003P3oool004<0oooo00<00000
0?ooo`3oool0o`3ooonn0?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool0o`3ooonK0?ooo`030000003oool0oooo00`0oooo00130?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`030000003oool0oooo00`0
oooo00130?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0o`3ooonI0?ooo`030000
003oool0oooo00`0oooo00130?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0o`3o
oonH0?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003oool0oooo0?l0oooo_P3oool0
0`000000oooo0?ooo`0<0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oookh0oooo00<000000?oo
o`3oool0303oool004<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3o0?oooiD0
oooo00<000000?ooo`3oool0303oool004<0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`3o0?oooi@0oooo00<000000?ooo`3oool0303oool004<0oooo0`00000X0?ooo`030000003o
ool0oooo0?l0ooooT@3oool3000000h0oooo00130?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0o`3ooonB0?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003oool0oooo
0?l0oooo_P3oool00`000000oooo0?ooo`0<0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oookh0
oooo00<000000?ooo`3oool0303oool004<0oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`3o0?ooohl0oooo00<000000?ooo`3oool0303oool004<0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`3o0?ooohh0oooo00<000000?ooo`3oool0303oool004<0oooo00<00000
0?ooo`3oool0;P3oool200000?l0ooooSP3oool00`000000oooo0?ooo`0<0?ooo`00@`3oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo0?l0ooooR`3oool00`000000oooo0?ooo`0<0?oo
o`00@`3oool00`000000oooo0?ooo`3o0?oookh0oooo00<000000?ooo`3oool0303oool004<0oooo
0`00003o0?oook`0oooo0`00000>0?ooo`00@`3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo0?l0ooooR03oool00`000000oooo0?ooo`0<0?ooo`00@`3oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo0?l0ooooQ`3oool00`000000oooo0?ooo`0<0?ooo`00@`3oool00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0<0?oo
o`00@`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0?l0ooooQ@3oool00`000000
oooo0?ooo`0<0?ooo`00=`3oool3000000T0oooo00<000000?ooo`3oool0o`3ooonn0?ooo`030000
003oool0oooo00`0oooo000h0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3o
oonn0?ooo`030000003oool0oooo00`0oooo000h0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0>P3oool00`000000oooo0?ooo`3o0?oooh40oooo00<000000?ooo`3oool0303oool0
02`0oooo1`0000050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`3o0?oooh00oooo00<000000?ooo`3oool0303oool003P0oooo00<000000?ooo`3o
ool0203oool4000003/0oooo00<000000?ooo`3oool0o`3oooml0?ooo`@000003P3oool003P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0?l0oooo
OP3oool00`000000oooo0?ooo`0<0?ooo`00>03oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0?l0oooo_P3oool00`000000oooo0?ooo`0<0?ooo`00>03oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0?l0oooo_P3oool00`000000oooo0?ooo`0<0?ooo`00=`3oool20000
00X0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`3o0?ooog/0oooo00<000000?oo
o`3oool0303oool003P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo0?l0ooooNP3oool00`000000oooo0?ooo`0<0?ooo`00@`3oool00`000000oooo
0?ooo`120?ooo`800000o`3ooomj0?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool0o`3ooomg0?ooo`030000003oool0oooo00`0oooo0013
0?ooo`030000003oool0oooo0?l0oooo_P3oool00`000000oooo0?ooo`0<0?ooo`00@`3oool30000
0?l0oooo_03oool3000000h0oooo00130?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3o
ool0o`3ooomd0?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003oool0oooo04P0oooo
0P00003o0?ooog@0oooo00<000000?ooo`3oool0303oool004<0oooo00<000000?ooo`3oool0BP3o
ool200000?l0ooooLP3oool00`000000oooo0?ooo`0<0?ooo`00@`3oool00`000000oooo0?ooo`3o
0?oookh0oooo00<000000?ooo`3oool0303oool004<0oooo00<000000?ooo`3oool0o`3ooonn0?oo
o`030000003oool0oooo00`0oooo00130?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool0o`3ooom/0?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003oool0oooo0500oooo
00<000000?ooo`3oool0o`3ooom[0?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003o
ool0oooo0540oooo00<000000?ooo`3oool0o`3ooomZ0?ooo`030000003oool0oooo00`0oooo0013
0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0o`3ooomY0?ooo`030000003oool0
oooo00`0oooo00130?ooo`<00000o`3ooonl0?ooo`<000003P3oool004<0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`3o0?ooofD0oooo00<000000?ooo`3oool0303oool004<0oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3o0?ooof@0oooo00<000000?ooo`3oool0
303oool004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3o0?ooof<0oooo00<0
00000?ooo`3oool0303oool004<0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`3o
0?ooof80oooo00<000000?ooo`3oool0303oool004<0oooo00<000000?ooo`3oool0o`3ooonn0?oo
o`030000003oool0oooo00`0oooo00130?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3o
ool0o`3ooomN0?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003oool0oooo05h0oooo
00<000000?ooo`3oool0o`3ooomM0?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003o
ool0oooo05l0oooo0P00003o0?oooed0oooo00<000000?ooo`3oool0303oool004<0oooo0`00001Q
0?ooo`030000003oool0oooo0?l0ooooF03oool3000000h0oooo00130?ooo`030000003oool0oooo
0?l0oooo_P3oool00`000000oooo0?ooo`0<0?ooo`00@`3oool00`000000oooo0?ooo`1U0?ooo`03
0000003oool0oooo0?l0ooooEP3oool00`000000oooo0?ooo`0<0?ooo`00@`3oool00`000000oooo
0?ooo`1V0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`0<0?ooo`00@`3o
ool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0?l0ooooE03oool00`000000oooo0?oo
o`0<0?ooo`00@`3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo0?l0ooooD`3oool0
0`000000oooo0?ooo`0<0?ooo`00403oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
0?l0oooo_P3oool00`000000oooo0?ooo`0<0?ooo`00403oool300000300oooo00<000000?ooo`3o
ool0K03oool00`000000oooo0?ooo`3o0?ooodl0oooo00<000000?ooo`3oool0303oool00100oooo
00<000000?ooo`3oool00`00000]0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0
o`3ooom>0?ooo`030000003oool0oooo00`0oooo000E0?ooo`800000;03oool3000006h0oooo0P00
003o0?oood`0oooo0`00000>0?ooo`00403oool00`000000oooo0?ooo`02000002h0oooo00<00000
0?ooo`3oool0L03oool00`000000oooo0?ooo`3o0?oood/0oooo00<000000?ooo`3oool0303oool0
0100oooo0`00000`0?ooo`030000003oool0oooo0?l0oooo_P3oool00`000000oooo0?ooo`0<0?oo
o`00403oool00`000000oooo0?ooo`03000002d0oooo00<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`3o0?ooodL0oooo00<000000?ooo`3oool0303oool001D0oooo0P00000/0?ooo`030000
003oool0oooo07D0oooo0P00003o0?ooodL0oooo00<000000?ooo`3oool0303oool00100oooo00<0
00000?ooo`3oool00P00000^0?ooo`030000003oool0oooo07L0oooo0P00003o0?ooodD0oooo00<0
00000?ooo`3oool0303oool00100oooo0`00000I0?ooo`<000000`3oool010000000oooo0?ooo`3o
ool3000000X0oooo00<000000?ooo`3oool0o`3ooonn0?ooo`030000003oool0oooo00`0oooo000@
0?ooo`030000003oool0oooo01P0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`3o0?ooocl0oooo00<0
00000?ooo`3oool0303oool002/0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`3o0?oooch0oooo00<0
00000?ooo`3oool0303oool000l0oooo2@0000090?ooo`L000000`3oool01@000000oooo0?ooo`3o
ool0000000X0oooo00<000000?ooo`3oool01P3oool4000007d0oooo00<000000?ooo`3oool0o`3o
oolj0?ooo`@000003P3oool000h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0@
0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo07l0oooo00<000000?ooo`3oool0o`3oooll0?ooo`030000003oool0oooo00`0oooo000=
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03`3oool01@000000oooo0?ooo`3o
ool0000000T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oookh0oooo00<0
00000?ooo`3oool0303oool00100oooo0P0000040?ooo`030000003oool0oooo0180oooo00D00000
0?ooo`3oool0oooo000000060?ooo`<000002P3oool00`000000oooo0?ooo`230?ooo`030000003o
ool0oooo0?l0oooo>03oool00`000000oooo0?ooo`0<0?ooo`00403oool00`000000oooo0?ooo`02
0?ooo`800000503oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`240?ooo`800000o`3ooolh0?ooo`030000003oool0oooo00`0oooo000@
0?ooo`030000003oool0oooo0080000000<0oooo0000003oool04`3oool01@000000oooo0?ooo`3o
ool0000000L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`260?ooo`800000o`3o
oolf0?ooo`030000003oool0oooo00`0oooo000@0?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool04`3oool3000000P0oooo100000080?ooo`030000003oool0oooo0?l0oooo_P3oool0
0`000000oooo0?ooo`0<0?ooo`00403oool2000000@0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`2;0?ooo`030000003oool0oooo0?l0oooo<03oool00`000000oooo0?ooo`0<0?oo
o`00403oool00`000000oooo0?ooo`020?ooo`800000;03oool00`000000oooo0?ooo`2<0?ooo`80
0000o`3oool`0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool09`3oool3000008h0oooo0P00003o0?ooob`0oooo0`00000>0?ooo`003P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0o`3o
oonn0?ooo`030000003oool0oooo00`0oooo000?0?ooo`T00000:`3oool00`000000oooo0?ooo`2C
0?ooo`030000003oool0oooo0?l0oooo:03oool00`000000oooo0?ooo`0<0?ooo`00@`3oool00`00
0000oooo0?ooo`2D0?ooo`800000o`3ooolX0?ooo`030000003oool0oooo00`0oooo00130?ooo`03
0000003oool0oooo09H0oooo0P00003o0?ooobH0oooo00<000000?ooo`3oool0303oool004<0oooo
00<000000?ooo`3oool0o`3ooonn0?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003o
ool0oooo09/0oooo00<000000?ooo`3oool0o`3ooolP0?ooo`030000003oool0oooo00`0oooo0013
0?ooo`030000003oool0oooo09`0oooo0P00003o0?ooob00oooo00<000000?ooo`3oool0303oool0
04<0oooo00<000000?ooo`3oool0WP3oool200000?l0oooo7P3oool00`000000oooo0?ooo`0<0?oo
o`00@`3oool00`000000oooo0?ooo`3o0?oookh0oooo00<000000?ooo`3oool0303oool004<0oooo
0`00002S0?ooo`030000003oool0oooo0?l0oooo5P3oool3000000h0oooo00130?ooo`030000003o
ool0oooo0:@0oooo0P00003o0?oooaP0oooo00<000000?ooo`3oool0303oool004<0oooo00<00000
0?ooo`3oool0YP3oool200000?l0oooo5P3oool00`000000oooo0?ooo`0<0?ooo`00@`3oool00`00
0000oooo0?ooo`3o0?oookh0oooo00<000000?ooo`3oool0303oool004<0oooo00<000000?ooo`3o
ool0Z`3oool200000?l0oooo4@3oool00`000000oooo0?ooo`0<0?ooo`00@`3oool00`000000oooo
0?ooo`2]0?ooo`800000o`3oool?0?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003o
ool0oooo0:l0oooo0P00003o0?ooo`d0oooo00<000000?ooo`3oool0303oool004<0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`3o0?ooo`L0oooo00<000000?ooo`3oool0303oool0
04<0oooo00<000000?ooo`3oool0]@3oool200000?l0oooo1`3oool00`000000oooo0?ooo`0<0?oo
o`00@`3oool300000;L0oooo0P00003o0?ooo`<0oooo0`00000>0?ooo`00@`3oool00`000000oooo
0?ooo`3o0?oookh0oooo00<000000?ooo`3oool0303oool004<0oooo00<000000?ooo`3oool0_03o
ool00`000000oooo0?ooo`3n0?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003oool0
oooo0;d0oooo0P00003n0?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003oool0oooo
0;l0oooo0P00003l0?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003oool0oooo0<@0
oooo00<000000?ooo`3oool0mP3oool00`000000oooo0?ooo`0<0?ooo`00@`3oool00`000000oooo
0?ooo`350?ooo`800000mP3oool00`000000oooo0?ooo`0<0?ooo`00@`3oool00`000000oooo0?oo
o`370?ooo`800000m03oool00`000000oooo0?ooo`0<0?ooo`00@`3oool00`000000oooo0?ooo`3o
0?oookh0oooo00<000000?ooo`3oool0303oool004<0oooo0`00003<0?ooo`<00000k03oool30000
00h0oooo00130?ooo`030000003oool0oooo0<l0oooo0`00003[0?ooo`030000003oool0oooo00`0
oooo00130?ooo`030000003oool0oooo0?l0oooo_P3oool00`000000oooo0?ooo`0<0?ooo`00@`3o
ool00`000000oooo0?ooo`3E0?ooo`800000iP3oool00`000000oooo0?ooo`0<0?ooo`00@`3oool0
0`000000oooo0?ooo`3G0?ooo`<00000h`3oool00`000000oooo0?ooo`0<0?ooo`00@`3oool00`00
0000oooo0?ooo`3o0?oookh0oooo00<000000?ooo`3oool0303oool003L0oooo0`0000090?ooo`03
0000003oool0oooo0=d0oooo0`00003M0?ooo`030000003oool0oooo00`0oooo000f0?ooo`050000
003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`3P0?ooo`<00000fP3oool00`000000
oooo0?ooo`0<0?ooo`00=P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3o
ool0o`3ooonn0?ooo`030000003oool0oooo00`0oooo000f0?ooo`050000003oool0oooo0?ooo`00
0000203ooooo00000<8000003P3oool003H0oooo00D000000?ooo`3oool0oooo000000080?ooo`03
0000003oool0oooo0>P0oooo0`00003B0?ooo`030000003oool0oooo00`0oooo000f0?ooo`050000
003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`3^0?ooo`030000003oool0oooo0<`0
oooo00<000000?ooo`3oool0303oool003H0oooo00D000000?ooo`3oool0oooo000000080?ooo`03
0000003oool0oooo0>l0oooo0P00003<0?ooo`030000003oool0oooo00`0oooo000f0?ooo`050000
003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`3a0?ooo`<00000b@3oool00`000000
oooo0?ooo`0<0?ooo`00=P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3o
ool0m`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo00`0oooo000g0?ooo`<00000
2@3oool00`000000oooo0?ooo`3h0?ooo`800000``3oool00`000000oooo0?ooo`0<0?ooo`00@`3o
ool00`000000oooo0?ooo`3j0?ooo`800000`@3oool00`000000oooo0?ooo`0<0?ooo`00@`3oool0
0`000000oooo0?ooo`3o0?ooo`<00000^`3oool00`000000oooo0?ooo`0<0?ooo`00@`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo0`00002h0?ooo`030000003oool0oooo00`0oooo00130?ooo`<0
0000o`3oool90?ooo`030000003oool0oooo0;00oooo0`00000>0?ooo`00@`3oool00`000000oooo
0?ooo`3o0?ooo`X0oooo0P00002b0?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003o
ool0oooo0?l0oooo303oool200000;00oooo00<000000?ooo`3oool0303oool004<0oooo00<00000
0?ooo`3oool0o`3ooolB0?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0303oool0
04<0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`@00000Y`3oool00`000000oooo0?ooo`0<0?oo
o`00@`3oool00`000000oooo0?ooo`3o0?oooaX0oooo00<000000?ooo`3oool0X@3oool00`000000
oooo0?ooo`0<0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oooa/0oooo0P00002Q0?ooo`030000
003oool0oooo00`0oooo00130?ooo`030000003oool0oooo0?l0oooo7@3oool2000009l0oooo00<0
00000?ooo`3oool0303oool004<0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`800000V@3oool0
0`000000oooo0?ooo`0<0?ooo`00@`3oool300000?l0oooo9@3oool3000009@0oooo0`00000>0?oo
o`00@`3oool00`000000oooo0?ooo`3o0?ooob/0oooo0`00002@0?ooo`030000003oool0oooo00`0
oooo00130?ooo`030000003oool0oooo0?l0oooo;P3oool3000008d0oooo00<000000?ooo`3oool0
303oool004<0oooo00<000000?ooo`3oool0o`3ooold0?ooo`800000R03oool00`000000oooo0?oo
o`0<0?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooocH0oooo0`0000250?ooo`030000003oool0
oooo00`0oooo00130?ooo`030000003oool0oooo0?l0oooo?@3oool00`000000oooo0?ooo`1n0?oo
o`030000003oool0oooo00`0oooo00130?ooo`030000003oool0oooo0?l0oooo?P3oool2000007h0
oooo00<000000?ooo`3oool0303oool004<0oooo00<000000?ooo`3oool0o`3ooom00?ooo`800000
O03oool00`000000oooo0?ooo`0<0?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooodH0oooo1000
001d0?ooo`030000003oool0oooo00`0oooo00130?ooo`<00000o`3ooom:0?ooo`030000003oool0
oooo06l0oooo0`00000>0?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooodh0oooo0`00001]0?oo
o`030000003oool0oooo00`0oooo00130?ooo`030000003oool0oooo0?l0ooooD@3oool3000006X0
oooo00<000000?ooo`3oool0303oool004<0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`@00000
H`3oool00`000000oooo0?ooo`0<0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oooe/0oooo00<0
00000?ooo`3oool00P3oool2000005`0oooo00<000000?ooo`3oool0303oool004<0oooo00<00000
0?ooo`3oool0o`3ooomR0?ooo`<00000F@3oool00`000000oooo0?ooo`0<0?ooo`00@`3oool00`00
0000oooo0?ooo`3o0?ooofP0oooo0`00001C0?ooo`030000003oool0oooo00`0oooo00130?ooo`03
0000003oool0oooo0?l0ooooJ`3oool300000500oooo00<000000?ooo`3oool0303oool004<0oooo
00<000000?ooo`3oool0o`3oooma0?ooo`<00000BP3oool00`000000oooo0?ooo`0<0?ooo`00@`3o
ool300000?l0ooooM03oool3000004D0oooo0`00000>0?ooo`00@`3oool00`000000oooo0?ooo`3o
0?ooogX0oooo0P0000120?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003oool0oooo
0?l0ooooO03oool3000003l0oooo00<000000?ooo`3oool0303oool004<0oooo00<000000?ooo`3o
ool0o`3ooon30?ooo`D00000=P3oool00`000000oooo0?ooo`0<0?ooo`00@`3oool00`000000oooo
0?ooo`3o0?oooh`0oooo0P00000`0?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003o
ool0oooo0?l0ooooSP3oool3000002d0oooo00<000000?ooo`3oool0303oool002`0oooo0`000003
0?ooo`040000003oool0oooo0?ooo`<000002P3oool00`000000oooo0?ooo`3o0?oooi@0oooo0`00
000W0?ooo`030000003oool0oooo00`0oooo000[0?ooo`050000003oool0oooo0?ooo`0000002@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooU`3oool3000000<0oooo0`00
000N0?ooo`030000003oool0oooo00`0oooo000[0?ooo`050000003oool0oooo0?ooo`0000002P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0ooooX03oool3000001/0oooo00<0
00000?ooo`3oool0303oool002/0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003o
ool0oooo00H0oooo1000003o0?ooojD0oooo0`00000B0?ooo`@000003P3oool002/0oooo00D00000
0?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3o
oonY0?ooo`<000000`3oool2000000d0oooo00<000000?ooo`3oool0303oool002/0oooo00D00000
0?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3o
oona0?ooo`<000002P3oool00`000000oooo0?ooo`0<0?ooo`00:`3oool01@000000oooo0?ooo`3o
ool0000000H0oooo0`00000:0?ooo`030000003oool0oooo0?l0oooo_P3oool00`000000oooo0?oo
o`0<0?ooo`00:`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`3o0?oookh0oooo00<000000?ooo`3oool0303oool002/0oooo00D00000
0?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3o
oonn0?ooo`030000003oool0oooo00`0oooo000/0?ooo`<00000203oool4000000P0oooo00<00000
0?ooo`3oool0o`3ooonn0?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003oool0oooo
0?l0oooo_P3oool00`000000oooo0?ooo`0<0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oookh0
oooo00<000000?ooo`3oool0303oool004<0oooo00<000000?ooo`3oool0o`3ooonn0?ooo`030000
003oool0oooo00`0oooo00130?ooo`<00000o`3ooonl0?ooo`<000003P3oool004<0oooo00<00000
0?ooo`3oool0o`3ooonn0?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003oool0oooo
0?l0oooo_P3oool00`000000oooo0?ooo`0<0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oookh0
oooo00<000000?ooo`3oool0303oool004<0oooo00<000000?ooo`3oool0o`3ooonn0?ooo`030000
003oool0oooo00`0oooo00130?ooo`030000003oool0oooo0?l0oooo_P3oool00`000000oooo0?oo
o`0<0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oookh0oooo00<000000?ooo`3oool0303oool0
04<0oooo00<000000?ooo`3oool0o`3ooonn0?ooo`030000003oool0oooo00`0oooo00130?ooo`03
0000003oool0oooo0?l0oooo_P3oool00`000000oooo0?ooo`0<0?ooo`00@`3oool300000?l0oooo
_03oool3000000h0oooo00130?ooo`030000003oool0oooo0?l0oooo_P3oool00`000000oooo0?oo
o`0<0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oookh0oooo00<000000?ooo`3oool0303oool0
04<0oooo00<000000?ooo`3oool0o`3ooonn0?ooo`030000003oool0oooo00`0oooo00130?ooo`03
0000003oool0oooo0?l0oooo_P3oool00`000000oooo0?ooo`0<0?ooo`00@`3oool00`000000oooo
0?ooo`3o0?oookh0oooo00<000000?ooo`3oool0303oool004<0oooo00<000000?ooo`3oool0o`3o
oonn0?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003oool0oooo0?l0oooo_P3oool0
0`000000oooo0?ooo`0<0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oookh0oooo00<000000?oo
o`3oool0303oool004<0oooo0`00003o0?oook`0oooo0`00000>0?ooo`00@`3oool00`000000oooo
0?ooo`3o0?oookh0oooo00<000000?ooo`3oool0303oool004<0oooo00<000000?ooo`3oool0o`3o
oonn0?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003oool0oooo0?l0oooo_P3oool0
0`000000oooo0?ooo`0<0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oookh0oooo00<000000?oo
o`3oool0303oool004<0oooo00<000000?ooo`3oool0o`3ooonn0?ooo`030000003oool0oooo00`0
oooo00130?ooo`030000003oool0oooo0?l0oooo_P3oool00`000000oooo0?ooo`0<0?ooo`00@`3o
ool00`000000oooo0?ooo`3o0?oookh0oooo00<000000?ooo`3oool0303oool004<0oooo00<00000
0?ooo`3oool0o`3ooonn0?ooo`030000003oool0oooo00`0oooo00130?ooo`<00000o`3ooonl0?oo
o`<000003P3oool004<0oooo00<000000?ooo`3oool0o`3ooonn0?ooo`030000003oool0oooo00`0
oooo00130?ooo`030000003oool0oooo0?l0oooo_P3oool00`000000oooo0?ooo`0<0?ooo`00@`3o
ool00`000000oooo0?ooo`3o0?oookh0oooo00<000000?ooo`3oool0303oool004<0oooo00<00000
0?ooo`3oool0o`3ooonn0?ooo`030000003oool0oooo00`0oooo00130?ooo`030000003oool0oooo
0?l0oooo_P3oool00`000000oooo0?ooo`0<0?ooo`00=`3oool3000000T0oooo00<000000?ooo`3o
ool0o`3ooonn0?ooo`030000003oool0oooo00`0oooo000h0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo
00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo
00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0303oool003P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00`0oooo000h0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0<0?ooo`00>03oool00`000000oooo0?ooo`080?oo
ool00000`P00000>0?ooo`00>03oool00`000000oooo0?ooo`3o0?ooomP0oooo000h0?ooo`030000
003oool0oooo0?l0oooof03oool003P0oooo00<000000?ooo`3oool0o`3ooooH0?ooo`00=`3oool2
00000?l0oooofP3oool003P0oooo00<000000?ooo`3oool0o`3ooooH0?ooo`00o`3ooooo0?oooa@0
oooo003o0?ooool0oooo503oool00?l0ooooo`3ooolD0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 529.563}, {326.938, 0}} -> {-0.321687, -2.4468, \
0.00410264, 0.0108379}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[{
    \( (*\ Linear\ \(Ansatz : \ w \((z)\)\)\  = \ 
        w1\  + \ 
          w2\ \(z : \ \ Evaluate\ integral\ for\ luminocity\ distance\)\ *) \
\[IndentingNewLine]\(f[z_, om_, w1_, w2_] := 
        1/Sqrt[om*\((1 + z)\)^3\  + \((1 - 
                    om)\)*\((1 + z)\)^\((3 \((1 + w1\  - \ w2)\))\) 
                Exp[3\ w2\ z]];\)\), "\n", 
    \(\(rr[zz_, om_, w1_, w2_] := 
        NIntegrate[f[z, om, w1, w2], {z, 0, zz}];\)\)}], "Input"],

Cell[BoxData[{
    \( (*\ Construct\ marginalization\ coefficients\ \((see\ Di\ astro - 
              ph/0401556\  .. )\)\ *) \[IndentingNewLine]\(Clear[chi2fa, 
        chi2fb, chi2fc, chi2fm];\)\), "\[IndentingNewLine]", 
    \(\(chi2fa[w1_, w2_] := 
        Sum[\((ld[i] - 
                  5\ Log[10, 
                      rr[zz[i], 0.3, w1, w2]*\((1 + zz[i])\)])\)^2/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\[IndentingNewLine]", 
    \(\(chi2fb[w1_, w2_] := 
        Sum[\((ld[i] - 
                5\ Log[10, rr[zz[i], 0.3, w1, w2]*\((1 + zz[i])\)])\)/\((sld[
                  i]^2)\), {i, 1, ndat}];\)\), "\[IndentingNewLine]", 
    \(\(chi2fc = Sum[1/\((sld[i]^2)\), {i, 1, ndat}];\)\)}], "Input"],

Cell[BoxData[
    \(\(\( (*\ 
      Construct\ function\ to\ minimized\ after\ marginalization\ *) \)\(\
\[IndentingNewLine]\)\(chi2fm[w1_, w2_] := 
      chi2fa[w1, w2] - chi2fb[w1, w2]^2/chi2fc\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ 
      Minimize\ with\ respect\ to\ om\ and\ find\ same\ result\ as\ with\ mb\ \
minimization . \ 
          Minimization\ and\ marginalization\ have\ the\ same\ \(effect\ !!\)\
\ *) \)\(\[IndentingNewLine]\)\(chmin6m = 
      FindMinimum[
        chi2fm[w1, w2], {w1, {\(-0.9\), \(-0.95\)}}, {w2, {0.03, 0.04}}, 
        MaxIterations \[Rule] 100]\)\)\)], "Input"],

Cell[BoxData[
    \({174.36472784914076`, {w1 \[Rule] \(-1.4001170051270924`\), 
        w2 \[Rule] 1.667544742975568`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(dchi2linear = 174.365 - 177.127\)], "Input"],

Cell[BoxData[
    \(\(-2.7620000000000005`\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ Construct\ w \((z)\)\ at\ best\ fit\ *) \[IndentingNewLine]\(hh[
          z_, om_, w1_, w2_] := 
        h0\ Sqrt[
            om*\((1 + z)\)^3\  + \((1 - 
                    om)\)*\((1 + z)\)^\((3 \((1 + w1\  - \ w2)\))\) 
                Exp[3\ w2\ z]];\)\), "\n", 
    \(ww[z_, om_, w1_, 
        w2_] := \((2\ \((1 + z)\)\ D[Log[hh[z, om, w1, w2]], z]/3\  - \ 
            1)\)/\((1 - \((h0/hh[z, om, w1, w2])\)^2\ om\ \((1 + 
                    z)\)^3)\)\), "\n", 
    \(\(ws6 = 
        ww[z, 0.3, w1, w2]\  /. \ Part[chmin6m, 2]\  // 
          FullSimplify;\)\), "\n", 
    \(plwzlinear = 
      Plot[ws6, {z, 0, 1.75}, PlotRange \[Rule] All, Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<z\>", "\<w(z)\>"}]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.544218 0.29712 0.201701 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.15986 -0.0125 -14.3125 -17.8125 ]
[.15986 -0.0125 14.3125 0 ]
[.29592 -0.0125 -10.7813 -17.8125 ]
[.29592 -0.0125 10.7813 0 ]
[.43197 -0.0125 -14.3125 -17.8125 ]
[.43197 -0.0125 14.3125 0 ]
[.56803 -0.0125 -5.53125 -17.8125 ]
[.56803 -0.0125 5.53125 0 ]
[.70408 -0.0125 -14.3125 -17.8125 ]
[.70408 -0.0125 14.3125 0 ]
[.84014 -0.0125 -10.7813 -17.8125 ]
[.84014 -0.0125 10.7813 0 ]
[.97619 -0.0125 -14.3125 -17.8125 ]
[.97619 -0.0125 14.3125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.125 -35.625 ]
[.5 -0.0125 5.125 -17.8125 ]
[-0.0125 .09542 -20.75 -8.90625 ]
[-0.0125 .09542 0 8.90625 ]
[-0.0125 .19627 -31.25 -8.90625 ]
[-0.0125 .19627 0 8.90625 ]
[-0.0125 .29712 -11.0625 -8.90625 ]
[-0.0125 .29712 0 8.90625 ]
[-0.0125 .39797 -21.5625 -8.90625 ]
[-0.0125 .39797 0 8.90625 ]
[-0.0125 .49882 -11.0625 -8.90625 ]
[-0.0125 .49882 0 8.90625 ]
[-0.0125 .59967 -21.5625 -8.90625 ]
[-0.0125 .59967 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -49.0625 -14.7188 ]
[-0.01875 .30902 -31.25 14.7188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.15986 0 m
.15986 .00625 L
s
gsave
.15986 -0.0125 -75.3125 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.29592 0 m
.29592 .00625 L
s
gsave
.29592 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.43197 0 m
.43197 .00625 L
s
gsave
.43197 -0.0125 -75.3125 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.56803 0 m
.56803 .00625 L
s
gsave
.56803 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.70408 0 m
.70408 .00625 L
s
gsave
.70408 -0.0125 -75.3125 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
1.000 setlinewidth
grestore
.84014 0 m
.84014 .00625 L
s
gsave
.84014 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -75.3125 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
1.000 setlinewidth
grestore
.125 Mabswid
.05102 0 m
.05102 .00375 L
s
.07823 0 m
.07823 .00375 L
s
.10544 0 m
.10544 .00375 L
s
.13265 0 m
.13265 .00375 L
s
.18707 0 m
.18707 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2415 0 m
.2415 .00375 L
s
.26871 0 m
.26871 .00375 L
s
.32313 0 m
.32313 .00375 L
s
.35034 0 m
.35034 .00375 L
s
.37755 0 m
.37755 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45918 0 m
.45918 .00375 L
s
.48639 0 m
.48639 .00375 L
s
.51361 0 m
.51361 .00375 L
s
.54082 0 m
.54082 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62245 0 m
.62245 .00375 L
s
.64966 0 m
.64966 .00375 L
s
.67687 0 m
.67687 .00375 L
s
.73129 0 m
.73129 .00375 L
s
.7585 0 m
.7585 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.81293 0 m
.81293 .00375 L
s
.86735 0 m
.86735 .00375 L
s
.89456 0 m
.89456 .00375 L
s
.92177 0 m
.92177 .00375 L
s
.94898 0 m
.94898 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.125 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .09542 m
.00625 .09542 L
s
gsave
-0.0125 .09542 -81.75 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .19627 m
.00625 .19627 L
s
gsave
-0.0125 .19627 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .29712 m
.00625 .29712 L
s
gsave
-0.0125 .29712 -72.0625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .39797 m
.00625 .39797 L
s
gsave
-0.0125 .39797 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .49882 m
.00625 .49882 L
s
gsave
-0.0125 .49882 -72.0625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .59967 m
.00625 .59967 L
s
gsave
-0.0125 .59967 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .11559 m
.00375 .11559 L
s
0 .13576 m
.00375 .13576 L
s
0 .15593 m
.00375 .15593 L
s
0 .1761 m
.00375 .1761 L
s
0 .21644 m
.00375 .21644 L
s
0 .23661 m
.00375 .23661 L
s
0 .25678 m
.00375 .25678 L
s
0 .27695 m
.00375 .27695 L
s
0 .31729 m
.00375 .31729 L
s
0 .33746 m
.00375 .33746 L
s
0 .35763 m
.00375 .35763 L
s
0 .3778 m
.00375 .3778 L
s
0 .41814 m
.00375 .41814 L
s
0 .43831 m
.00375 .43831 L
s
0 .45848 m
.00375 .45848 L
s
0 .47865 m
.00375 .47865 L
s
0 .51899 m
.00375 .51899 L
s
0 .53916 m
.00375 .53916 L
s
0 .55933 m
.00375 .55933 L
s
0 .5795 m
.00375 .5795 L
s
0 .07525 m
.00375 .07525 L
s
0 .05508 m
.00375 .05508 L
s
0 .03491 m
.00375 .03491 L
s
0 .01474 m
.00375 .01474 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -115.875 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.7188 12.9063 translate
90 rotate
-75.7188 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.063 17.500 moveto
(H) show
77.625 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.875 17.500 moveto
(L) show
88.438 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.15986 .61178 m
.15986 .61803 L
s
.29592 .61178 m
.29592 .61803 L
s
.43197 .61178 m
.43197 .61803 L
s
.56803 .61178 m
.56803 .61803 L
s
.70408 .61178 m
.70408 .61803 L
s
.84014 .61178 m
.84014 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05102 .61428 m
.05102 .61803 L
s
.07823 .61428 m
.07823 .61803 L
s
.10544 .61428 m
.10544 .61803 L
s
.13265 .61428 m
.13265 .61803 L
s
.18707 .61428 m
.18707 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2415 .61428 m
.2415 .61803 L
s
.26871 .61428 m
.26871 .61803 L
s
.32313 .61428 m
.32313 .61803 L
s
.35034 .61428 m
.35034 .61803 L
s
.37755 .61428 m
.37755 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45918 .61428 m
.45918 .61803 L
s
.48639 .61428 m
.48639 .61803 L
s
.51361 .61428 m
.51361 .61803 L
s
.54082 .61428 m
.54082 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62245 .61428 m
.62245 .61803 L
s
.64966 .61428 m
.64966 .61803 L
s
.67687 .61428 m
.67687 .61803 L
s
.73129 .61428 m
.73129 .61803 L
s
.7585 .61428 m
.7585 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.81293 .61428 m
.81293 .61803 L
s
.86735 .61428 m
.86735 .61803 L
s
.89456 .61428 m
.89456 .61803 L
s
.92177 .61428 m
.92177 .61803 L
s
.94898 .61428 m
.94898 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .09542 m
1 .09542 L
s
.99375 .19627 m
1 .19627 L
s
.99375 .29712 m
1 .29712 L
s
.99375 .39797 m
1 .39797 L
s
.99375 .49882 m
1 .49882 L
s
.99375 .59967 m
1 .59967 L
s
.125 Mabswid
.99625 .11559 m
1 .11559 L
s
.99625 .13576 m
1 .13576 L
s
.99625 .15593 m
1 .15593 L
s
.99625 .1761 m
1 .1761 L
s
.99625 .21644 m
1 .21644 L
s
.99625 .23661 m
1 .23661 L
s
.99625 .25678 m
1 .25678 L
s
.99625 .27695 m
1 .27695 L
s
.99625 .31729 m
1 .31729 L
s
.99625 .33746 m
1 .33746 L
s
.99625 .35763 m
1 .35763 L
s
.99625 .3778 m
1 .3778 L
s
.99625 .41814 m
1 .41814 L
s
.99625 .43831 m
1 .43831 L
s
.99625 .45848 m
1 .45848 L
s
.99625 .47865 m
1 .47865 L
s
.99625 .51899 m
1 .51899 L
s
.99625 .53916 m
1 .53916 L
s
.99625 .55933 m
1 .55933 L
s
.99625 .5795 m
1 .5795 L
s
.99625 .07525 m
1 .07525 L
s
.99625 .05508 m
1 .05508 L
s
.99625 .03491 m
1 .03491 L
s
.99625 .01474 m
1 .01474 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .29712 m
1 .29712 L
s
.5 Mabswid
.02381 .01472 m
.06244 .03859 L
.10458 .06463 L
.14415 .08909 L
.18221 .11261 L
.22272 .13765 L
.26171 .16175 L
.30316 .18736 L
.34309 .21204 L
.3815 .23578 L
.42237 .26104 L
.46172 .28536 L
.49955 .30874 L
.53984 .33364 L
.57861 .3576 L
.61984 .38308 L
.65954 .40762 L
.69774 .43123 L
.73838 .45635 L
.77751 .48053 L
.81909 .50623 L
.85916 .53099 L
.89771 .55482 L
.93871 .58016 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{634.938, 392.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009j0001R2000`400?l00000o`00003oo`3ooooo
0?ooog`0oooo003o0?ooool0ooooO03oool00?l0ooooo`3oooml0?ooo`00o`3ooooo0?ooog`0oooo
003o0?ooool0ooooO03oool00?l0ooooF03oool600000?l0oooo7P3oool00?l0ooooF@3oool01@00
0000oooo0?ooo`3oool000000?l0oooo7P3oool00?l0ooooFP3oool00`000000oooo0?ooo`3o0?oo
oal0oooo003o0?oooeX0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`00o`3ooomK0?ooo`030000
003oool0oooo0?l0oooo7P3oool00?l0ooooF03oool01@000000oooo0?ooo`3oool000000?l0oooo
7`3oool00?l0ooooF03oool600000?l0oooo7P3oool00?l0ooooo`3oooml0?ooo`00o`3ooooo0?oo
og`0oooo003o0?ooool0ooooO03oool00?l0ooooo`3oooml0?ooo`00o`3ooooo0?ooog`0oooo003o
0?ooool0ooooO03oool00?l0ooooo`3oooml0?ooo`00o`3ooooo0?ooog`0oooo003o0?ooool0oooo
O03oool00?l0ooooo`3oooml0?ooo`00o`3ooooo0?ooog`0oooo001<0?ooo`<00000@@3oool30000
00<0oooo00@000000?ooo`3oool0oooo1@0000020?ooo`<00000?03oool3000000<0oooo00@00000
0?ooo`3oool0oooo0`00000l0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo0`0000120?ooo`<00000@@3oool3000000<0oooo00@000000?ooo`3oool0oooo
1@0000020?ooo`<00000?03oool3000000<0oooo00@000000?ooo`3oool0oooo0`00000l0?ooo`<0
00000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0`00000:0?ooo`00
B`3oool01@000000oooo0?ooo`3oool0000003l0oooo00D000000?ooo`3oool0oooo000000070?oo
o`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0>03oool01@000000oooo0?ooo`3o
ool0000000T0oooo00<000000?ooo`3oool0>03oool01@000000oooo0?ooo`3oool0000000L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo03X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`00B`3oool01@000000oooo
0?ooo`3oool0000003l0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0=`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<00000
0?ooo`3oool0=`3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`00B`3oool01@000000oooo0?ooo`3oool0000003l0oooo00D0
00000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
=`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0=`3oool01@000000
oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0o0?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`00B`3oool01@000000oooo0?ooo`3oool0000003l0oooo00D000000?ooo`3oool0oooo00000009
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0=`3oool01@000000oooo0?ooo`3o
ool0000000X0oooo00<000000?ooo`3oool0=`3oool01@000000oooo0?ooo`3oool0000000P0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`00B`3oool01@000000oooo0?oo
o`3oool0000003l0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0>03oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?oo
o`3oool0>03oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`070?ooo`00B`3oool01@000000oooo0?ooo`3oool0000003l0oooo00D00000
0?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00<00000>`3oool01@000000oooo0?oo
o`3oool0000000H0oooo0`00000k0?ooo`050000003oool0oooo0?ooo`0000002@3oool010000000
oooo0?ooo`3oool3000004<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00<00000?@3oool00`000000oooo0?ooo`060?ooo`<00000?@3oool00`00
0000oooo0?ooo`090?ooo`040000003oool0oooo0?ooo`<000002P3oool004/0oooo00D000000?oo
o`3oool0oooo0000000o0?ooo`050000003oool0oooo0?ooo`0000002P3oool010000000oooo0?oo
o`00000m0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0k0?ooo`05
0000003oool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3oool0000004D0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000003l0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00T0oooo00D0
00000?ooo`3oool0oooo0000000<0?ooo`00B`3oool01@000000oooo0?ooo`3oool0000003l0oooo
00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`0j0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`0j
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000@`3oool200000480oooo0P0000080?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`0k0?ooo`8000002@3oool00`000000oooo0?ooo`0k0?ooo`80
00001`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000002`3oool004`0
oooo0`0000110?ooo`<00000203oool3000000@0oooo1000000j0?ooo`<00000203oool4000003X0
oooo0`0000070?ooo`D000000`3oool400000440oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`070?ooo`<00000103oool4000003/0oooo00<000000?ooo`3oool01`3oool4000003/0
oooo00<000000?ooo`3oool01P3oool5000000<0oooo100000080?ooo`00o`3ooooo0?ooog`0oooo
003o0?ooool0ooooO03oool00?l0ooooo`3oooml0?ooo`00o`3ooooo0?ooog`0oooo003o0?ooool0
ooooO03oool00?l0ooooo`3oooml0?ooo`00o`3ooooo0?ooog`0oooo003o0?ooool0ooooO03oool0
0?l0ooooo`3oooml0?ooo`00o`3ooooo0?ooog`0oooo00100?ooool00000o`00000g000000D0oooo
00100?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00400oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo04X0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo04X0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo04X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?oo
o`00@03oool00`000000oooo0?ooo`3o0?ooool0oooo<`3oool00`000000oooo0?ooo`030?ooo`00
@03oool00`000000oooo0?ooo`3o0?ooool0oooo<`3oool00`000000oooo0?ooo`030?ooo`00@03o
ool00`000000oooo0?ooo`3o0?ooool0oooo<`3oool00`000000oooo0?ooo`030?ooo`00@03oool0
0`000000oooo0?ooo`3o0?ooool0oooo<`3oool00`000000oooo0?ooo`030?ooo`00@03oool30000
00X0oooo00<000000?ooo`3oool0o`3ooooo0?ooob@0oooo0`0000050?ooo`00@03oool00`000000
oooo0?ooo`0;0?ooo`800000o`3ooooo0?ooobH0oooo00<000000?ooo`3oool00`3oool00400oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?ooool0oooo8`3oool00`000000oooo
0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`0>0?ooo`800000o`3ooooo0?ooob<0oooo00<0
00000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0403oool200000?l0ooooo`3ooolQ
0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0o`3ooooo0?oooah0oooo00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3o
ool04`3oool200000?l0ooooo`3ooolN0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0o`3ooooo0?oooa/0oooo00<000000?ooo`3oool0
0`3oool00400oooo00<000000?ooo`3oool05P3oool200000?l0ooooo`3ooolK0?ooo`030000003o
ool0oooo00<0oooo00100?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3ooooo
0?oooaP0oooo00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool06@3oool20000
0?l0ooooo`3ooolH0?ooo`030000003oool0oooo00<0oooo00100?ooo`<000006`3oool200000?l0
ooooo`3ooolD0?ooo`<000001@3oool00400oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`3o0?ooool0oooo4`3oool00`000000oooo0?ooo`030?ooo`00@03oool00`000000oooo0?oo
o`0N0?ooo`800000o`3ooooo0?oooa<0oooo00<000000?ooo`3oool00`3oool00400oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`3o0?ooool0oooo403oool00`000000oooo0?ooo`03
0?ooo`00@03oool00`000000oooo0?ooo`0Q0?ooo`800000o`3ooooo0?oooa00oooo00<000000?oo
o`3oool00`3oool00400oooo00<000000?ooo`3oool08`3oool200000?l0ooooo`3oool>0?ooo`03
0000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
o`3ooooo0?ooo`/0oooo00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool09P3o
ool200000?l0ooooo`3oool;0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003oool0
oooo02P0oooo0P00003o0?ooool0oooo2@3oool00`000000oooo0?ooo`030?ooo`00@03oool00`00
0000oooo0?ooo`0Z0?ooo`800000o`3ooooo0?ooo`L0oooo00<000000?ooo`3oool00`3oool00400
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`3o0?ooool0oooo103oool00`000000
oooo0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`0]0?ooo`800000o`3ooooo0?ooo`@0oooo
00<000000?ooo`3oool00`3oool00400oooo0`00000_0?ooo`800000o`3ooooo0?ooo`<000001@3o
ool00400oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`3o0?ooooh0oooo00<00000
0?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0<P3oool200000?l0oooooP3oool00`00
0000oooo0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`0d0?ooo`800000o`3ooool0?ooo`03
0000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo03H0oooo0P00003o0?ooooX0oooo
00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`3o0?ooooL0oooo00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0>@3oool2
00000?l0oooom`3oool00`000000oooo0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo0?l0oooom03oool00`000000oooo0?ooo`030?ooo`00@03oool00`000000
oooo0?ooo`0l0?ooo`800000o`3ooood0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000
003oool0oooo03h0oooo0P00003o0?oooo80oooo00<000000?ooo`3oool00`3oool00400oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`3o0?ooonl0oooo00<000000?ooo`3oool00`3o
ool00400oooo0`0000110?ooo`800000o`3oooo]0?ooo`<000001@3oool00400oooo00<000000?oo
o`3oool0@`3oool00`000000oooo0?ooo`3o0?ooon`0oooo00<000000?ooo`3oool00`3oool00400
oooo00<000000?ooo`3oool0A03oool200000?l0ooook03oool00`000000oooo0?ooo`030?ooo`00
@03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0?l0ooooj@3oool00`000000oooo
0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`170?ooo`800000o`3ooooY0?ooo`030000003o
ool0oooo00<0oooo00100?ooo`030000003oool0oooo04T0oooo0P00003o0?ooonL0oooo00<00000
0?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?oo
on@0oooo00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0C03oool200000?l0
ooooi03oool00`000000oooo0?ooo`030?ooo`00<P3oool3000000/0oooo00<000000?ooo`3oool0
CP3oool00`000000oooo0?ooo`3o0?ooon40oooo00<000000?ooo`3oool00`3oool003<0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`1?0?ooo`800000o`3ooooQ0?ooo`030000003o
ool0oooo00<0oooo000c0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0D@3oool2
00000?l0oooog`3oool00`000000oooo0?ooo`030?ooo`009`3oool7000000D0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0?l0oooog03oool00`00
0000oooo0?ooo`030?ooo`00<`3oool00`000000oooo0?ooo`0:0?ooo`@00000D`3oool200000?l0
oooof03oool5000000D0oooo000c0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
EP3oool200000?l0oooofP3oool00`000000oooo0?ooo`030?ooo`00<`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0o`3ooooG0?ooo`030000003o
ool0oooo00<0oooo000c0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0F@3oool2
00000?l0ooooe`3oool00`000000oooo0?ooo`030?ooo`00<P3oool2000000`0oooo00<000000?oo
o`3oool0F`3oool200000?l0ooooe@3oool00`000000oooo0?ooo`030?ooo`00<`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo05d0oooo0P00003o0?ooom<0oooo00<000000?ooo`3o
ool00`3oool00400oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`3o0?ooom00oooo
00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0H03oool200000?l0ooood03o
ool00`000000oooo0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`1R0?ooo`800000o`3oooo>
0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo06@0oooo00<000000?oo
o`3oool0o`3oooo;0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo06D0
oooo0P00003o0?oool/0oooo00<000000?ooo`3oool00`3oool00400oooo0`00001W0?ooo`030000
003oool0oooo0?l0ooooaP3oool3000000D0oooo00100?ooo`030000003oool0oooo06P0oooo0P00
003o0?ooolP0oooo00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0JP3oool2
00000?l0ooooaP3oool00`000000oooo0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`1/0?oo
o`030000003oool0oooo0?l0oooo``3oool00`000000oooo0?ooo`030?ooo`00@03oool00`000000
oooo0?ooo`1]0?ooo`800000o`3oooo30?ooo`030000003oool0oooo00<0oooo00100?ooo`030000
003oool0oooo06l0oooo00<000000?ooo`3oool0o`3oooo00?ooo`030000003oool0oooo00<0oooo
00100?ooo`030000003oool0oooo0700oooo0P00003o0?oool00oooo00<000000?ooo`3oool00`3o
ool00400oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`3o0?oookd0oooo00<00000
0?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0L`3oool200000?l0oooo_@3oool00`00
0000oooo0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`1e0?ooo`800000o`3ooonk0?ooo`03
0000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
o`3ooonh0?ooo`030000003oool0oooo00<0oooo00100?ooo`<00000N03oool200000?l0oooo]P3o
ool3000000D0oooo00100?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0o`3ooone
0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo07/0oooo0P00003o0?oo
okD0oooo00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0O@3oool00`000000
oooo0?ooo`3o0?oook80oooo00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0
OP3oool200000?l0oooo/P3oool00`000000oooo0?ooo`030?ooo`00@03oool00`000000oooo0?oo
o`200?ooo`800000o`3ooon`0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003oool0
oooo0880oooo00<000000?ooo`3oool0o`3ooon]0?ooo`030000003oool0oooo00<0oooo00100?oo
o`030000003oool0oooo08<0oooo0P00003o0?ooojd0oooo00<000000?ooo`3oool00`3oool00400
oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`3o0?ooojX0oooo00<000000?ooo`3o
ool00`3oool00400oooo00<000000?ooo`3oool0QP3oool200000?l0ooooZP3oool00`000000oooo
0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0?l0ooooY`3o
ool00`000000oooo0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`290?ooo`800000o`3ooonW
0?ooo`030000003oool0oooo00<0oooo00100?ooo`<00000R`3oool200000?l0ooooX`3oool30000
00D0oooo00100?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0o`3ooonR0?ooo`03
0000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo08h0oooo0P00003o0?oooj80oooo
00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0T03oool00`000000oooo0?oo
o`3o0?oooil0oooo00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0T@3oool2
00000?l0ooooW`3oool00`000000oooo0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`2C0?oo
o`800000o`3ooonM0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo09D0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000
003oool0oooo09H0oooo0P00003o0?oooiX0oooo00<000000?ooo`3oool00`3oool00400oooo00<0
00000?ooo`3oool0V03oool200000?l0ooooV03oool00`000000oooo0?ooo`030?ooo`00@03oool0
0`000000oooo0?ooo`2J0?ooo`800000o`3ooonF0?ooo`030000003oool0oooo00<0oooo00100?oo
o`030000003oool0oooo09`0oooo00<000000?ooo`3oool0o`3ooonC0?ooo`030000003oool0oooo
00<0oooo00100?ooo`<00000W@3oool200000?l0ooooT@3oool3000000D0oooo00100?ooo`030000
003oool0oooo09l0oooo0P00003o0?oooi40oooo00<000000?ooo`3oool00`3oool00400oooo00<0
00000?ooo`3oool0X@3oool00`000000oooo0?ooo`3o0?ooohh0oooo00<000000?ooo`3oool00`3o
ool00400oooo00<000000?ooo`3oool0XP3oool200000?l0ooooSP3oool00`000000oooo0?ooo`03
0?ooo`00@03oool00`000000oooo0?ooo`2T0?ooo`800000o`3ooon<0?ooo`030000003oool0oooo
00<0oooo00100?ooo`030000003oool0oooo0:H0oooo0P00003o0?ooohX0oooo00<000000?ooo`3o
ool00`3oool00400oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`3o0?ooohL0oooo
00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0Z@3oool200000?l0ooooQ`3o
ool00`000000oooo0?ooo`030?ooo`009`3oool3000000<0oooo00@000000?ooo`3oool0oooo0`00
000<0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0o`3ooon40?ooo`030000003o
ool0oooo00<0oooo000V0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0:`0oooo0P00003o0?oooh@0oooo00<000000?ooo`3oool00`3o
ool002H0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0[P3oool200000?l0ooooPP3oool00`000000oooo0?ooo`030?ooo`00703oool7
000000<0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00P0oooo1000
002_0?ooo`030000003oool0oooo0?l0ooooN`3oool5000000D0oooo000V0?ooo`050000003oool0
oooo0?ooo`0000002P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0;40oooo0P00
003o0?ooogl0oooo00<000000?ooo`3oool00`3oool002H0oooo00D000000?ooo`3oool0oooo0000
00090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?oo
o`3o0?ooog`0oooo00<000000?ooo`3oool00`3oool002H0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`<00000303oool00`000000oooo0?ooo`2d0?ooo`800000o`3oooml0?ooo`030000003o
ool0oooo00<0oooo000V0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0o`3ooomi0?ooo`030000003o
ool0oooo00<0oooo000V0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0;L0oooo0P00003o0?ooogT0oooo00<000000?ooo`3oool00`3o
ool002L0oooo0`0000080?ooo`@000002P3oool00`000000oooo0?ooo`2i0?ooo`800000o`3ooomg
0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo0;/0oooo00<000000?oo
o`3oool0o`3ooomd0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo0;`0
oooo0P00003o0?ooog@0oooo00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0
_P3oool00`000000oooo0?ooo`3o0?ooog40oooo00<000000?ooo`3oool00`3oool00400oooo00<0
00000?ooo`3oool0_`3oool200000?l0ooooL@3oool00`000000oooo0?ooo`030?ooo`00@03oool0
0`000000oooo0?ooo`310?ooo`030000003oool0oooo0?l0ooooKP3oool00`000000oooo0?ooo`03
0?ooo`00@03oool300000<80oooo0P00003o0?ooof`0oooo0`0000050?ooo`00@03oool00`000000
oooo0?ooo`340?ooo`800000o`3ooom/0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000
003oool0oooo0<H0oooo00<000000?ooo`3oool0o`3ooomY0?ooo`030000003oool0oooo00<0oooo
00100?ooo`030000003oool0oooo0<L0oooo0P00003o0?ooofT0oooo00<000000?ooo`3oool00`3o
ool00400oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`3o0?ooofH0oooo00<00000
0?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0bP3oool200000?l0ooooIP3oool00`00
0000oooo0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo0?l0
ooooH`3oool00`000000oooo0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`3=0?ooo`800000
o`3ooomS0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo0<l0oooo0P00
003o0?ooof40oooo00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0d@3oool0
0`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool00`3oool00400oooo00<000000?oo
o`3oool0dP3oool200000?l0ooooGP3oool00`000000oooo0?ooo`030?ooo`00@03oool300000=@0
oooo00<000000?ooo`3oool0o`3ooomI0?ooo`<000001@3oool00400oooo00<000000?ooo`3oool0
e@3oool200000?l0ooooF`3oool00`000000oooo0?ooo`030?ooo`00@03oool00`000000oooo0?oo
o`3G0?ooo`800000o`3ooomI0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003oool0
oooo0=T0oooo00<000000?ooo`3oool0o`3ooomF0?ooo`030000003oool0oooo00<0oooo00100?oo
o`030000003oool0oooo0=X0oooo0P00003o0?oooeH0oooo00<000000?ooo`3oool00`3oool00400
oooo00<000000?ooo`3oool0g03oool200000?l0ooooE03oool00`000000oooo0?ooo`030?ooo`00
@03oool00`000000oooo0?ooo`3N0?ooo`030000003oool0oooo0?l0ooooD@3oool00`000000oooo
0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`3O0?ooo`800000o`3ooomA0?ooo`030000003o
ool0oooo00<0oooo00100?ooo`030000003oool0oooo0>40oooo00<000000?ooo`3oool0o`3ooom>
0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo0>80oooo0P00003o0?oo
odh0oooo00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0i03oool200000?l0
ooooC03oool00`000000oooo0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`3V0?ooo`030000
003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`030?ooo`00@03oool300000>L0oooo0P00
003o0?ooodL0oooo0`0000050?ooo`00@03oool00`000000oooo0?ooo`3Y0?ooo`800000o`3ooom7
0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo0>/0oooo00<000000?oo
o`3oool0o`3ooom40?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo0>`0
oooo0P00003o0?oood@0oooo00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0
kP3oool00`000000oooo0?ooo`3o0?oood40oooo00<000000?ooo`3oool00`3oool00400oooo00<0
00000?ooo`3oool0k`3oool200000?l0oooo@@3oool00`000000oooo0?ooo`030?ooo`00@03oool0
0`000000oooo0?ooo`3a0?ooo`800000o`3ooolo0?ooo`030000003oool0oooo00<0oooo00100?oo
o`030000003oool0oooo0?<0oooo00<000000?ooo`3oool0o`3oooll0?ooo`030000003oool0oooo
00<0oooo00100?ooo`030000003oool0oooo0?@0oooo0P00003o0?oooc`0oooo00<000000?ooo`3o
ool00`3oool00400oooo00<000000?ooo`3oool0mP3oool00`000000oooo0?ooo`3o0?ooocT0oooo
00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0m`3oool200000?l0oooo>@3o
ool00`000000oooo0?ooo`030?ooo`00@03oool300000?T0oooo00<000000?ooo`3oool0o`3ooold
0?ooo`<000001@3oool00400oooo00<000000?ooo`3oool0nP3oool200000?l0oooo=P3oool00`00
0000oooo0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`3l0?ooo`800000o`3ooold0?ooo`03
0000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo0?h0oooo00<000000?ooo`3oool0
o`3ooola0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo0?l0oooo0P00
003o0?oooc40oooo00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0o`3oool2
0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`030?ooo`002`3oool00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo0?l0oooo0`3oool200000?l0oooo;P3oool00`00
0000oooo0?ooo`030?ooo`002`3oool300000380oooo00<000000?ooo`3oool0o`3oool50?ooo`80
0000o`3oool/0?ooo`030000003oool0oooo00<0oooo000;0?ooo`030000003oool0oooo00<00000
8@3oool3000000/0oooo00<000000?ooo`3oool0o`3oool70?ooo`030000003oool0oooo0?l0oooo
:@3oool00`000000oooo0?ooo`030?ooo`00403oool2000001l0oooo00D000000?ooo`3oool0oooo
0000000:0?ooo`030000003oool0oooo0?l0oooo203oool200000?l0oooo:@3oool00`000000oooo
0?ooo`030?ooo`002`3oool00`000000oooo0?ooo`0200000240oooo00D000000?ooo`3oool0oooo
0000000:0?ooo`030000003oool0oooo0?l0oooo2P3oool200000?l0oooo9`3oool00`000000oooo
0?ooo`030?ooo`002`3oool3000002<0oooo00D000000?ooo`3oool0oooo0000000:0?ooool00000
o`00000g000000D0oooo000;0?ooo`030000003oool0oooo00<00000803oool01@000000oooo0?oo
o`3oool0000000X0oooo00<000000?ooo`3oool0o`3oool=0?ooo`800000o`3ooolT0?ooo`030000
003oool0oooo00<0oooo000@0?ooo`8000007`3oool01@000000oooo0?ooo`3oool0000000X0oooo
00<000000?ooo`3oool0o`3oool?0?ooo`800000o`3ooolR0?ooo`030000003oool0oooo00<0oooo
000;0?ooo`030000003oool0oooo008000008@3oool01@000000oooo0?ooo`3oool0000000X0oooo
00<000000?ooo`3oool0o`3ooolA0?ooo`800000o`3ooolP0?ooo`030000003oool0oooo00<0oooo
000;0?ooo`<000008`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0
o`3ooolC0?ooo`030000003oool0oooo0?l0oooo7@3oool00`000000oooo0?ooo`030?ooo`002`3o
ool00`000000oooo0?ooo`0S0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo
0?ooo`3o0?oooa@0oooo0P00003o0?oooad0oooo00<000000?ooo`3oool00`3oool000X0oooo2@00
000O0?ooo`<000002`3oool00`000000oooo0?ooo`3o0?oooaH0oooo0P00003o0?oooa/0oooo00<0
00000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo0?l0oooo603oool00`000000oooo0?ooo`3o0?oooaP0oooo00<00000
0?ooo`3oool00`3oool000P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo0?l0oooo6@3oool200000?l0oooo603oool00`000000oooo0?ooo`030?oo
o`00@03oool00`000000oooo0?ooo`3o0?oooa/0oooo00<000000?ooo`3oool0o`3ooolE0?ooo`03
0000003oool0oooo00<0oooo000;0?ooo`800000103oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo0?l0oooo703oool200000?l0oooo5@3oool00`000000oooo0?ooo`030?ooo`002`3o
ool00`000000oooo0?ooo`020?ooo`800000;P3oool00`000000oooo0?ooo`3o0?oooah0oooo0P00
003o0?oooa<0oooo00<000000?ooo`3oool00`3oool000/0oooo00<000000?ooo`3oool00P000000
0`3oool000000?ooo`0]0?ooo`<00000o`3ooolP0?ooo`030000003oool0oooo0?l0oooo3P3oool3
000000D0oooo000;0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`3o0?ooob40oooo0P00003o0?oooa00oooo00<000000?ooo`3oool00`3oool000/0
oooo0P0000040?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`03
0000003oool0oooo0?l0oooo3@3oool00`000000oooo0?ooo`030?ooo`002`3oool00`000000oooo
0?ooo`020?ooo`800000;P3oool00`000000oooo0?ooo`3o0?ooob@0oooo0P00003o0?ooo`d0oooo
00<000000?ooo`3oool00`3oool000P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo0?l0oooo9P3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<0
00000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo0?l0oooo9`3oool200000?l0oooo2P3oool00`000000oooo0?ooo`03
0?ooo`002P3oool9000002d0oooo00<000000?ooo`3oool0o`3ooolY0?ooo`800000o`3oool80?oo
o`030000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo0?l0oooo:`3oool00`000000
oooo0?ooo`3o0?ooo`D0oooo00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0
o`3oool/0?ooo`800000o`3oool50?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003o
ool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`3o0?ooo`80oooo00<000000?ooo`3oool00`3o
ool00400oooo00<000000?ooo`3oool0o`3oool_0?ooo`800000o`3oool20?ooo`030000003oool0
oooo00<0oooo00100?ooo`<00000o`3ooola0?ooo`030000003oool0oooo0?`0oooo0`0000050?oo
o`00@03oool00`000000oooo0?ooo`3o0?oooc80oooo0P00003n0?ooo`030000003oool0oooo00<0
oooo00100?ooo`030000003oool0oooo0?l0oooo=03oool200000?`0oooo00<000000?ooo`3oool0
0`3oool00400oooo00<000000?ooo`3oool0o`3ooolf0?ooo`030000003oool0oooo0?T0oooo00<0
00000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0o`3ooolg0?ooo`800000n@3oool0
0`000000oooo0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?oo
o`3oool0mP3oool00`000000oooo0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`3o0?ooocX0
oooo0P00003f0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo0?l0oooo
?03oool00`000000oooo0?ooo`3c0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003o
ool0oooo0?l0oooo?@3oool200000?<0oooo00<000000?ooo`3oool00`3oool00400oooo00<00000
0?ooo`3oool0o`3ooolo0?ooo`800000l@3oool00`000000oooo0?ooo`030?ooo`00@03oool00`00
0000oooo0?ooo`3o0?oood40oooo00<000000?ooo`3oool0kP3oool00`000000oooo0?ooo`030?oo
o`00@03oool00`000000oooo0?ooo`3o0?oood80oooo0P00003^0?ooo`030000003oool0oooo00<0
oooo00100?ooo`<00000o`3ooom40?ooo`030000003oool0oooo0>T0oooo0`0000050?ooo`00@03o
ool00`000000oooo0?ooo`3o0?ooodD0oooo0P00003[0?ooo`030000003oool0oooo00<0oooo0010
0?ooo`030000003oool0oooo0?l0ooooA`3oool200000>T0oooo00<000000?ooo`3oool00`3oool0
0400oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo0>H0oooo00<000000?oo
o`3oool00`3oool00400oooo00<000000?ooo`3oool0o`3ooom:0?ooo`800000iP3oool00`000000
oooo0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`3o0?oood`0oooo0P00003T0?ooo`030000
003oool0oooo00<0oooo00100?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?oo
o`3Q0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo0?l0ooooC`3oool2
00000>40oooo00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0o`3ooomA0?oo
o`030000003oool0oooo0=h0oooo00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3o
ool0o`3ooomB0?ooo`800000gP3oool00`000000oooo0?ooo`030?ooo`00@03oool00`000000oooo
0?ooo`3o0?oooe@0oooo0P00003L0?ooo`030000003oool0oooo00<0oooo00100?ooo`<00000o`3o
oomF0?ooo`030000003oool0oooo0=L0oooo0`0000050?ooo`00@03oool00`000000oooo0?ooo`3o
0?oooeL0oooo0P00003I0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo
0?l0ooooF@3oool200000=L0oooo00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3o
ool0o`3ooomK0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00400oooo
00<000000?ooo`3oool0o`3ooomL0?ooo`800000e03oool00`000000oooo0?ooo`030?ooo`00@03o
ool00`000000oooo0?ooo`3o0?oooeh0oooo0P00003B0?ooo`030000003oool0oooo00<0oooo0010
0?ooo`030000003oool0oooo0?l0ooooH03oool00`000000oooo0?ooo`3?0?ooo`030000003oool0
oooo00<0oooo00100?ooo`030000003oool0oooo0?l0ooooH@3oool200000<l0oooo00<000000?oo
o`3oool00`3oool002L0oooo0`0000030?ooo`040000003oool0oooo0?ooo`<00000303oool00`00
0000oooo0?ooo`3o0?ooof<0oooo0P00003=0?ooo`030000003oool0oooo00<0oooo000V0?ooo`05
0000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0?l0ooooI@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00<0oooo000V0?ooo`05
0000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0?l0ooooIP3oool200000<X0oooo00<000000?ooo`3oool00`3oool002H0oooo00D000000?ooo`3o
ool0oooo0000000:0?ooo`030000003oool0oooo00P0oooo1000003o0?ooofL0oooo00<000000?oo
o`3oool0``3oool5000000D0oooo000V0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooJ@3oool200000<L0oooo00<000000?oo
o`3oool00`3oool002H0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0o`3ooom[0?ooo`800000a@3oool00`000000oooo0?ooo`030?oo
o`009P3oool01@000000oooo0?ooo`3oool0000000H0oooo0`00000<0?ooo`030000003oool0oooo
0?l0ooooK@3oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo00<0oooo000V0?ooo`05
0000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
0?l0ooooKP3oool200000<80oooo00<000000?ooo`3oool00`3oool002H0oooo00D000000?ooo`3o
ool0oooo000000070?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooom`0?oo
o`800000`03oool00`000000oooo0?ooo`030?ooo`009`3oool3000000P0oooo1000000:0?ooo`03
0000003oool0oooo0?l0ooooLP3oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo00<0
oooo00100?ooo`030000003oool0oooo0?l0ooooL`3oool200000;d0oooo00<000000?ooo`3oool0
0`3oool00400oooo00<000000?ooo`3oool0o`3ooome0?ooo`800000^`3oool00`000000oooo0?oo
o`030?ooo`00@03oool00`000000oooo0?ooo`3o0?ooogL0oooo00<000000?ooo`3oool0^03oool0
0`000000oooo0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`3o0?ooogP0oooo0P00002h0?oo
o`030000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo0?l0ooooNP3oool00`000000
oooo0?ooo`2e0?ooo`030000003oool0oooo00<0oooo00100?ooo`<00000o`3ooomk0?ooo`800000
/`3oool3000000D0oooo00100?ooo`030000003oool0oooo0?l0ooooO@3oool200000;<0oooo00<0
00000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0o`3ooomo0?ooo`030000003oool0
oooo0;00oooo00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0o`3ooon00?oo
o`800000/03oool00`000000oooo0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`3o0?oooh80
oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`030?ooo`00@03oool00`000000oooo
0?ooo`3o0?oooh<0oooo0P00002]0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003o
ool0oooo0?l0ooooQ@3oool200000:/0oooo00<000000?ooo`3oool00`3oool00400oooo00<00000
0?ooo`3oool0o`3ooon70?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool00`3oool0
0400oooo00<000000?ooo`3oool0o`3ooon80?ooo`800000Z03oool00`000000oooo0?ooo`030?oo
o`00@03oool00`000000oooo0?ooo`3o0?ooohX0oooo0P00002V0?ooo`030000003oool0oooo00<0
oooo00100?ooo`030000003oool0oooo0?l0ooooS03oool00`000000oooo0?ooo`2S0?ooo`030000
003oool0oooo00<0oooo00100?ooo`<00000o`3ooon=0?ooo`800000X@3oool3000000D0oooo0010
0?ooo`030000003oool0oooo0?l0ooooS`3oool200000:40oooo00<000000?ooo`3oool00`3oool0
0400oooo00<000000?ooo`3oool0o`3ooonA0?ooo`030000003oool0oooo09h0oooo00<000000?oo
o`3oool00`3oool00400oooo00<000000?ooo`3oool0o`3ooonB0?ooo`800000WP3oool00`000000
oooo0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`3o0?oooi@0oooo00<000000?ooo`3oool0
V`3oool00`000000oooo0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`3o0?oooiD0oooo0P00
002K0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo0?l0ooooU`3oool2
000009T0oooo00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0o`3ooonI0?oo
o`030000003oool0oooo09H0oooo00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`800000UP3oool00`000000oooo0?ooo`030?ooo`00@03oool00`000000oooo
0?ooo`3o0?oooi`0oooo0P00002D0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003o
ool0oooo0?l0ooooWP3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo00<0oooo0010
0?ooo`<00000o`3ooonO0?ooo`800000S`3oool3000000D0oooo00100?ooo`030000003oool0oooo
0?l0ooooX@3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo00<0oooo00100?ooo`03
0000003oool0oooo0?l0ooooXP3oool2000008h0oooo00<000000?ooo`3oool00`3oool00400oooo
00<000000?ooo`3oool0o`3ooonT0?ooo`800000S03oool00`000000oooo0?ooo`030?ooo`00@03o
ool00`000000oooo0?ooo`3o0?ooojH0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?oo
o`030?ooo`00@03oool00`000000oooo0?ooo`3o0?ooojL0oooo0P0000290?ooo`030000003oool0
oooo00<0oooo00100?ooo`030000003oool0oooo0?l0ooooZ@3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo0?l0ooooZP3oool2000008H0
oooo00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0o`3ooon/0?ooo`030000
003oool0oooo08<0oooo00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0o`3o
oon]0?ooo`800000P`3oool00`000000oooo0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`3o
0?ooojl0oooo0P0000210?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo
0?l0oooo/@3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00<0oooo00100?ooo`<0
0000o`3ooonb0?ooo`800000O03oool3000000D0oooo00100?ooo`030000003oool0oooo0?l0oooo
]03oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003o
ool0oooo0?l0oooo]@3oool2000007/0oooo00<000000?ooo`3oool00`3oool00400oooo00<00000
0?ooo`3oool0o`3ooong0?ooo`800000N@3oool00`000000oooo0?ooo`030?ooo`00@03oool00`00
0000oooo0?ooo`3o0?oookT0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`030?oo
o`00@03oool00`000000oooo0?ooo`3o0?oookX0oooo0P00001f0?ooo`030000003oool0oooo00<0
oooo00100?ooo`030000003oool0oooo0?l0oooo_03oool2000007@0oooo00<000000?ooo`3oool0
0`3oool00400oooo00<000000?ooo`3oool0o`3ooonn0?ooo`800000LP3oool00`000000oooo0?oo
o`030?ooo`00<P3oool3000000/0oooo00<000000?ooo`3oool0o`3oooo00?ooo`030000003oool0
oooo06l0oooo00<000000?ooo`3oool00`3oool003<0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`3o0?oool40oooo0P00001_0?ooo`030000003oool0oooo00<0oooo000c0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3oooo30?ooo`800000K@3oool00`000000
oooo0?ooo`030?ooo`00<`3oool00`000000oooo0?ooo`0:0?ooo`@00000o`3oooo40?ooo`030000
003oool0oooo06H0oooo1@0000050?ooo`00<`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0?l0ooooaP3oool2000006X0oooo00<000000?ooo`3oool00`3oool003<0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?ooolP0oooo0P00001X0?ooo`030000003oool0
oooo00<0oooo000c0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3oooo:0?oo
o`800000IP3oool00`000000oooo0?ooo`030?ooo`00<`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0?l0ooooc03oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo00<0
oooo000b0?ooo`800000303oool00`000000oooo0?ooo`3o0?ooold0oooo0P00001S0?ooo`030000
003oool0oooo00<0oooo000c0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3o
ooo?0?ooo`800000H@3oool00`000000oooo0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`3o
0?ooom40oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`030?ooo`00@03oool00`00
0000oooo0?ooo`3o0?ooom80oooo0P00001N0?ooo`030000003oool0oooo00<0oooo00100?ooo`03
0000003oool0oooo0?l0ooooe03oool2000005`0oooo00<000000?ooo`3oool00`3oool00400oooo
00<000000?ooo`3oool0o`3ooooF0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0
0`3oool00400oooo00<000000?ooo`3oool0o`3ooooG0?ooo`800000F@3oool00`000000oooo0?oo
o`030?ooo`00@03oool300000?l0oooof@3oool00`000000oooo0?ooo`1D0?ooo`<000001@3oool0
0400oooo00<000000?ooo`3oool0o`3ooooJ0?ooo`800000EP3oool00`000000oooo0?ooo`030?oo
o`00@03oool00`000000oooo0?ooo`3o0?ooom`0oooo0P00001D0?ooo`030000003oool0oooo00<0
oooo00100?ooo`030000003oool0oooo0?l0oooogP3oool00`000000oooo0?ooo`1A0?ooo`030000
003oool0oooo00<0oooo00100?ooo`030000003oool0oooo0?l0oooog`3oool200000540oooo00<0
00000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0o`3ooooQ0?ooo`800000C`3oool0
0`000000oooo0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`3o0?ooon<0oooo00<000000?oo
o`3oool0C03oool00`000000oooo0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`3o0?ooon@0
oooo0P00001<0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo0?l0oooo
iP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003o
ool0oooo0?l0ooooi`3oool2000004T0oooo00<000000?ooo`3oool00`3oool00400oooo00<00000
0?ooo`3oool0o`3ooooY0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool00`3oool0
0400oooo0`00003o0?ooonX0oooo0P0000140?ooo`<000001@3oool00400oooo00<000000?ooo`3o
ool0o`3oooo/0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool00`3oool00400oooo
00<000000?ooo`3oool0o`3oooo]0?ooo`800000@`3oool00`000000oooo0?ooo`030?ooo`00@03o
ool00`000000oooo0?ooo`3o0?ooonl0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?oo
o`030?ooo`00@03oool00`000000oooo0?ooo`3o0?oooo00oooo0P0000100?ooo`030000003oool0
oooo00<0oooo00100?ooo`030000003oool0oooo0?l0oooolP3oool00`000000oooo0?ooo`0m0?oo
o`030000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo0?l0ooool`3oool2000003d0
oooo00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0o`3ooooe0?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0o`3o
ooof0?ooo`800000>P3oool00`000000oooo0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`3o
0?ooooP0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`030?ooo`00@03oool00`00
0000oooo0?ooo`3o0?ooooT0oooo0P00000g0?ooo`030000003oool0oooo00<0oooo00100?ooo`<0
0000o`3ooook0?ooo`800000<`3oool3000000D0oooo00100?ooo`030000003oool0oooo0?l0oooo
o@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003o
ool0oooo0?l0oooooP3oool200000380oooo00<000000?ooo`3oool00`3oool00400oooo00<00000
0?ooo`3oool0o`3ooooo0?ooo`40oooo0P00000`0?ooo`030000003oool0oooo00<0oooo00100?oo
o`030000003oool0oooo0?l0ooooo`3oool30?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool00`3oool00400oooo00<000000?ooo`3oool0o`3ooooo0?ooo`@0oooo0P00000]0?ooo`03
0000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo0?l0ooooo`3oool60?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool00`3oool00400oooo00<000000?ooo`3oool0o`3o
oooo0?ooo`L0oooo0P00000Z0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003oool0
oooo0?l0ooooo`3oool90?ooo`800000:03oool00`000000oooo0?ooo`030?ooo`00@03oool00`00
0000oooo0?ooo`3o0?ooool0oooo2`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
00<0oooo00100?ooo`030000003oool0oooo0?l0ooooo`3oool<0?ooo`8000009@3oool00`000000
oooo0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`3o0?ooool0oooo3P3oool2000002<0oooo
00<000000?ooo`3oool00`3oool00400oooo0`00003o0?ooool0oooo403oool00`000000oooo0?oo
o`0N0?ooo`<000001@3oool00400oooo00<000000?ooo`3oool0o`3ooooo0?oooa40oooo0P00000P
0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo0?l0ooooo`3ooolC0?oo
o`8000007P3oool00`000000oooo0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`3o0?ooool0
oooo5@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000
003oool0oooo0?l0ooooo`3ooolF0?ooo`8000006`3oool00`000000oooo0?ooo`030?ooo`00@03o
ool00`000000oooo0?ooo`3o0?ooool0oooo603oool2000001T0oooo00<000000?ooo`3oool00`3o
ool00400oooo00<000000?ooo`3oool0o`3ooooo0?oooaX0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`3o0?ooool0oooo6`3oool20000
01H0oooo00<000000?ooo`3oool00`3oool002L0oooo0`0000030?ooo`040000003oool0oooo0?oo
o`<00000303oool00`000000oooo0?ooo`3o0?ooool0oooo7@3oool2000001@0oooo00<000000?oo
o`3oool00`3oool002P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0?l0ooooo`3ooolO0?ooo`8000004P3oool00`000000oooo0?ooo`030?ooo`00
:03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooob40oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`030?ooo`00:03o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo1000003o0?ooool0oooo8@3o
ool2000000/0oooo1@0000050?ooo`00:03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0o`3ooooo0?ooob@0oooo0P00000=0?ooo`030000003oool0
oooo00<0oooo000X0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`3o0?ooool0oooo9P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00<0oooo000X0?ooo`030000003oool0oooo00H0oooo0`00000<0?ooo`030000003oool0oooo0?l0
ooooo`3ooolc0?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooool0oooo<`3oool00`000000oooo
0?ooo`030?ooo`009`3oool2000000T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`3o0?ooool0oooo<`3oool00`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`07
0?ooo`@000002P3oool00`000000oooo0?ooo`3o0?ooool0oooo<`3oool00`000000oooo0?ooo`03
0?ooo`00@03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`030?ooo`00@03oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
0`3oool00400ooooo`00003o000003L000001@3oool00001\
\>"],
  ImageRangeCache->{{{0, 633.938}, {391.438, 0}} -> {-0.252805, -1.84805, \
0.00325624, 0.00878579}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Show[{plwzlind, plwzlinear, plw20q, plw15p, 
        Graphics[{\[IndentingNewLine]{Dashing[{0.005, 0.005}], 
              Line[{{0, \(-1\)}, {1.75, \(-1\)}}]}}]}, 
      Epilog \[Rule] {Text[\*"\"\<\!\(\[CapitalDelta]\[Chi]\^2\)=-2.8\>\"", \
{1.34, 1}], 
          Text[\*"\"\<\!\(\[CapitalDelta]\[Chi]\^2\)=-3.2\>\"", {1.6, 0.55}], 
          Text[\*"\"\<\[CapitalEDoubleDot],  \!\(\[CapitalDelta]\[Chi]\^2\)=0\
\>\"", {0.5, \(-1.05\)}], 
          Text[\*"\"\<Phantom, s=1.5, \
\!\(\[CapitalDelta]\[Chi]\^2\)=1.4\>\"", {0.85, \(-1.22\)}], 
          Text[\*"\"\<Quintessence, s=2, \!\(\[CapitalDelta]\[Chi]\^2\)=7.8\>\
\"", {0.9, \(-0.84\)}]}, 
      PlotRange \[Rule] {{0, 1.75}, {\(-1.6\), 
            1.2}}]\)\(\[IndentingNewLine]\)\( (*\ \(--\(--\(--\(--\(--\(--\(\
--\(--\(--\(--\(--\(--\(--\(--\(--\(-Fig . \ \ \(\(\(\(\(\(\(\(\(\(\(\(\(\(\(\
\(\(\(\(\(\(\(\(\(\(\(\(\(\(\(4\ --\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)\
--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)--\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\(-\)\ *) \)\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.571429 0.353162 0.220726 [
[.14286 -0.0125 -14.3125 -17.8125 ]
[.14286 -0.0125 14.3125 0 ]
[.28571 -0.0125 -10.7813 -17.8125 ]
[.28571 -0.0125 10.7813 0 ]
[.42857 -0.0125 -14.3125 -17.8125 ]
[.42857 -0.0125 14.3125 0 ]
[.57143 -0.0125 -5.53125 -17.8125 ]
[.57143 -0.0125 5.53125 0 ]
[.71429 -0.0125 -14.3125 -17.8125 ]
[.71429 -0.0125 14.3125 0 ]
[.85714 -0.0125 -10.7813 -17.8125 ]
[.85714 -0.0125 10.7813 0 ]
[1 -0.0125 -14.3125 -17.8125 ]
[1 -0.0125 14.3125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.125 -35.625 ]
[.5 -0.0125 5.125 -17.8125 ]
[-0.0125 .02207 -31.25 -8.90625 ]
[-0.0125 .02207 0 8.90625 ]
[-0.0125 .13244 -20.75 -8.90625 ]
[-0.0125 .13244 0 8.90625 ]
[-0.0125 .2428 -31.25 -8.90625 ]
[-0.0125 .2428 0 8.90625 ]
[-0.0125 .35316 -11.0625 -8.90625 ]
[-0.0125 .35316 0 8.90625 ]
[-0.0125 .46353 -21.5625 -8.90625 ]
[-0.0125 .46353 0 8.90625 ]
[-0.0125 .57389 -11.0625 -8.90625 ]
[-0.0125 .57389 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -49.0625 -14.7188 ]
[-0.01875 .30902 -31.25 14.7188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14286 0 m
.14286 .00625 L
s
gsave
.14286 -0.0125 -75.3125 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.28571 0 m
.28571 .00625 L
s
gsave
.28571 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.42857 0 m
.42857 .00625 L
s
gsave
.42857 -0.0125 -75.3125 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.57143 0 m
.57143 .00625 L
s
gsave
.57143 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.71429 0 m
.71429 .00625 L
s
gsave
.71429 -0.0125 -75.3125 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
1.000 setlinewidth
grestore
.85714 0 m
.85714 .00625 L
s
gsave
.85714 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -75.3125 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
1.000 setlinewidth
grestore
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.125 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02207 m
.00625 .02207 L
s
gsave
-0.0125 .02207 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
0 .13244 m
.00625 .13244 L
s
gsave
-0.0125 .13244 -81.75 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .2428 m
.00625 .2428 L
s
gsave
-0.0125 .2428 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .35316 m
.00625 .35316 L
s
gsave
-0.0125 .35316 -72.0625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .46353 m
.00625 .46353 L
s
gsave
-0.0125 .46353 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .57389 m
.00625 .57389 L
s
gsave
-0.0125 .57389 -72.0625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .08829 m
.00375 .08829 L
s
0 .11036 m
.00375 .11036 L
s
0 .15451 m
.00375 .15451 L
s
0 .17658 m
.00375 .17658 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .26487 m
.00375 .26487 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .44145 m
.00375 .44145 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .52974 m
.00375 .52974 L
s
0 .55182 m
.00375 .55182 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -115.875 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.7188 12.9063 translate
90 rotate
-75.7188 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.063 17.500 moveto
(H) show
77.625 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.875 17.500 moveto
(L) show
88.438 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.14286 .61178 m
.14286 .61803 L
s
.28571 .61178 m
.28571 .61803 L
s
.42857 .61178 m
.42857 .61803 L
s
.57143 .61178 m
.57143 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.85714 .61178 m
.85714 .61803 L
s
.125 Mabswid
.02857 .61428 m
.02857 .61803 L
s
.05714 .61428 m
.05714 .61803 L
s
.08571 .61428 m
.08571 .61803 L
s
.11429 .61428 m
.11429 .61803 L
s
.17143 .61428 m
.17143 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.22857 .61428 m
.22857 .61803 L
s
.25714 .61428 m
.25714 .61803 L
s
.31429 .61428 m
.31429 .61803 L
s
.34286 .61428 m
.34286 .61803 L
s
.37143 .61428 m
.37143 .61803 L
s
.4 .61428 m
.4 .61803 L
s
.45714 .61428 m
.45714 .61803 L
s
.48571 .61428 m
.48571 .61803 L
s
.51429 .61428 m
.51429 .61803 L
s
.54286 .61428 m
.54286 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.62857 .61428 m
.62857 .61803 L
s
.65714 .61428 m
.65714 .61803 L
s
.68571 .61428 m
.68571 .61803 L
s
.74286 .61428 m
.74286 .61803 L
s
.77143 .61428 m
.77143 .61803 L
s
.8 .61428 m
.8 .61803 L
s
.82857 .61428 m
.82857 .61803 L
s
.88571 .61428 m
.88571 .61803 L
s
.91429 .61428 m
.91429 .61803 L
s
.94286 .61428 m
.94286 .61803 L
s
.97143 .61428 m
.97143 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02207 m
1 .02207 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .2428 m
1 .2428 L
s
.99375 .35316 m
1 .35316 L
s
.99375 .46353 m
1 .46353 L
s
.99375 .57389 m
1 .57389 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .06622 m
1 .06622 L
s
.99625 .08829 m
1 .08829 L
s
.99625 .11036 m
1 .11036 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .17658 m
1 .17658 L
s
.99625 .19865 m
1 .19865 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .26487 m
1 .26487 L
s
.99625 .28694 m
1 .28694 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33109 m
1 .33109 L
s
.99625 .37523 m
1 .37523 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .41938 m
1 .41938 L
s
.99625 .44145 m
1 .44145 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .50767 m
1 .50767 L
s
.99625 .52974 m
1 .52974 L
s
.99625 .55182 m
1 .55182 L
s
.99625 .59596 m
1 .59596 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .35316 m
1 .35316 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ .01 .01 ] 0 setdash
0 .00506 m
.04057 .05326 L
.08481 .09903 L
.12636 .13673 L
.16632 .16899 L
.20885 .19969 L
.2498 .22623 L
.29331 .2517 L
.33524 .27391 L
.37557 .29343 L
.41848 .31245 L
.4598 .32927 L
.49953 .34421 L
.54183 .35896 L
.58254 .37212 L
.62583 .38514 L
.66752 .39682 L
.70762 .40733 L
.7503 .41782 L
.79139 .4273 L
.83505 .43676 L
.87712 .44534 L
.9176 .45314 L
.96065 .46098 L
1 .46777 L
s
[ ] 0 setdash
0 .04412 m
.04057 .07025 L
.08481 .09875 L
.12636 .12551 L
.16632 .15125 L
.20885 .17865 L
.2498 .20502 L
.29331 .23305 L
.33524 .26006 L
.37557 .28604 L
.41848 .31368 L
.4598 .34029 L
.49953 .36588 L
.54183 .39313 L
.58254 .41935 L
.62583 .44723 L
.66752 .47409 L
.70762 .49992 L
.7503 .52741 L
.79139 .55387 L
.83505 .582 L
.87712 .60909 L
s
.87712 .60909 m
.891 .61803 L
s
0 .21656 m
.04636 .20027 L
.09692 .18771 L
.14441 .17893 L
.19008 .17232 L
.23869 .16667 L
.28548 .16223 L
.33521 .15832 L
.38313 .15518 L
.42923 .15262 L
.47827 .15028 L
.52549 .14836 L
.57089 .14675 L
.61924 .14527 L
.66576 .14402 L
.71523 .14286 L
.76288 .14188 L
.80871 .14104 L
.85749 .14026 L
.90444 .13958 L
.95434 .13895 L
s
.95434 .13895 m
1 .13843 L
s
0 .07854 m
.04636 .08108 L
.09692 .08453 L
.14441 .08812 L
.19008 .09167 L
.23869 .09539 L
.28548 .0988 L
.33521 .10217 L
.38313 .10514 L
.42923 .10774 L
.47827 .11023 L
.52549 .11237 L
.57089 .11421 L
.61924 .11597 L
.66576 .11747 L
.71523 .11889 L
.76288 .12011 L
.80871 .12115 L
.85749 .12215 L
.90444 .12301 L
.95434 .12382 L
s
.95434 .12382 m
1 .12449 L
s
[ .005 .005 ] 0 setdash
0 .13244 m
1 .13244 L
s
gsave
.76571 .57389 -91.875 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Dc) show
79.688 11.875 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
85.188 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
94.188 17.500 moveto
(-) show
103.188 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
120.750 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.91429 .47456 -91.875 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Dc) show
79.688 11.875 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
85.188 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
94.188 17.500 moveto
(-) show
103.188 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.2) show
120.750 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.28571 .1214 -92.375 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\313) show
73.188 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
83.500 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Dc) show
100.188 11.875 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
105.688 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
114.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
121.750 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.48571 .08388 -135.219 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Phantom) show
112.875 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
119.750 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
125.250 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
151.813 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
158.688 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Dc) show
175.375 11.875 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
180.875 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
189.875 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
207.438 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.51429 .16775 -142.594 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Quintessence) show
138.125 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
145.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
150.500 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
159.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
166.563 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
173.438 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Dc) show
190.125 11.875 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
195.625 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
204.625 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.8) show
222.188 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{762.375, 471.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;j0001eb000`400?l00000o`00003oo`3ooooo
0?oooo`0oooo003o0?ooool0ooooo03oool00?l0ooooo`3ooool0?ooo`00o`3ooooo0?oooo`0oooo
003o0?ooool0ooooo03oool00?l0ooooo`3ooool0?ooo`00o`3ooooo0?oooo`0oooo003o0?oooi80
oooo1P00003o0?ooof@0oooo003o0?oooi<0oooo00D000000?ooo`3oool0oooo0000003o0?ooof@0
oooo003o0?oooi@0oooo00<000000?ooo`3oool0o`3ooomU0?ooo`00o`3ooonD0?ooo`030000003o
ool0oooo0?l0ooooI@3oool00?l0ooooU@3oool00`000000oooo0?ooo`3o0?ooof@0oooo003o0?oo
oi80oooo00D000000?ooo`3oool0oooo0000003o0?ooofD0oooo003o0?oooi80oooo1P00003o0?oo
of@0oooo003o0?ooool0ooooo03oool00?l0ooooo`3ooool0?ooo`00o`3ooooo0?oooo`0oooo003o
0?ooool0ooooo03oool00?l0ooooo`3ooool0?ooo`00o`3ooooo0?oooo`0oooo003o0?ooool0oooo
o03oool00?l0ooooo`3ooool0?ooo`00o`3ooooo0?oooo`0oooo003o0?ooool0ooooo03oool00?l0
ooooo`3ooool0?ooo`00U@3oool3000000<0oooo00@000000?ooo`3oool0oooo1@0000020?ooo`<0
0000D@3oool3000000<0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`<000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0`00001F0?ooo`<00000EP3oool30000
00<0oooo00@000000?ooo`3oool0oooo1@0000020?ooo`<00000DP3oool3000000<0oooo00@00000
0?ooo`3oool0oooo0`00001A0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo0`0000060?ooo`00U03oool01@000000oooo0?ooo`3oool0000000L0oooo00@0
00000?ooo`3oool000001@3oool00`000000oooo0?ooo`1=0?ooo`050000003oool0oooo0?ooo`00
00002@3oool00`000000oooo0?ooo`1>0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`070?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0D03oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo002D0?ooo`050000003oool0oooo
0?ooo`000000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04`0oooo00D00000
0?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo04d0oooo00D000000?ooo`3oool0oooo
000000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0D`3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool009@0oooo00D0
00000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
C03oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0C@3oool01@000000
oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1>0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`00U03oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`1<0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1=
0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo04h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0080oooo002D0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo04d0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000
003oool0oooo04h0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool009@0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`03
0000003oool0oooo00<00000D03oool01@000000oooo0?ooo`3oool0000000H0oooo0`00001A0?oo
o`050000003oool0oooo0?ooo`0000002@3oool010000000oooo0?ooo`3oool3000005L0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<00000D`3o
ool00`000000oooo0?ooo`060?ooo`<00000DP3oool00`000000oooo0?ooo`090?ooo`040000003o
ool0oooo0?ooo`<000001P3oool009@0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`040000
003oool0oooo00000580oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo
0540oooo00D000000?ooo`3oool0oooo000000090?ooo`050000003oool0oooo0?ooo`000000F@3o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000
E@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0
2@3oool01@000000oooo0?ooo`3oool0000000P0oooo002D0?ooo`050000003oool0oooo0?ooo`00
00001P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0C`3oool01@00
0000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0D03oool01@000000oooo0?ooo`3o
ool0000000D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000005L0oooo
0P00001G0?ooo`800000203oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool0D@3oool2000000T0oooo00<000000?ooo`3oool0D03oool2000000L0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000L0oooo002E0?ooo`<00000203oool3000000@0
oooo1000001?0?ooo`<00000203oool400000500oooo0`0000070?ooo`D000000`3oool4000005D0
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`070?ooo`<00000103oool400000540
oooo00<000000?ooo`3oool01`3oool400000500oooo00<000000?ooo`3oool01P3oool5000000<0
oooo100000040?ooo`00o`3ooooo0?oooo`0oooo003o0?ooool0ooooo03oool00?l0ooooo`3ooool
0?ooo`00o`3ooooo0?oooo`0oooo003o0?ooool0ooooo03oool00?l0ooooo`3ooool0?ooo`00o`3o
oooo0?oooo`0oooo003o0?ooool0ooooo03oool00?l0ooooo`3ooool0?ooo`00o`3ooooo0?oooo`0
oooo003o0?ooool0ooooo03oool003d0ooooo`00003o00000;4000003P3oool003d0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00`0oooo000m0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?oo
o`00?@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3o
ool0G`3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3o
ool0G`3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00`0oooo000m0?ooo`800000
H03oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0
G`3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0
G`3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0000003o0?ooool0oooo[@3o
ool00`000000oooo0?ooo`0<0?ooo`00?@3oool010000000oooo0?ooo`00003o0?ooool0oooo[03o
ool00`000000oooo0?ooo`0<0?ooo`00?@3oool01@000000oooo0?ooo`3oool000000?l0ooooo`3o
oon[0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0o`3ooooo0?ooojP0oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?oo
o`3oool0o`3ooooo0?ooojd0oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooojd0oooo00<000000?ooo`3oool0303oool002<0oooo0`0000030?ooo`040000
003oool0oooo0?ooo`<000003@3oool00`000000oooo0?ooo`3o0?ooool0oooo[@3oool00`000000
oooo0?ooo`0<0?ooo`00903oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0o`3ooooo0?ooojd0oooo00<000000?ooo`3oool0303oool002@0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0ooooo`3o
oon]0?ooo`030000003oool0oooo00`0oooo000I0?ooo`L00000103oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o
0?ooool0ooooY03oool00`000000oooo0?ooo`0<0?ooo`00903oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo1P0000040?ooo`030000003oool0oooo0?l0ooooo`3ooonN0?oo
o`H000003P3oool002@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooooo0?oooj80oooo00<000000?ooo`3o
ool0303oool002@0oooo00<000000?ooo`3oool01P3oool3000000d0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`3o0?ooool0ooooX@3oool00`000000oooo0?ooo`0<0?ooo`00903o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`3o0?ooool0ooooX03oool00`000000oooo0?ooo`0<0?ooo`008`3oool2
000000T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo0?l0ooooo`3ooonO0?ooo`030000003oool0oooo00`0oooo000T0?ooo`030000003oool0oooo
00L0oooo1000000;0?ooo`030000003oool0oooo0?l0ooooo`3ooon]0?ooo`030000003oool0oooo
00`0oooo000m0?ooo`030000003oool0oooo0?l0ooooo`3ooon]0?ooo`030000003oool0oooo00`0
oooo000m0?ooo`030000003oool0oooo0?l0ooooo`3ooon]0?ooo`030000003oool0oooo00`0oooo
000m0?ooo`030000003oool0oooo0?l0ooooo`3ooon]0?ooo`030000003oool0oooo00`0oooo000m
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooooo0?oooi/0oooo00<00000
0?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?oo
ool0ooooVP3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0?l0ooooo`3ooonI0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0o`3ooooo0?oooiT0oooo00<000000?ooo`3oool0
303oool003d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3o0?ooool0ooooV03o
ool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo0?l0ooooo`3ooonG0?ooo`030000003oool0oooo00`0oooo000m0?ooo`@00000o`3ooooo0?oo
ojT0oooo1000000>0?ooo`00?@3oool300000?l0ooooo`3ooon]0?ooo`030000003oool0oooo00`0
oooo000m0?ooo`040000003oool0oooo00000?l0ooooo`3ooon/0?ooo`030000003oool0oooo00`0
oooo000m0?ooo`040000003oool0oooo0?ooo`800000o`3ooooo0?ooojX0oooo00<000000?ooo`3o
ool0303oool003d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooool0oooo
Y`3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`040?ooo`8000004P3o
ool00`000000oooo0?ooo`3o0?ooool0ooooTP3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool0
0`000000oooo0?ooo`060?ooo`8000004@3oool00`000000oooo0?ooo`3o0?ooool0ooooT@3oool0
0`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0o`3ooooo0?oooi00oooo00<000000?ooo`3oool0303oool003d0
oooo00<000000?ooo`3oool02@3oool2000000l0oooo00<000000?ooo`3oool0o`3ooooo0?oooi00
oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooo`3ooon?0?ooo`030000003oool0oooo00`0oooo
000m0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo0?l0ooooo`3o
oon>0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooi`0oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?oo
o`3oool03`3oool200000?l0ooooo`3ooonL0?ooo`030000003oool0oooo00`0oooo000m0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0o`3ooooo0?oooiT0oooo00<000000?ooo`3o
ool0303oool003d0oooo00<000000?ooo`3oool04P3oool200000?l0ooooo`3ooonI0?ooo`030000
003oool0oooo00`0oooo000m0?ooo`@000004`3oool2000000/0oooo00<000000?ooo`3oool0o`3o
oooo0?ooohH0oooo1000000>0?ooo`00?@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0o`3ooooo0?ooohP0oooo00<000000?ooo`3oool0303oool0
03d0oooo00<000000?ooo`3oool05`3oool2000000X0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ohL0oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooo`3ooon60?ooo`030000003oool0oooo00`0
oooo000m0?ooo`030000003oool0oooo01X0oooo0P0000090?ooo`030000003oool0oooo0?l0oooo
o`3ooon50?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo01`0oooo0P00
00080?ooo`030000003oool0oooo0?l0ooooo`3ooon40?ooo`030000003oool0oooo00`0oooo000m
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0o`3ooom:0?ooo`040000003oool0
oooo0?ooo`800000o`3oooll0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0
oooo01l0oooo0P00003o0?oooaD0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0<
0?ooo`060000003oool0oooo0000003oool00000o`3ooolk0?ooo`030000003oool0oooo00`0oooo
000m0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0o`3ooolC0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`00003o0?ooocd0oooo
00<000000?ooo`3oool0303oool003d0oooo4000000E0?ooo`800000gP3oool3000000D0oooo0`00
00001@3oool00000000000000000oooo00P0000000D0oooo00000000000000000?ooo`02000000<0
oooo0`0000020?ooo`<0000000D0oooo00000000000000000?ooo`03000000030?ooo`0000000000
00D0oooo0`00000<0?ooo`<000000`3oool010000000oooo0?ooo`3oool3000000@0oooo0P000004
0?ooo`T0000000@0oooo0000003oool00000503oool3000000<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`3o0?oooaT0oooo00<000000?ooo`3oool0303oool003d0oooo00<00000
0?ooo`3oool03@3ooolF000000030?ooo`000000000000D0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`050?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`040000
003oool0oooo000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00@0
00000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000T0oooo00D000000?ooo`3o
ool000000?ooo`07000000@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P00000:0?ooo`L00000103oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo6@3oool00`000000oooo0?ooo`0<
0?ooo`00?@3oool00`000000oooo0?ooo`0S0?ooo``00000e03oool00`000000oooo0?ooo`050?oo
o`070000003oool0oooo0?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo
00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`3o0?oooaT0oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?oo
o`3oool09`3oool2000000@0oooo3P0000380?ooo`030000003oool0oooo00D0oooo00D000000?oo
o`3oool0oooo000000020?ooo`@000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3o
ool0oooo0000000:0?ooo`8000003@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`800000503oool00`00
0000oooo0?ooo`050?ooo`H00000o`3ooolJ0?ooo`030000003oool0oooo00`0oooo000m0?ooo`03
0000003oool0oooo02T0oooo0P0000040?ooo`030000003oool0oooo00T0oooo3@00002k0?ooo`D0
00000`3oool01@000000oooo0?ooo`3oool0000000D0oooo00@000000?ooo`3oool000000`3oool0
10000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`L0
0000103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`040000003oool0oooo000000P0oooo1`0000040?ooo`030000003oool0
oooo00D0oooo00D000000?ooo`3oool0oooo0000003o0?oooa/0oooo00<000000?ooo`3oool0303o
ool003d0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01D0oooo4000002[0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P000002
0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P0000020?ooo`040000003oool0
oooo000000<0oooo00H000000?ooo`3oool0oooo0000003oool300000080oooo0P0000020?ooo`03
0000003oool0oooo00L0oooo00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0
oooo0?ooo`D000003P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo00000?l0oooo
6`3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool4000002/0oooo0P00000Z0?ooo`h00000W@3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0000003oool00P0000030?ooo`<00000
0`3oool010000000oooo0000000000020?ooo`<000000`3oool3000000<0oooo00@000000?ooo`00
000000000P3oool2000000/0oooo0`00000<0?ooo`030000003oool0oooo00H0oooo0`00000=0?oo
o`030000003oool0000000@0oooo0P0000040?ooo`80000000<0oooo0000003oool03@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool000000?l0oooo603oool4000000h0oooo000m0?ooo`03
0000003oool0oooo02h0oooo0P00000f0?ooo`X00000T`3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000001<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`000000o`3ooolK0?ooo`030000003oool0oooo
00`0oooo000m0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0?@3oool;000008P0
oooo00<000000?ooo`3oool00P3oool010000000oooo00000000000C0?ooo`030000003oool0oooo
02T0oooo0P0000090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`0000003@3oool00`00
0000oooo0?ooo`0;0?ooo`8000002P3oool200000?l0oooo6`3oool00`000000oooo0?ooo`0<0?oo
o`00?@3oool00`000000oooo0?ooo`0a0?ooo`800000B03oool>000007T0oooo1P0000030?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool01`3oool4000000`0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0o`3ooolI0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo03<0oooo
0P00001D0?oooa000000f@3oool010000000oooo0?ooo`00003o0?ooocH0oooo00<000000?ooo`3o
ool0303oool003d0oooo00<000000?ooo`3oool0=03oool2000006<0oooo4000003:0?ooo`800000
o`3ooolg0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo03H0oooo0P00
001a0?oooa000000o`3ooooc0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0
oooo03L0oooo0P0000200?ooo`h00000o`3ooooU0?ooo`030000003oool0oooo00`0oooo000m0?oo
o`030000003oool0oooo03P0oooo0`00002<0?ooo`/00000o`3ooooJ0?ooo`030000003oool0oooo
00`0oooo000m0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`000000UP3oool<00000?l0
oooocP3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`0l0?ooo`800000
X03oool>00000?l0oooo`03oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo0:/0oooo4000003o0?oook00oooo00<000000?ooo`3oool0303o
ool003d0oooo00<000000?ooo`3oool0?`3oool200000;/0oooo4000003o0?oooj00oooo00<00000
0?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`380?oo
oa000000o`3ooon@0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo03h0
oooo00@000000?ooo`3oool0oooo0P00003H0?oooaP00000o`3ooomh0?ooo`030000003oool0oooo
00`0oooo000m0?ooo`@00000?P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0>d0
oooo6@00003o0?oooe`0oooo1000000>0?ooo`00?@3oool00`000000oooo0?ooo`100?ooo`800000
0`3oool00`000000oooo0?ooo`1h0?ooo`040000003oool0oooo0?ooo`800000Q`3oool@00000?l0
ooooC`3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`120?ooo`040000
003oool0oooo0?ooo`800000I`3oool00`000000oooo0?ooo`0?0?ooo`060000003oool0oooo0000
003oool00000UP3ooolH00000?l0oooo=`3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`00
0000oooo0?ooo`130?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`0>0?ooo`040000003oool0oooo00000;00oooo8@00003o0?oooaH0oooo00<00000
0?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0B@3oool2000005T0oooo0`0000040?oo
o`<0000000<0oooo0000000000001`3oool9000000040?ooo`000000oooo000001@0oooo0`00002j
0?ooob000000m@3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`1;0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P00000:0?ooo`L000000P3oool0
1@000000oooo0?ooo`3oool000000=T0oooo8@00003D0?ooo`030000003oool0oooo00`0oooo000m
0?ooo`030000003oool0oooo04`0oooo0P00001G0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool04@3oool01@000000oooo0?ooo`3oool000000?X0oooo8@00002c0?ooo`030000003o
ool0oooo00`0oooo000m0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`8000004P3oool01@000000oooo0?ooo`3oool000000?l0oooo703o
oolP000009<0oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`040?ooo`800000E@3oool01@000000oooo0?ooo`3oool0000000l0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000P0oooo1`0000020?ooo`05
0000003oool0oooo0?ooo`000000o`3oooll0?oood400000DP3oool00`000000oooo0?ooo`0<0?oo
o`00?@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0D`3oool010000000oooo0?ooo`00000?0?ooo`050000003oool0oooo0?ooo`000000103oool0
1@000000oooo0?ooo`3oool000000100oooo00D000000?ooo`3oool0oooo0000003o0?ooogd0oooo
8@00000a0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo04X0oooo00<0
00000?ooo`3oool01@3oool2000005<0oooo00<000000?ooo`0000004@3oool00`000000oooo0000
00040?ooo`800000103oool5000000/0oooo00D000000?ooo`3oool0oooo0000003o0?oooih0oooo
<P00000>0?ooo`00?@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0D03oool00`000000oooo0000000A0?ooo`030000003oool0000000`0oooo00<0
00000?ooo`0000002`3oool01@000000oooo0?ooo`3oool000000?l0ooooc`3oool00`000000oooo
0?ooo`0<0?ooo`00;P3oool3000000`0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?oo
o`060?ooo`800000D@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0000000d0oooo00<0
00000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool000000?l0ooooc`3oool00`000000oooo
0?ooo`0<0?ooo`00;`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04d0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`<00000o`3oooo@0?ooo`030000003o
ool0oooo00`0oooo000_0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0F03oool2
00000780oooo00<000000?ooo`3oool0o`3ooooM0?ooo`030000003oool0oooo00`0oooo000S0?oo
o`L000001@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05X0oooo0P00001]0?oo
o`040000003oool0oooo00000?l0oooog`3oool00`000000oooo0?ooo`0<0?ooo`00;`3oool00`00
0000oooo0?ooo`0;0?ooo`H0000000<0oooo0000000000000`0000020?ooo`D000000P3oool40000
00<0oooo100000030?ooo`@000000P3oool500000080oooo1@0000020?ooo`D000000P3oool40000
00<0oooo100000030?ooo`@000000`3oool400000080oooo1@0000000`3oool00000000000040000
0080oooo1@0000020?ooo`@000000`3oool4000000<0oooo100000030?ooo`@000000P3oool50000
0080oooo1@0000020?ooo`D000000P3oool4000000<0oooo100000030?ooo`@000000`3oool40000
0080oooo1@0000020?ooo`D000000P3oool400000080oooo1@0000030?ooo`@000000`3oool40000
0080oooo1@0000020?ooo`D000000P3oool500000080oooo100000030?ooo`@000000`3oool40000
00<0oooo100000020?ooo`D000000P3oool500000080oooo1@0000020?ooo`@000000`3oool40000
00<0oooo100000030?ooo`@000000P3oool500000080oooo1@0000020?ooo`D000000P3oool40000
00<0oooo100000030?ooo`@000000`3oool400000080oooo1@0000020?ooo`D000000P3oool40000
00<0oooo100000030?ooo`@000000`3oool400000080oooo1@0000020?ooo`D000000P3oool50000
0080oooo100000030?ooo`@000000`3oool4000000<0oooo100000020?ooo`D000000P3oool50000
0080oooo1@0000020?ooo`@000000`3oool4000000<0oooo100000030?ooo`@000000P3oool50000
0080oooo1@0000020?ooo`D000000P3oool4000000<0oooo100000030?ooo`@000000P3oool50000
0080oooo1@0000020?ooo`D000000P3oool4000000<0oooo100000030?ooo`@000000`3oool40000
0080oooo1@0000020?ooo`D000000P3oool500000080oooo100000030?ooo`@000000`3oool40000
00<0oooo100000020?ooo`D000000P3oool500000080oooo1@0000020?ooo`@000000`3oool40000
00<0oooo2000000>0?ooo`00;`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool01`3oool200000?l0ooooo`3ooom>0?ooo`030000003oool0oooo00`0
oooo000_0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0E03oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0?l0ooooo`3ooom;0?ooo`030000003oool0oooo00`0oooo
000_0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`080?ooo`800000o`3ooooo0?oood/0oooo00<000000?ooo`3oool0303oool002h0oooo0P00000=
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool02@3oool200000?l0oooom`3ooomB
000000h0oooo000_0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0oooo/P3ooom200000540oooo00<000000?oo
o`3oool0303oool003d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0:0?ooo`80
0000o`3ooonB0?ooob000000T`3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo
0?ooo`1W0?ooo`030000003oool0oooo0?l0ooooCP3ooom100000;<0oooo00<000000?ooo`3oool0
303oool003d0oooo00<000000?ooo`3oool0J03oool200000?l0oooo;@3ooolQ00000?@0oooo00<0
00000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0JP3oool200000?l0oooo2`3ooolP
00000?l0oooo5P3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`1M0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0k`3ooolH00000?l0oooo=P3oool00`00
0000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo00`0
oooo0P00003O0?oooa000000o`3ooom>0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000
003oool0oooo05l0oooo0P00000>0?ooo`030000003oool0oooo0<<0oooo6@00003o0?oooeh0oooo
00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?oo
o`0<0?ooo`800000ZP3ooolI00000?l0ooooM`3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool0
0`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0U`3oool@
00000?l0ooooT03oool00`000000oooo0?ooo`0<0?ooo`00?@3oool400000780oooo0P0000270?oo
oa000000o`3ooonM0?ooo`@000003P3oool003d0oooo00<000000?ooo`3oool0M@3oool2000007D0
oooo4000003o0?oook00oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0
M`3oool00`000000oooo0?ooo`1T0?ooo`h00000:@3oool2000006h0oooo00@000000?ooo`3oool0
oooo0P00003o0?ooob40oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0
J03oool00`000000oooo0?ooo`0=0?ooo`800000F@3oool;000003H0oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00`0oooo00H000000?ooo`3oool0
00000?ooo`00003o0?ooob00oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3o
ool0J@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo04X0oooo300000100?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0;0?ooo`04
0000003oool0oooo00000?l0oooo8P3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000
oooo0?ooo`1Z0?ooo`030000003oool0oooo00h0oooo0P00000o0?ooo`/00000BP3oool4000000D0
oooo0P0000000`3oool000000?ooo`06000000050?ooo`00000000000000003oool00P0000030?oo
o`<000000P3oool3000000<0oooo0`0000040?ooo`<0000000D0oooo00000000000000000?ooo`03
00000080oooo0`0000040?ooo`<000000P3oool2000000D0oooo0`00000<0?ooo`D000000P3oool2
000000@0oooo2@000000103oool000000?ooo`00000D0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool300000?l0oooo00<000000?ooo`3oool0303oool003d0oooo00<00000
0?ooo`3oool0J`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0380oooo2P00001D
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`<0000000D0
oooo0000003oool0oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`000003
0?ooo`030000003oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool000000P3oool7
000000<0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo0?ooo`8000002P3oool7000000<0oooo00<000000?ooo`3oool01`3oool01@000000oooo
0?ooo`3oool000000?h0oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0
K03oool00`000000oooo0?ooo`0?0?ooo`8000009`3oool;000005d0oooo00<000000?ooo`3oool0
103oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo00000080oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool00000
0?h0oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0K@3oool00`000000
oooo0?ooo`0@0?ooo`8000006`3oool:000006P0oooo00<000000?ooo`3oool0103oool010000000
oooo0?ooo`0000030?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo0000
00020?ooo`050000003oool0oooo0?ooo`0000001P3oool2000000@0oooo0P0000030?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool02`3oool2000000l0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0P00000D0?ooo`030000003oool0oooo00H0
oooo00D000000?ooo`3oool0oooo0000003n0?ooo`030000003oool0oooo00`0oooo000m0?ooo`03
0000003oool0oooo0880oooo00<000000?ooo`3oool0403oool800000780oooo00<000000?ooo`3o
ool0103oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo00000080oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0?ooo`D0000000<0oooo0000003oool0
103oool00`000000oooo0?ooo`030?ooo`D0000000<0oooo0000003oool00P3oool010000000oooo
0?ooo`0000060?ooo`D00000203oool00`000000oooo0?ooo`030?ooo`L000001@3oool00`000000
oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`000008
0?ooo`L00000103oool00`000000oooo0?ooo`070?ooo`030000003oool000000?l0oooo00<00000
0?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0P`3oool2000000P0oooo2000001j0?oo
o`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000`3oool01@000000oooo00000000
0000oooo00<000000P3oool010000000oooo0?ooo`0000030?ooo`070000003oool0oooo0?ooo`00
0000oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3o
ool400000080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo00H0oooo00@000000?ooo`3oool000003`3oool00`000000oooo0?ooo`080?oo
o`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000001<0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`3n0?ooo`030000003oool0oooo00`0oooo000m
0?ooo`030000003oool0oooo08D0oooo200000220?ooo`030000003oool0oooo00@0oooo00@00000
0?ooo`00000000000P3oool200000080oooo00D000000?ooo`3oool000000?ooo`0200000080oooo
0`0000030?ooo`<000000`3oool3000000<0oooo0`0000030?ooo`<000000P3oool010000000oooo
0000000000040?ooo`<00000103oool3000000X0oooo0`00000?0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`000000103oool2000000@0oooo1000000?0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`000000o`3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo
0?ooo`1c0?ooo`030000003oool0oooo00L0oooo200000000`3oool00000000000270?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`170?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`0000002`3oool00`000000oooo0000000?0?ooo`030000
003oool0oooo00D0oooo00D000000?ooo`3oool0oooo0000003n0?ooo`030000003oool0oooo00`0
oooo000m0?ooo`030000003oool0oooo07@0oooo2@00000;0?ooo`800000QP3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0@`3oool01@000000oooo
0?ooo`3oool0000000/0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool00000
0?h0oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0K@3oool:000001<0
oooo00<000000?ooo`3oool0Q03oool4000000/0oooo00<000000?ooo`3oool0CP3oool3000000d0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`D000001`3oool300000?l0
oooo00<000000?ooo`3oool0303oool003d0oooo1000001T0?ooo`P000002P3oool00`000000oooo
0?ooo`0A0?ooo`800000o`3oool40?ooo`030000003oool0oooo0?l0oooo5P3oool4000000h0oooo
000m0?ooo`030000003oool0oooo05h0oooo1`00000C0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0o@3oool010000000oooo0?ooo`00003o0?oooa/0oooo00<000000?ooo`3oool0
303oool003d0oooo00<000000?ooo`3oool0F@3oool500000300oooo0P00003n0?ooo`800000o`3o
oolL0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo05<0oooo1P00000g
0?ooo`030000003oool0oooo0?l0ooooo`3ooolJ0?ooo`030000003oool0oooo00`0oooo000m0?oo
o`030000003oool0oooo04h0oooo1@00000n0?ooo`800000o`3ooooo0?oooaX0oooo00<000000?oo
o`3oool0303oool003d0oooo00<000000?ooo`3oool0B@3oool500000300oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool00`000000oooo0?ooo`0<0?ooo`00
?@3oool00`000000oooo0?ooo`130?ooo`H00000=P3oool00`000000oooo0?ooo`0B0?ooo`800000
o`3ooooo0?oooaL0oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0?`3o
ool4000003d0oooo0P00000D0?ooo`800000o`3ooooo0?oooaD0oooo00<000000?ooo`3oool0303o
ool003d0oooo00<000000?ooo`3oool0>`3oool4000004<0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`3o0?ooool0oooo4P3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`00
0000oooo0?ooo`0g0?ooo`@00000B03oool00`000000oooo0?ooo`0C0?ooo`800000o`3ooooo0?oo
oa80oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0<`3oool4000006@0
oooo00<000000?ooo`3oool0o`3ooooo0?ooo`l0oooo00<000000?ooo`3oool0303oool003d0oooo
00<000000?ooo`3oool0;`3oool4000006T0oooo0P00003o0?ooool0oooo3`3oool00`000000oooo
0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`0[0?ooo`@00000K`3oool00`000000oooo0?oo
o`3o0?ooool0oooo303oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`0W
0?ooo`@00000GP3oool00`000000oooo0?ooo`0C0?ooo`800000o`3ooooo0?ooo``0oooo00<00000
0?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool08`3oool4000006<0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`3o0?ooool0oooo2@3oool00`000000oooo0?ooo`0<0?oo
o`00?@3oool4000001h0oooo1000001X0?ooo`8000005@3oool200000?l0ooooo`3oool60?ooo`@0
00003P3oool003d0oooo00<000000?ooo`3oool0703oool3000006h0oooo00<000000?ooo`3oool0
503oool200000?l0ooooo`3oool70?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003o
ool0oooo01T0oooo0`00001b0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3o
oooo0?ooo`@0oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool05P3oool3
000008h0oooo0P00003o0?ooool0oooo103oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`00
0000oooo0?ooo`0C0?ooo`<00000T`3oool00`000000oooo0?ooo`3o0?ooool0oooo0@3oool00`00
0000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`0@0?ooo`<00000U`3oool200000?l0
ooooo`3oool10?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo00h0oooo
0P0000240?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3oooom0?ooo`030000
003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`8000005P3o
ool200000?l0ooooo@3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`08
0?ooo`<00000S03oool2000001H0oooo00<000000?ooo`3oool0o`3ooooj0?ooo`030000003oool0
oooo00`0oooo000m0?ooo`030000003oool0oooo00D0oooo0`00002A0?ooo`8000005@3oool20000
0?l0oooonP3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`020?ooo`<0
0000[@3oool00`000000oooo0?ooo`3o0?ooooL0oooo00<000000?ooo`3oool0303oool003d0oooo
00<000000?ooo`0000000P00002a0?ooo`800000o`3oooog0?ooo`030000003oool0oooo00`0oooo
000m0?ooo`800000]P3oool00`000000oooo0?ooo`3o0?oooo@0oooo00<000000?ooo`3oool0303o
ool003d0oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`0C0?ooo`800000o`3ooood
0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo0:40oooo00<000000?oo
o`3oool0503oool200000?l0oooolP3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool400000:40
oooo0P00000F0?ooo`030000003oool0oooo0?l0ooook03oool4000000h0oooo000m0?ooo`030000
003oool0oooo0:@0oooo00<000000?ooo`3oool0503oool200000?l0ooook`3oool00`000000oooo
0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0o`3oooo/0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0
oooo0;h0oooo0P00003o0?ooon`0oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?oo
o`3oool0`03oool00`000000oooo0?ooo`3o0?ooonT0oooo00<000000?ooo`3oool0303oool003d0
oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0C0?ooo`800000o`3ooooY0?ooo`03
0000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo0:`0oooo0P00000E0?ooo`030000
003oool0oooo0?l0ooooiP3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?oo
o`2^0?ooo`030000003oool0oooo01<0oooo0P00003o0?ooonH0oooo00<000000?ooo`3oool0303o
ool003d0oooo00<000000?ooo`3oool0[`3oool2000001D0oooo00<000000?ooo`3oool0o`3ooooS
0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo0;40oooo00<000000?oo
o`3oool04`3oool200000?l0ooooh`3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo0?l0ooooh03oool00`000000oooo0?ooo`0<0?ooo`00
?@3oool00`000000oooo0?ooo`3:0?ooo`800000o`3ooooP0?ooo`030000003oool0oooo00`0oooo
000S0?ooo`<000000`3oool010000000oooo0?ooo`3oool3000000d0oooo00<000000?ooo`3oool0
]`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0oooog@3oool00`000000oooo
0?ooo`0<0?ooo`008P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`2h0?ooo`8000004`3oool200000?l0oooog@3oool00`000000oooo
0?ooo`0<0?ooo`008P3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
o`3ooooJ0?ooo`030000003oool0oooo00`0oooo000I0?ooo`L000000P3oool01@000000oooo0?oo
o`3oool0000000X0oooo00<000000?ooo`3oool02@3oool600000;P0oooo0P00000C0?ooo`800000
o`3ooooE0?ooo`H000003P3oool00280oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo0?l0ooooe`3oool00`000000oooo0?ooo`0<0?ooo`008P3oool01@000000oooo0?oo
o`3oool0000000T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3C0?ooo`800000
o`3ooooG0?ooo`030000003oool0oooo00`0oooo000R0?ooo`050000003oool0oooo0?ooo`000000
1P3oool3000000d0oooo00<000000?ooo`3oool0e@3oool200000?l0ooooe@3oool00`000000oooo
0?ooo`0<0?ooo`008P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
o`3ooooB0?ooo`030000003oool0oooo00`0oooo000R0?ooo`050000003oool0oooo0?ooo`000000
1`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0<@0oooo0P00000B0?ooo`800000
o`3ooooB0?ooo`030000003oool0oooo00`0oooo000S0?ooo`<00000203oool4000000/0oooo00<0
00000?ooo`3oool0aP3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0ooooc`3o
ool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`370?ooo`8000004P3oool2
00000?l0ooooc`3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`390?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0o`3oooo<0?ooo`030000003oool0oooo
00`0oooo000m0?ooo`030000003oool0oooo0=h0oooo0P00003o0?oool`0oooo00<000000?ooo`3o
ool0303oool003d0oooo00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`3o0?ooolT0oooo
00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?oo
o`0?0?ooo`800000o`3oooo90?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0
oooo0=00oooo0P00000A0?ooo`030000003oool0oooo0?l0ooooaP3oool00`000000oooo0?ooo`0<
0?ooo`00?@3oool00`000000oooo0?ooo`3B0?ooo`800000403oool200000?l0ooooaP3oool00`00
0000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`3D0?ooo`800000403oool00`000000
oooo0?ooo`3o0?oool<0oooo00<000000?ooo`3oool0303oool003d0oooo1000003V0?ooo`800000
o`3oooo00?ooo`@000003P3oool003d0oooo00<000000?ooo`3oool0j@3oool00`000000oooo0?oo
o`3o0?oool00oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0f`3oool0
0`000000oooo0?ooo`0<0?ooo`800000o`3oooo00?ooo`030000003oool0oooo00`0oooo000m0?oo
o`030000003oool0oooo0=`0oooo0P00000>0?ooo`800000o`3ooonn0?ooo`030000003oool0oooo
00`0oooo000m0?ooo`030000003oool0oooo0=h0oooo0P00000>0?ooo`030000003oool0oooo0?l0
oooo^`3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`3P0?ooo`800000
3@3oool200000?l0oooo^`3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?oo
o`3a0?ooo`030000003oool0oooo0?l0oooo^03oool00`000000oooo0?ooo`0<0?ooo`00?@3oool0
0`000000oooo0?ooo`3b0?ooo`800000o`3ooonh0?ooo`030000003oool0oooo00`0oooo000m0?oo
o`030000003oool0oooo0?@0oooo00<000000?ooo`3oool0o`3ooone0?ooo`030000003oool0oooo
00`0oooo000m0?ooo`030000003oool0oooo0>L0oooo0P00000<0?ooo`800000o`3ooone0?ooo`03
0000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo0>T0oooo0`00000;0?ooo`030000
003oool0oooo0?l0oooo/P3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?oo
o`3/0?ooo`8000002P3oool200000?l0oooo/P3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool0
0`000000oooo0?ooo`3j0?ooo`800000o`3ooon`0?ooo`030000003oool0oooo00`0oooo000m0?oo
o`030000003oool0oooo0?`0oooo00<000000?ooo`3oool0o`3ooon]0?ooo`030000003oool0oooo
00`0oooo000m0?ooo`030000003oool0oooo0?@0oooo00<000000?ooo`3oool01P3oool200000?l0
oooo[@3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool400000?@0oooo0P0000080?ooo`030000
003oool0oooo0?l0ooooY`3oool4000000h0oooo000m0?ooo`030000003oool0oooo0?L0oooo0P00
00070?ooo`800000o`3ooonZ0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0
oooo0?T0oooo0P0000070?ooo`030000003oool0oooo0?l0ooooY`3oool00`000000oooo0?ooo`0<
0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooo`@0oooo0P00003o0?ooojL0oooo00<000000?oo
o`3oool0303oool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`3o0?ooo`H0
oooo00<000000?ooo`3oool0o`3ooonT0?ooo`030000003oool0oooo00`0oooo00060?ooo`<00000
=03oool00`000000oooo0?ooo`3o0?ooo`40oooo00<000000?ooo`3oool00`3oool200000?l0oooo
Y03oool00`000000oooo0?ooo`0<0?ooo`001P3oool00`000000oooo0?ooo`0300000340oooo00<0
00000?ooo`3oool0o`3oool20?ooo`8000001@3oool00`000000oooo0?ooo`3o0?oooj40oooo00<0
00000?ooo`3oool0303oool000/0oooo0P00000`0?ooo`030000003oool0oooo0?l0oooo103oool2
000000@0oooo0P00003o0?oooj40oooo00<000000?ooo`3oool0303oool000H0oooo00<000000?oo
o`3oool00P00000b0?ooo`030000003oool0oooo0?l0oooo1P3oool2000000@0oooo00<000000?oo
o`3oool0o`3ooonN0?ooo`030000003oool0oooo00`0oooo00060?ooo`<00000=03oool00`000000
oooo0?ooo`3o0?ooo`d0oooo0P00003o0?oooih0oooo00<000000?ooo`3oool0303oool000H0oooo
00<000000?ooo`3oool00`00000a0?ooo`030000003oool0oooo0?l0oooo3`3oool200000?l0oooo
W03oool00`000000oooo0?ooo`0<0?ooo`002`3oool200000300oooo00<000000?ooo`3oool0o`3o
ool=0?ooo`8000000P3oool00`000000oooo0?ooo`3o0?oooiT0oooo00<000000?ooo`3oool0303o
ool000H0oooo00<000000?ooo`3oool00P00000b0?ooo`030000003oool0oooo0?l0oooo3`3oool2
000000030?ooo`00000000000?l0ooooV@3oool00`000000oooo0?ooo`0<0?ooo`001P3oool30000
03@0oooo00<000000?ooo`3oool0o`3ooolA0?ooo`80000000<0oooo0000003oool0o`3ooonG0?oo
o`030000003oool0oooo00`0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool0o`3ooolC0?ooo`@00000o`3ooonF0?ooo`030000003oool0oooo00`0oooo00050?ooo`T00000
;`3oool00`000000oooo0?ooo`3o0?oooaL0oooo00<000000?ooo`3oool0o`3ooonC0?ooo`030000
003oool0oooo00`0oooo00040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0;03o
ool400000?l0oooo5`3oool300000?l0ooooS`3oool4000000h0oooo00030?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`3o0?oooaX0oooo0`00003o
0?oooi00oooo00<000000?ooo`3oool0303oool000H0oooo0P0000040?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`@00000o`3ooon>0?ooo`030000003oool0oooo
00`0oooo00060?ooo`030000003oool0oooo0080oooo0P00000`0?ooo`030000003oool0oooo0?l0
oooo7@3oool010000000oooo00000000003o0?oooh`0oooo00<000000?ooo`3oool0303oool000H0
oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`0_0?ooo`030000003oool0oooo0?l0
oooo7P3oool200000?l0ooooS@3oool00`000000oooo0?ooo`0<0?ooo`001P3oool00`000000oooo
000000030?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0o`3ooolP0?ooo`030000
003oool0oooo0?l0ooooRP3oool00`000000oooo0?ooo`0<0?ooo`001P3oool2000000@0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`3o0?ooob40oooo0P0000040?ooo`800000o`3o
oon40?ooo`030000003oool0oooo00`0oooo00060?ooo`030000003oool0oooo0080oooo0P00000`
0?ooo`030000003oool0oooo0?l0oooo8`3oool00`000000oooo0?ooo`030?ooo`<00000o`3ooon1
0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo0?l0oooo903oool20000
00H0oooo0P00003o0?ooogl0oooo00<000000?ooo`3oool0303oool000<0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0oooo9P3oool200000?l0
ooooQ@3oool00`000000oooo0?ooo`0<0?ooo`00103oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`030000003oool0oooo0?l0oooo
PP3oool00`000000oooo0?ooo`0<0?ooo`001@3oool9000002l0oooo00<000000?ooo`3oool0o`3o
oolY0?ooo`800000203oool200000?l0ooooN03oool00`000000oooo0?ooo`0<0?ooo`00?@3oool0
0`000000oooo0?ooo`3o0?ooob/0oooo00<000000?ooo`3oool01`3oool300000?l0ooooM@3oool0
0`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooob`0oooo0P00000:0?oo
o`800000o`3ooomc0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo0?l0
oooo;P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0ooooL03oool00`000000
oooo0?ooo`0<0?ooo`00?@3oool400000?l0oooo;P3oool200000?l0ooooN@3oool4000000h0oooo
000m0?ooo`030000003oool0oooo0?l0oooo<@3oool00`000000oooo0?ooo`0<0?ooo`800000o`3o
oom[0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo0?l0oooo<P3oool2
000000h0oooo0`00003o0?ooofP0oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?oo
o`3oool0o`3ooold0?ooo`8000003`3oool200000?l0ooooIP3oool00`000000oooo0?ooo`0<0?oo
o`00?@3oool00`000000oooo0?ooo`3o0?ooocH0oooo00<000000?ooo`3oool0o`3ooomd0?ooo`03
0000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo0?l0oooo=`3oool200000?l0oooo
M03oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<0
00000?ooo`3oool04@3oool200000?l0ooooGP3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool0
0`000000oooo0?ooo`3o0?ooocX0oooo0P00000C0?ooo`<00000o`3ooomK0?ooo`030000003oool0
oooo00`0oooo000m0?ooo`030000003oool0oooo0?l0oooo?03oool2000001@0oooo0P00003o0?oo
oeT0oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0o`3oooln0?ooo`03
0000003oool0oooo0?l0ooooK03oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo
0?ooo`3o0?ooocl0oooo0P00000I0?ooo`030000003oool0oooo0?l0ooooD03oool00`000000oooo
0?ooo`0<0?ooo`00;P3oool3000000`0oooo00<000000?ooo`3oool0o`3ooom10?ooo`800000603o
ool200000?l0ooooD03oool00`000000oooo0?ooo`0<0?ooo`00;@3oool01@000000oooo0?ooo`3o
ool0000000/0oooo00<000000?ooo`3oool0o`3ooom30?ooo`030000003oool0oooo01L0oooo0P00
003o0?ooodh0oooo00<000000?ooo`3oool0303oool002d0oooo00D000000?ooo`3oool0oooo0000
000;0?ooo`030000003oool0oooo0?l0ooooA03oool2000001T0oooo0P00003o0?oood`0oooo00<0
00000?ooo`3oool0303oool002d0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`030000003o
ool0oooo0?l0ooooAP3oool00`000000oooo0?ooo`3o0?ooof@0oooo00<000000?ooo`3oool0303o
ool002d0oooo00D000000?ooo`3oool0oooo0000000;0?ooool00000o`00002a000000h0oooo000]
0?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000oooo0?ooo`3o0?ooodT0oooo0P00
000N0?ooo`<00000o`3ooom10?ooo`030000003oool0oooo00`0oooo000]0?ooo`050000003oool0
oooo0?ooo`0000002`3oool00`000000oooo0?ooo`3o0?oood/0oooo00<000000?ooo`3oool07P3o
ool200000?l0oooo?`3oool00`000000oooo0?ooo`0<0?ooo`00;@3oool01@000000oooo0?ooo`3o
ool0000000/0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`800000o`3ooomO0?ooo`030000003o
ool0oooo00`0oooo000]0?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000oooo0?oo
o`3o0?ooodh0oooo0P00000T0?ooo`030000003oool0oooo0?l0oooo=P3oool00`000000oooo0?oo
o`0<0?ooo`00;P3oool3000000`0oooo00<000000?ooo`3oool0o`3ooom@0?ooo`030000003oool0
oooo0280oooo0P00003o0?ooocH0oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?oo
o`3oool0o`3ooomA0?ooo`800000903oool200000?l0oooo=03oool00`000000oooo0?ooo`0<0?oo
o`00?@3oool00`000000oooo0?ooo`3o0?oooe<0oooo0P00000T0?ooo`800000o`3ooolb0?ooo`03
0000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo
0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0o`3o
oomF0?ooo`800000:@3oool200000?l0oooo:P3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool0
0`000000oooo0?ooo`3o0?oooeP0oooo00<000000?ooo`3oool0:03oool300000?l0oooo9`3oool0
0`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`3o0?oooeT0oooo0P00000[0?oo
o`800000o`3ooolU0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo0?l0
ooooF`3oool00`000000oooo0?ooo`3o0?ooodl0oooo00<000000?ooo`3oool0303oool003d0oooo
00<000000?ooo`3oool0o`3ooomL0?ooo`800000<03oool200000?l0oooo7@3oool00`000000oooo
0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool0;`3o
ool300000?l0oooo6P3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool400000?l0ooooGP3oool2
00000380oooo0P00003o0?oooaD0oooo1000000>0?ooo`00?@3oool00`000000oooo0?ooo`3o0?oo
of40oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo00`0oooo000m0?ooo`03
0000003oool0oooo0?l0ooooHP3oool2000003L0oooo0P00003o0?oooa00oooo00<000000?ooo`3o
ool0303oool003d0oooo00<000000?ooo`3oool0o`3ooomT0?ooo`800000=`3oool300000?l0oooo
3@3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooofH0oooo00<0
00000?ooo`3oool0=`3oool200000?l0oooo2`3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool0
0`000000oooo0?ooo`3o0?ooofL0oooo0P00003o0?oood@0oooo00<000000?ooo`3oool0303oool0
03d0oooo00<000000?ooo`3oool0o`3ooomY0?ooo`030000003oool0oooo03`0oooo0P00003o0?oo
o`<0oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0o`3ooomZ0?ooo`80
0000?P3oool300000?l0oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0
o`3ooom/0?ooo`030000003oool0oooo03h0oooo0`00003l0?ooo`030000003oool0oooo00`0oooo
000m0?ooo`030000003oool0oooo0?l0ooooK@3oool2000004H0oooo0P00003e0?ooo`030000003o
ool0oooo00`0oooo000m0?ooo`030000003oool0oooo0?l0ooooK`3oool00`000000oooo0?ooo`15
0?ooo`@00000l@3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`3o0?oo
og00oooo0P0000190?ooo`800000k`3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000
oooo0?ooo`3o0?ooog80oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo00`0
oooo000m0?ooo`030000003oool0oooo0?l0ooooL`3oool2000004d0oooo0P00003X0?ooo`030000
003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo0?l0ooooM@3oool00`000000oooo0?oo
o`1<0?ooo`<00000i@3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool400000?l0ooooM@3oool2
000004l0oooo0`00003O0?ooo`@000003P3oool003d0oooo00<000000?ooo`3oool0o`3ooomh0?oo
o`030000003oool0oooo0?l0oooo<P3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000
oooo0?ooo`3o0?ooogT0oooo0P00001E0?ooo`<00000f@3oool00`000000oooo0?ooo`0<0?ooo`00
?@3oool00`000000oooo0?ooo`3o0?ooog/0oooo0P00001F0?ooo`@00000e@3oool00`000000oooo
0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooogd0oooo00<000000?ooo`3oool0o`3o
ool]0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo0?l0ooooOP3oool2
000005d0oooo0P00003=0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo
0?l0ooooP03oool00`000000oooo0?ooo`1L0?ooo`<00000bP3oool00`000000oooo0?ooo`0<0?oo
o`00?@3oool00`000000oooo0?ooo`3o0?oooh40oooo0P00001O0?ooo`800000b03oool00`000000
oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`3o0?oooh<0oooo00<000000?ooo`3oool0
o`3ooolW0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo0?l0ooooQ03o
ool2000006@0oooo1000002n0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0
oooo0?l0ooooQP3oool00`000000oooo0?ooo`1U0?ooo`@00000^P3oool00`000000oooo0?ooo`0<
0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooohL0oooo0P00003o0?ooob@0oooo00<000000?oo
o`3oool0303oool003d0oooo00<000000?ooo`3oool0o`3ooon90?ooo`800000K03oool400000;40
oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0o`3ooon;0?ooo`030000
003oool0oooo06d0oooo1000002]0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003o
ool0oooo0?l0ooooS03oool200000?l0oooo7`3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool4
00000?l0ooooS@3oool00`000000oooo0?ooo`1d0?ooo`800000XP3oool4000000h0oooo000m0?oo
o`030000003oool0oooo0?l0ooooS`3oool2000007H0oooo0`00002R0?ooo`030000003oool0oooo
00`0oooo000m0?ooo`030000003oool0oooo0?l0ooooT@3oool00`000000oooo0?ooo`1f0?ooo`80
0000X03oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`3o0?oooi80oooo
0P00001n0?ooo`800000V03oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?oo
o`3o0?oooi@0oooo00<000000?ooo`3oool0O@3oool4000009@0oooo00<000000?ooo`3oool0303o
ool003d0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`800000P@3oool200000980oooo00<00000
0?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0o`3ooonG0?ooo`030000003oool0oooo
08D0oooo0P00002;0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo0?l0
ooooV03oool2000008L0oooo100000270?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000
003oool0oooo0?l0ooooVP3oool00`000000oooo0?ooo`280?ooo`800000Q@3oool00`000000oooo
0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`3o0?oooi/0oooo0P00002@0?ooo`800000O@3o
ool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`3o0?oooid0oooo0P00002@
0?ooo`@00000N@3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`3o0?oo
oil0oooo00<000000?ooo`3oool0T@3oool2000007L0oooo00<000000?ooo`3oool0303oool003d0
oooo00<000000?ooo`3oool0o`3ooonP0?ooo`800000V03oool4000006h0oooo00<000000?ooo`3o
ool0303oool003d0oooo00<000000?ooo`3oool0o`3ooonR0?ooo`030000003oool0oooo09T0oooo
1000001Z0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo0?l0ooooX`3o
ool200000?l0oooo203oool00`000000oooo0?ooo`0<0?ooo`00?@3oool400000?l0ooooY03oool0
0`000000oooo0?ooo`2P0?ooo`<00000GP3oool4000000h0oooo000m0?ooo`030000003oool0oooo
0?l0ooooYP3oool200000:<0oooo1000001M0?ooo`030000003oool0oooo00`0oooo000m0?ooo`03
0000003oool0oooo0?l0ooooZ03oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo05@0
oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0o`3ooonY0?ooo`800000
Z`3oool400000580oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0o`3o
oon[0?ooo`030000003oool0oooo0:`0oooo0`00001?0?ooo`030000003oool0oooo00`0oooo000m
0?ooo`030000003oool0oooo0?l0oooo[03oool200000;D0oooo0`0000160?ooo`030000003oool0
oooo00`0oooo000m0?ooo`030000003oool0oooo0?l0oooo[P3oool00`000000oooo0?ooo`2e0?oo
o`@00000@P3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooojl0
oooo0P00003k0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo0?l0oooo
/@3oool00`000000oooo0?ooo`2l0?ooo`D00000=`3oool00`000000oooo0?ooo`0<0?ooo`00?@3o
ool00`000000oooo0?ooo`3o0?oook80oooo0P0000310?ooo`<00000=03oool00`000000oooo0?oo
o`0<0?ooo`00?@3oool00`000000oooo0?ooo`3o0?oook@0oooo00<000000?ooo`3oool0aP3oool4
000002/0oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0o`3ooone0?oo
o`800000bP3oool4000002L0oooo00<000000?ooo`3oool0303oool002<0oooo0`0000030?ooo`04
0000003oool0oooo0?ooo`<000003@3oool00`000000oooo0?ooo`3o0?oookL0oooo00<000000?oo
o`3oool0lP3oool00`000000oooo0?ooo`0<0?ooo`008P3oool01@000000oooo0?ooo`3oool00000
00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?oookP0oooo0P00003A0?oo
o`<000007P3oool00`000000oooo0?ooo`0<0?ooo`008P3oool01@000000oooo0?ooo`3oool00000
00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?oookX0oooo0P00003B0?oo
o`D000006@3oool00`000000oooo0?ooo`0<0?ooo`008P3oool01@000000oooo0?ooo`3oool00000
00X0oooo00<000000?ooo`3oool02@3oool600000?l0oooo^@3oool00`000000oooo0?ooo`3I0?oo
o`@000002`3oool6000000h0oooo000R0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo_@3oool2000009d0oooo00@000000?oo
o`3oool0oooo0P00000j0?ooo`@00000303oool00`000000oooo0?ooo`0<0?ooo`008P3oool01@00
0000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o
0?oookl0oooo00<000000?ooo`3oool0V`3oool01P000000oooo0?ooo`000000oooo000004<0oooo
0`0000030?ooo`030000003oool0oooo00`0oooo000R0?ooo`050000003oool0oooo0?ooo`000000
1P3oool3000000d0oooo00<000000?ooo`3oool0o`3oooo00?ooo`800000V`3oool010000000oooo
0?ooo`0000180?ooo`@000003P3oool00280oooo00D000000?ooo`3oool0oooo000000060?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3oooo20?ooo`030000003oool0oooo08l0
oooo2@000000103oool000000?ooo`00000L0?ooo`@000000`3oool010000000oooo0?ooo`3oool5
000001l0oooo00<000000?ooo`3oool0303oool00280oooo00D000000?ooo`3oool0oooo00000007
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3oooo30?ooo`800000T03oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`8000002P3oool7000000l0oooo00<0
00000?ooo`3oool01@3oool010000000oooo0?ooo`00000O0?ooo`030000003oool0oooo00`0oooo
000S0?ooo`<00000203oool4000000/0oooo00<000000?ooo`3oool0o`3oooo50?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo00`0oooo000m0?ooo`030000003oool0oooo0?l0ooooaP3oool2000008d0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`8000004P3oool7000000H0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00`0oooo000m0?oo
o`030000003oool0oooo0?l0oooob03oool00`000000oooo0?ooo`2;0?ooo`050000003oool0oooo
0?ooo`000000103oool010000000oooo0?ooo`0000080?ooo`L000003`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0303oool003d0oooo00<00000
0?ooo`3oool0o`3oooo90?ooo`800000R`3oool01@000000oooo0?ooo`3oool0000000@0oooo00D0
00000?ooo`3oool0oooo0000000K0?ooo`8000002`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo0?l0oooob`3oool00`000000oooo0?oo
o`290?ooo`030000003oool0000000@0oooo0P0000040?ooo`D000005`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0303oool003d0oooo00<00000
0?ooo`3oool0o`3oooo<0?ooo`800000R@3oool00`000000oooo0000000<0?ooo`030000003oool0
000001P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo00`0oooo000m0?ooo`030000003oool0oooo0?l0oooocP3oool2000008L0oooo00<000000?oo
o`0000003@3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000001P3oool0
1@000000oooo0?ooo`3oool0000001l0oooo00<000000?ooo`3oool0303oool003d0oooo00<00000
0?ooo`3oool0o`3oooo@0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0C0?ooo`<00000203oool300000200oooo00<000000?ooo`3oool0303oool0
03d0oooo00<000000?ooo`3oool0o`3ooooA0?ooo`800000U@3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo00`0oooo000m0?ooo`@00000o`3ooooB0?ooo`030000003oool0oooo08l0
oooo00@000000?ooo`3oool00000@03oool4000000h0oooo000m0?ooo`030000003oool0oooo0?l0
ooooe03oool200000900oooo0P0000140?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000
003oool0oooo0?l0ooooeP3oool200000=@0oooo00<000000?ooo`3oool0303oool003d0oooo00<0
00000?ooo`3oool0o`3ooooH0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool0303o
ool003d0oooo00<000000?ooo`3oool0o`3ooooI0?ooo`800000d@3oool00`000000oooo0?ooo`0<
0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooom/0oooo00<000000?ooo`3oool0cP3oool00`00
0000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooom`0oooo0P00003>0?ooo`03
0000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo0?l0oooogP3oool200000<`0oooo
00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0o`3ooooP0?ooo`030000003o
ool0oooo0<T0oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0o`3ooooQ
0?ooo`800000b@3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`3o0?oo
on<0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000
oooo0?ooo`3o0?ooon@0oooo0P0000360?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000
003oool0oooo0?l0ooooiP3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo00`0oooo
000m0?ooo`030000003oool0oooo0?l0ooooi`3oool200000<<0oooo00<000000?ooo`3oool0303o
ool003d0oooo00<000000?ooo`3oool0o`3ooooY0?ooo`030000003oool0oooo0<00oooo00<00000
0?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0o`3ooooZ0?ooo`800000`03oool00`00
0000oooo0?ooo`0<0?ooo`00?@3oool400000?l0ooooj`3oool00`000000oooo0?ooo`2j0?ooo`@0
00003P3oool003d0oooo00<000000?ooo`3oool0o`3oooo]0?ooo`800000_@3oool00`000000oooo
0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooonl0oooo00<000000?ooo`3oool0^P3o
ool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`3o0?oooo00oooo0P00002j
0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo0?l0oooolP3oool20000
0;P0oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0o`3ooood0?ooo`03
0000003oool0oooo0;D0oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0
o`3ooooe0?ooo`800000]@3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?oo
o`3o0?ooooL0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool0
0`000000oooo0?ooo`3o0?ooooP0oooo0P00002b0?ooo`030000003oool0oooo00`0oooo000m0?oo
o`030000003oool0oooo0?l0oooonP3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo
00`0oooo000m0?ooo`030000003oool0oooo0?l0oooon`3oool200000:l0oooo00<000000?ooo`3o
ool0303oool003d0oooo00<000000?ooo`3oool0o`3oooom0?ooo`030000003oool0oooo0:`0oooo
00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0o`3oooon0?ooo`800000[03o
ool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooool0oooo0@3oool0
0`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo
0?l0ooooo`3oool20?ooo`800000Z@3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool400000?l0
ooooo`3oool30?ooo`800000Y03oool4000000h0oooo000m0?ooo`030000003oool0oooo0?l0oooo
o`3oool60?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0303oool003d0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooo`L0oooo0P00002T0?ooo`030000003oool0oooo00`0oooo000m
0?ooo`030000003oool0oooo0?l0ooooo`3oool90?ooo`030000003oool0oooo0:40oooo00<00000
0?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo0P00002Q0?oo
o`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo0?l0ooooo`3oool<0?ooo`80
0000W`3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooool0oooo
3P3oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003o
ool0oooo0?l0ooooo`3oool?0?ooo`800000W03oool00`000000oooo0?ooo`0<0?ooo`00?@3oool0
0`000000oooo0?ooo`3o0?ooool0oooo4@3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0
oooo00`0oooo000m0?ooo`030000003oool0oooo0?l0ooooo`3ooolB0?ooo`800000V@3oool00`00
0000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooool0oooo503oool2000009L0
oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?oo
o`3o0?ooool0oooo5`3oool2000009@0oooo00<000000?ooo`3oool0303oool003d0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooaT0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0<
0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooool0oooo6P3oool200000940oooo00<000000?oo
o`3oool0303oool003d0oooo1000003o0?ooool0oooo6`3oool2000008`0oooo1000000>0?ooo`00
?@3oool00`000000oooo0?ooo`3o0?ooool0oooo7P3oool00`000000oooo0?ooo`2<0?ooo`030000
003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo0?l0ooooo`3ooolO0?ooo`800000S03o
ool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool0
0`000000oooo0?ooo`290?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo
0?l0ooooo`3ooolR0?ooo`800000R@3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000
oooo0?ooo`3o0?ooool0oooo903oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00`0
oooo000m0?ooo`030000003oool0oooo0?l0ooooo`3ooolU0?ooo`800000QP3oool00`000000oooo
0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooool0oooo9`3oool00`000000oooo0?oo
o`230?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo0?l0oooomP3oool0
10000000oooo0?ooo`3oool2000002/0oooo0P0000230?ooo`030000003oool0oooo00`0oooo000m
0?ooo`030000003oool0oooo0?l0oooom`3oool01P000000oooo0?ooo`000000oooo000002`0oooo
00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?oo
o`3o0?ooooL0oooo00@000000?ooo`3oool00000;`3oool200000800oooo00<000000?ooo`3oool0
303oool002h0oooo0`00000<0?ooo`030000003oool0oooo0?l0ooookP3oool9000000040?ooo`00
0000oooo000001`0oooo1@0000020?ooo`030000003oool0oooo0080oooo0`0000060?ooo`030000
003oool0oooo07d0oooo00<000000?ooo`3oool0303oool002l0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`3o0?ooonl0oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`3oool2000000X0oooo1`00000<0?ooo`040000003oool0oooo000000H0oooo00D000000?ooo`3o
ool0oooo000000060?ooo`800000O@3oool00`000000oooo0?ooo`0<0?ooo`00;`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooook`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`05
0000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo
00`0oooo000_0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3oooo_0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool200000180oooo1`0000050?ooo`03
0000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000090?ooo`800000NP3oool00`00
0000oooo0?ooo`0<0?ooo`00;`3oool00`000000oooo0?ooo`0;0?ooo`H00000o`3oooo]0?ooo`05
0000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000080?ooo`L000003P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0LP3oool6
000000h0oooo000_0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3oooo`0?oo
o`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000001d0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`800000M`3oool00`000000oooo0?oo
o`0<0?ooo`00;`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooool@3oool0
0`000000oooo000000040?ooo`800000103oool5000001P0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0000000?0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0303oool0
02l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?oooo40oooo00<000000?oo
o`000000303oool00`000000oooo0000000H0?ooo`030000003oool0oooo00@0oooo00D000000?oo
o`3oool0oooo0000000?0?ooo`800000M03oool00`000000oooo0?ooo`0<0?ooo`00;P3oool20000
00d0oooo00<000000?ooo`3oool0o`3ooooa0?ooo`030000003oool0000000d0oooo00<000000?oo
o`3oool04`3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo0000
000A0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0303oool002l0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?oooo80oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0C0?ooo`<00000203oool3000001<0oooo0P00001a0?ooo`030000003oool0
oooo00`0oooo000m0?ooo`030000003oool0oooo0?l0ooooo`3oool30?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000
oooo0?ooo`3o0?ooool0oooo00@000000?ooo`3oool00000>@3oool2000006h0oooo00<000000?oo
o`3oool0303oool003d0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`40oooo0P00000l0?ooo`03
0000003oool0oooo06/0oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0
o`3ooooo0?oood00oooo0P00001[0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003o
ool0oooo0?l0ooooo`3ooom20?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0303o
ool003d0oooo00<000000?ooo`3oool0o`3ooooo0?oood<0oooo0P00001X0?ooo`030000003oool0
oooo00`0oooo000m0?ooo`030000003oool0oooo0?l0ooooo`3ooom50?ooo`800000IP3oool00`00
0000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooool0ooooA`3oool00`000000
oooo0?ooo`1S0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo0?l0oooo
o`3ooom80?ooo`800000H`3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool400000?l0ooooo`3o
oom90?ooo`030000003oool0oooo05d0oooo1000000>0?ooo`00?@3oool00`000000oooo0?ooo`3o
0?ooool0ooooB`3oool200000600oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?oo
o`3oool0o`3ooooo0?ooodd0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0<0?oo
o`00?@3oool00`000000oooo0?ooo`3o0?ooool0ooooCP3oool2000005d0oooo00<000000?ooo`3o
ool0303oool003d0oooo00<000000?ooo`3oool0o`3ooooo0?oooe00oooo00<000000?ooo`3oool0
FP3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3o
ool2000005X0oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0o`3ooooo
0?oooe<0oooo0P00001H0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo
0?l0ooooo`3ooomE0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0303oool003d0
oooo00<000000?ooo`3oool0o`3ooooo0?oooeH0oooo0P00001E0?ooo`030000003oool0oooo00`0
oooo000m0?ooo`030000003oool0oooo0?l0ooooo`3ooomH0?ooo`030000003oool0oooo0580oooo
00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0o`3ooooo0?oooeT0oooo0P00
001B0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo05l0oooo00<00000
0?ooo`3oool0G`3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo05l0oooo00<00000
0?ooo`3oool0G`3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00d0oooo0P00001@
0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030000003oool0oooo05l0oooo00<000000?oo
o`3oool0G`3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo05l0oooo00<000000?oo
o`3oool0G`3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0C@3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`80
00004P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`040000
003oool0000000000100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0303oool003d0ooooo`00003o00000;400000
3P3oool00?l0ooooo`3ooool0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 761.375}, {470.188, 0}} -> {-0.158137, -1.90066, \
0.0025542, 0.00661246}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ \(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(\
--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(-\(---\)\)\)\)\)\)\)\)\)\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)*) \[IndentingNewLine]\[IndentingNewLine] \
(*\ Quintom\ \(model : \ 
            Find\ w \((z)\)\ for\ given\ slope\ s\ of\ the\ linear\ potential \
. \ Present\ time\)\  = \ \(tt\ \((corresponds\ to\ a = 1)\) . \ 
              Run\ trials\ for\ initial\ condition\ for\ field\ fi\ \((f0)\)\ \
and\ initial\ time\ ti\ until\ we\ get\ field\ energy\ enf\  = \ \(0.7\ and\ \
H \((z = 0)\)\  = 
            1\ at\ present\ time\ \(\(tt\)\(.\)\)\)\)\ *) \[IndentingNewLine] \
(*\ \(--\(--\(--\(--\ \ s\)\)\)\)\  = \ \(\(\(0.2\ \ \ --\)--\) 
            q = \(-\(\(0.05--\)--\)\) \(--\(--\(--\(--\(--\(--\(--\(--\(--\(\
--\(--\(--\(--\(--\(---\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\ *) \
\[IndentingNewLine]\(Clear[aa, fi, a, aad, aadd, fidas, tas, f, rr, hht, 
        hha];\)\), "\n", 
    \(aa = a[t]; \ fi1 = f1[t]; \ fi2 = f2[t];\), "\n", 
    \(\(aad = D[aa, t];\)\), "\n", 
    \(\(aadd = D[aa, {t, 2}];\)\), "\n", 
    \(fi1d = D[fi1, t]; \ fi2d = D[fi2, t];\), "\n", 
    \(fi1dd = D[fi1, {t, 2}]; \ fi2dd = D[fi2, {t, 2}];\), "\n", 
    \(ti = 0.00001; \ t0 = 4.3; \ f0 = 2.6;\), "\n", 
    \(om0m = 0.3; \ ss = 0.2; \ q = \(-0.05\);\), "\n", 
    \(\(eq1 = 
        aadd/aa\  \[Equal] \ \(-fi1d^2\)\ \  + fi2d^2\ \  + ss\ fi1\  + 
            ss\ fi2\  + q\ fi1\ fi2 - \ om0m/\((2\ aa^3)\);\)\), "\n", 
    \(\(eq2 = 
        fi1dd\ \  + \ \ \ 3\ \ fi1d\ \((aad/aa)\)\  + \ ss\  + \ 
            q\ fi2 \[Equal] 0;\)\), "\n", 
    \(\(eq3 = 
        fi2dd\ \  + \ \ \ 3\ \ fi2d\ \((aad/aa)\)\  - \ ss\  - \ 
            q\ fi1 \[Equal] 0;\)\), "\n", 
    \(\(eqb1 = f1[ti] == f0;\)\), "\n", 
    \(\(eqb2 = \(f1'\)[ti] == 0;\)\), "\n", 
    \(\(eqb3 = f2[ti] \[Equal] f0;\)\), "\n", 
    \(\(eqb4 = \(f2'\)[ti] == 0;\)\), "\n", 
    \(\(eqb5 = 
        a[ti] \[Equal] \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((2/3)\);\)\), "\n", 
    \(\(eqb6 = \(a'\)[
            ti] \[Equal] \((2/
                3)\)\ \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((\(-1\)/
                  3)\);\)\), "\n", 
    \(\(sol2 = 
        NDSolve[{eq1, eq2, eq3, eqb1, eqb2, eqb3, eqb4, eqb5, eqb6}, {aa, 
            fi1, fi2}, {t, ti, t0}, MaxSteps \[Rule] 10000000];\)\), "\n", 
    \(\(asol = Part[Evaluate[a[t] /. sol2], 1];\)\), "\n", 
    \(\(f1sol = Part[Evaluate[f1[t] /. sol2], 1];\)\), "\n", 
    \(\(f2sol = 
        Part[Evaluate[f2[t] /. sol2], 1];\)\), "\[IndentingNewLine]", 
    \(\(df1sol = D[f1sol, t];\)\), "\[IndentingNewLine]", 
    \(\(df2sol = D[f2sol, t];\)\), "\[IndentingNewLine]", 
    \(\(enf = 
        0.5\ df1sol^2\  - 0.5\ df2sol^2\  + \ ss\ f1sol + \ ss\ f2sol\  + \ 
          q\ f1sol\ f2sol;\)\), "\n", 
    \(\(ppf = 
        0.5\ df1sol^2\  - 0.5\ df2sol^2\  - \ ss\ f1sol - \ ss\ f2sol\  - \ 
          q\ f1sol\ f2sol;\)\), "\n", 
    \(\(wft[t1_] := ppf/enf\  /. \ t -> t1\ ;\)\ \), "\[IndentingNewLine]", 
    \(\(as[t1_] := asol\  /. \ t -> t1\ ;\)\), "\[IndentingNewLine]", 
    \(\(tt = Part[FindRoot[as[t] == 1, {t, 0.1}], 1, 2];\)\), "\n", 
    \(\(tas[a_] := 
        Part[FindRoot[as[t] \[Equal] a, {t, 0.3}], 1, 2];\)\), "\n", 
    \(\(hht[t1_] := D[asol, t]/asol\  /. \ t -> t1\ ;\)\), "\n", 
    \(\(hha[a_] := hht[tas[a]];\)\), "\n", 
    \(\(hhz[z_] := hha[1/\((z + 1)\)];\)\), "\n", 
    \(enf\  /. \ t \[Rule] tt\), "\n", 
    \(hhz[0]\), "\[IndentingNewLine]", 
    \(\(wfa[a_] := wft[tas[a]];\)\), "\n", 
    \(\(wfz[z_] := wfa[1/\((z + 1)\)];\)\), "\n", 
    \(\(plm = 
        Plot[wfz[z], {z, 0, 2}, Frame \[Rule] True, PlotRange \[Rule] All, 
          FrameLabel \[Rule] {"\<z\>", "\<w(z)\>"}];\)\), \
"\[IndentingNewLine]", 
    \(\(hhzt = 
        Sqrt[\((1 - om0m)\) + om0m \((1 + z)\)^3] /. 
          om0m \[Rule] 0.3;\)\)}], "Input"],

Cell[BoxData[
    \(0.702004696813943`\)], "Output"],

Cell[BoxData[
    \(1.003327687357658`\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.476191 64589.7 64589.1 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.2619 -0.0125 -10.7813 -17.8125 ]
[.2619 -0.0125 10.7813 0 ]
[.5 -0.0125 -5.53125 -17.8125 ]
[.5 -0.0125 5.53125 0 ]
[.7381 -0.0125 -10.7813 -17.8125 ]
[.7381 -0.0125 10.7813 0 ]
[.97619 -0.0125 -5.53125 -17.8125 ]
[.97619 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.125 -35.625 ]
[.5 -0.0125 5.125 -17.8125 ]
[-0.0125 .08937 -59.5 -8.90625 ]
[-0.0125 .08937 0 8.90625 ]
[-0.0125 .21855 -59.5 -8.90625 ]
[-0.0125 .21855 0 8.90625 ]
[-0.0125 .34773 -20.75 -8.90625 ]
[-0.0125 .34773 0 8.90625 ]
[-0.0125 .47691 -20.75 -8.90625 ]
[-0.0125 .47691 0 8.90625 ]
[-0.0125 .60609 -20.75 -8.90625 ]
[-0.0125 .60609 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -77.3125 -14.7188 ]
[-0.01875 .30902 -59.5 14.7188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.125 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08937 m
.00625 .08937 L
s
gsave
-0.0125 .08937 -120.5 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.00001) show
1.000 setlinewidth
grestore
0 .21855 m
.00625 .21855 L
s
gsave
-0.0125 .21855 -120.5 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.00001) show
1.000 setlinewidth
grestore
0 .34773 m
.00625 .34773 L
s
gsave
-0.0125 .34773 -81.75 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .47691 m
.00625 .47691 L
s
gsave
-0.0125 .47691 -81.75 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .60609 m
.00625 .60609 L
s
gsave
-0.0125 .60609 -81.75 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .12167 m
.00375 .12167 L
s
0 .15396 m
.00375 .15396 L
s
0 .18626 m
.00375 .18626 L
s
0 .25085 m
.00375 .25085 L
s
0 .28314 m
.00375 .28314 L
s
0 .31543 m
.00375 .31543 L
s
0 .38002 m
.00375 .38002 L
s
0 .41232 m
.00375 .41232 L
s
0 .44461 m
.00375 .44461 L
s
0 .5092 m
.00375 .5092 L
s
0 .5415 m
.00375 .5415 L
s
0 .57379 m
.00375 .57379 L
s
0 .05708 m
.00375 .05708 L
s
0 .02478 m
.00375 .02478 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -144.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.7188 12.9063 translate
90 rotate
-75.7188 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.063 17.500 moveto
(H) show
77.625 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.875 17.500 moveto
(L) show
88.438 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08937 m
1 .08937 L
s
.99375 .21855 m
1 .21855 L
s
.99375 .34773 m
1 .34773 L
s
.99375 .47691 m
1 .47691 L
s
.99375 .60609 m
1 .60609 L
s
.125 Mabswid
.99625 .12167 m
1 .12167 L
s
.99625 .15396 m
1 .15396 L
s
.99625 .18626 m
1 .18626 L
s
.99625 .25085 m
1 .25085 L
s
.99625 .28314 m
1 .28314 L
s
.99625 .31543 m
1 .31543 L
s
.99625 .38002 m
1 .38002 L
s
.99625 .41232 m
1 .41232 L
s
.99625 .44461 m
1 .44461 L
s
.99625 .5092 m
1 .5092 L
s
.99625 .5415 m
1 .5415 L
s
.99625 .57379 m
1 .57379 L
s
.99625 .05708 m
1 .05708 L
s
.99625 .02478 m
1 .02478 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .08937 m
1 .08937 L
s
.5 Mabswid
.02381 .01472 m
.06244 .15881 L
.10458 .2752 L
.14415 .35576 L
.18221 .4138 L
.22272 .46007 L
.26171 .49339 L
.30316 .51995 L
.34309 .53914 L
.3815 .55323 L
.42237 .56469 L
.46172 .57316 L
.49955 .57951 L
.53984 .58479 L
.57861 .58878 L
.61984 .59212 L
.65954 .59465 L
.69774 .59661 L
.73838 .59828 L
.77751 .59958 L
.81909 .6007 L
.85916 .60157 L
.89771 .60226 L
.93871 .60286 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{565.25, 349.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008e0001GB000`400?l00000o`00003oo`3ooooo
0?ooocL0oooo003o0?ooool0oooo=`3oool00?l0ooooo`3ooolg0?ooo`00o`3ooooo0?ooocL0oooo
003o0?ooool0oooo=`3oool00?l0ooooo`3ooolg0?ooo`00o`3ooooo0?ooocL0oooo003o0?ooool0
oooo=`3oool00?l0ooooo`3ooolg0?ooo`00o`3ooooo0?ooocL0oooo003o0?oood<0oooo1P00003]
0?ooo`00o`3ooom40?ooo`050000003oool0oooo0?ooo`000000k@3oool00?l0ooooA@3oool00`00
0000oooo0?ooo`3^0?ooo`00o`3ooom50?ooo`030000003oool0oooo0>h0oooo003o0?ooodH0oooo
00<000000?ooo`3oool0k@3oool00?l0oooo@`3oool01@000000oooo0?ooo`3oool000000>h0oooo
003o0?oood<0oooo1P00003]0?ooo`00o`3ooooo0?ooocL0oooo003o0?ooool0oooo=`3oool00?l0
ooooo`3ooolg0?ooo`00o`3ooooo0?ooocL0oooo003o0?ooool0oooo=`3oool00?l0ooooo`3ooolg
0?ooo`00o`3ooooo0?ooocL0oooo003o0?ooool0oooo=`3oool00?l0ooooo`3ooolg0?ooo`00o`3o
oooo0?ooocL0oooo001P0?ooo`<00000J@3oool3000000<0oooo00@000000?ooo`3oool0oooo0`00
001Z0?ooo`<00000JP3oool3000000<0oooo00@000000?ooo`3oool0oooo0`00001Y0?ooo`D00000
2P3oool005l0oooo00D000000?ooo`3oool0oooo0000001W0?ooo`050000003oool0oooo0?ooo`00
00002@3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`1W0?ooo`040000003oool0oooo000000X0oooo001O0?ooo`05
0000003oool0oooo0?ooo`000000I`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<00000
0?ooo`3oool0I`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0I`3oool00`000000oooo0?ooo`0:0?ooo`00G`3oool01@000000oooo0?ooo`3oool0
000006L0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo06L0oooo00<0
00000?ooo`3oool0JP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo06P0oooo00<0
00000?ooo`3oool02@3oool005l0oooo00D000000?ooo`3oool0oooo0000001W0?ooo`050000003o
ool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo06X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00T0oooo
001O0?ooo`050000003oool0oooo0?ooo`000000I`3oool01@000000oooo0?ooo`3oool0000000T0
oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`080?ooo`00G`3oool01@000000oooo
0?ooo`3oool0000006L0oooo00D000000?ooo`3oool0oooo000000060?ooo`<00000J`3oool00`00
0000oooo0?ooo`1Z0?ooo`030000003oool0oooo00H0oooo0`00001]0?ooo`030000003oool0oooo
00P0oooo001O0?ooo`050000003oool0oooo0?ooo`000000I`3oool01@000000oooo0?ooo`3oool0
000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`080?ooo`00G`3oool01@00
0000oooo0?ooo`3oool0000006L0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003o
ool0oooo06T0oooo0P00001[0?ooo`8000002@3oool00`000000oooo0?ooo`1X0?ooo`050000003o
ool0oooo0?ooo`0000002P3oool00600oooo0`00001Y0?ooo`<00000203oool4000006T0oooo00<0
00000?ooo`3oool0JP3oool00`000000oooo0?ooo`070?ooo`@00000J03oool3000000/0oooo003o
0?ooool0oooo=`3oool00?l0ooooo`3ooolg0?ooo`00o`3ooooo0?ooocL0oooo003o0?ooool0oooo
=`3oool00?l0ooooo`3ooolg0?ooo`00o`3ooooo0?ooocL0oooo003o0?ooool0oooo=`3oool00?l0
ooooo`3ooolg0?ooo`00o`3ooooo0?ooocL0oooo001F0?ooool00000h000000005H0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool02@3oool100000000EP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`090?ooo`400000001F0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1_0?ooo`03
0000003oool0oooo06h0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`090?ooo`40
0000001F0?ooo`030000003oool0oooo0?l0oooog03oool100000000EP3oool00`000000oooo0?oo
o`3o0?ooom`0oooo0@00000005H0oooo00<000000?ooo`3oool0o`3ooooL0?ooo`400000001F0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooooA0?ooo`400000001F0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooooA0?ooo`400000001F0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0o`3oooo@0?ooo`400000001F0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0o`3oooo@0?ooo`400000001F0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0o`3oooo@0?ooo`400000001F0?ooo`<000002@3oool00`00
0000oooo0?ooo`3o0?ooolh0oooo0`00000005H0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`3o0?oooll0oooo0@00000005H0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`3o0?oooll0oooo0@00000005H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`3o0?oooll0oooo0@00000005H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o
0?oooll0oooo0@00000005H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?oo
olh0oooo0@00000005H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?ooolh0
oooo0@00000005H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?ooolh0oooo
0@00000005H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooold0oooo0@00
000005H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooold0oooo0@000000
05H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooold0oooo0@00000005H0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooold0oooo0@00000005H0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?oool`0oooo0@00000005H0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?oool`0oooo0@00000005H0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?oool`0oooo0@00000005H0oooo0`00000>0?oo
o`030000003oool0oooo0?l0oooob@3oool300000000EP3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0?l0oooob`3oool100000000EP3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0?l0oooob`3oool100000000EP3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0?l0oooob`3oool100000000EP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0?l0oooobP3oool100000000EP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0?l0oooobP3oool100000000EP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0
oooobP3oool100000000EP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0oooo
bP3oool100000000EP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0oooob@3o
ool100000000EP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0oooob@3oool1
00000000EP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0oooob@3oool10000
0000EP3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0oooob03oool100000000
8P3oool3000000<0oooo00<000000?ooo`3oool00P3oool3000000@0oooo0`0000040?ooo`<00000
103oool3000000@0oooo0`00000:0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
o`3oooo80?ooo`400000000S0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?ooolP0oooo0@00000002<0oooo00<000000?oo
o`3oool01P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000
00020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0
oooob03oool1000000005`3oool7000000D0oooo00<000000?ooo`3oool01P3oool01@000000oooo
0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0ooooa`3oool1000000008`3oool0
0`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`090?ooool00000h000000002<0oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo00000002
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0oooo
a`3oool1000000008`3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000
0P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0o`3oooo70?ooo`400000000S0?ooo`030000003oool0oooo
00H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3o0?ooolH0
oooo0@0000000280oooo0P0000080?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000
oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000`3oool2000000/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`3o0?ooolH0oooo0@00000002<0oooo00<000000?ooo`3oool01`3oool3000000@0oooo0`000004
0?ooo`<00000103oool3000000D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0?l0ooooaP3oool100000000EP3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo0?l0ooooa@3oool100000000EP3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo0?l0ooooa@3oool100000000EP3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo0?l0ooooa@3oool100000000EP3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo0?l0ooooa@3oool100000000EP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo0?l0ooooa03oool100000000EP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
0?l0ooooa03oool100000000EP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0
ooooa03oool100000000EP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0oooo
a03oool100000000EP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0oooo``3o
ool100000000EP3oool3000001H0oooo00<000000?ooo`3oool0o`3oooo10?ooo`<00000001F0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0o`3oooo30?ooo`400000001F0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0o`3oooo20?ooo`400000001F0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0o`3oooo20?ooo`400000001F0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0o`3oooo20?ooo`400000001F0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0o`3oooo20?ooo`400000001F0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0o`3oooo10?ooo`400000001F0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool0o`3oooo10?ooo`400000001F0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0o`3oooo10?ooo`400000001F0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0o`3oooo00?ooo`400000001F0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0o`3oooo00?ooo`400000001F0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0o`3oooo00?ooo`400000001F0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0o`3oooo00?ooo`400000001F0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
o`3ooono0?ooo`400000001F0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0o`3o
oono0?ooo`400000001F0?ooo`<000006P3oool00`000000oooo0?ooo`3o0?oookd0oooo0`000000
05H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`3o0?oookl0oooo0@00000005H0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`3o0?oookh0oooo0@00000005H0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`3o0?oookh0oooo0@00000005H0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`3o0?oookh0oooo0@00000005H0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`3o0?oookd0oooo0@00000005H0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`3o0?oookd0oooo0@00000005H0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`3o0?oookd0oooo0@00000005H0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`3o0?oook`0oooo0@00000005H0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`3o0?oook`0oooo0@00000005H0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`3o0?oook/0oooo0@00000005H0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`3o0?oook/0oooo0@00000005H0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`3o0?oook/0oooo0@00000005H0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`3o0?oookX0oooo0@00000005H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`3o0?oookX0oooo0@00000005H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3o
0?oookX0oooo0@00000005H0oooo0`00000P0?ooo`030000003oool0oooo0?l0oooo]`3oool30000
0000EP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0?l0oooo^@3oool100000000
EP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0?l0oooo^@3oool100000000EP3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0oooo^03oool100000000EP3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0oooo^03oool100000000EP3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo0?l0oooo]`3oool100000000EP3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo0?l0oooo]`3oool100000000EP3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0?l0oooo]`3oool100000000EP3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo0?l0oooo]P3oool100000000EP3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0?l0oooo]P3oool100000000EP3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0?l0oooo]P3oool100000000EP3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo0?l0oooo]@3oool1000000008P3oool3000000<0oooo00<000000?ooo`3oool0
0P3oool3000000@0oooo0`0000040?ooo`<00000103oool3000000@0oooo0`00000:0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0o`3ooone0?ooo`400000000S0?ooo`030000003o
ool0oooo00H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`3o
0?oookD0oooo0@00000002<0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0
00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000
0P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo0?l0oooo]03oool1000000005`3oool7000000D0oooo
00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3o
ool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool02@3oool4000002@0oooo00<000000?ooo`3oool0o`3o
oona0?ooo`@00000000S0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`3o0?oook<0oooo0@00000002<0oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo00000002
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0?l0oooo
/`3oool1000000008`3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000
0P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool0o`3ooonc0?ooo`400000000S0?ooo`030000003oool0oooo
00H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3o0?oook80
oooo0@0000000280oooo0P0000080?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000
oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000`3oool2000000/0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`3o0?oook80oooo0@00000002<0oooo00<000000?ooo`3oool01`3oool3000000@0oooo0`000004
0?ooo`<00000103oool3000000D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo0?l0oooo/P3oool100000000EP3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo0?l0oooo/@3oool100000000EP3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo0?l0oooo/@3oool100000000EP3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo0?l0oooo/@3oool100000000EP3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo0?l0oooo/03oool100000000EP3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo0?l0oooo/03oool100000000EP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
0?l0oooo[`3oool100000000EP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0?l0
oooo[`3oool100000000EP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0?l0oooo
[`3oool100000000EP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0oooo[P3o
ool100000000EP3oool3000002/0oooo00<000000?ooo`3oool0o`3ooon/0?ooo`<00000001F0?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool0o`3ooon^0?ooo`400000001F0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool0o`3ooon]0?ooo`400000001F0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool0o`3ooon]0?ooo`400000001F0?ooo`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool0o`3ooon]0?ooo`400000001F0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool0o`3ooon/0?ooo`400000001F0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0o`3ooon/0?ooo`400000001F0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool0o`3ooon[0?ooo`400000001F0?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool0o`3ooon[0?ooo`400000001F0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool0o`3ooon[0?ooo`400000001F0?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool0o`3ooonZ0?ooo`400000001F0?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool0o`3ooonZ0?ooo`400000001F0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool0o`3ooonZ0?ooo`400000001F0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
o`3ooonY0?ooo`400000001F0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0o`3o
oonY0?ooo`400000001F0?ooo`<00000<@3oool00`000000oooo0?ooo`3o0?ooojH0oooo0`000000
00H0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo
0?l0ooooZ03oool1000000001P3oool3000004d0oooo00<000000?ooo`3oool0<P3oool00`000000
oooo0?ooo`3o0?ooojL0oooo0@00000000H0oooo00<000000?ooo`3oool00`00001:0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool0o`3ooonW0?ooo`400000000;0?ooo`800000B@3o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0?l0ooooYP3oool1000000001P3oool0
0`000000oooo0?ooo`02000004/0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`3o
0?ooojH0oooo0@00000000H0oooo0`00001=0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0o`3ooonU0?ooo`40000000060?ooo`030000003oool0oooo00<00000BP3oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo0?l0ooooY@3oool1000000002`3oool2000004T0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`3o0?oooj@0oooo0@00000000H0oooo00<0
00000?ooo`3oool00P00001;0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0o`3o
oonT0?ooo`40000000060?ooo`<00000C@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo0?l0ooooX`3oool1000000001P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0o`3ooonS0?ooo`40000000050?ooo`T00000B03oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo0?l0ooooXP3oool100000000103oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`3o0?oooj80oooo0@00000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`140?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0o`3ooonQ0?ooo`4000000006
0?ooo`800000103oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool0o`3ooonQ0?ooo`40000000060?ooo`030000003oool0oooo0080oooo0P0000190?oo
o`<00000>@3oool00`000000oooo0?ooo`3o0?oooih0oooo0`00000000H0oooo00<000000?ooo`3o
ool00P0000000`3oool000000?ooo`180?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0o`3ooonP0?ooo`40000000060?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0?l0ooooW`3oool1000000001P3o
ool2000000@0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0j0?ooo`030000003o
ool0oooo0?l0ooooW`3oool1000000001P3oool00`000000oooo0?ooo`020?ooo`800000B@3oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0ooooWP3oool100000000EP3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0ooooWP3oool1000000000`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0?03oool00`000000
oooo0?ooo`3o0?oooid0oooo0@00000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`150?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0o`3ooonM0?ooo`400000
00050?ooo`T00000B03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0?l0ooooW03o
ool100000000EP3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0?l0ooooW03oool1
00000000EP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0?l0ooooV`3oool10000
0000B@3oool3000000X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`3o0?oooi/0
oooo0@00000004X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0o0?ooo`030000
003oool0oooo0?l0ooooVP3oool100000000BP3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`400000000n0?ooo`L000001@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0o`3ooonI
0?ooo`400000001:0?ooo`030000003oool0oooo00T0oooo1000000o0?ooo`030000003oool0oooo
0?l0ooooUP3oool400000000BP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0o`3ooonH0?ooo`400000001:0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3o0?oooiP0oooo0@00000004X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0?l0ooooU`3o
ool100000000B@3oool2000000/0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`3o
0?oooiL0oooo0@00000004X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo0?l0ooooUP3oool100000000EP3oool00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo0?l0ooooUP3oool100000000EP3oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo0?l0ooooU@3oool100000000EP3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo0?l0ooooU03oool100000000EP3oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo0?l0ooooU03oool100000000EP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
0?l0ooooT`3oool100000000EP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0?l0
ooooT`3oool100000000EP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0?l0oooo
TP3oool100000000EP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0?l0ooooT@3o
ool100000000EP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0?l0ooooT@3oool1
00000000EP3oool3000004T0oooo00<000000?ooo`3oool0o`3ooon>0?ooo`<00000001F0?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool0o`3ooon?0?ooo`400000001F0?ooo`030000
003oool0oooo04X0oooo00<000000?ooo`3oool0o`3ooon?0?ooo`400000001F0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0o`3ooon>0?ooo`400000001F0?ooo`030000003oool0
oooo04`0oooo00<000000?ooo`3oool0o`3ooon=0?ooo`400000001F0?ooo`030000003oool0oooo
04`0oooo00<000000?ooo`3oool0o`3ooon=0?ooo`400000001F0?ooo`030000003oool0oooo04d0
oooo00<000000?ooo`3oool0o`3ooon<0?ooo`400000001F0?ooo`030000003oool0oooo04h0oooo
00<000000?ooo`3oool0o`3ooon;0?ooo`400000001F0?ooo`030000003oool0oooo04h0oooo00<0
00000?ooo`3oool0o`3ooon;0?ooo`400000001F0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool0o`3ooon:0?ooo`400000001F0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool0o`3ooon:0?ooo`400000001F0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool0o`3ooon90?ooo`400000001F0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0
o`3ooon80?ooo`400000001F0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0o`3o
oon80?ooo`400000001F0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0o`3ooon7
0?ooo`400000001F0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0o`3ooon60?oo
o`400000001F0?ooo`<00000D`3oool00`000000oooo0?ooo`3o0?oooh@0oooo0`00000005H0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3o0?ooohD0oooo0@00000005H0oooo00<0
00000?ooo`3oool0E@3oool00`000000oooo0?ooo`3o0?oooh@0oooo0@00000005H0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`3o0?oooh<0oooo0@00000005H0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`3o0?oooh80oooo0@00000005H0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`3o0?oooh80oooo0@00000005H0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`3o0?oooh40oooo0@00000005H0oooo00<000000?ooo`3oool0F@3o
ool00`000000oooo0?ooo`3o0?oooh00oooo0@00000005H0oooo00<000000?ooo`3oool0FP3oool0
0`000000oooo0?ooo`3o0?ooogl0oooo0@00000005H0oooo00<000000?ooo`3oool0F`3oool00`00
0000oooo0?ooo`3o0?ooogh0oooo0@00000005H0oooo00<000000?ooo`3oool0G03oool00`000000
oooo0?ooo`3o0?ooogd0oooo0@00000005H0oooo00<000000?ooo`3oool0G@3oool00`000000oooo
0?ooo`3o0?ooog`0oooo0@00000005H0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?oo
o`3o0?ooog`0oooo0@00000005H0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3o
0?ooog/0oooo0@00000005H0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`3o0?oo
ogX0oooo0@00000005H0oooo0`00001P0?ooo`030000003oool0oooo0?l0ooooM`3oool300000000
EP3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0?l0ooooN03oool100000000EP3o
ool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0?l0ooooM`3oool100000000EP3oool0
0`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0?l0ooooMP3oool100000000EP3oool00`00
0000oooo0?ooo`1T0?ooo`030000003oool0oooo0?l0ooooM@3oool100000000EP3oool00`000000
oooo0?ooo`1T0?ooo`030000003oool0oooo0?l0ooooM@3oool100000000EP3oool00`000000oooo
0?ooo`1U0?ooo`030000003oool0oooo0?l0ooooM03oool100000000EP3oool00`000000oooo0?oo
o`1V0?ooo`030000003oool0oooo0?l0ooooL`3oool100000000EP3oool00`000000oooo0?ooo`1W
0?ooo`030000003oool0oooo0?l0ooooLP3oool100000000EP3oool00`000000oooo0?ooo`1X0?oo
o`030000003oool0oooo0?l0ooooL@3oool100000000EP3oool00`000000oooo0?ooo`1Y0?ooo`03
0000003oool0oooo0?l0ooooL03oool100000000EP3oool00`000000oooo0?ooo`1Z0?ooo`800000
o`3ooom`0?ooo`40000000190?ooo`<000002P3oool00`000000oooo0?ooo`1/0?ooo`030000003o
ool0oooo0?l0ooooK@3oool100000000BP3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo06d0oooo00<000000?ooo`3oool0o`3ooom/0?ooo`400000001:0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`3o0?ooof/0oooo0@00000003h0
oooo1`0000050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0K`3oool00`000000
oooo0?ooo`3o0?ooofX0oooo0@00000004X0oooo00<000000?ooo`3oool02@3oool4000006l0oooo
0P00003o0?ooofL0oooo1000000004X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`1b0?ooo`030000003oool0oooo0?l0ooooI`3oool100000000BP3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0o`3ooomV0?ooo`400000001:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`3o0?oo
ofD0oooo0@00000004T0oooo0P00000;0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3o
ool0o`3ooomT0?ooo`400000001:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
MP3oool200000?l0ooooI03oool100000000EP3oool00`000000oooo0?ooo`1h0?ooo`030000003o
ool0oooo0?l0ooooH@3oool100000000EP3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0
oooo0?l0ooooH03oool100000000EP3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo
0?l0ooooG`3oool100000000EP3oool00`000000oooo0?ooo`1k0?ooo`800000o`3ooomO0?ooo`40
0000001F0?ooo`030000003oool0oooo07d0oooo0P00003o0?oooed0oooo0@00000005H0oooo00<0
00000?ooo`3oool0O`3oool00`000000oooo0?ooo`3o0?oooeX0oooo0@00000005H0oooo00<00000
0?ooo`3oool0P03oool200000?l0ooooFP3oool100000000EP3oool00`000000oooo0?ooo`220?oo
o`800000o`3ooomH0?ooo`400000001F0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3o
ool0o`3ooomE0?ooo`400000001F0?ooo`<00000Q@3oool200000?l0ooooD`3oool300000000EP3o
ool00`000000oooo0?ooo`270?ooo`800000o`3ooomC0?ooo`400000001F0?ooo`030000003oool0
oooo08T0oooo00<000000?ooo`3oool0o`3ooom@0?ooo`400000001F0?ooo`030000003oool0oooo
08X0oooo0P00003o0?oooe00oooo0@00000005H0oooo00<000000?ooo`3oool0S03oool200000?l0
ooooCP3oool100000000EP3oool00`000000oooo0?ooo`2>0?ooo`800000o`3ooom<0?ooo`400000
001F0?ooo`030000003oool0oooo0900oooo0P00003o0?ooodX0oooo0@00000005H0oooo00<00000
0?ooo`3oool0TP3oool200000?l0ooooB03oool100000000EP3oool00`000000oooo0?ooo`2D0?oo
o`800000o`3ooom60?ooo`400000001F0?ooo`030000003oool0oooo09H0oooo0P00003o0?oood@0
oooo0@00000005H0oooo00<000000?ooo`3oool0V03oool200000?l0oooo@P3oool100000000EP3o
ool00`000000oooo0?ooo`2J0?ooo`800000o`3ooom00?ooo`400000001F0?ooo`030000003oool0
oooo09`0oooo0P00003o0?oooch0oooo0@00000005H0oooo00<000000?ooo`3oool0WP3oool20000
0?l0oooo?03oool100000000EP3oool00`000000oooo0?ooo`2P0?ooo`<00000o`3oooli0?ooo`40
0000001F0?ooo`030000003oool0oooo0:<0oooo0P00003o0?ooocL0oooo0@00000005H0oooo0`00
002U0?ooo`<00000o`3ooolb0?ooo`<00000001F0?ooo`030000003oool0oooo0:P0oooo0P00003o
0?oooc80oooo0@00000005H0oooo00<000000?ooo`3oool0ZP3oool300000?l0oooo;`3oool10000
0000EP3oool00`000000oooo0?ooo`2]0?ooo`<00000o`3oool/0?ooo`400000001F0?ooo`030000
003oool0oooo0;00oooo0P00003o0?ooobX0oooo0@00000005H0oooo00<000000?ooo`3oool0/P3o
ool300000?l0oooo9`3oool100000000EP3oool00`000000oooo0?ooo`2e0?ooo`<00000o`3ooolT
0?ooo`400000001F0?ooo`030000003oool0oooo0;P0oooo1000003o0?ooob00oooo0@00000005H0
oooo00<000000?ooo`3oool0_03oool300000?l0oooo7@3oool100000000EP3oool00`000000oooo
0?ooo`2o0?ooo`<00000o`3ooolJ0?ooo`400000001F0?ooo`030000003oool0oooo0<80oooo1000
003o0?oooaH0oooo0@00000005H0oooo00<000000?ooo`3oool0aP3oool400000?l0oooo4P3oool1
00000000EP3oool00`000000oooo0?ooo`3:0?ooo`@00000o`3oool>0?ooo`400000001F0?ooo`03
0000003oool0oooo0<h0oooo1@00003o0?ooo`T0oooo0@00000005H0oooo00<000000?ooo`3oool0
d`3oool400000?l0oooo1@3oool100000000EP3oool300000=L0oooo1@00003m0?ooo`<00000001F
0?ooo`030000003oool0oooo0=`0oooo1P00003i0?ooo`400000001F0?ooo`030000003oool0oooo
0>80oooo1P00003c0?ooo`400000001F0?ooo`030000003oool0oooo0>P0oooo2000003[0?ooo`40
0000001F0?ooo`030000003oool0oooo0?00oooo2P00003Q0?ooo`400000001F0?ooo`030000003o
ool0oooo0?X0oooo2P00003G0?ooo`400000001F0?ooo`030000003oool0oooo0?l0oooo1@3oool9
00000<h0oooo0@00000005H0oooo00<000000?ooo`3oool0o`3oool>0?ooo`T00000a@3oool10000
0000EP3oool00`000000oooo0?ooo`3o0?oooaL0oooo2P00002k0?ooo`400000001F0?ooo`030000
003oool0oooo0?l0oooo8@3oool?00000:`0oooo0@00000005H0oooo00<000000?ooo`3oool0o`3o
ool`0?oooa800000VP3oool100000000EP3oool00`000000oooo0?ooo`3o0?oood80oooo4`000027
0?ooo`40000000190?ooo`<000002P3oool00`000000oooo0?ooo`3o0?oooeD0oooo9P00001Q0?oo
o`400000001:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooomk0?ooobL0
0000>P3oool100000000BP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo
XP3oool_000000/0oooo0@00000003h0oooo1`0000050?ooo`030000003oool0oooo00T0oooo1000
003o0?ooomP0oooo1000000004X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o
0?ooom`0oooo0@00000004X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?oo
om`0oooo0@00000004X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo06l0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1^0?ooo`03
0000003oool0oooo06l0oooo00<000000?ooo`3oool02@3oool100000000BP3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00T0oooo0@00000004T0oooo0P00000;0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00T0oooo0@00000004X0oooo00<000000?ooo`3oool02@3ooooo00000>000000003o0?oo
ool0oooo=`3oool00?l0ooooo`3ooolg0?ooo`00o`3ooooo0?ooocL0oooo003o0?ooool0oooo=`3o
ool00?l0ooooo`3ooolg0?ooo`00o`3ooooo0?ooocL0oooo003o0?ooool0oooo=`3oool00001\
\>"],
  ImageRangeCache->{{{0, 564.25}, {348.375, 0}} -> {-0.429151, -1.00001, \
0.0043947, 3.24004*^-08}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ \(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(\
--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(-\(---\)\)\)\)\)\)\)\)\)\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)*) \[IndentingNewLine]\[IndentingNewLine] \
(*\ Quintom\ \(model : \ 
            Find\ w \((z)\)\ for\ given\ slope\ s\ of\ the\ linear\ potential \
. \ Present\ time\)\  = \ \(tt\ \((corresponds\ to\ a = 1)\) . \ 
              Run\ trials\ for\ initial\ condition\ for\ field\ fi\ \((f0)\)\ \
and\ initial\ time\ ti\ until\ we\ get\ field\ energy\ enf\  = \ \(0.7\ and\ \
H \((z = 0)\)\  = 
            1\ at\ present\ time\ \(\(tt\)\(.\)\)\)\)\ *) \[IndentingNewLine] \
(*\ \(--\(--\(--\(--\ \ s\)\)\)\)\  = \ \(\(\(0.2\ \ \ --\)--\) 
            q = \(\(0.05--\)--\) \(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(\
--\(--\(--\(--\(---\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\ *) \
\[IndentingNewLine]\(Clear[aa, fi, a, aad, aadd, fidas, tas, f, rr, hht, 
        hha];\)\), "\n", 
    \(aa = a[t]; \ fi1 = f1[t]; \ fi2 = f2[t];\), "\n", 
    \(\(aad = D[aa, t];\)\), "\n", 
    \(\(aadd = D[aa, {t, 2}];\)\), "\n", 
    \(fi1d = D[fi1, t]; \ fi2d = D[fi2, t];\), "\n", 
    \(fi1dd = D[fi1, {t, 2}]; \ fi2dd = D[fi2, {t, 2}];\), "\n", 
    \(ti = 0.00001; \ t0 = 4.3; \ f0 = 1.47;\), "\n", 
    \(om0m = 0.3; \ ss = 0.2; \ q = 0.05;\), "\n", 
    \(\(eq1 = 
        aadd/aa\  \[Equal] \ \(-fi1d^2\)\ \  + fi2d^2\ \  + ss\ fi1\  + 
            ss\ fi2\  + q\ fi1\ fi2 - \ om0m/\((2\ aa^3)\);\)\), "\n", 
    \(\(eq2 = 
        fi1dd\ \  + \ \ \ 3\ \ fi1d\ \((aad/aa)\)\  + \ ss\  + \ 
            q\ fi2 \[Equal] 0;\)\), "\n", 
    \(\(eq3 = 
        fi2dd\ \  + \ \ \ 3\ \ fi2d\ \((aad/aa)\)\  - \ ss\  - \ 
            q\ fi1 \[Equal] 0;\)\), "\n", 
    \(\(eqb1 = f1[ti] == f0;\)\), "\n", 
    \(\(eqb2 = \(f1'\)[ti] == 0;\)\), "\n", 
    \(\(eqb3 = f2[ti] \[Equal] f0;\)\), "\n", 
    \(\(eqb4 = \(f2'\)[ti] == 0;\)\), "\n", 
    \(\(eqb5 = 
        a[ti] \[Equal] \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((2/3)\);\)\), "\n", 
    \(\(eqb6 = \(a'\)[
            ti] \[Equal] \((2/
                3)\)\ \((9\ om0m/4)\)^\((1/3)\)\ \ ti^\((\(-1\)/
                  3)\);\)\), "\n", 
    \(\(sol2 = 
        NDSolve[{eq1, eq2, eq3, eqb1, eqb2, eqb3, eqb4, eqb5, eqb6}, {aa, 
            fi1, fi2}, {t, ti, t0}, MaxSteps \[Rule] 10000000];\)\), "\n", 
    \(\(asol = Part[Evaluate[a[t] /. sol2], 1];\)\), "\n", 
    \(\(f1sol = Part[Evaluate[f1[t] /. sol2], 1];\)\), "\n", 
    \(\(f2sol = 
        Part[Evaluate[f2[t] /. sol2], 1];\)\), "\[IndentingNewLine]", 
    \(\(df1sol = D[f1sol, t];\)\), "\[IndentingNewLine]", 
    \(\(df2sol = D[f2sol, t];\)\), "\[IndentingNewLine]", 
    \(\(enf = 
        0.5\ df1sol^2\  - 0.5\ df2sol^2\  + \ ss\ f1sol + \ ss\ f2sol\  + \ 
          q\ f1sol\ f2sol;\)\), "\n", 
    \(\(ppf = 
        0.5\ df1sol^2\  - 0.5\ df2sol^2\  - \ ss\ f1sol - \ ss\ f2sol\  - \ 
          q\ f1sol\ f2sol;\)\), "\n", 
    \(\(wft[t1_] := ppf/enf\  /. \ t -> t1\ ;\)\ \), "\[IndentingNewLine]", 
    \(\(as[t1_] := asol\  /. \ t -> t1\ ;\)\), "\[IndentingNewLine]", 
    \(\(tt = Part[FindRoot[as[t] == 1, {t, 0.1}], 1, 2];\)\), "\n", 
    \(\(tas[a_] := 
        Part[FindRoot[as[t] \[Equal] a, {t, 0.3}], 1, 2];\)\), "\n", 
    \(\(hht[t1_] := D[asol, t]/asol\  /. \ t -> t1\ ;\)\), "\n", 
    \(\(hha[a_] := hht[tas[a]];\)\), "\n", 
    \(\(hhz[z_] := hha[1/\((z + 1)\)];\)\), "\n", 
    \(enf\  /. \ t \[Rule] tt\), "\n", 
    \(hhz[0]\), "\[IndentingNewLine]", 
    \(\(wfa[a_] := wft[tas[a]];\)\), "\n", 
    \(\(wfz[z_] := wfa[1/\((z + 1)\)];\)\), "\n", 
    \(\(plpl = 
        Plot[wfz[z], {z, 0, 2}, Frame \[Rule] True, PlotRange \[Rule] All, 
          FrameLabel \[Rule] {"\<z\>", "\<w(z)\>"}];\)\), \
"\[IndentingNewLine]", 
    \(\(hhzt = 
        Sqrt[\((1 - om0m)\) + om0m \((1 + z)\)^3] /. 
          om0m \[Rule] 0.3;\)\)}], "Input"],

Cell[BoxData[
    \(0.6959729144008228`\)], "Output"],

Cell[BoxData[
    \(1.0003173660239688`\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.476191 4164.3 4164.29 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.2619 -0.0125 -10.7813 -17.8125 ]
[.2619 -0.0125 10.7813 0 ]
[.5 -0.0125 -5.53125 -17.8125 ]
[.5 -0.0125 5.53125 0 ]
[.7381 -0.0125 -10.7813 -17.8125 ]
[.7381 -0.0125 10.7813 0 ]
[.97619 -0.0125 -5.53125 -17.8125 ]
[.97619 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.125 -35.625 ]
[.5 -0.0125 5.125 -17.8125 ]
[-0.0125 .01197 -20.75 -8.90625 ]
[-0.0125 .01197 0 8.90625 ]
[-0.0125 .09525 -59.5 -8.90625 ]
[-0.0125 .09525 0 8.90625 ]
[-0.0125 .17854 -59.5 -8.90625 ]
[-0.0125 .17854 0 8.90625 ]
[-0.0125 .26182 -59.5 -8.90625 ]
[-0.0125 .26182 0 8.90625 ]
[-0.0125 .34511 -59.5 -8.90625 ]
[-0.0125 .34511 0 8.90625 ]
[-0.0125 .4284 -52.4375 -8.90625 ]
[-0.0125 .4284 0 8.90625 ]
[-0.0125 .51168 -59.5 -8.90625 ]
[-0.0125 .51168 0 8.90625 ]
[-0.0125 .59497 -59.5 -8.90625 ]
[-0.0125 .59497 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -77.3125 -14.7188 ]
[-0.01875 .30902 -59.5 14.7188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.125 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01197 m
.00625 .01197 L
s
gsave
-0.0125 .01197 -81.75 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .09525 m
.00625 .09525 L
s
gsave
-0.0125 .09525 -120.5 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.99998) show
1.000 setlinewidth
grestore
0 .17854 m
.00625 .17854 L
s
gsave
-0.0125 .17854 -120.5 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.99996) show
1.000 setlinewidth
grestore
0 .26182 m
.00625 .26182 L
s
gsave
-0.0125 .26182 -120.5 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.99994) show
1.000 setlinewidth
grestore
0 .34511 m
.00625 .34511 L
s
gsave
-0.0125 .34511 -120.5 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.99992) show
1.000 setlinewidth
grestore
0 .4284 m
.00625 .4284 L
s
gsave
-0.0125 .4284 -113.438 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9999) show
1.000 setlinewidth
grestore
0 .51168 m
.00625 .51168 L
s
gsave
-0.0125 .51168 -120.5 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.99988) show
1.000 setlinewidth
grestore
0 .59497 m
.00625 .59497 L
s
gsave
-0.0125 .59497 -120.5 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.99986) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03279 m
.00375 .03279 L
s
0 .05361 m
.00375 .05361 L
s
0 .07443 m
.00375 .07443 L
s
0 .11607 m
.00375 .11607 L
s
0 .1369 m
.00375 .1369 L
s
0 .15772 m
.00375 .15772 L
s
0 .19936 m
.00375 .19936 L
s
0 .22018 m
.00375 .22018 L
s
0 .241 m
.00375 .241 L
s
0 .28265 m
.00375 .28265 L
s
0 .30347 m
.00375 .30347 L
s
0 .32429 m
.00375 .32429 L
s
0 .36593 m
.00375 .36593 L
s
0 .38675 m
.00375 .38675 L
s
0 .40757 m
.00375 .40757 L
s
0 .44922 m
.00375 .44922 L
s
0 .47004 m
.00375 .47004 L
s
0 .49086 m
.00375 .49086 L
s
0 .5325 m
.00375 .5325 L
s
0 .55332 m
.00375 .55332 L
s
0 .57415 m
.00375 .57415 L
s
0 .61579 m
.00375 .61579 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -144.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.7188 12.9063 translate
90 rotate
-75.7188 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.063 17.500 moveto
(H) show
77.625 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.875 17.500 moveto
(L) show
88.438 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01197 m
1 .01197 L
s
.99375 .09525 m
1 .09525 L
s
.99375 .17854 m
1 .17854 L
s
.99375 .26182 m
1 .26182 L
s
.99375 .34511 m
1 .34511 L
s
.99375 .4284 m
1 .4284 L
s
.99375 .51168 m
1 .51168 L
s
.99375 .59497 m
1 .59497 L
s
.125 Mabswid
.99625 .03279 m
1 .03279 L
s
.99625 .05361 m
1 .05361 L
s
.99625 .07443 m
1 .07443 L
s
.99625 .11607 m
1 .11607 L
s
.99625 .1369 m
1 .1369 L
s
.99625 .15772 m
1 .15772 L
s
.99625 .19936 m
1 .19936 L
s
.99625 .22018 m
1 .22018 L
s
.99625 .241 m
1 .241 L
s
.99625 .28265 m
1 .28265 L
s
.99625 .30347 m
1 .30347 L
s
.99625 .32429 m
1 .32429 L
s
.99625 .36593 m
1 .36593 L
s
.99625 .38675 m
1 .38675 L
s
.99625 .40757 m
1 .40757 L
s
.99625 .44922 m
1 .44922 L
s
.99625 .47004 m
1 .47004 L
s
.99625 .49086 m
1 .49086 L
s
.99625 .5325 m
1 .5325 L
s
.99625 .55332 m
1 .55332 L
s
.99625 .57415 m
1 .57415 L
s
.99625 .61579 m
1 .61579 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .60332 m
.06244 .45889 L
.10458 .34234 L
.14415 .26175 L
.18221 .20373 L
.22272 .15752 L
.26171 .12425 L
.30316 .09776 L
.34309 .07861 L
.3815 .06457 L
.42237 .05315 L
.46172 .04472 L
.49955 .0384 L
.53984 .03314 L
.57861 .02917 L
.61984 .02585 L
.65954 .02333 L
.69774 .02138 L
.73838 .01972 L
.77751 .01843 L
.81909 .01732 L
.85916 .01645 L
.89771 .01577 L
.93871 .01517 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{596.188, 368.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L2000`400?l00000o`00003oo`3ooooo
0?oooeH0oooo003o0?ooool0ooooEP3oool00?l0ooooo`3ooomF0?ooo`00o`3ooooo0?oooeH0oooo
003o0?ooool0ooooEP3oool00?l0ooooo`3ooomF0?ooo`00o`3ooooo0?oooeH0oooo003o0?ooool0
ooooEP3oool00?l0ooooo`3ooomF0?ooo`00o`3ooooo0?oooeH0oooo003o0?ooool0ooooEP3oool0
0?l0ooooDP3oool600000?d0oooo003o0?oooe<0oooo00D000000?ooo`3oool0oooo0000003m0?oo
o`00o`3ooomD0?ooo`030000003oool0oooo0?h0oooo003o0?oooe@0oooo00<000000?ooo`3oool0
oP3oool00?l0ooooE@3oool00`000000oooo0?ooo`3m0?ooo`00o`3ooomB0?ooo`050000003oool0
oooo0?ooo`000000oP3oool00?l0ooooDP3oool600000?d0oooo003o0?ooool0ooooEP3oool00?l0
ooooo`3ooomF0?ooo`00o`3ooooo0?oooeH0oooo003o0?ooool0ooooEP3oool00?l0ooooo`3ooomF
0?ooo`00o`3ooooo0?oooeH0oooo003o0?ooool0ooooEP3oool00?l0ooooo`3ooomF0?ooo`00o`3o
oooo0?oooeH0oooo003o0?ooool0ooooEP3oool00?l0ooooo`3ooomF0?ooo`00H@3oool300000740
oooo0`0000030?ooo`040000003oool0oooo0?ooo`<00000L@3oool300000740oooo0`0000030?oo
o`040000003oool0oooo0?ooo`<00000L03oool5000000/0oooo001P0?ooo`050000003oool0oooo
0?ooo`000000K`3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0K`3o
ool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0KP3o
ool010000000oooo0?ooo`00000;0?ooo`00H03oool01@000000oooo0?ooo`3oool0000006l0oooo
00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3o
ool0L@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3o
ool02`3oool00600oooo00D000000?ooo`3oool0oooo0000001_0?ooo`050000003oool0oooo0?oo
o`0000002P3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo0740oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00X0oooo001P0?ooo`05
0000003oool0oooo0?ooo`000000K`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<00000
0?ooo`3oool0KP3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0K`3oool00`000000oooo0?ooo`0:0?ooo`00H03oool01@000000oooo0?ooo`3oool0
000006l0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo06l0oooo00<0
00000?ooo`3oool0L@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool02@3oool00600oooo00D000000?ooo`3oool0oooo0000001_0?ooo`050000003o
ool0oooo0?ooo`0000001P3oool300000780oooo00<000000?ooo`3oool0L@3oool00`000000oooo
0?ooo`060?ooo`<00000M03oool00`000000oooo0?ooo`090?ooo`00H03oool01@000000oooo0?oo
o`3oool0000006l0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo07@0
oooo00<000000?ooo`3oool02@3oool00600oooo00D000000?ooo`3oool0oooo0000001_0?ooo`05
0000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`1`0?ooo`800000LP3oool20000
00T0oooo00<000000?ooo`3oool0K`3oool01@000000oooo0?ooo`3oool0000000/0oooo001Q0?oo
o`<00000L@3oool3000000P0oooo1000001`0?ooo`030000003oool0oooo0740oooo00<000000?oo
o`3oool01`3oool4000006l0oooo0`00000<0?ooo`00o`3ooooo0?oooeH0oooo003o0?ooool0oooo
EP3oool00?l0ooooo`3ooomF0?ooo`00o`3ooooo0?oooeH0oooo003o0?ooool0ooooEP3oool00?l0
ooooo`3ooomF0?ooo`00o`3ooooo0?oooeH0oooo003o0?ooool0ooooEP3oool00?l0ooooo`3ooomF
0?ooo`00EP3ooooo00000?l00000001F0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00X0oooo0@00000004T0oooo
0`00000:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo00X0oooo0@00000004X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0MP3o
ool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool02P3o
ool100000000BP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooon`3oool1
00000000?P3oool7000000D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?oo
oo/0oooo0@00000004X0oooo00<000000?ooo`3oool02@3oool500000?l0oooom@3oool500000000
BP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooodP3ooolM000000`0oooo
0@00000004X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?oooiD0oooo?@00
000Y0?ooo`400000001:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooon0
0?oooaD00000IP3oool100000000B@3oool2000000/0oooo00<000000?ooo`3oool0o`3ooom/0?oo
oa@00000N`3oool100000000BP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0
ooooF03ooolD000008l0oooo0@00000005H0oooo00<000000?ooo`3oool0o`3ooom40?oooa@00000
X`3oool100000000EP3oool00`000000oooo0?ooo`3o0?oooc@0oooo4000002g0?ooo`400000001F
0?ooo`030000003oool0oooo0?l0oooo:P3oool:00000<L0oooo0@00000005H0oooo00<000000?oo
o`3oool0o`3ooolP0?ooo`X00000d@3oool100000000EP3oool300000?l0oooo5P3oool:00000=T0
oooo0`00000005H0oooo00<000000?ooo`3oool0o`3oool<0?ooo`X00000i@3oool100000000EP3o
ool00`000000oooo0?ooo`3o0?ooo`80oooo2P00003_0?ooo`400000001F0?ooo`030000003oool0
oooo0?P0oooo2@00003i0?ooo`400000001F0?ooo`030000003oool0oooo0?80oooo1P00003o0?oo
o`<0oooo0@00000005H0oooo00<000000?ooo`3oool0k03oool600000?l0oooo2@3oool100000000
EP3oool00`000000oooo0?ooo`3W0?ooo`D00000o`3oool?0?ooo`400000001F0?ooo`030000003o
ool0oooo0><0oooo1000003o0?oooa@0oooo0@00000005H0oooo00<000000?ooo`3oool0g`3oool4
00000?l0oooo603oool100000000EP3oool00`000000oooo0?ooo`3K0?ooo`@00000o`3ooolL0?oo
o`400000001F0?ooo`030000003oool0oooo0=L0oooo1000003o0?ooob00oooo0@00000005H0oooo
0`00003C0?ooo`@00000o`3ooolR0?ooo`<00000001F0?ooo`030000003oool0oooo0<l0oooo1000
003o0?ooobP0oooo0@00000005H0oooo00<000000?ooo`3oool0c03oool300000?l0oooo;03oool1
00000000EP3oool00`000000oooo0?ooo`380?ooo`@00000o`3oool_0?ooo`400000001F0?ooo`03
0000003oool0oooo0<D0oooo0`00003o0?oooc<0oooo0@00000005H0oooo00<000000?ooo`3oool0
`@3oool400000?l0oooo=P3oool100000000EP3oool00`000000oooo0?ooo`2n0?ooo`<00000o`3o
oolj0?ooo`400000001F0?ooo`030000003oool0oooo0;/0oooo0`00003o0?ooocd0oooo0@000000
05H0oooo00<000000?ooo`3oool0^@3oool200000?l0oooo@03oool100000000EP3oool00`000000
oooo0?ooo`2f0?ooo`<00000o`3ooom20?ooo`400000001F0?ooo`030000003oool0oooo0;<0oooo
0`00003o0?ooodD0oooo0@00000005H0oooo0`00002a0?ooo`800000o`3ooom60?ooo`<00000001F
0?ooo`030000003oool0oooo0:h0oooo0`00003o0?ooodX0oooo0@00000005H0oooo00<000000?oo
o`3oool0Z`3oool300000?l0ooooC@3oool100000000EP3oool00`000000oooo0?ooo`2Y0?ooo`80
0000o`3ooom@0?ooo`400000001F0?ooo`030000003oool0oooo0:L0oooo0P00003o0?oooe80oooo
0@00000005H0oooo00<000000?ooo`3oool0Y03oool300000?l0ooooE03oool100000000EP3oool0
0`000000oooo0?ooo`2R0?ooo`800000o`3ooomG0?ooo`400000000R0?ooo`<000000`3oool01000
0000oooo0?ooo`3oool2000000D0oooo0P0000050?ooo`8000001@3oool2000000H0oooo0`00000:
0?ooo`030000003oool0oooo0:00oooo0P00003o0?oooeT0oooo0@0000000240oooo00D000000?oo
o`3oool0oooo000000080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00090?ooo`030000003oool0oooo09d0oooo0`00003o0?oooe/0oooo0@0000000240oooo00D00000
0?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo09/0oooo0P00003o0?oooeh0oooo0@00000001P0oooo1`00
00020?ooo`050000003oool0oooo0?ooo`0000001`3oool4000000<0oooo100000030?ooo`@00000
0`3oool400000080oooo00D000000?ooo`3oool0oooo000000090?ooo`D00000U`3oool200000?l0
ooooG03oool5000000008@3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0000000X0oooo
00<000000?ooo`3oool0U`3oool200000?l0ooooHP3oool1000000008@3oool01@000000oooo0?oo
o`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?oo
o`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0U@3oool200000?l0ooooI03o
ool1000000008@3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0000000X0oooo00<00000
0?ooo`3oool0U03oool00`000000oooo0?ooo`3o0?ooof@0oooo0@0000000240oooo00D000000?oo
o`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0TP3oool2
00000?l0ooooI`3oool1000000008@3oool01@000000oooo0?ooo`3oool0000000H0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo
0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo
0?ooo`0000002@3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0?l0ooooI`3oool1
000000008P3oool3000000P0oooo0`0000040?ooo`<00000103oool3000000@0oooo0`0000040?oo
o`<000002P3oool00`000000oooo0?ooo`2?0?ooo`800000o`3ooomZ0?ooo`400000001F0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0o`3ooomZ0?ooo`400000001F0?ooo`030000
003oool0oooo08`0oooo0P00003o0?ooofd0oooo0@00000005H0oooo00<000000?ooo`3oool0R`3o
ool00`000000oooo0?ooo`3o0?ooofd0oooo0@00000005H0oooo00<000000?ooo`3oool0R@3oool2
00000?l0ooooL03oool100000000EP3oool3000008P0oooo00<000000?ooo`3oool0o`3ooom^0?oo
o`<00000001F0?ooo`030000003oool0oooo08H0oooo0P00003o0?ooog<0oooo0@00000005H0oooo
00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`3o0?ooog<0oooo0@00000005H0oooo00<0
00000?ooo`3oool0P`3oool200000?l0ooooMP3oool100000000EP3oool00`000000oooo0?ooo`22
0?ooo`030000003oool0oooo0?l0ooooMP3oool100000000EP3oool00`000000oooo0?ooo`210?oo
o`030000003oool0oooo0?l0ooooM`3oool100000000EP3oool00`000000oooo0?ooo`200?ooo`03
0000003oool0oooo0?l0ooooN03oool100000000EP3oool00`000000oooo0?ooo`1o0?ooo`030000
003oool0oooo0?l0ooooN@3oool100000000EP3oool00`000000oooo0?ooo`1m0?ooo`800000o`3o
ooml0?ooo`400000001F0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0o`3oooml
0?ooo`400000001F0?ooo`<00000N`3oool00`000000oooo0?ooo`3o0?ooog/0oooo0`00000005H0
oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`3o0?ooogh0oooo0@00000005H0oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`3o0?ooogl0oooo0@00000005H0oooo00<0
00000?ooo`3oool0N03oool00`000000oooo0?ooo`3o0?oooh00oooo0@00000005H0oooo00<00000
0?ooo`3oool0M`3oool00`000000oooo0?ooo`3o0?oooh40oooo0@00000005H0oooo00<000000?oo
o`3oool0MP3oool00`000000oooo0?ooo`3o0?oooh80oooo0@00000005H0oooo00<000000?ooo`3o
ool0M@3oool00`000000oooo0?ooo`3o0?oooh<0oooo0@00000005H0oooo00<000000?ooo`3oool0
L`3oool200000?l0ooooQP3oool100000000EP3oool00`000000oooo0?ooo`1b0?ooo`030000003o
ool0oooo0?l0ooooQP3oool100000000EP3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0
oooo0?l0ooooQ`3oool100000000EP3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo
0?l0ooooR03oool100000000EP3oool3000006l0oooo00<000000?ooo`3oool0o`3ooon70?ooo`<0
0000001F0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0o`3ooon:0?ooo`400000
001F0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0o`3ooon;0?ooo`400000001F
0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0o`3ooon<0?ooo`400000001F0?oo
o`030000003oool0oooo06/0oooo00<000000?ooo`3oool0o`3ooon=0?ooo`400000001F0?ooo`03
0000003oool0oooo06X0oooo00<000000?ooo`3oool0o`3ooon>0?ooo`400000001F0?ooo`030000
003oool0oooo06X0oooo00<000000?ooo`3oool0o`3ooon>0?ooo`400000000R0?ooo`<000000`3o
ool010000000oooo0?ooo`3oool2000000D0oooo0P0000050?ooo`8000001@3oool2000000H0oooo
0`00000:0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0o`3ooon?0?ooo`400000
000Q0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo0?l0
ooooT03oool1000000008@3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`3o0?oooi40oooo0@00000001P0oooo1`0000020?ooo`050000003oool0oooo0?oo
o`0000001`3oool4000000<0oooo100000030?ooo`@000000`3oool400000080oooo00D000000?oo
o`3oool0oooo000000090?ooo`D00000I03oool00`000000oooo0?ooo`3o0?ooohh0oooo1@000000
0240oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool0I@3oool00`000000oooo0?ooo`3o0?oooi<0oooo0@0000000240oooo00D000000?oo
o`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?oo
o`0000000P3oool200000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1T0?oo
o`030000003oool0oooo0?l0ooooU03oool1000000008@3oool01@000000oooo0?ooo`3oool00000
00H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool00000000000X0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`3o0?oo
oiD0oooo0@0000000240oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0680oooo00<000000?ooo`3oool0o`3ooonF0?ooo`400000000Q0?ooo`050000
003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1Q0?ooo`030000
003oool0oooo0?l0ooooU`3oool1000000008P3oool3000000P0oooo0`0000040?ooo`<00000103o
ool3000000@0oooo0`0000060?ooo`8000002@3oool00`000000oooo0?ooo`1P0?ooo`030000003o
ool0oooo0?l0ooooV03oool100000000EP3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0
oooo0?l0ooooV@3oool100000000EP3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo
0?l0ooooV@3oool100000000EP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0?l0
ooooVP3oool100000000EP3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0?l0oooo
V`3oool100000000EP3oool3000005`0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`<00000001F
0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0o`3ooonM0?ooo`400000001F0?oo
o`030000003oool0oooo05X0oooo00<000000?ooo`3oool0o`3ooonN0?ooo`400000001F0?ooo`03
0000003oool0oooo05T0oooo00<000000?ooo`3oool0o`3ooonO0?ooo`400000001F0?ooo`030000
003oool0oooo05T0oooo00<000000?ooo`3oool0o`3ooonO0?ooo`400000001F0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool0o`3ooonP0?ooo`400000001F0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool0o`3ooonQ0?ooo`400000001F0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool0o`3ooonQ0?ooo`400000001F0?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool0o`3ooonR0?ooo`400000001F0?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool0o`3ooonR0?ooo`400000001F0?ooo`030000003oool0oooo05D0oooo00<0
00000?ooo`3oool0o`3ooonS0?ooo`400000001F0?ooo`<00000E03oool00`000000oooo0?ooo`3o
0?oooj80oooo0`00000005H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3o0?oo
oj@0oooo0@00000005H0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`3o0?ooojD0
oooo0@00000005H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`3o0?ooojH0oooo
0@00000005H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`3o0?ooojH0oooo0@00
000005H0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`3o0?ooojL0oooo0@000000
05H0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`3o0?ooojP0oooo0@00000005H0
oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`3o0?ooojP0oooo0@00000005H0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`3o0?ooojT0oooo0@00000005H0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`3o0?ooojT0oooo0@00000005H0oooo0`00001>
0?ooo`030000003oool0oooo0?l0ooooZ03oool300000000EP3oool00`000000oooo0?ooo`1=0?oo
o`030000003oool0oooo0?l0ooooZ`3oool100000000EP3oool00`000000oooo0?ooo`1=0?ooo`03
0000003oool0oooo0?l0ooooZ`3oool100000000EP3oool00`000000oooo0?ooo`1<0?ooo`030000
003oool0oooo0?l0oooo[03oool100000000EP3oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo0?l0oooo[@3oool100000000EP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0
oooo0?l0oooo[@3oool100000000EP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo
0?l0oooo[P3oool1000000008P3oool3000000<0oooo00@000000?ooo`3oool0oooo0P0000050?oo
o`8000001@3oool2000000D0oooo0P0000080?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`3o0?ooojh0oooo0@0000000240oooo00D000000?ooo`3o
ool0oooo000000080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo0?l0oooo[`3oool1000000008@3oool01@000000
oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo04P0oooo00<000000?ooo`3oool0o`3ooon`0?ooo`400000000H0?ooo`L0
00000P3oool01@000000oooo0?ooo`3oool0000000L0oooo100000030?ooo`@000000`3oool40000
00<0oooo100000000`3oool0000000000004000000T0oooo00<000000?ooo`3oool0B03oool00`00
0000oooo0?ooo`3o0?oook00oooo0@0000000240oooo00D000000?ooo`3oool0oooo000000060?oo
o`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D0
00000?ooo`3oool0oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?oo
o`030000003oool0oooo00P0oooo1@0000150?ooo`030000003oool0oooo0?l0oooo[@3oool50000
00008@3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000X0oooo00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`3o0?oook80oooo0@0000000240oooo00D000000?ooo`3o
ool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0000000:0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool0o`3ooonb0?ooo`400000000Q0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000
oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`000000
2P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0?l0oooo/`3oool1000000008@3o
ool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D00000
0?ooo`3oool0oooo000000040?ooo`8000002P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo0?l0oooo/`3oool1000000008P3oool3000000P0oooo0`0000040?ooo`<00000103oool3
000000@0oooo0`0000060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`3o0?oook@0oooo0@00000005H0oooo00<000000?ooo`3oool0A03oool00`00
0000oooo0?ooo`3o0?oook@0oooo0@00000005H0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`3o0?oookD0oooo0@00000005H0oooo00<000000?ooo`3oool0@`3oool00`000000oooo
0?ooo`3o0?oookD0oooo0@00000005H0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`3o0?oookH0oooo0@00000005H0oooo0`0000120?ooo`030000003oool0oooo0?l0oooo]03oool3
00000000EP3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0?l0oooo]`3oool10000
00001P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool0o`3ooong0?ooo`40000000060?ooo`<00000C@3oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo0?l0oooo^03oool1000000001P3oool00`000000oooo0?ooo`03000004X0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`3o0?oookP0oooo0@00000000/0oooo0P000019
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0o`3oooni0?ooo`40000000060?oo
o`030000003oool0oooo00800000B`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
0?l0oooo^@3oool1000000001P3oool3000004d0oooo00<000000?ooo`3oool0?P3oool00`000000
oooo0?ooo`3o0?oookX0oooo0@00000000H0oooo00<000000?ooo`3oool00`00001:0?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool0o`3ooonj0?ooo`400000000;0?ooo`800000B@3o
ool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0?l0oooo^`3oool1000000001P3oool0
0`000000oooo0?ooo`02000004/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`3o
0?oook/0oooo0@00000000H0oooo0`00001=0?ooo`<00000?03oool00`000000oooo0?ooo`3o0?oo
okX0oooo0`00000000H0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo0?l0oooo_03oool1000000001@3oool9000004P0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`3o0?oookd0oooo0@00000000@0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3o
oonm0?ooo`40000000030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0?l0oooo_P3oool100000000EP3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo0?l0oooo_P3oool1000000001P3oool2000000@0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0?l0
oooo_`3oool1000000001P3oool00`000000oooo0?ooo`020?ooo`800000B@3oool00`000000oooo
0?ooo`0i0?ooo`030000003oool0oooo0?l0oooo_`3oool1000000001P3oool00`000000oooo0?oo
o`02000000030?ooo`000000oooo04P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`3o0?oool00oooo0@00000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`17
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0o`3oooo00?ooo`40000000060?oo
o`800000103oool00`000000oooo0?ooo`170?ooo`<00000=`3oool00`000000oooo0?ooo`3o0?oo
okl0oooo0`00000000H0oooo00<000000?ooo`3oool00P3oool2000004T0oooo00<000000?ooo`3o
ool0=`3oool00`000000oooo0?ooo`3o0?oool40oooo0@00000000<0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0
o`3oooo20?ooo`40000000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0?l0oooo`P3oool1000000001@3oool9
000004P0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`3o0?oool<0oooo0@000000
05H0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`3o0?oool<0oooo0@00000005H0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`3o0?oool@0oooo0@0000000280oooo
0`0000030?ooo`040000003oool0oooo0?ooo`8000001@3oool2000000D0oooo0P0000050?ooo`80
00001@3oool5000000T0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`3o0?oool@0
oooo0@0000000240oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
0?l0ooooa@3oool1000000008@3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03<0oooo00<000000?oo
o`3oool0o`3oooo50?ooo`400000000H0?ooo`L000000P3oool01@000000oooo0?ooo`3oool00000
00L0oooo100000030?ooo`@000000`3oool4000000<0oooo100000050?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`3o0?ooolH0oooo0@0000000240
oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`080?ooo`D00000<03oool00`000000
oooo0?ooo`3o0?oool80oooo1@0000000240oooo00D000000?ooo`3oool0oooo000000060?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D00000
0?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0o`3oooo70?ooo`400000
000Q0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool000000080
oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo0?l0ooooa`3oool1000000008@3oool01@000000oooo0?ooo`3o
ool0000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo00000006
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`3o
0?ooolL0oooo0@0000000240oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0
oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
000000T0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`3o0?ooolP0oooo0@000000
0280oooo0`0000080?ooo`<00000103oool3000000@0oooo0`0000040?ooo`<00000103oool30000
00X0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`3o0?ooolP0oooo0@00000005H0
oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`3o0?ooolP0oooo0@00000005H0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`3o0?ooolT0oooo0@00000005H0oooo00<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`3o0?ooolT0oooo0@00000005H0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`3o0?ooolX0oooo0@00000005H0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`3o0?ooolX0oooo0@00000005H0oooo0`00000^0?ooo`03
0000003oool0oooo0?l0oooob03oool300000000EP3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo0?l0oooob`3oool100000000EP3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo0?l0oooob`3oool100000000EP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo0?l0oooob`3oool100000000EP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
0?l0ooooc03oool100000000EP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0?l0
ooooc03oool100000000EP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0?l0oooo
c03oool100000000EP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0ooooc@3o
ool100000000EP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0ooooc@3oool1
00000000EP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0ooooc@3oool10000
0000EP3oool3000002X0oooo00<000000?ooo`3oool0o`3oooo<0?ooo`<00000001F0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0o`3oooo>0?ooo`400000001F0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`400000001F0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`400000001F0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`400000001F0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool0o`3oooo@0?ooo`400000001F0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0o`3oooo@0?ooo`400000001F0?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0o`3oooo@0?ooo`400000001F0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0o`3ooooA0?ooo`400000001F0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool0o`3ooooA0?ooo`400000001F0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool0o`3ooooA0?ooo`400000001F0?ooo`<000009P3oool00`000000oooo0?ooo`3o0?ooom00oooo
0`00000005H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3o0?ooom80oooo0@00
000005H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3o0?ooom80oooo0@000000
05H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3o0?ooom<0oooo0@00000005H0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3o0?ooom<0oooo0@00000005H0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`3o0?ooom@0oooo0@00000005H0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`3o0?ooom@0oooo0@00000002T0oooo0`000003
0?ooo`040000003oool0oooo0?ooo`8000001@3oool2000000D0oooo0P0000050?ooo`800000303o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0?l0ooooe03oool100000000:03oool0
1@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo0?l0ooooe@3oool100000000:03oool01@000000oooo0?ooo`3o
ool0000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo0?l0ooooe@3oool1000000007`3oool700000080oooo00D000000?ooo`3oool0oooo0000
00070?ooo`@000000`3oool4000000<0oooo100000030?ooo`@000002@3oool500000240oooo00<0
00000?ooo`3oool0o`3ooooA0?ooo`D00000000X0?ooo`050000003oool0oooo0?ooo`0000001P3o
ool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`3o0?ooomH0oooo0@00000002P0oooo00D000000?oo
o`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?oo
o`0000002@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0?l0ooooeP3oool10000
0000:03oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo
00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool0o`3ooooF0?ooo`400000000X0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000
oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`3o0?ooomL0oooo0@00000002P0oooo00D000000?ooo`3oool0oooo
000000060?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000002@3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0ooooe`3oool100000000:@3oool3
000000P0oooo0`0000040?ooo`<00000103oool3000000@0oooo0`00000:0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool0o`3ooooG0?ooo`400000001F0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool0o`3ooooH0?ooo`400000001F0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool0o`3ooooH0?ooo`400000001F0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool0o`3ooooI0?ooo`400000001F0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0o`3ooooI0?ooo`400000001F0?ooo`<000007`3oool00`000000oooo0?ooo`3o
0?ooomL0oooo0`00000005H0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3o0?oo
omX0oooo0@00000005H0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3o0?ooomX0
oooo0@00000005H0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3o0?ooomX0oooo
0@00000005H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3o0?ooom/0oooo0@00
000005H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3o0?ooom/0oooo0@000000
05H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3o0?ooom/0oooo0@00000005H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`3o0?ooom`0oooo0@00000005H0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`3o0?ooom`0oooo0@00000005H0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`3o0?ooom`0oooo0@00000005H0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`3o0?ooom`0oooo0@00000005H0oooo0`00000K0?oo
o`030000003oool0oooo0?l0oooof`3oool300000000EP3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo0?l0oooog@3oool100000000EP3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo0?l0oooog@3oool100000000EP3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo0?l0oooog@3oool100000000EP3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo0?l0oooogP3oool100000000EP3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
0?l0oooogP3oool100000000EP3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0?l0
oooogP3oool100000000EP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0oooo
g`3oool100000000EP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0oooog`3o
ool100000000EP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0oooog`3oool1
00000000EP3oool3000001T0oooo00<000000?ooo`3oool0o`3ooooM0?ooo`<00000001F0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3ooooP0?ooo`400000001F0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0o`3ooooP0?ooo`400000001F0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0o`3ooooP0?ooo`400000001F0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0o`3ooooP0?ooo`400000001F0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0o`3ooooQ0?ooo`400000001F0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool0o`3ooooQ0?ooo`400000000R0?ooo`<000000`3oool010000000oooo
0?ooo`3oool2000000D0oooo0P0000050?ooo`8000001P3oool3000000@0oooo0`00000:0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0o`3ooooQ0?ooo`400000000Q0?ooo`050000
003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?oo
o`3oool0oooo000000090?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0o`3ooooR
0?ooo`400000000Q0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo0?l0oooohP3oool100000000603oool700000080oooo00D000000?ooo`3oool0oooo
000000070?ooo`@000000`3oool4000000<0oooo100000020?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`3o0?ooon80oooo0@0000000240oooo00D000000?ooo`3oool0oooo000000060?oo
o`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`000000
2P3oool5000001@0oooo00<000000?ooo`3oool0o`3ooooN0?ooo`D00000000Q0?ooo`050000003o
ool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3o
ool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3o
0?ooon<0oooo0@0000000240oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0
oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`0000002P3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0ooooh`3oool1000000008@3oool01@000000oooo
0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo0?l0ooooh`3oool1000000008@3oool01@000000oooo0?ooo`3oool0000000H0
oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0
ooooh`3oool1000000008P3oool3000000P0oooo0`0000040?ooo`<00000103oool3000000@0oooo
0`0000040?ooo`<000002P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0oooo
i03oool100000000EP3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0ooooi03o
ool100000000EP3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0ooooi03oool1
00000000EP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0ooooi@3oool10000
0000EP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0ooooi@3oool100000000
EP3oool3000001<0oooo00<000000?ooo`3oool0o`3ooooS0?ooo`<00000001F0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0o`3ooooU0?ooo`400000001F0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0o`3ooooV0?ooo`400000001F0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0o`3ooooV0?ooo`400000001F0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0o`3ooooV0?ooo`400000001F0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0o`3ooooW0?ooo`400000001F0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0o`3ooooW0?ooo`400000001F0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0o`3ooooW0?ooo`400000001F0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0o`3ooooW0?ooo`400000001F0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0o`3ooooX0?ooo`400000001F0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
o`3ooooX0?ooo`400000001F0?ooo`<00000403oool00`000000oooo0?ooo`3o0?ooonH0oooo0`00
000005H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?ooonP0oooo0@000000
05H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooonT0oooo0@00000005H0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooonT0oooo0@00000005H0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooonT0oooo0@00000005H0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?ooonX0oooo0@00000005H0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?ooonX0oooo0@00000005H0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`3o0?ooonX0oooo0@00000005H0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`3o0?ooonX0oooo0@00000005H0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`3o0?ooon/0oooo0@00000005H0oooo0`00000=0?ooo`030000003o
ool0oooo0?l0ooooj@3oool300000000EP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0?l0ooooj`3oool100000000EP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0?l0ooooj`3oool100000000EP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0
ooook03oool100000000EP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo
k03oool100000000EP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0ooook03o
ool100000000EP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooook@3oool1
000000008P3oool3000000<0oooo00@000000?ooo`3oool0oooo0P0000050?ooo`8000001@3oool2
000000H0oooo0`0000040?ooo`<000002P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo0?l0ooook@3oool1000000008@3oool01@000000oooo0?ooo`3oool0000000P0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0?l0ooook@3oool1000000008@3oool01@000000oooo0?oo
o`3oool0000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`050000
003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?ooond0oooo0@00000001P0
oooo1`0000020?ooo`050000003oool0oooo0?ooo`0000001`3oool4000000<0oooo100000030?oo
o`@000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000
00090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3oooo^0?ooo`400000000Q
0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool000000080oooo
00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo000000030?ooo`050000003oool0oooo0?ooo`0000002@3oool5000000P0oooo00<00000
0?ooo`3oool0o`3ooooZ0?ooo`D00000000Q0?ooo`050000003oool0oooo0?ooo`0000001P3oool0
1@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`8000000P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3oooo^0?ooo`40
0000000Q0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo000000030?ooo`040000003oool00000000000X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`3o0?ooonh0oooo0@0000000240oooo00D000000?ooo`3oool0oooo
000000060?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3o
ooo_0?ooo`400000000Q0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0ooook`3oool1000000008P3oool30000
00P0oooo0`0000040?ooo`<00000103oool3000000@0oooo0`0000060?ooo`8000002@3oool00`00
0000oooo0?ooo`3o0?oooo/0oooo0@00000005H0oooo00<000000?ooo`3oool0o`3ooook0?ooo`40
0000001F0?ooo`030000003oool0oooo0?l0oooon`3oool100000000EP3oool00`000000oooo0?oo
o`3o0?oooo/0oooo0@00000005H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1f
0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`1f
0?ooo`030000003oool0oooo00X0oooo0@00000005H0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02P3oool10000
0000EP3oool3000000T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo00P0oooo0`00000005H0ooooo`00003o00000000o`3ooooo0?oooeH0oooo003o
0?ooool0ooooEP3oool00?l0ooooo`3ooomF0?ooo`00o`3ooooo0?oooeH0oooo003o0?ooool0oooo
EP3oool00001\
\>"],
  ImageRangeCache->{{{0, 595.188}, {367.5, 0}} -> {-0.408848, -1.00002, \
0.0041321, 4.7251*^-07}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\($TextStyle = {FontFamily \[Rule] "\<Times\>", 
          FontSize \[Rule] 14};\)\), "\[IndentingNewLine]", 
    \(Show[{plpl, plm}, 
      Epilog \[Rule] {Text["\<q=0.05\>", {0.5, \(-0.99996\)}], 
          Text["\<q=-0.05\>", {0.2, \(-1\)}]}]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.476191 3893.92 3893.87 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.2619 -0.0125 -10.7813 -17.8125 ]
[.2619 -0.0125 10.7813 0 ]
[.5 -0.0125 -5.53125 -17.8125 ]
[.5 -0.0125 5.53125 0 ]
[.7381 -0.0125 -10.7813 -17.8125 ]
[.7381 -0.0125 10.7813 0 ]
[.97619 -0.0125 -5.53125 -17.8125 ]
[.97619 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.125 -35.625 ]
[.5 -0.0125 5.125 -17.8125 ]
[-0.0125 .05037 -20.75 -8.90625 ]
[-0.0125 .05037 0 8.90625 ]
[-0.0125 .12824 -59.5 -8.90625 ]
[-0.0125 .12824 0 8.90625 ]
[-0.0125 .20612 -59.5 -8.90625 ]
[-0.0125 .20612 0 8.90625 ]
[-0.0125 .284 -59.5 -8.90625 ]
[-0.0125 .284 0 8.90625 ]
[-0.0125 .36188 -59.5 -8.90625 ]
[-0.0125 .36188 0 8.90625 ]
[-0.0125 .43975 -52.4375 -8.90625 ]
[-0.0125 .43975 0 8.90625 ]
[-0.0125 .51763 -59.5 -8.90625 ]
[-0.0125 .51763 0 8.90625 ]
[-0.0125 .59551 -59.5 -8.90625 ]
[-0.0125 .59551 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -77.3125 -14.7188 ]
[-0.01875 .30902 -59.5 14.7188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.2619 .20612 -22.3438 -8.90625 ]
[.2619 .20612 22.3438 8.90625 ]
[.11905 .05037 -26.8438 -8.90625 ]
[.11905 .05037 26.8438 8.90625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -71.7813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.125 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .05037 m
.00625 .05037 L
s
gsave
-0.0125 .05037 -81.75 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .12824 m
.00625 .12824 L
s
gsave
-0.0125 .12824 -120.5 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.99998) show
1.000 setlinewidth
grestore
0 .20612 m
.00625 .20612 L
s
gsave
-0.0125 .20612 -120.5 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.99996) show
1.000 setlinewidth
grestore
0 .284 m
.00625 .284 L
s
gsave
-0.0125 .284 -120.5 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.99994) show
1.000 setlinewidth
grestore
0 .36188 m
.00625 .36188 L
s
gsave
-0.0125 .36188 -120.5 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.99992) show
1.000 setlinewidth
grestore
0 .43975 m
.00625 .43975 L
s
gsave
-0.0125 .43975 -113.438 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9999) show
1.000 setlinewidth
grestore
0 .51763 m
.00625 .51763 L
s
gsave
-0.0125 .51763 -120.5 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.99988) show
1.000 setlinewidth
grestore
0 .59551 m
.00625 .59551 L
s
gsave
-0.0125 .59551 -120.5 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.99986) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .06984 m
.00375 .06984 L
s
0 .08931 m
.00375 .08931 L
s
0 .10878 m
.00375 .10878 L
s
0 .14771 m
.00375 .14771 L
s
0 .16718 m
.00375 .16718 L
s
0 .18665 m
.00375 .18665 L
s
0 .22559 m
.00375 .22559 L
s
0 .24506 m
.00375 .24506 L
s
0 .26453 m
.00375 .26453 L
s
0 .30347 m
.00375 .30347 L
s
0 .32294 m
.00375 .32294 L
s
0 .34241 m
.00375 .34241 L
s
0 .38135 m
.00375 .38135 L
s
0 .40082 m
.00375 .40082 L
s
0 .42029 m
.00375 .42029 L
s
0 .45922 m
.00375 .45922 L
s
0 .47869 m
.00375 .47869 L
s
0 .49816 m
.00375 .49816 L
s
0 .5371 m
.00375 .5371 L
s
0 .55657 m
.00375 .55657 L
s
0 .57604 m
.00375 .57604 L
s
0 .0309 m
.00375 .0309 L
s
0 .01143 m
.00375 .01143 L
s
0 .61498 m
.00375 .61498 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -144.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.7188 12.9063 translate
90 rotate
-75.7188 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.063 17.500 moveto
(H) show
77.625 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.875 17.500 moveto
(L) show
88.438 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .05037 m
1 .05037 L
s
.99375 .12824 m
1 .12824 L
s
.99375 .20612 m
1 .20612 L
s
.99375 .284 m
1 .284 L
s
.99375 .36188 m
1 .36188 L
s
.99375 .43975 m
1 .43975 L
s
.99375 .51763 m
1 .51763 L
s
.99375 .59551 m
1 .59551 L
s
.125 Mabswid
.99625 .06984 m
1 .06984 L
s
.99625 .08931 m
1 .08931 L
s
.99625 .10878 m
1 .10878 L
s
.99625 .14771 m
1 .14771 L
s
.99625 .16718 m
1 .16718 L
s
.99625 .18665 m
1 .18665 L
s
.99625 .22559 m
1 .22559 L
s
.99625 .24506 m
1 .24506 L
s
.99625 .26453 m
1 .26453 L
s
.99625 .30347 m
1 .30347 L
s
.99625 .32294 m
1 .32294 L
s
.99625 .34241 m
1 .34241 L
s
.99625 .38135 m
1 .38135 L
s
.99625 .40082 m
1 .40082 L
s
.99625 .42029 m
1 .42029 L
s
.99625 .45922 m
1 .45922 L
s
.99625 .47869 m
1 .47869 L
s
.99625 .49816 m
1 .49816 L
s
.99625 .5371 m
1 .5371 L
s
.99625 .55657 m
1 .55657 L
s
.99625 .57604 m
1 .57604 L
s
.99625 .0309 m
1 .0309 L
s
.99625 .01143 m
1 .01143 L
s
.99625 .61498 m
1 .61498 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .60332 m
.06244 .46827 L
.10458 .35929 L
.14415 .28393 L
.18221 .22968 L
.22272 .18646 L
.26171 .15536 L
.30316 .13058 L
.34309 .11268 L
.3815 .09956 L
.42237 .08888 L
.46172 .08099 L
.49955 .07509 L
.53984 .07017 L
.57861 .06646 L
.61984 .06335 L
.65954 .06099 L
.69774 .05917 L
.73838 .05762 L
.77751 .05641 L
.81909 .05537 L
.85916 .05456 L
.89771 .05392 L
.93871 .05336 L
.97619 .05294 L
s
.02381 .01472 m
.06244 .0234 L
.10458 .03042 L
.14415 .03528 L
.18221 .03877 L
.22272 .04156 L
.26171 .04357 L
.30316 .04517 L
.34309 .04633 L
.3815 .04718 L
.42237 .04787 L
.46172 .04838 L
.49955 .04876 L
.53984 .04908 L
.57861 .04932 L
.61984 .04952 L
.65954 .04968 L
.69774 .0498 L
.73838 .0499 L
.77751 .04997 L
.81909 .05004 L
.85916 .05009 L
.89771 .05014 L
.93871 .05017 L
.97619 .0502 L
s
gsave
.2619 .20612 -83.3438 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
70.063 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
79.063 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
103.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.11905 .05037 -87.8438 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
70.063 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
79.063 17.500 moveto
(-) show
88.063 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
112.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{848.438, 524.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=@000232000`400?l00000o`00003oo`3ooooo
0?ooool0ooooD`3oool00?l0ooooo`3ooooo0?oooe<0oooo003o0?ooool0ooooo`3ooomC0?ooo`00
o`3ooooo0?ooool0ooooD`3oool00?l0ooooo`3ooooo0?oooe<0oooo003o0?ooool0ooooo`3ooomC
0?ooo`00o`3ooooo0?ooool0ooooD`3oool00?l0ooooo`3ooooo0?oooe<0oooo003o0?ooool0oooo
o`3ooomC0?ooo`00o`3ooooo0?ooool0ooooD`3oool00?l0ooooo`3ooooo0?oooe<0oooo003o0?oo
om<0oooo1P00003o0?ooogT0oooo003o0?ooom@0oooo00D000000?ooo`3oool0oooo0000003o0?oo
ogT0oooo003o0?ooomD0oooo00<000000?ooo`3oool0o`3ooomj0?ooo`00o`3ooooE0?ooo`030000
003oool0oooo0?l0ooooNP3oool00?l0ooooeP3oool00`000000oooo0?ooo`3o0?ooogT0oooo003o
0?ooom<0oooo00D000000?ooo`3oool0oooo0000003o0?ooogX0oooo003o0?ooom<0oooo1P00003o
0?ooogT0oooo003o0?ooool0ooooo`3ooomC0?ooo`00o`3ooooo0?ooool0ooooD`3oool00?l0oooo
o`3ooooo0?oooe<0oooo003o0?ooool0ooooo`3ooomC0?ooo`00o`3ooooo0?ooool0ooooD`3oool0
0?l0ooooo`3ooooo0?oooe<0oooo003o0?ooool0ooooo`3ooomC0?ooo`00o`3ooooo0?ooool0oooo
D`3oool00?l0ooooo`3ooooo0?oooe<0oooo003o0?ooool0ooooo`3ooomC0?ooo`00o`3ooooo0?oo
ool0ooooD`3oool006/0oooo0`00002/0?ooo`<000000`3oool010000000oooo0?ooo`3oool30000
0:`0oooo0`00002/0?ooo`<000000`3oool010000000oooo0?ooo`3oool300000:/0oooo1@00000A
0?ooo`00JP3oool01@000000oooo0?ooo`3oool000000:X0oooo00D000000?ooo`3oool0oooo0000
00090?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0[03oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0:T0oooo00@000000?ooo`3oool000004@3oool006X0oooo00D0
00000?ooo`3oool0oooo0000002Z0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000
oooo0?ooo`2Y0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`2Y0?ooo`030000003oool0oooo0140oooo001Z0?ooo`050000003oool0oooo0?ooo`00
0000ZP3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0Z@3oool00`00
0000oooo0?ooo`2/0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0ZP3oool00`00
0000oooo0?ooo`0@0?ooo`00JP3oool01@000000oooo0?ooo`3oool000000:X0oooo00D000000?oo
o`3oool0oooo0000000:0?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0[03oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0403oool0
06X0oooo00D000000?ooo`3oool0oooo0000002Z0?ooo`050000003oool0oooo0?ooo`0000002@3o
ool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo00l0oooo001Z0?ooo`050000003oool0
oooo0?ooo`000000ZP3oool01@000000oooo0?ooo`3oool0000000H0oooo0`00002]0?ooo`030000
003oool0oooo0:`0oooo00<000000?ooo`3oool01P3oool300000:l0oooo00<000000?ooo`3oool0
3`3oool006X0oooo00D000000?ooo`3oool0oooo0000002Z0?ooo`050000003oool0oooo0?ooo`00
00001P3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo00l0oooo001Z0?ooo`050000
003oool0oooo0?ooo`000000ZP3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?oo
o`3oool0Z`3oool200000:d0oooo0P0000090?ooo`030000003oool0oooo0:X0oooo00D000000?oo
o`3oool0oooo0000000A0?ooo`00J`3oool300000:`0oooo0`0000080?ooo`@00000Z`3oool00`00
0000oooo0?ooo`2/0?ooo`030000003oool0oooo00L0oooo1000002Z0?ooo`<000004P3oool00?l0
ooooo`3ooooo0?oooe<0oooo003o0?ooool0ooooo`3ooomC0?ooo`00o`3ooooo0?ooool0ooooD`3o
ool00?l0ooooo`3ooooo0?oooe<0oooo003o0?ooool0ooooo`3ooomC0?ooo`00o`3ooooo0?ooool0
ooooD`3oool00?l0ooooo`3ooooo0?oooe<0oooo003o0?ooool0ooooo`3ooomC0?ooo`00o`3ooooo
0?ooool0ooooD`3oool00?l0ooooo`3ooooo0?oooe<0oooo003o0?ooool0ooooo`3ooomC0?ooo`00
o`3ooooo0?ooool0ooooD`3oool005/0ooooo`00003o00000?L00000001K0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo00l0oooo0@00000005/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool03`3oool100000000F`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0?0?ooo`400000001K0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
/@3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0
/@3oool00`000000oooo0?ooo`0?0?ooo`400000001K0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0/@3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo0;40oooo00<0
00000?ooo`3oool0/@3oool00`000000oooo0?ooo`0?0?ooo`400000001K0?ooo`030000003oool0
oooo0?l0ooooo`3ooooc0?ooo`400000001K0?ooo`030000003oool0oooo0?l0ooooo`3ooooc0?oo
o`400000001K0?ooo`@00000o`3ooooo0?ooonl0oooo1000000005/0oooo00<000000?ooo`3oool0
o`3ooooo0?oooo<0oooo0@00000005/0oooo00<000000?ooo`3oool0o`3ooooo0?oooo<0oooo0@00
000005/0oooo00<000000?ooo`3oool03`3oool300000?l0ooooo`3ooooQ0?ooo`400000001K0?oo
o`030000003oool0oooo0180oooo1@00003o0?ooool0oooog03oool100000000F`3oool00`000000
oooo0?ooo`0G0?ooo`D00000o`3ooooo0?ooomL0oooo0@00000005/0oooo00<000000?ooo`3oool0
703oool400000?l0ooooo`3ooooC0?ooo`400000001K0?ooo`030000003oool0oooo0200oooo1@00
003o0?ooool0oooocP3oool100000000F`3oool00`000000oooo0?ooo`0U0?ooo`D00000o`3ooooo
0?ooolT0oooo0@00000005/0oooo00<000000?ooo`3oool0:P3oool500000?l0ooooo`3oooo40?oo
o`400000001K0?ooo`030000003oool0oooo02l0oooo1@00003o0?ooool0oooo_`3oool100000000
F`3oool00`000000oooo0?ooo`0d0?ooo`H00000o`3ooooo0?oookT0oooo0@00000005/0oooo00<0
00000?ooo`3oool0>P3oool500000?l0ooooo`3ooond0?ooo`400000001K0?ooo`030000003oool0
oooo03l0oooo1@00003o0?ooool0oooo[`3oool100000000F`3oool00`000000oooo0?ooo`140?oo
o`H00000o`3ooooo0?ooojT0oooo0@00000005/0oooo100000190?ooo`L00000o`3ooooo0?oooil0
oooo1000000005/0oooo00<000000?ooo`3oool0D@3oool:00000?l0ooooo`3ooonH0?ooo`400000
001K0?ooo`030000003oool0oooo05/0oooo2P00003o0?ooool0ooooSP3oool100000000F`3oool0
0`000000oooo0?ooo`1U0?ooo`X00000o`3ooooo0?oooh@0oooo0@00000005/0oooo00<000000?oo
o`3oool0K`3oool:00000?l0ooooo`3ooomj0?ooo`400000001K0?ooo`030000003oool0oooo07T0
oooo2P00003o0?ooool0ooooL03oool100000000F`3oool00`000000oooo0?ooo`230?ooo``00000
o`3ooooo0?ooof@0oooo0@00000005/0oooo00<000000?ooo`3oool0S`3oool?00000?l0ooooo`3o
oomE0?ooo`400000001K0?ooo`030000003oool0oooo0480oooo0`00001I0?ooo`l00000o`3ooooo
0?ooodH0oooo0@00000005/0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`1W0?oo
o`l00000o`3ooooo0?ooocL0oooo0@00000005/0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`1f0?oooaL00000o`3ooooo0?ooob00oooo0@00000004X0oooo0`00000>0?ooo`030000
003oool0oooo0400oooo0P0000000`3oool000000?ooo`0D0?ooo`<000000`3oool00`000000oooo
0?ooo`020?ooo`<000000`3oool3000006H0oooo7P00003o0?ooool0oooo0P3oool100000000B`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool00P00
00020?ooo`L000002`3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0
oooo000000050?ooo`030000003oool0oooo0840oooo?000003o0?ooolD0oooo0@00000004/0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0o0?ooo`050000003oool0oooo0?ooo`00
0000503oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo00000006
0?ooo`030000003oool0oooo0;`0oooo?000003o0?ooohT0oooo0@0000000400oooo1`0000040?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0?`3oool01@000000oooo0?ooo`3oool0
000000/0oooo1`0000020?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?oo
o`3oool0000000H0oooo00<000000?ooo`3oool0n03ooonc00000=D0oooo0@00000004/0oooo00<0
00000?ooo`3oool03@3oool6000003`0oooo00D000000?ooo`3oool0oooo000000020?ooo`L00000
2`3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000060?oo
o`030000003oool0oooo0?l0oooo[03oooo4000000`0oooo1P00000004/0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00800000503oool01@000000
oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0
oooo0?l0ooooo`3ooon30?ooo`400000001;0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0@03oool2000000030?ooo`000000oooo01<0oooo00D000000?ooo`3oool0oooo00000006
0?ooo`050000003oool0oooo0?ooo`0000000P3oool300000?l0ooooo`3ooom80?ooobd000004@3o
ool100000000B`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo05P0oooo00D00000
0?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`3o0?ooool0oooo3@3ooolk000003h0oooo0@00000004X0oooo0P00000?0?ooo`030000003o
ool0oooo05P0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`3o0?ooolh0oooo?@00001i0?ooo`400000001;0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0F@3oool3000000P0oooo0`0000040?ooo`@00000
o`3ooonf0?oooaL00000]P3oool100000000F`3oool00`000000oooo0?ooo`3o0?ooool0oooo5P3o
ool@00000<d0oooo0@00000005/0oooo00<000000?ooo`3oool0o`3ooooo0?oooaH00000g@3oool1
00000000F`3oool00`000000oooo0?ooo`3o0?ooonT0oooo5P00003c0?ooo`400000001K0?ooo`03
0000003oool0oooo0?l0oooofP3oool?00000?l0oooo2P3oool100000000F`3oool00`000000oooo
0?ooo`3o0?oool/0oooo3`00003o0?oooaT0oooo0@00000005/0oooo00<000000?ooo`3oool0o`3o
oonk0?oooa000000o`3ooolX0?ooo`400000001K0?ooo`030000003oool0oooo0?l0oooo[`3oool<
00000?l0oooo>03oool100000000F`3oool00`000000oooo0?ooo`3o0?ooojD0oooo2P00003o0?oo
od@0oooo0@00000005/0oooo00<000000?ooo`3oool0o`3ooonK0?ooo`X00000o`3ooom>0?ooo`40
0000001K0?ooo`@00000o`3ooonB0?ooo`P00000o`3ooomE0?ooo`@00000001K0?ooo`030000003o
ool0oooo0?l0ooooR`3oool800000?l0ooooH03oool100000000F`3oool00`000000oooo0?ooo`3o
0?oooh@0oooo1`00003o0?ooofP0oooo0@00000005/0oooo00<000000?ooo`3oool0o`3oooml0?oo
o`P00000o`3ooom_0?ooo`400000001K0?ooo`030000003oool0oooo0?l0ooooM@3oool700000?l0
ooooM`3oool100000000F`3oool00`000000oooo0?ooo`3o0?ooofh0oooo1`00003o0?ooogh0oooo
0@00000005/0oooo00<000000?ooo`3oool0o`3ooomV0?ooo`P00000o`3ooon50?ooo`400000001K
0?ooo`030000003oool0oooo0?l0ooooG`3oool700000?l0ooooS@3oool100000000F`3oool00`00
0000oooo0?ooo`3o0?oooeT0oooo1P00003o0?oooi@0oooo0@00000005/0oooo00<000000?ooo`3o
ool0o`3ooomD0?ooo`D00000o`3ooonJ0?ooo`400000001K0?ooo`030000003oool0oooo0?l0oooo
C`3oool500000?l0ooooW`3oool100000000F`3oool00`000000oooo0?ooo`3o0?ooodX0oooo1@00
003o0?oooj@0oooo0@00000005/0oooo00<000000?ooo`3oool0o`3ooom50?ooo`D00000o`3ooonY
0?ooo`400000001K0?ooo`030000003oool0oooo0?l0oooo@03oool500000?l0oooo[P3oool10000
0000F`3oool400000?l0oooo>`3oool400000?l0oooo/03oool400000000F`3oool00`000000oooo
0?ooo`3o0?ooocP0oooo1000003o0?oookL0oooo0@00000005/0oooo00<000000?ooo`3oool0o`3o
oold0?ooo`@00000o`3ooonk0?ooo`400000001K0?ooo`030000003oool0oooo0?l0oooo<03oool4
00000?l0oooo_`3oool100000000F`3oool00`000000oooo0?ooo`3o0?ooob`0oooo1000003o0?oo
ol<0oooo0@00000005/0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`@00000o`3oooo70?ooo`40
0000001K0?ooo`030000003oool0oooo0?l0oooo903oool400000?l0oooob`3oool100000000F`3o
ool00`000000oooo0?ooo`3o0?ooob00oooo1000003o0?oooll0oooo0@00000005/0oooo00<00000
0?ooo`3oool0o`3ooolM0?ooo`<00000o`3ooooC0?ooo`400000001K0?ooo`030000003oool0oooo
0?l0oooo6P3oool300000?l0ooooeP3oool100000000F`3oool00`000000oooo0?ooo`3o0?oooaL0
oooo0`00003o0?ooomT0oooo0@00000005/0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`<00000
o`3ooooL0?ooo`400000001K0?ooo`030000003oool0oooo0?l0oooo4@3oool300000?l0oooog`3o
ool100000000F`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo0P00003o0?ooon80oooo0@000000
05/0oooo00<000000?ooo`3oool0o`3oool<0?ooo`<00000o`3ooooT0?ooo`400000001K0?ooo`@0
0000o`3oool80?ooo`<00000o`3ooooT0?ooo`@00000001K0?ooo`030000003oool0oooo0?l0oooo
1P3oool300000?l0oooojP3oool100000000F`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo0`00
003o0?ooond0oooo0@00000005/0oooo00<000000?ooo`3oool0o`3oool300000?l0ooool03oool1
00000000F`3oool00`000000oooo0?ooo`3m0?ooo`800000o`3ooooc0?ooo`400000001K0?ooo`03
0000003oool0oooo0?/0oooo0P00003o0?ooooD0oooo0@00000005/0oooo00<000000?ooo`3oool0
n03oool300000?l0oooom`3oool100000000F`3oool00`000000oooo0?ooo`3f0?ooo`800000o`3o
oooj0?ooo`400000001K0?ooo`030000003oool0oooo0?@0oooo0P00003o0?oooo`0oooo0@000000
05/0oooo00<000000?ooo`3oool0lP3oool200000?l0oooooP3oool100000000F`3oool00`000000
oooo0?ooo`3_0?ooo`<00000o`3ooooo0?ooo`40oooo0@00000002@0oooo0`0000030?ooo`040000
003oool0oooo0?ooo`8000001@3oool2000000D0oooo0P0000050?ooo`8000001P3oool3000000d0
oooo00<000000?ooo`3oool0k@3oool200000?l0ooooo`3oool40?ooo`400000000S0?ooo`050000
003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`000000303oool00`000000oooo0?ooo`3[0?ooo`800000o`3ooooo0?ooo`H0oooo0@00000002<0
oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0>P0oooo0`00003o0?ooool0oooo203oool1
000000006@3oool7000000<0oooo00D000000?ooo`3oool0oooo000000070?ooo`@000000`3oool4
000000<0oooo100000030?ooo`@000000P3oool01@000000oooo0?ooo`3oool0000000`0oooo00<0
00000?ooo`3oool0iP3oool200000?l0ooooo`3oool;0?ooo`400000000S0?ooo`050000003oool0
oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`0000003@3oool600000>40oooo0P00003o0?ooool0oooo203oool6
000000008`3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0hP3oool200000?l0ooooo`3oool?0?ooo`400000000S0?ooo`050000003oool0oooo0?oo
o`0000001P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000
00020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`0000003@3oool00`000000oooo0?ooo`3P0?ooo`800000o`3ooooo0?oooa40
oooo0@00000002<0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?oo
o`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000
00020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000`0
oooo00<000000?ooo`3oool0gP3oool200000?l0ooooo`3ooolC0?ooo`400000000S0?ooo`050000
003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo0=d0
oooo00<000000?ooo`3oool0o`3ooooo0?oooa<0oooo0@00000002@0oooo0`0000080?ooo`<00000
103oool3000000@0oooo0`0000040?ooo`<00000103oool3000000d0oooo00<000000?ooo`3oool0
f`3oool200000?l0ooooo`3ooolF0?ooo`400000001K0?ooo`030000003oool0oooo0=X0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooaH0oooo0@00000005/0oooo00<000000?ooo`3oool0f03oool2
00000?l0ooooo`3ooolI0?ooo`400000001K0?ooo`030000003oool0oooo0=H0oooo0P00003o0?oo
ool0oooo6`3oool100000000F`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0?l0
ooooo`3ooolK0?ooo`400000001K0?ooo`030000003oool0oooo0=<0oooo0P00003o0?ooool0oooo
7P3oool100000000F`3oool00`000000oooo0?ooo`3A0?ooo`800000o`3ooooo0?ooob00oooo0@00
000005/0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`3o0?ooool0oooo803oool1
00000000F`3oool00`000000oooo0?ooo`3>0?ooo`800000o`3ooooo0?ooob<0oooo0@00000005/0
oooo1000003;0?ooo`800000o`3ooooo0?ooob80oooo1000000005/0oooo00<000000?ooo`3oool0
b`3oool00`000000oooo0?ooo`3o0?ooool0oooo9@3oool100000000F`3oool00`000000oooo0?oo
o`390?ooo`800000o`3ooooo0?ooobP0oooo0@00000005/0oooo00<000000?ooo`3oool0b03oool0
0`000000oooo0?ooo`3o0?ooool0oooo:03oool100000000F`3oool00`000000oooo0?ooo`360?oo
o`800000o`3ooooo0?ooob/0oooo0@00000005/0oooo00<000000?ooo`3oool0a03oool200000?l0
ooooo`3oool]0?ooo`400000001K0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
o`3ooooo0?ooobd0oooo0@00000005/0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?oo
o`3o0?ooool0oooo;P3oool100000000F`3oool00`000000oooo0?ooo`300?ooo`800000o`3ooooo
0?oooc40oooo0@00000005/0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`3o0?oo
ool0oooo<@3oool100000000F`3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo0?l0
ooooo`3ooolb0?ooo`400000001K0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0
o`3ooooo0?oooc<0oooo0@00000005/0oooo00<000000?ooo`3oool0^`3oool200000?l0ooooo`3o
oolf0?ooo`400000001K0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0o`3ooooo
0?ooocH0oooo0@00000005/0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`3o0?oo
ool0oooo=`3oool100000000F`3oool400000;L0oooo00<000000?ooo`3oool0o`3ooooo0?ooocD0
oooo1000000005/0oooo00<000000?ooo`3oool0]P3oool200000?l0ooooo`3ooolk0?ooo`400000
001K0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool0o`3ooooo0?oooc/0oooo0@00
000005/0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`3o0?ooool0oooo?03oool1
00000000F`3oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo0?l0ooooo`3ooolm0?oo
o`400000001K0?ooo`030000003oool0oooo0;40oooo0P00003o0?ooool0oooo@03oool100000000
F`3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo0?l0ooooo`3ooom00?ooo`400000
001K0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0o`3ooooo0?oood40oooo0@00
000005/0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`3o0?ooool0oooo@P3oool1
00000000F`3oool00`000000oooo0?ooo`2/0?ooo`800000o`3ooooo0?ooodD0oooo0@00000005/0
oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`3o0?ooool0ooooA@3oool100000000
F`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo0?l0ooooo`3ooom60?ooo`400000
001K0?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0o`3ooooo0?ooodL0oooo0@00
000005/0oooo00<000000?ooo`3oool0Y`3oool200000?l0ooooo`3ooom:0?ooo`400000001K0?oo
o`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3ooooo0?ooodX0oooo0@00000005/0
oooo1000002T0?ooo`030000003oool0oooo0?l0ooooo`3ooom80?ooo`@00000001K0?ooo`030000
003oool0oooo0:@0oooo00<000000?ooo`3oool0o`3ooooo0?oood`0oooo0@00000005/0oooo00<0
00000?ooo`3oool0X`3oool00`000000oooo0?ooo`3o0?ooool0ooooC@3oool100000000F`3oool0
0`000000oooo0?ooo`2R0?ooo`030000003oool0oooo0?l0ooooo`3ooom>0?ooo`400000001K0?oo
o`030000003oool0oooo0:40oooo00<000000?ooo`3oool0o`3ooooo0?ooodl0oooo0@00000005/0
oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`3o0?ooool0ooooD03oool100000000
F`3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`400000
001K0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0o`3ooooo0?oooe80oooo0@00
000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0C0?ooo`<00000o`3ooooo
0?ooocd0oooo0@00000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo0?l0ooooo`3oooll0?ooo`400000001K0?ooo`030000003oool0oooo09`0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3o0?ooool0oooo?03oool100000000
903oool3000000<0oooo00@000000?ooo`3oool0oooo0P0000050?ooo`8000001@3oool2000000D0
oooo0P0000060?ooo`<000003@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo01<0
oooo0P0000000`3oool000000?ooo`0;0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`<0
00000`3oool300000?l0ooooo`3ooolN0?ooo`400000000S0?ooo`050000003oool0oooo0?ooo`00
0000203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000303oool00`00
0000oooo0?ooo`2J0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P0000020?oo
o`L000000P3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo0000
00050?ooo`030000003oool0oooo0?l0ooooo`3ooolK0?ooo`400000000S0?ooo`050000003oool0
oooo0?ooo`0000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3oool0
oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0
000000H0oooo00<000000?ooo`3oool0o`3ooooo0?oooaX0oooo0@00000001T0oooo1`0000030?oo
o`050000003oool0oooo0?ooo`0000001`3oool4000000<0oooo100000030?ooo`@000000`3oool4
00000080oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo09P0oooo00<0
00000?ooo`3oool05@3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0
oooo000000060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`3o0?oo
ool0oooo6P3oool1000000008`3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?oo
o`000000303oool6000009@0oooo00<000000?ooo`3oool05P3oool01@000000oooo0?ooo`3oool0
00000080oooo1`0000020?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?oo
o`3oool0000000H0oooo00<000000?ooo`3oool0o`3ooooo0?oooaD0oooo1P00000002<0oooo00D0
00000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000
oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000P3oool200000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`2F0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool00P00000;0?ooo`050000003o
ool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooa/0oooo0@00000002<0oooo00D000000?ooo`3oool0oooo000000060?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D00000
0?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
00000000000=0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool06@3oool200000003
0?ooo`000000oooo00X0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo
0?ooo`0000000P3oool300000?l0ooooo`3ooolN0?ooo`400000000S0?ooo`050000003oool0oooo
0?ooo`0000001P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo
02T0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`3o0?ooool0oooo7P3oool1000000008`3oool01@000000oooo0?ooo`3o
ool0000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0Z
0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool0o`3ooooo0?oooad0oooo0@00000002@0oooo0`0000080?ooo`<00000103o
ool3000000@0oooo0`0000040?ooo`<000001P3oool2000000`0oooo00<000000?ooo`3oool0TP3o
ool00`000000oooo0?ooo`0/0?ooo`<00000203oool3000000@0oooo1000003o0?ooool0oooo703o
ool100000000F`3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0?l0ooooo`3ooomO
0?ooo`400000001K0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0o`3ooooo0?oo
of00oooo0@00000005/0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`3o0?ooool0
ooooH@3oool100000000F`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0?l0oooo
o`3ooomR0?ooo`400000001K0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0o`3o
oooo0?ooof80oooo0@00000005/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`3o
0?ooool0ooooH`3oool100000000F`3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
0?l0ooooo`3ooomT0?ooo`400000001K0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooofD0oooo0@00000005/0oooo100000290?ooo`030000003oool0oooo0?l0oooo
o`3ooomS0?ooo`@00000001K0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0o`3o
oooo0?ooofL0oooo0@00000005/0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`3o
0?ooool0ooooJ03oool100000000F`3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo
0?l0ooooo`3ooomY0?ooo`400000001K0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooofX0oooo0@00000005/0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`3o0?ooool0ooooJP3oool100000000F`3oool00`000000oooo0?ooo`250?ooo`030000003o
ool0oooo0?l0ooooo`3ooom[0?ooo`400000001K0?ooo`030000003oool0oooo08@0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooof`0oooo0@00000005/0oooo00<000000?ooo`3oool0P`3oool00`00
0000oooo0?ooo`3o0?ooool0ooooK@3oool100000000F`3oool00`000000oooo0?ooo`230?ooo`03
0000003oool0oooo0?l0ooooo`3ooom]0?ooo`400000001K0?ooo`030000003oool0oooo0880oooo
00<000000?ooo`3oool0o`3ooooo0?ooofh0oooo0@00000005/0oooo00<000000?ooo`3oool0P@3o
ool00`000000oooo0?ooo`3o0?ooool0ooooK`3oool100000000F`3oool00`000000oooo0?ooo`21
0?ooo`030000003oool0oooo0?l0ooooo`3ooom_0?ooo`400000001K0?ooo`030000003oool0oooo
0800oooo00<000000?ooo`3oool0o`3ooooo0?ooog00oooo0@00000005/0oooo00<000000?ooo`3o
ool0O`3oool00`000000oooo0?ooo`3o0?ooool0ooooL@3oool100000000F`3oool4000007h0oooo
00<000000?ooo`3oool0o`3ooooo0?ooofh0oooo1000000005/0oooo00<000000?ooo`3oool0OP3o
ool00`000000oooo0?ooo`3o0?ooool0ooooLP3oool100000000F`3oool00`000000oooo0?ooo`1m
0?ooo`030000003oool0oooo0?l0ooooo`3ooomc0?ooo`400000001K0?ooo`030000003oool0oooo
07`0oooo00<000000?ooo`3oool0o`3ooooo0?ooog@0oooo0@00000005/0oooo00<000000?ooo`3o
ool0O03oool00`000000oooo0?ooo`3o0?ooool0ooooM03oool100000000F`3oool00`000000oooo
0?ooo`1k0?ooo`030000003oool0oooo0?l0ooooo`3ooome0?ooo`400000001K0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool0o`3ooooo0?ooogH0oooo0@00000005/0oooo00<00000
0?ooo`3oool0NP3oool00`000000oooo0?ooo`3o0?ooool0ooooMP3oool100000000F`3oool00`00
0000oooo0?ooo`1i0?ooo`030000003oool0oooo0?l0ooooo`3ooomg0?ooo`400000001K0?ooo`03
0000003oool0oooo07P0oooo00<000000?ooo`3oool0o`3ooooo0?ooogP0oooo0@00000005/0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`3o0?ooool0ooooN@3oool100000000F`3o
ool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0?l0ooooo`3ooomi0?ooo`400000001K
0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0o`3ooooo0?ooogX0oooo0@000000
05/0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`3o0?ooool0ooooN`3oool10000
0000F`3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo0?l0ooooo`3ooomk0?ooo`40
0000001K0?ooo`@00000L`3oool00`000000oooo0?ooo`3o0?ooool0ooooN@3oool400000000F`3o
ool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0?l0ooooo`3ooomm0?ooo`400000001K
0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0o`3ooooo0?ooogh0oooo0@000000
05/0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`3o0?ooool0ooooOP3oool10000
0000F`3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0ooooo`3ooomo0?ooo`40
0000001K0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0o`3ooooo0?oooh00oooo
0@00000005/0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`3o0?ooool0ooooP03o
ool100000000F`3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0?l0ooooo`3ooon1
0?ooo`400000001K0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oh80oooo0@00000005/0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`3o0?ooool0
ooooPP3oool100000000F`3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo0?l0oooo
o`3ooon30?ooo`400000000T0?ooo`<000000`3oool010000000oooo0?ooo`3oool2000000D0oooo
0P0000050?ooo`8000001@3oool2000000P0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`1/0?ooo`030000003oool0oooo0?l0ooooo`3ooon40?ooo`400000000S0?ooo`050000003o
ool0oooo0?ooo`000000203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`3o0?ooool0ooooQ@3oool1000000008`3o
ool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0o`3ooooo0?ooohD0oooo
0@00000001T0oooo1`0000030?ooo`050000003oool0oooo0?ooo`0000001`3oool4000000<0oooo
100000030?ooo`@000000`3oool4000000030?ooo`000000000000@00000303oool6000006L0oooo
00<000000?ooo`3oool0o`3ooooo0?oooh40oooo1P00000002<0oooo00D000000?ooo`3oool0oooo
000000060?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo
000000030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0J@3oool00`000000oooo
0?ooo`3o0?ooool0ooooQ`3oool1000000008`3oool01@000000oooo0?ooo`3oool0000000H0oooo
00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000d0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`3o0?ooool0oooo
Q`3oool1000000008`3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0
oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
00000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0000000d0oooo00<0
00000?ooo`3oool0J03oool00`000000oooo0?ooo`3o0?ooool0ooooR03oool1000000008`3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0000000d0oooo00<000000?ooo`3oool0J03oool0
0`000000oooo0?ooo`3o0?ooool0ooooR03oool1000000008`3oool01@000000oooo0?ooo`3oool0
000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000
0P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000040?oo
o`8000003@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0?l0ooooo`3ooon90?oo
o`400000000T0?ooo`<00000203oool3000000@0oooo0`0000040?ooo`<00000103oool3000000H0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0?l0
ooooo`3ooon90?ooo`400000001K0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0
o`3ooooo0?ooohX0oooo0@00000000H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`1V0?ooo`030000003oool0oooo0?l0ooooo`3ooon:0?ooo`40000000060?ooo`<00000DP3oool0
0`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0?l0ooooo`3ooon;0?ooo`40000000060?oo
o`030000003oool0oooo00<00000C`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo
0?l0ooooo`3ooon;0?ooo`400000000;0?ooo`800000CP3oool00`000000oooo0?ooo`1T0?ooo`03
0000003oool0oooo0?l0ooooo`3ooon<0?ooo`40000000060?ooo`030000003oool0oooo00800000
D03oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0?l0ooooo`3ooon<0?ooo`400000
00060?ooo`<00000DP3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0?l0ooooo`3o
oon=0?ooo`40000000060?ooo`030000003oool0oooo00<00000C`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo0?l0ooooo`3ooon=0?ooo`400000000;0?ooo`800000CP3oool40000
0640oooo00<000000?ooo`3oool0o`3ooooo0?oooh/0oooo1000000000H0oooo00<000000?ooo`3o
ool00P00001@0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0o`3ooooo0?ooohh0
oooo0@00000000H0oooo0`00001B0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0
o`3ooooo0?ooohl0oooo0@00000000H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`1Q0?ooo`030000003oool0oooo0?l0ooooo`3ooon?0?ooo`40000000050?ooo`T00000C@3oool0
0`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0?l0ooooo`3ooon@0?ooo`40000000040?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1O0?oo
o`030000003oool0oooo0?l0ooooo`3ooonA0?ooo`40000000030?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0?l0
ooooo`3ooonA0?ooo`40000000060?ooo`800000103oool00`000000oooo0?ooo`1<0?ooo`030000
003oool0oooo05h0oooo00<000000?ooo`3oool0o`3ooooo0?oooi80oooo0@00000000H0oooo00<0
00000?ooo`3oool00P3oool2000004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?oo
o`3o0?ooool0ooooTP3oool1000000001P3oool00`000000oooo0?ooo`02000000030?ooo`000000
oooo04d0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`3o0?ooool0ooooT`3oool1
000000001P3oool00`000000oooo000000030?ooo`030000003oool0oooo04`0oooo00<000000?oo
o`3oool0G@3oool00`000000oooo0?ooo`3o0?ooool0ooooT`3oool1000000001P3oool2000000@0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0?l0
ooooo`3ooonD0?ooo`40000000060?ooo`030000003oool0oooo0080oooo0P00001>0?ooo`030000
003oool0oooo05`0oooo00<000000?ooo`3oool0o`3ooooo0?oooi@0oooo0@00000005/0oooo00<0
00000?ooo`3oool0F`3oool00`000000oooo0?ooo`3o0?ooool0ooooU@3oool1000000000`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0F`3oool0
0`000000oooo0?ooo`3o0?ooool0ooooU@3oool100000000103oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo04X0oooo1000001I0?ooo`030000003oool0oooo0?l0ooooo`3ooonC0?oo
o`@0000000050?ooo`T00000C@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0?l0
ooooo`3ooonF0?ooo`400000001K0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0
o`3ooooo0?oooiL0oooo0@00000005/0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?oo
o`3o0?ooool0ooooU`3oool100000000F`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo0?l0ooooo`3ooonH0?ooo`400000001K0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool0o`3ooooo0?oooiP0oooo0@00000005/0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`3o0?ooool0ooooV@3oool100000000F`3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo0?l0ooooo`3ooonI0?ooo`400000001K0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooiX0oooo0@00000005/0oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`3o0?ooool0ooooV`3oool100000000F`3oool00`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo0?l0ooooo`3ooonK0?ooo`400000001K0?ooo`030000003oool0oooo05@0
oooo00<000000?ooo`3oool0o`3ooooo0?oooi`0oooo0@00000005/0oooo00<000000?ooo`3oool0
E03oool00`000000oooo0?ooo`3o0?ooool0ooooW03oool100000000F`3oool00`000000oooo0?oo
o`1C0?ooo`030000003oool0oooo0?l0ooooo`3ooonM0?ooo`400000001K0?ooo`030000003oool0
oooo05<0oooo00<000000?ooo`3oool0o`3ooooo0?oooid0oooo0@00000005/0oooo1000001A0?oo
o`030000003oool0oooo0?l0ooooo`3ooonK0?ooo`@00000001K0?ooo`030000003oool0oooo0580
oooo00<000000?ooo`3oool0o`3ooooo0?oooih0oooo0@00000005/0oooo00<000000?ooo`3oool0
D@3oool00`000000oooo0?ooo`3o0?ooool0ooooW`3oool100000000F`3oool00`000000oooo0?oo
o`1A0?ooo`030000003oool0oooo0?l0ooooo`3ooonO0?ooo`400000001K0?ooo`030000003oool0
oooo0500oooo00<000000?ooo`3oool0o`3ooooo0?oooj00oooo0@00000005/0oooo00<000000?oo
o`3oool0D03oool00`000000oooo0?ooo`3o0?ooool0ooooX03oool100000000F`3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo0?l0ooooo`3ooonQ0?ooo`400000001K0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool0o`3ooooo0?oooj40oooo0@00000005/0oooo00<0
00000?ooo`3oool0CP3oool00`000000oooo0?ooo`3o0?ooool0ooooXP3oool100000000F`3oool0
0`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0?l0ooooo`3ooonR0?ooo`400000001K0?oo
o`030000003oool0oooo04d0oooo00<000000?ooo`3oool0o`3ooooo0?oooj<0oooo0@00000002@0
oooo0`0000030?ooo`040000003oool0oooo0?ooo`8000001@3oool2000000D0oooo0P0000050?oo
o`8000001@3oool5000000`0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3o0?oo
ool0ooooX`3oool1000000008`3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo04`0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooj@0oooo0@00000002<0oooo00D000000?ooo`3oool0oooo00000009
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1<
0?ooo`030000003oool0oooo0?l0ooooo`3ooonT0?ooo`400000000I0?ooo`L000000`3oool01@00
0000oooo0?ooo`3oool0000000L0oooo100000030?ooo`@000000`3oool4000000<0oooo10000005
0?ooo`030000003oool0oooo00/0oooo1P0000180?ooo`030000003oool0oooo0?l0ooooo`3ooonP
0?ooo`H00000000S0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3o
ool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0ooooo`3ooonU0?ooo`400000000S0?ooo`05
0000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool000000080oooo00D00000
0?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo
0?ooo`3oool0000000H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo0?l0ooooo`3ooonV0?ooo`400000000S0?ooo`050000003oool0oooo0?ooo`00
00001P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo00000002
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000H0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0?l0oooo
o`3ooonV0?ooo`400000000S0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo
0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0?l0ooooo`3ooonV0?ooo`400000000S
0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool000000080oooo
00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool0o`3ooooo0?ooojL0oooo0@00000002@0oooo0`000008
0?ooo`<00000103oool3000000@0oooo0`0000040?ooo`<00000103oool3000000d0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`3o0?ooool0ooooY`3oool100000000F`3oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo0?l0ooooo`3ooonW0?ooo`400000001K0?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool0o`3ooooo0?ooojP0oooo0@00000005/0oooo
00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`3o0?ooool0ooooZ03oool100000000F`3o
ool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0?l0ooooo`3ooonY0?ooo`400000001K
0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0o`3ooooo0?ooojT0oooo0@000000
05/0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3o0?ooool0ooooZ@3oool10000
0000F`3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0?l0ooooo`3ooonZ0?ooo`40
0000001K0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0o`3ooooo0?ooojX0oooo
0@00000005/0oooo100000140?ooo`030000003oool0oooo0?l0ooooo`3ooonX0?ooo`@00000001K
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0o`3ooooo0?oooj/0oooo0@000000
05/0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`3o0?ooool0ooooZ`3oool10000
0000F`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0?l0ooooo`3ooon/0?ooo`40
0000001K0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0o`3ooooo0?oooj`0oooo
0@00000005/0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`3o0?ooool0oooo[03o
ool100000000F`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0?l0ooooo`3ooon]
0?ooo`400000001K0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ojd0oooo0@00000005/0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`3o0?ooool0
oooo[P3oool100000000F`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0?l0oooo
o`3ooon^0?ooo`400000001K0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0o`3o
oooo0?ooojh0oooo0@00000005/0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3o
0?ooool0oooo[`3oool100000000F`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
0?l0ooooo`3ooon_0?ooo`400000001K0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3o
ool0o`3ooooo0?oook00oooo0@00000005/0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`3o0?ooool0oooo/03oool100000000F`3oool4000003l0oooo00<000000?ooo`3oool0o`3o
oooo0?ooojd0oooo1000000005/0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`3o
0?ooool0oooo/@3oool100000000F`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
0?l0ooooo`3ooona0?ooo`400000001K0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0o`3ooooo0?oook40oooo0@00000005/0oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`3o0?ooool0oooo/P3oool100000000F`3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo0?l0ooooo`3ooonb0?ooo`400000001K0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0o`3ooooo0?oook<0oooo0@00000005/0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`3o0?ooool0oooo/`3oool100000000F`3oool00`000000oooo0?ooo`0m0?ooo`03
0000003oool0oooo0?l0ooooo`3ooonc0?ooo`400000001K0?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0o`3ooooo0?oook@0oooo0@00000005/0oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0?ooo`3o0?ooool0oooo]03oool100000000F`3oool00`000000oooo0?ooo`0k
0?ooo`030000003oool0oooo0?l0ooooo`3ooone0?ooo`400000001K0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0o`3ooooo0?oookD0oooo0@00000005/0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`3o0?ooool0oooo]@3oool100000000F`3oool4000003T0oooo
00<000000?ooo`3oool0o`3ooooo0?oook<0oooo1000000005/0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`3o0?ooool0oooo]P3oool100000000F`3oool00`000000oooo0?ooo`0i
0?ooo`030000003oool0oooo0?l0ooooo`3ooong0?ooo`400000001K0?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool0o`3ooooo0?oookL0oooo0@00000005/0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`3o0?ooool0oooo]`3oool100000000F`3oool00`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo0?l0ooooo`3ooonh0?ooo`400000001K0?ooo`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool0o`3ooooo0?oookP0oooo0@00000005/0oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`3o0?ooool0oooo^03oool100000000F`3oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo0?l0ooooo`3oooni0?ooo`400000001K0?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool0o`3ooooo0?oookT0oooo0@00000005/0oooo
00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`3o0?ooool0oooo^P3oool100000000F`3o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0?l0ooooo`3ooonj0?ooo`400000000[
0?ooo`<000000`3oool010000000oooo0?ooo`3oool2000000D0oooo0P0000050?ooo`8000001@3o
ool2000000l0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`3o0?ooool0oooo^P3o
ool100000000:P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0?l0ooooo`3ooonk0?ooo`400000000Z
0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool0o`3ooooo0?oook/0oooo0@0000000200oooo1`000003
0?ooo`050000003oool0oooo0?ooo`0000001`3oool4000000<0oooo100000030?ooo`@000000`3o
ool4000000`0oooo1P00000a0?ooo`030000003oool0oooo0?l0ooooo`3ooong0?ooo`H00000000Z
0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool000000080oooo
00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`3o
0?ooool0oooo_03oool100000000:P3oool01@000000oooo0?ooo`3oool0000000H0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo
0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0o`3ooooo0?oook`0oooo0@00000002X0oooo00D000000?ooo`3o
ool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`00
0000303oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0?l0ooooo`3ooonm0?ooo`40
0000000Z0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`3o0?ooool0oooo_@3oool100000000:P3oool01@000000oooo0?ooo`3oool0000000H0oooo
00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003o
ool0oooo03<0oooo00<000000?ooo`3oool0o`3ooooo0?oookd0oooo0@00000002/0oooo0`000008
0?ooo`<00000103oool3000000@0oooo0`0000040?ooo`<000003@3oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo0?l0ooooo`3ooonn0?ooo`400000001K0?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool0o`3ooooo0?oookh0oooo0@00000005/0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`3o0?ooool0oooo_`3oool100000000F`3oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo0?l0ooooo`3ooono0?ooo`400000001K0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool0o`3ooooo0?oookl0oooo0@00000005/0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`3o0?ooool0oooo`03oool100000000F`3oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo0?l0ooooo`3oooo00?ooo`400000001K0?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool0o`3ooooo0?oool40oooo0@00000005/0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`3o0?ooool0oooo`@3oool100000000F`3o
ool4000002h0oooo00<000000?ooo`3oool0o`3ooooo0?oookh0oooo1000000005/0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`3o0?ooool0oooo`P3oool100000000F`3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo0?l0ooooo`3oooo20?ooo`400000001K0?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool0o`3ooooo0?oool80oooo0@00000005/0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`3o0?ooool0oooo``3oool100000000F`3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0ooooo`3oooo30?ooo`400000001K
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0o`3ooooo0?oool@0oooo0@000000
05/0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`3o0?ooool0ooooa03oool10000
0000F`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0?l0ooooo`3oooo40?ooo`40
0000001K0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0o`3ooooo0?ooolD0oooo
0@00000005/0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`3o0?ooool0ooooa@3o
ool100000000F`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0ooooo`3oooo5
0?ooo`400000001K0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0o`3ooooo0?oo
olD0oooo0@00000005/0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`3o0?ooool0
ooooaP3oool100000000F`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0?l0oooo
o`3oooo60?ooo`400000001K0?ooo`@00000:@3oool00`000000oooo0?ooo`3o0?ooool0oooo``3o
ool400000000F`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0ooooo`3oooo7
0?ooo`400000001K0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3ooooo0?oo
olL0oooo0@00000005/0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?ooool0
ooooa`3oool100000000F`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0oooo
o`3oooo70?ooo`400000001K0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooolP0oooo0@00000005/0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`3o
0?ooool0oooob03oool100000000F`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
0?l0ooooo`3oooo80?ooo`400000001K0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooolT0oooo0@00000005/0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`3o0?ooool0oooob@3oool100000000F`3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo0?l0ooooo`3oooo90?ooo`400000001K0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooolT0oooo0@00000005/0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`3o0?ooool0oooobP3oool100000000F`3oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo0?l0ooooo`3oooo:0?ooo`400000001K0?ooo`@000009@3oool00`000000oooo
0?ooo`3o0?ooool0ooooa`3oool400000000F`3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo0?l0ooooo`3oooo;0?ooo`400000001K0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0o`3ooooo0?oool/0oooo0@00000005/0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`3o0?ooool0oooob`3oool100000000F`3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo0?l0ooooo`3oooo;0?ooo`400000001K0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0o`3ooooo0?oool`0oooo0@00000005/0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`3o0?ooool0ooooc03oool100000000F`3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo0?l0ooooo`3oooo<0?ooo`400000001K0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0o`3ooooo0?ooold0oooo0@00000005/0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`3o0?ooool0ooooc@3oool100000000F`3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo0?l0ooooo`3oooo=0?ooo`400000000T0?ooo`<000000`3o
ool010000000oooo0?ooo`3oool2000000D0oooo0P0000050?ooo`8000001P3oool3000000@0oooo
0`00000=0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0o`3ooooo0?ooold0oooo
0@00000002<0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`3o0?ooool0oooocP3oool1000000008`3oool01@000000oooo0?ooo`3oool00000
00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo
0?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`3o0?ooool0oooocP3oool1000000006@3oool7
000000<0oooo00D000000?ooo`3oool0oooo000000070?ooo`@000000`3oool4000000<0oooo1000
00020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000`0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3o0?ooool0oooocP3oool100000000
8`3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000020?oo
o`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`000000103oool00`000000oooo0000000=0?ooo`H000007P3oool00`000000oooo0?oo
o`3o0?ooool0oooobP3oool6000000008`3oool01@000000oooo0?ooo`3oool0000000H0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool0o`3ooooo0?oooll0oooo0@00000002<0
oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0000000@0oooo00<000000?ooo`0000003@3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0?l0ooooo`3oooo?0?ooo`400000000S0?ooo`050000003oool0oooo0?ooo`000000
1P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?oo
o`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D0
00000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
o`3ooooo0?oooll0oooo0@00000002<0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000
003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?oo
o`3oool0000000`0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`3o0?ooool0oooo
d03oool100000000903oool3000000P0oooo0`0000040?ooo`<00000103oool3000000@0oooo0`00
00040?ooo`<000003@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0?l0ooooo`3o
ooo@0?ooo`400000001K0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0o`3ooooo
0?ooom00oooo0@00000005/0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3o0?oo
ool0ooood@3oool100000000F`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0
ooooo`3ooooA0?ooo`400000001K0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
o`3ooooo0?ooom40oooo0@00000005/0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`3o0?ooool0ooood@3oool100000000F`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo0?l0ooooo`3ooooB0?ooo`400000001K0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0o`3ooooo0?ooom80oooo0@00000005/0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`3o0?ooool0oooodP3oool100000000F`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo0?l0ooooo`3ooooC0?ooo`400000001K0?ooo`@00000703oool00`000000oooo0?oo
o`3o0?ooool0ooood03oool400000000F`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo0?l0ooooo`3ooooC0?ooo`400000001K0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0o`3ooooo0?ooom<0oooo0@00000005/0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`3o0?ooool0ooooe03oool100000000F`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo0?l0ooooo`3ooooD0?ooo`400000001K0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooom@0oooo0@00000005/0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`3o0?ooool0ooooe03oool100000000F`3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo0?l0ooooo`3ooooE0?ooo`400000001K0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0o`3ooooo0?ooomD0oooo0@00000005/0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`3o0?ooool0ooooe@3oool100000000F`3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo0?l0ooooo`3ooooF0?ooo`400000001K0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0o`3ooooo0?ooomH0oooo0@00000005/0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`3o0?ooool0ooooeP3oool100000000F`3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo0?l0ooooo`3ooooF0?ooo`400000001K0?ooo`@00000
603oool00`000000oooo0?ooo`3o0?ooool0ooooe03oool400000000F`3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo0?l0ooooo`3ooooG0?ooo`400000001K0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0o`3ooooo0?ooomL0oooo0@00000005/0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`3o0?ooool0oooof03oool100000000F`3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo0?l0ooooo`3ooooH0?ooo`400000001K0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0o`3ooooo0?ooomP0oooo0@00000005/0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`3o0?ooool0oooof03oool100000000F`3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0?l0ooooo`3ooooI0?ooo`400000001K0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0o`3ooooo0?ooomT0oooo0@00000005/0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`3o0?ooool0oooof@3oool100000000
F`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0ooooo`3ooooJ0?ooo`400000
001K0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0o`3ooooo0?ooomX0oooo0@00
000005/0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3o0?ooool0oooofP3oool1
00000000F`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0ooooo`3ooooJ0?oo
o`400000001K0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3ooooo0?ooom/0
oooo0@00000005/0oooo1000000D0?ooo`030000003oool0oooo0?l0ooooo`3ooooH0?ooo`@00000
001K0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3ooooo0?ooom/0oooo0@00
000005/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3o0?ooool0oooog03oool1
00000000F`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0ooooo`3ooooL0?oo
o`400000001K0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0o`3ooooo0?ooom`0
oooo0@00000005/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3o0?ooool0oooo
g03oool100000000F`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0ooooo`3o
oooM0?ooo`400000001K0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0o`3ooooo
0?ooomd0oooo0@00000005/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3o0?oo
ool0oooog@3oool100000000F`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0
ooooo`3ooooN0?ooo`400000001K0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
o`3ooooo0?ooomh0oooo0@00000002@0oooo0`0000030?ooo`040000003oool0oooo0?ooo`800000
1@3oool2000000D0oooo0P0000060?ooo`<00000103oool3000000d0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`3o0?ooool0oooogP3oool1000000008`3oool01@000000oooo0?oo
o`3oool0000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?oo
o`000000303oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0ooooo`3ooooN0?oo
o`400000000S0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooO0?ooo`400000000I0?ooo`L000000`3oool01@000000oooo0?ooo`3o
ool0000000L0oooo100000030?ooo`@000000`3oool400000080oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooO0?ooo`400000000S0?ooo`050000003oool0oooo0?ooo`00
00001P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo00000002
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000030?ooo`050000003o
ool0oooo0?ooo`000000303oool6000000h0oooo00<000000?ooo`3oool0o`3ooooo0?ooomX0oooo
1P00000002<0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo0080oooo0P0000020?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`3o0?ooool0ooooh03oool1000000008`3oool01@00
0000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003o
ool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`00
00000`3oool010000000oooo00000000000=0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0o`3ooooo0?ooon00oooo0@00000002<0oooo00D000000?ooo`3oool0oooo000000060?oo
o`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D0
00000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0o`3ooooo0?ooon00
oooo0@00000002<0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?oo
o`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000
00020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0o`3ooooo0?ooon00oooo0@00000002@0oooo0`00
00080?ooo`<00000103oool3000000@0oooo0`0000040?ooo`<000001P3oool2000000`0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooool0ooooh@3oool100000000F`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooo`3ooooQ0?ooo`400000001K0?oo
o`030000003oool0oooo0?l0ooooo`3ooooc0?ooo`400000001K0?ooo`030000003oool0oooo0?l0
ooooo`3ooooc0?ooo`400000001K0?ooo`030000003oool0oooo0?l0ooooo`3ooooc0?ooo`400000
001K0?ooo`030000003oool0oooo0?l0ooooo`3ooooc0?ooo`400000001K0?ooo`030000003oool0
oooo0?l0ooooo`3ooooc0?ooo`400000001K0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0/@3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo0;40oooo00<000000?oo
o`3oool0/@3oool00`000000oooo0?ooo`0?0?ooo`400000001K0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo0;40
oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0?0?ooo`400000001K0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo00l0oooo0@00000005/0oooo1000000>0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0<0?ooo`@00000001K0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo00l0oooo0@00000005/0ooooo`00003o00000?L00000003o0?ooool0ooooo`3ooomC0?ooo`00
o`3ooooo0?ooool0ooooD`3oool00?l0ooooo`3ooooo0?oooe<0oooo003o0?ooool0ooooo`3ooomC
0?ooo`00o`3ooooo0?ooool0ooooD`3oool00001\
\>"],
  ImageRangeCache->{{{0, 847.438}, {523.375, 0}} -> {-0.304193, -1.00003, \
0.00277843, 3.39782*^-07}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\($TextStyle = {FontFamily \[Rule] "\<Times\>", 
          FontSize \[Rule] 14};\)\), "\[IndentingNewLine]", 
    \(Show[{plasq1, plasp1}, 
      Epilog \[Rule] {Text["\<Phantom, s=1\>", {3.1, 15}], 
          Text["\<Quintessence s=1\>", {3. , 2}]}, \ 
      Frame \[Rule] True]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238091 0.238095 0.0147123 0.0212413 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.2619 -0.0125 -5.53125 -17.8125 ]
[.2619 -0.0125 5.53125 0 ]
[.5 -0.0125 -5.53125 -17.8125 ]
[.5 -0.0125 5.53125 0 ]
[.7381 -0.0125 -5.53125 -17.8125 ]
[.7381 -0.0125 5.53125 0 ]
[.97619 -0.0125 -5.53125 -17.8125 ]
[.97619 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -11.75 -35.625 ]
[.5 -0.0125 11.75 -17.8125 ]
[-0.0125 .01471 -11.0625 -8.90625 ]
[-0.0125 .01471 0 8.90625 ]
[-0.0125 .12092 -11.0625 -8.90625 ]
[-0.0125 .12092 0 8.90625 ]
[-0.0125 .22713 -18.125 -8.90625 ]
[-0.0125 .22713 0 8.90625 ]
[-0.0125 .33333 -18.125 -8.90625 ]
[-0.0125 .33333 0 8.90625 ]
[-0.0125 .43954 -18.125 -8.90625 ]
[-0.0125 .43954 0 8.90625 ]
[-0.0125 .54575 -18.125 -8.90625 ]
[-0.0125 .54575 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -35.9375 -11.6563 ]
[-0.01875 .30902 -18.125 11.6563 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.7619 .33333 -41.1563 -8.90625 ]
[.7619 .33333 41.1563 8.90625 ]
[.7381 .05719 -52.0625 -8.90625 ]
[.7381 .05719 52.0625 8.90625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -72.75 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
73.063 19.750 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
78.563 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
82.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01471 m
.00625 .01471 L
s
gsave
-0.0125 .01471 -72.0625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .12092 m
.00625 .12092 L
s
gsave
-0.0125 .12092 -72.0625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .22713 m
.00625 .22713 L
s
gsave
-0.0125 .22713 -79.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .33333 m
.00625 .33333 L
s
gsave
-0.0125 .33333 -79.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
0 .43954 m
.00625 .43954 L
s
gsave
-0.0125 .43954 -79.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .54575 m
.00625 .54575 L
s
gsave
-0.0125 .54575 -79.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03595 m
.00375 .03595 L
s
0 .05719 m
.00375 .05719 L
s
0 .07844 m
.00375 .07844 L
s
0 .09968 m
.00375 .09968 L
s
0 .14216 m
.00375 .14216 L
s
0 .1634 m
.00375 .1634 L
s
0 .18464 m
.00375 .18464 L
s
0 .20588 m
.00375 .20588 L
s
0 .24837 m
.00375 .24837 L
s
0 .26961 m
.00375 .26961 L
s
0 .29085 m
.00375 .29085 L
s
0 .31209 m
.00375 .31209 L
s
0 .35457 m
.00375 .35457 L
s
0 .37581 m
.00375 .37581 L
s
0 .39706 m
.00375 .39706 L
s
0 .4183 m
.00375 .4183 L
s
0 .46078 m
.00375 .46078 L
s
0 .48202 m
.00375 .48202 L
s
0 .50326 m
.00375 .50326 L
s
0 .5245 m
.00375 .5245 L
s
0 .56699 m
.00375 .56699 L
s
0 .58823 m
.00375 .58823 L
s
0 .60947 m
.00375 .60947 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -99.6875 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
72.6563 12.9063 translate
90 rotate
-72.6563 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.250 17.500 moveto
(H) show
73.813 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
77.750 17.500 moveto
(L) show
82.313 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01471 m
1 .01471 L
s
.99375 .12092 m
1 .12092 L
s
.99375 .22713 m
1 .22713 L
s
.99375 .33333 m
1 .33333 L
s
.99375 .43954 m
1 .43954 L
s
.99375 .54575 m
1 .54575 L
s
.125 Mabswid
.99625 .03595 m
1 .03595 L
s
.99625 .05719 m
1 .05719 L
s
.99625 .07844 m
1 .07844 L
s
.99625 .09968 m
1 .09968 L
s
.99625 .14216 m
1 .14216 L
s
.99625 .1634 m
1 .1634 L
s
.99625 .18464 m
1 .18464 L
s
.99625 .20588 m
1 .20588 L
s
.99625 .24837 m
1 .24837 L
s
.99625 .26961 m
1 .26961 L
s
.99625 .29085 m
1 .29085 L
s
.99625 .31209 m
1 .31209 L
s
.99625 .35457 m
1 .35457 L
s
.99625 .37581 m
1 .37581 L
s
.99625 .39706 m
1 .39706 L
s
.99625 .4183 m
1 .4183 L
s
.99625 .46078 m
1 .46078 L
s
.99625 .48202 m
1 .48202 L
s
.99625 .50326 m
1 .50326 L
s
.99625 .5245 m
1 .5245 L
s
.99625 .56699 m
1 .56699 L
s
.99625 .58823 m
1 .58823 L
s
.99625 .60947 m
1 .60947 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02382 .01473 m
.02493 .01524 L
.02595 .01552 L
.02823 .01602 L
.03234 .01674 L
.04168 .01803 L
.06052 .0201 L
.10055 .02366 L
.13848 .0267 L
.17497 .02958 L
.2138 .03275 L
.25118 .03598 L
.28712 .0393 L
.32539 .0431 L
.36223 .04704 L
.40139 .05153 L
.43911 .05612 L
.4754 .06076 L
.51401 .06586 L
.55118 .07084 L
.59069 .07607 L
.62875 .08087 L
.66537 .08505 L
.68394 .08691 L
.70432 .0887 L
.72395 .09012 L
.74184 .09108 L
.7464 .09127 L
.75135 .09145 L
.75564 .09158 L
.76037 .09169 L
.76278 .09174 L
.76538 .09178 L
.76681 .0918 L
.76812 .09181 L
.76945 .09183 L
.77069 .09184 L
.77177 .09184 L
.77291 .09185 L
.77357 .09185 L
.77419 .09185 L
.77534 .09185 L
.77657 .09185 L
.77769 .09184 L
.77893 .09184 L
.78024 .09183 L
.78264 .0918 L
.78492 .09177 L
.7892 .09168 L
.79381 .09155 L
Mistroke
.79884 .09136 L
.80786 .0909 L
.81623 .09031 L
.8263 .08938 L
.83577 .08826 L
.85346 .08541 L
.86275 .08344 L
.87257 .08094 L
.89013 .07505 L
.89916 .07104 L
.90882 .06561 L
.91351 .06236 L
.91794 .05874 L
.92226 .05443 L
.92625 .04931 L
.92857 .04543 L
Mfstroke
.02381 .01472 m
.02499 .01525 L
.02605 .01554 L
.02846 .01606 L
.03279 .01681 L
.04262 .01815 L
.06244 .02029 L
.10458 .02397 L
.14451 .0271 L
.18292 .03007 L
.22379 .03336 L
.26314 .03682 L
.30098 .04054 L
.34126 .04509 L
.38004 .0502 L
.42126 .05666 L
.46097 .06414 L
.49916 .07279 L
.53981 .08394 L
.57894 .09703 L
.62052 .1141 L
.66059 .13439 L
.69914 .15837 L
.74014 .18984 L
.77963 .22744 L
.8176 .27204 L
.85802 .33091 L
.89693 .40151 L
.93829 .49553 L
.97619 .60332 L
s
gsave
.7619 .33333 -102.156 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Phantom) show
112.875 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
119.750 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
125.250 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
141.313 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.7381 .05719 -113.063 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Quintessence) show
141.563 17.500 moveto
(s) show
147.063 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.063 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
163.125 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00Y03oool2000007X0oooo002S0?ooo`040000003o
ool0oooo000007T0oooo002I0?ooo`<000000`3oool3000000050?ooo`000000oooo0?ooo`000000
0`3oool2000007@0oooo002J0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
0P3oool01`000000oooo0?ooo`3oool000000?ooo`000000L`3oool009X0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`000000M@3oool0
09X0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`050000003oool0
oooo0?ooo`000000M@3oool009X0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3o
ool2000000@0oooo00<000000?ooo`3oool0L`3oool009X0oooo1`0000090?ooo`030000003oool0
oooo07<0oooo002J0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool30000
07@0oooo002J0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`1c0?ooo`00VP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0L`3oool009T0oooo0`0000030?ooo`<00000OP3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool003L0oooo0`00000b0?ooo`<00000<@3oool500000340oooo
1000000d0?ooo`030000003oool0oooo00l0oooo000f0?ooo`050000003oool0oooo0?ooo`000000
<P3oool00`000000oooo0?ooo`0a0?ooo`040000003oool0oooo000003D0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`0?0?ooo`00=P3oool01@000000oooo0?ooo`3oool000000380
oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool03`3oool003H0oooo00D000000?ooo`3oool0oooo0000000b0?ooo`03
0000003oool0oooo03<0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0]0?ooo`H0
0000403oool003H0oooo00D000000?ooo`3oool0oooo0000000b0?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0]0?ooo`050000003oool0oooo0?oo
o`0000004@3oool003H0oooo00D000000?ooo`3oool0oooo0000000b0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0<@3oool200000340oooo00@000000?ooo`3oool000004@3oool0
03H0oooo00D000000?ooo`3oool0oooo0000000b0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool000000140oooo000f0?oo
o`050000003oool0oooo0?ooo`000000<P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0000000A0?ooo`00=P3oool01@00
0000oooo0?ooo`3oool000000340oooo0P00000b0?ooo`050000003oool0oooo0?ooo`000000<@3o
ool01@000000oooo0?ooo`3oool000000380oooo0P00000A0?ooo`00=`3oool3000003<0oooo00<0
00000?ooo`3oool0<@3oool3000003<0oooo0`00000d0?ooo`030000003oool0oooo00l0oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000Y
0?ooo`<000001`3ooooQ000000`0oooo000X0?ooo`050000003oool0oooo0?ooo`0000001P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo000X0?ooo`050000003oool0oooo
0?ooo`0000001P3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00X0oooo000X0?oo
o`050000003oool0oooo0?ooo`0000001P3oool2000000<0oooo0P00003H0?ooo`800000303oool0
02P0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00<0oooo3000003>
0?ooo`030000003oool0oooo00X0oooo000X0?ooo`050000003oool0oooo0?ooo`0000001P3oool0
0`000000oooo0?ooo`090?oooa000000a03oool00`000000oooo0?ooo`0:0?ooo`00:03oool01@00
0000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0603oool:000005D0oooo0P00001T
0?ooo`030000003oool0oooo00X0oooo000X0?ooo`050000003oool0oooo0?ooo`0000001P3oool0
0`000000oooo0?ooo`0P0?oooa@00000@P3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0
oooo00X0oooo000X0?ooo`050000003oool0oooo0?ooo`0000001P3oool200000380oooo2`00000i
0?ooo`030000003oool0oooo06@0oooo0P00000<0?ooo`00:@3oool3000000L0oooo00<000000?oo
o`3oool0>@3oool<000002h0oooo100000050?ooo`80000000<0oooo0000003oool01P0000001@3o
ool00000000000000000oooo008000000`3oool300000080oooo0`0000030?ooo`<00000103oool3
000000050?ooo`00000000000000003oool00`0000020?ooo`<00000103oool3000000H0oooo0`00
000<0?ooo`<000002`3oool00`000000oooo0?ooo`0:0?ooo`00<`3oool00`000000oooo0?ooo`12
0?ooo``00000903oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3o
ool3000000050?ooo`000000oooo0?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000
003oool000000`3oool00`000000oooo000000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`040000003oool0oooo000000<0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo
0000003oool01`0000001@3oool000000?ooo`3oool0000000`0oooo00<000000?ooo`3oool02P3o
ool003<0oooo00<000000?ooo`3oool0BP3oool;000001`0oooo00<000000?ooo`3oool0103oool0
10000000oooo0?ooo`0000030?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0
oooo000000020?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`040000003o
ool0oooo000000`0oooo00<000000?ooo`3oool02P3oool003<0oooo00<000000?ooo`3oool0D`3o
ool8000001H0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000030?ooo`040000
003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo
0?ooo`0000001P3oool2000000@0oooo0P0000030?ooo`030000003oool0oooo00<0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203o
ool2000000T0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00X0oooo
000c0?ooo`800000FP3oool:000000h0oooo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`0000030?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo0?ooo`D0000000<0oooo0000003oool0103oool00`000000oooo0?ooo`03
0?ooo`D0000000<0oooo0000003oool00P3oool010000000oooo0?ooo`0000060?ooo`D000001@3o
ool00`000000oooo0?ooo`020?ooo`L00000103oool00`000000oooo0?ooo`090?ooo`800000303o
ool003<0oooo00<000000?ooo`3oool0H03oool<000000D0oooo00<000000?ooo`3oool0103oool0
10000000oooo0?ooo`0000030?ooo`050000003oool000000000003oool00`0000020?ooo`040000
003oool0oooo000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`@000000P3oool010000000oooo
0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`0000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0:0?ooo`00<`3oool00`000000oooo0?ooo`1W0?ooo`@0000000<0oooo0000
000000001P0000040?ooo`040000003oool0000000000080oooo0P0000020?ooo`050000003oool0
oooo0000003oool00P0000020?ooo`<000000`3oool3000000<0oooo0`0000030?ooo`<000000`3o
ool300000080oooo00@000000?ooo`0000000000103oool3000000@0oooo0`0000070?ooo`<00000
103oool2000000H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`00<`3o
ool00`000000oooo0?ooo`1[0?ooo`@000000P3oool00`000000oooo0?ooo`09000000l0oooo00<0
00000?ooo`3oool0=`3oool2000000P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0:0?ooo`00<`3oool00`000000oooo0?ooo`1_0?ooo`@00000103oool00`000000oooo0?ooo`03
0?ooo`T000001P3oool00`000000oooo0?ooo`0d0?ooo`<000002@3oool2000000`0oooo00<00000
0?ooo`3oool02P3oool003<0oooo0P00001c0?ooo`D000002`3oool010000000oooo0?ooo`3oool8
00000380oooo0`00000=0?ooo`030000003oool0oooo00T0oooo0P00000<0?ooo`00<`3oool00`00
0000oooo0?ooo`1e0?ooo`<000005P3oool;00000280oooo1@00000M0?ooo`030000003oool0oooo
00X0oooo000c0?ooo`030000003oool0oooo07P0oooo0`00000N0?ooo`d000002P3oool;00000280
oooo00<000000?ooo`3oool02P3oool003<0oooo00<000000?ooo`3oool0N`3oool3000002P0oooo
2P00000]0?ooo`030000003oool0oooo00X0oooo000c0?ooo`800000O`3oool3000005/0oooo0P00
000<0?ooo`00:03oool3000000P0oooo00<000000?ooo`3oool0P@3oool2000005X0oooo00<00000
0?ooo`3oool02P3oool002/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`230?oo
o`800000F03oool00`000000oooo0?ooo`0:0?ooo`00;03oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo08D0oooo0P00001F0?ooo`030000003oool0oooo00X0oooo000/0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0Q`3oool3000005<0oooo00<000000?ooo`3oool0
2P3oool002`0oooo00<000000?ooo`3oool0103oool2000008/0oooo0P00001@0?ooo`800000303o
ool002/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2<0?ooo`800000C`3oool0
0`000000oooo0?ooo`0:0?ooo`00:03oool3000000P0oooo00<000000?ooo`3oool0SP3oool20000
04d0oooo00<000000?ooo`3oool02P3oool002P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`2@0?ooo`800000B`3oool00`000000oooo0?ooo`0:0?ooo`00:@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0980oooo0P0000190?ooo`030000003oool0oooo00X0oooo
000Y0?ooo`@000001P3oool2000009D0oooo0P0000160?ooo`800000303oool003<0oooo00<00000
0?ooo`3oool0UP3oool2000004D0oooo00<000000?ooo`3oool02P3oool003<0oooo00<000000?oo
o`3oool0V03oool2000004<0oooo00<000000?ooo`3oool02P3oool003<0oooo00<000000?ooo`3o
ool0VP3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00X0oooo000c0?ooo`030000
003oool0oooo09/0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0:0?ooo`00<`3o
ool2000009d0oooo00<000000?ooo`3oool0?@3oool2000000`0oooo000c0?ooo`030000003oool0
oooo09d0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0:0?ooo`00<`3oool00`00
0000oooo0?ooo`2N0?ooo`800000?@3oool00`000000oooo0?ooo`0:0?ooo`00<`3oool00`000000
oooo0?ooo`2P0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool02P3oool003<0oooo
0P00002R0?ooo`030000003oool0oooo03P0oooo0P00000<0?ooo`00<`3oool00`000000oooo0?oo
o`2R0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool02P3oool003<0oooo00<00000
0?ooo`3oool0X`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00X0oooo000c0?oo
o`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0:0?oo
o`00<`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool02P3oool003<0oooo0P00002W0?ooo`030000003oool0oooo03<0oooo0P00000<0?ooo`008P3o
ool3000000@0oooo0`0000070?ooo`030000003oool0oooo0:L0oooo0P00000d0?ooo`030000003o
ool0oooo00X0oooo000S0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`0:0?ooo`008`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001P3o
ool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3o
ool002<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo000S
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000060?ooo`800000[@3o
ool00`000000oooo0?ooo`0]0?ooo`800000303oool002<0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo00X0oooo000S0?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000060?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`0:0?ooo`008`3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`0000001P3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool02P3oool00280oooo0P0000040?ooo`050000003oool0oooo0?ooo`0000001P3o
ool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02P3o
ool002<0oooo00<000000?ooo`3oool00`3oool3000000L0oooo0P00002a0?ooo`030000003oool0
oooo02T0oooo0P00000<0?ooo`00<`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool02P3oool003<0oooo00<000000?ooo`3oool0/P3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo00X0oooo000c0?ooo`030000003oool0oooo0;80oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0:0?ooo`00<`3oool200000;@0oooo00<0
00000?ooo`3oool09P3oool2000000`0oooo000B0?ooo`030000003oool0oooo00800000703oool0
0`000000oooo0?ooo`2d0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool02P3oool0
0140oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo0;D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0:0?ooo`004@3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0]@3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00X0oooo000A0?ooo`060000003oool0oooo
0000003oool00000703oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool02P3oool00180oooo1P00000K0?ooo`800000^03oool00`000000oooo0?ooo`0R
0?ooo`800000303oool001L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`2g0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool02P3oool003<0oooo00<000000?ooo`3o
ool0^03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00X0oooo000@0?ooo`T00000
6P3oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
2P3oool000l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo0;<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo00X0oooo000>0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05P3oool2
00000;D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0O0?ooo`800000303oool0
0140oooo00<000000?ooo`3oool03P3oool3000000<0oooo0`0000080?ooo`030000003oool0oooo
0840oooo0`0000050?ooo`<0000000D0oooo00000000000000000?ooo`08000000050?ooo`000000
00000000003oool00P0000030?ooo`<000000P3oool3000000050?ooo`00000000000000003oool0
1@0000050?ooo`<000003@3oool300000100oooo00<000000?ooo`3oool02P3oool000l0oooo2@00
000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`220?ooo`030000003oool0oooo00D0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0
oooo00@000000?ooo`3oool000000`3oool020000000oooo0?ooo`000000oooo0000003oool00000
0`3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`000000203oool01000
0000oooo0000000000020?ooo`L00000103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00X0oooo000A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0PP3oool00`00
0000oooo0?ooo`050?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`040000003o
ool0oooo000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00P0oooo0P00000=
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool001H0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0PP3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000000P3oool4
00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000
0`3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000002@3oool30000
00d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`003P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`040?ooo`800000P`3oool5000000<0oooo00D000000?ooo`3oool0oooo000000050?oo
o`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00H0
oooo00H000000?ooo`3oool0oooo0000003oool7000000@0oooo00<000000?ooo`3oool03P3oool2
000000`0oooo000?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0PP3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo008000000P3oool00`000000oooo000000030?oo
o`030000003oool00000008000000P3oool010000000oooo0?ooo`0000030?ooo`060000003oool0
oooo0?ooo`000000oooo0`0000020?ooo`8000000P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00800000303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo
000@0?ooo`T000002P3oool00`000000oooo0?ooo`020?ooo`<00000203oool00`000000oooo0?oo
o`220?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool000000?ooo`02000000<0oooo
0`0000030?ooo`040000003oool0000000000080oooo0`0000030?ooo`<000000`3oool010000000
oooo0000000000020?ooo`8000002P3oool3000000030?ooo`000000oooo00X0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`008`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000001<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool00280oooo0P0000050?ooo`03
0000003oool0oooo00L0oooo0P0000230?ooo`030000003oool0oooo0080oooo00@000000?ooo`00
000000004`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo0P00000@0?oo
o`800000303oool002<0oooo00<000000?ooo`3oool00`3oool4000000H0oooo00<000000?ooo`3o
ool0P@3oool6000000<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool003<0oooo00<000000?ooo`3oool0
`@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00X0oooo000c0?ooo`030000003o
ool0oooo0<40oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0:0?ooo`00<`3oool0
0`000000oooo0?ooo`320?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool02P3oool0
03<0oooo0P0000340?ooo`030000003oool0oooo01H0oooo0P00000<0?ooo`00<`3oool00`000000
oooo0?ooo`330?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02P3oool003<0oooo
00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00X0oooo
000c0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0:0?ooo`00<`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool02P3oool003<0oooo0P0000360?ooo`030000003oool0oooo01@0oooo0P00000<0?oo
o`00<`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool02P3oool003<0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00X0oooo000c0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0:0?ooo`00<`3oool00`000000oooo0?ooo`370?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool02P3oool003<0oooo0P0000390?ooo`030000003oool0oooo
0140oooo0P00000<0?ooo`008@3oool5000000<0oooo0`0000070?ooo`030000003oool0oooo0<P0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0:0?ooo`008P3oool010000000oooo
0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`390?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool02P3oool002<0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0b@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000T0?ooo`050000003oool0oooo0?oo
o`0000000`3oool00`000000oooo0?ooo`040?ooo`800000bP3oool00`000000oooo0?ooo`0@0?oo
o`800000303oool002@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00X0oooo000U0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`3:0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02P3oool002D0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0</0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`009@3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0b`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo000Q0?ooo`050000003oool0oooo0?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000000H0oooo0P00003=0?ooo`030000003oool0
oooo00d0oooo0P00000<0?ooo`008P3oool3000000@0oooo0`0000070?ooo`030000003oool0oooo
0<`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`00<`3oool00`000000
oooo0?ooo`3<0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02P3oool003<0oooo
00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo
000c0?ooo`030000003oool0oooo0<d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0:0?ooo`00<`3oool200000<l0oooo00<000000?ooo`3oool02`3oool2000000`0oooo000c0?oo
o`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?oo
o`00<`3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02P3oool003<0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00X0oooo000c0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0:0?ooo`00<`3oool200000=40oooo00<000000?ooo`3oool02@3oool2
000000`0oooo000c0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0:0?ooo`00<`3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool003<0oooo00<000000?ooo`3oool0d@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00X0oooo000c0?ooo`030000003oool0oooo0=40oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`00<`3oool200000=<0oooo00<00000
0?ooo`3oool01`3oool2000000`0oooo000Q0?ooo`D000000P3oool3000000P0oooo00<000000?oo
o`3oool0dP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo000R0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3B0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool002<0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0:0?ooo`00903oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo0P00003D0?ooo`030000003oool0oooo00H0oooo0P00000<0?ooo`00903o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0d`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo000U0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3D0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool02P3oool002D0oooo00<000000?ooo`3oool00`0000080?oo
o`030000003oool0oooo0=@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?oo
o`009@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0=D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`008@3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool01`3oool200000=H0oooo00<000000?ooo`3oool0103oool20000
00`0oooo000R0?ooo`<00000103oool4000000H0oooo00<000000?ooo`3oool0e@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo000c0?ooo`030000003oool0oooo0=H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`00<`3oool00`000000oooo0?oo
o`3F0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool003<0oooo00<00000
0?ooo`3oool0eP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo000c0?oo
o`800000f03oool00`000000oooo0?ooo`020?ooo`800000303oool003<0oooo00<000000?ooo`3o
ool0e`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo000c0?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`00<`3o
ool00`000000oooo0?ooo`3H0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3o
ool003<0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`0:0?ooo`00<`3oool20000
00<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool0<`3oool010000000oooo0?ooo`3oool2000000`0oooo000c0?oo
on400000303oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.06353, -8.76473, \
0.0187404, 0.210062}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\($TextStyle = {FontFamily \[Rule] "\<Times\>", 
          FontSize \[Rule] 14};\)\), "\[IndentingNewLine]", 
    \(Show[{plfsq1, plfsp1}, 
      Epilog \[Rule] {Text["\<Phantom, s=1\>", {2, 1.3}], 
          Text["\<Quintessence s=1\>", {3.2, 0}]}, \ Frame \[Rule] True, 
      Axes \[Rule] False]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238091 0.238095 0.339807 0.157556 [
[.02381 -0.0125 -5.53125 -17.8125 ]
[.02381 -0.0125 5.53125 0 ]
[.2619 -0.0125 -5.53125 -17.8125 ]
[.2619 -0.0125 5.53125 0 ]
[.5 -0.0125 -5.53125 -17.8125 ]
[.5 -0.0125 5.53125 0 ]
[.7381 -0.0125 -5.53125 -17.8125 ]
[.7381 -0.0125 5.53125 0 ]
[.97619 -0.0125 -5.53125 -17.8125 ]
[.97619 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -11.75 -35.625 ]
[.5 -0.0125 11.75 -17.8125 ]
[-0.0125 .02469 -20.75 -8.90625 ]
[-0.0125 .02469 0 8.90625 ]
[-0.0125 .10347 -31.25 -8.90625 ]
[-0.0125 .10347 0 8.90625 ]
[-0.0125 .18225 -20.75 -8.90625 ]
[-0.0125 .18225 0 8.90625 ]
[-0.0125 .26103 -31.25 -8.90625 ]
[-0.0125 .26103 0 8.90625 ]
[-0.0125 .33981 -11.0625 -8.90625 ]
[-0.0125 .33981 0 8.90625 ]
[-0.0125 .41859 -21.5625 -8.90625 ]
[-0.0125 .41859 0 8.90625 ]
[-0.0125 .49736 -11.0625 -8.90625 ]
[-0.0125 .49736 0 8.90625 ]
[-0.0125 .57614 -21.5625 -8.90625 ]
[-0.0125 .57614 0 8.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -49.0625 -21.9688 ]
[-0.01875 .30902 -31.25 21.9688 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .54463 -41.1563 -8.90625 ]
[.5 .54463 41.1563 8.90625 ]
[.78571 .33981 -52.0625 -8.90625 ]
[.78571 .33981 52.0625 8.90625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5313 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -72.75 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
73.063 19.750 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
78.563 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
82.500 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02469 m
.00625 .02469 L
s
gsave
-0.0125 .02469 -81.75 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .10347 m
.00625 .10347 L
s
gsave
-0.0125 .10347 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
0 .18225 m
.00625 .18225 L
s
gsave
-0.0125 .18225 -81.75 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .26103 m
.00625 .26103 L
s
gsave
-0.0125 .26103 -92.25 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .33981 m
.00625 .33981 L
s
gsave
-0.0125 .33981 -72.0625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .41859 m
.00625 .41859 L
s
gsave
-0.0125 .41859 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .49736 m
.00625 .49736 L
s
gsave
-0.0125 .49736 -72.0625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .57614 m
.00625 .57614 L
s
gsave
-0.0125 .57614 -82.5625 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04045 m
.00375 .04045 L
s
0 .05621 m
.00375 .05621 L
s
0 .07196 m
.00375 .07196 L
s
0 .08772 m
.00375 .08772 L
s
0 .11923 m
.00375 .11923 L
s
0 .13498 m
.00375 .13498 L
s
0 .15074 m
.00375 .15074 L
s
0 .1665 m
.00375 .1665 L
s
0 .19801 m
.00375 .19801 L
s
0 .21376 m
.00375 .21376 L
s
0 .22952 m
.00375 .22952 L
s
0 .24527 m
.00375 .24527 L
s
0 .27678 m
.00375 .27678 L
s
0 .29254 m
.00375 .29254 L
s
0 .3083 m
.00375 .3083 L
s
0 .32405 m
.00375 .32405 L
s
0 .35556 m
.00375 .35556 L
s
0 .37132 m
.00375 .37132 L
s
0 .38707 m
.00375 .38707 L
s
0 .40283 m
.00375 .40283 L
s
0 .43434 m
.00375 .43434 L
s
0 .4501 m
.00375 .4501 L
s
0 .46585 m
.00375 .46585 L
s
0 .48161 m
.00375 .48161 L
s
0 .51312 m
.00375 .51312 L
s
0 .52887 m
.00375 .52887 L
s
0 .54463 m
.00375 .54463 L
s
0 .56039 m
.00375 .56039 L
s
0 .00894 m
.00375 .00894 L
s
0 .5919 m
.00375 .5919 L
s
0 .60765 m
.00375 .60765 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -123.125 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
82.9688 12.9063 translate
90 rotate
-82.9688 -12.9063 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(V) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.063 17.500 moveto
(H) show
77.625 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
85.313 17.500 moveto
(H) show
89.875 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.813 17.500 moveto
(L) show
98.375 17.500 moveto
(L) show
102.938 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02469 m
1 .02469 L
s
.99375 .10347 m
1 .10347 L
s
.99375 .18225 m
1 .18225 L
s
.99375 .26103 m
1 .26103 L
s
.99375 .33981 m
1 .33981 L
s
.99375 .41859 m
1 .41859 L
s
.99375 .49736 m
1 .49736 L
s
.99375 .57614 m
1 .57614 L
s
.125 Mabswid
.99625 .04045 m
1 .04045 L
s
.99625 .05621 m
1 .05621 L
s
.99625 .07196 m
1 .07196 L
s
.99625 .08772 m
1 .08772 L
s
.99625 .11923 m
1 .11923 L
s
.99625 .13498 m
1 .13498 L
s
.99625 .15074 m
1 .15074 L
s
.99625 .1665 m
1 .1665 L
s
.99625 .19801 m
1 .19801 L
s
.99625 .21376 m
1 .21376 L
s
.99625 .22952 m
1 .22952 L
s
.99625 .24527 m
1 .24527 L
s
.99625 .27678 m
1 .27678 L
s
.99625 .29254 m
1 .29254 L
s
.99625 .3083 m
1 .3083 L
s
.99625 .32405 m
1 .32405 L
s
.99625 .35556 m
1 .35556 L
s
.99625 .37132 m
1 .37132 L
s
.99625 .38707 m
1 .38707 L
s
.99625 .40283 m
1 .40283 L
s
.99625 .43434 m
1 .43434 L
s
.99625 .4501 m
1 .4501 L
s
.99625 .46585 m
1 .46585 L
s
.99625 .48161 m
1 .48161 L
s
.99625 .51312 m
1 .51312 L
s
.99625 .52887 m
1 .52887 L
s
.99625 .54463 m
1 .54463 L
s
.99625 .56039 m
1 .56039 L
s
.99625 .00894 m
1 .00894 L
s
.99625 .5919 m
1 .5919 L
s
.99625 .60765 m
1 .60765 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02382 .46585 m
.02493 .46585 L
.02595 .46585 L
.02712 .46585 L
.02823 .46584 L
.0302 .46583 L
.03234 .46582 L
.0347 .4658 L
.0372 .46577 L
.04168 .4657 L
.04631 .46562 L
.05065 .46552 L
.06052 .46523 L
.07059 .46484 L
.0798 .46441 L
.10055 .46316 L
.13827 .45994 L
.17455 .45579 L
.21317 .45034 L
.25034 .4442 L
.28984 .43683 L
.3279 .42899 L
.36453 .42084 L
.40348 .41154 L
.44099 .402 L
.47707 .39228 L
.51547 .3813 L
.55243 .37007 L
.59172 .35731 L
.62958 .34407 L
.66599 .33026 L
.70473 .31409 L
.74204 .29659 L
.7779 .27721 L
.81609 .25233 L
.85284 .22104 L
.87188 .19956 L
.88157 .1862 L
.89193 .16911 L
.90175 .14872 L
.91068 .12412 L
.91499 .10873 L
.91966 .08755 L
.9218 .07543 L
.92406 .06003 L
.926 .04379 L
.92813 .02059 L
.92857 .01472 L
s
.02381 .43434 m
.02499 .43434 L
.02605 .43434 L
.02729 .43435 L
.02846 .43435 L
.03053 .43436 L
.03279 .43438 L
.03527 .4344 L
.0379 .43443 L
.04262 .4345 L
.04749 .4346 L
.05205 .43471 L
.06244 .43503 L
.07305 .43546 L
.08274 .43594 L
.10458 .43733 L
.14429 .4409 L
.18248 .44552 L
.22313 .45156 L
.26226 .45832 L
.30384 .4663 L
.34391 .47456 L
.38246 .48287 L
.42346 .49193 L
.46295 .50073 L
.50092 .50917 L
.54134 .51807 L
.58025 .52649 L
.62161 .53527 L
.66146 .54355 L
.69979 .55135 L
.74057 .55947 L
.77984 .56712 L
.81759 .57434 L
.85779 .58188 L
.89648 .589 L
.93762 .59645 L
.97619 .60332 L
s
gsave
.5 .54463 -102.156 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Phantom) show
112.875 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
119.750 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
125.250 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
141.313 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.78571 .33981 -113.063 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 25.8125 translate 1 -1 scale
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Quintessence) show
141.563 17.500 moveto
(s) show
147.063 17.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.063 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
163.125 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{688.063, 425.25},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:`0001ZB000`400?l00000o`00003oo`3ooooo
0?oook80oooo003o0?ooool0oooo/P3oool00?l0ooooo`3ooonb0?ooo`00o`3ooomh0?ooo`800000
o`3ooolh0?ooo`00o`3ooomg0?ooo`040000003oool0oooo00000?l0oooo=`3oool00?l0ooooM`3o
ool010000000oooo0?ooo`00003o0?ooocL0oooo003o0?ooofd0oooo0`0000030?ooo`<0000000D0
oooo0000003oool0oooo000000020?ooo`800000o`3ooolc0?ooo`00o`3ooom^0?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo0000
0?l0oooo<P3oool00?l0ooooKP3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000o`3ooold0?ooo`00o`3ooom^0?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`030000003oool0oooo0?l0oooo<P3oool0
0?l0ooooKP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0o`3ooolb0?ooo`00o`3ooom^0?ooo`L00000203oool00`000000oooo0?ooo`3o0?oooc80
oooo003o0?ooofh0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`<00000
o`3ooolc0?ooo`00o`3ooom^0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`3o0?oooc80oooo003o0?ooofh0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo<P3oool00?l0ooooK@3oool30000
00<0oooo0`00003o0?oooc`0oooo003o0?ooool0oooo/P3oool00?l0ooooo`3ooonb0?ooo`00o`3o
oooo0?oook80oooo003o0?ooool0oooo/P3oool00?l0ooooo`3ooonb0?ooo`00o`3ooooo0?oook80
oooo003o0?ooool0oooo/P3oool004h0oooo0`00002@0?ooo`<00000S`3oool5000008d0oooo1000
002B0?ooo`030000003oool0oooo0180oooo001=0?ooo`050000003oool0oooo0?ooo`000000T03o
ool00`000000oooo0?ooo`2?0?ooo`040000003oool0oooo00000940oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`0B0?ooo`00C@3oool01@000000oooo0?ooo`3oool000000900oooo
00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool04P3oool004d0oooo00D000000?ooo`3oool0oooo0000002@0?ooo`030000
003oool0oooo0940oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`2;0?ooo`H00000
4`3oool004d0oooo00D000000?ooo`3oool0oooo0000002@0?ooo`030000003oool0oooo0940oooo
00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`2;0?ooo`050000003oool0oooo0?ooo`00
0000503oool004d0oooo00D000000?ooo`3oool0oooo0000002@0?ooo`030000003oool0oooo0980
oooo00<000000?ooo`3oool0S@3oool2000008l0oooo00@000000?ooo`3oool00000503oool004d0
oooo00D000000?ooo`3oool0oooo0000002@0?ooo`030000003oool0oooo0980oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0000001@0oooo001=0?ooo`05
0000003oool0oooo0?ooo`000000T03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0000000D0?ooo`00C@3oool01@000000
oooo0?ooo`3oool0000008l0oooo0P00002@0?ooo`050000003oool0oooo0?ooo`000000S@3oool0
1@000000oooo0?ooo`3oool000000900oooo0P00000D0?ooo`00CP3oool300000940oooo00<00000
0?ooo`3oool0S`3oool3000008l0oooo0`00002B0?ooo`030000003oool0oooo0180oooo003o0?oo
ool0oooo/P3oool00?l0ooooo`3ooonb0?ooo`00o`3ooooo0?oook80oooo003o0?ooool0oooo/P3o
ool00?l0ooooo`3ooonb0?ooo`00o`3ooooo0?oook80oooo003o0?ooool0oooo/P3oool00?l0oooo
o`3ooonb0?ooo`00o`3ooooo0?oook80oooo003o0?ooool0oooo/P3oool00?l0ooooo`3ooonb0?oo
o`00@@3ooooo00000?l00000J`0000060?ooo`00@@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00@0oooo00110?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0103o
ool00440oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2@0?ooo`030000003oool0
oooo08l0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0o`3ooooo0?oo
ofL0oooo00<000000?ooo`3oool0103oool00440oooo0`00003o0?ooool0ooooI@3oool3000000H0
oooo00110?ooo`030000003oool0oooo0?l0ooooo`3ooomW0?ooo`030000003oool0oooo00@0oooo
00110?ooo`030000003oool0oooo0?l0ooooo`3ooomW0?ooo`030000003oool0oooo00@0oooo0011
0?ooo`030000003oool0oooo0?l0ooooo`3ooomW0?ooo`030000003oool0oooo00@0oooo00110?oo
o`030000003oool0oooo0?l0ooooo`3ooolk0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0103oool00440oooo00<000000?ooo`3oool0o`3ooooo0?oooc/0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`040?ooo`00<@3oool5000000/0oooo00<000000?ooo`3oool0
o`3ooooo0?oooc/0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`040?ooo`00<P3o
ool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0?l0ooooo`3ooolk0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0103oool003<0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`3o0?ooool0oooo>`3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo00@0oooo000X0?ooo`L000001@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0?l0ooooo`3ooolk0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0103oool0
03@0oooo00<000000?ooo`3oool02P3oool500000?l0ooooo`3oooli0?ooo`030000003oool0oooo
02H0oooo100000060?ooo`00=@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0
ooooo`3ooolk0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0103oool003D0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooool0oooo>`3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo00@0oooo000e0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooc/0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`040?ooo`00<@3oool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool0o`3o
oooo0?oooc/0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`040?ooo`00<P3oool3
000000`0oooo00<000000?ooo`3oool0o`3ooooo0?ooocX0oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo0?l0
ooooo`3ooolj0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0103oool00440oooo
00<000000?ooo`3oool0o`3ooooo0?ooocX0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo00@0oooo00110?ooo`<00000o`3ooooo0?ooocX0oooo00<00000
0?ooo`3oool0:03oool3000000H0oooo00110?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3o
ool0o`3ooooo0?ooocX0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`040?ooo`00
@@3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo00@0oooo00110?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0o`3ooooo
0?ooocX0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`040?ooo`00@@3oool00`00
0000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
00@0oooo00110?ooo`030000003oool0oooo0?l0ooooo`3oooli0?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0o`3ooooo0?ooocT0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`040?ooo`00@@3oool300000?l0ooooo`3o
ooli0?ooo`030000003oool0oooo02T0oooo0`0000060?ooo`00@@3oool00`000000oooo0?ooo`3o
0?ooool0oooo>@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00@0oooo00110?oo
o`030000003oool0oooo0?l0ooooo`3oooli0?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool0103oool00440oooo00<000000?ooo`3oool0o`3ooooo0?ooocT0oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0oooo
>@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003o
ool0oooo0?l0ooooo`3oooli0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0103o
ool00440oooo00<000000?ooo`3oool0o`3ooooo0?ooocP0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0oooo>03oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo0?l0
ooooo`3ooolh0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0103oool00440oooo
00<000000?ooo`3oool0o`3ooooo0?ooocP0oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`040?ooo`00@@3oool300000?l0ooooo`3ooolg0?ooo`030000003oool0oooo02/0oooo0`00
00060?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0oooo=`3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo0?l0ooooo`3ooolg0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3o
ool0o`3ooooo0?ooocL0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`040?ooo`00
@@3oool00`000000oooo0?ooo`3o0?ooool0oooo=`3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo00@0oooo00110?ooo`030000003oool0oooo0?l0ooooo`3ooolg0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0o`3ooooo
0?ooocH0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`040?ooo`00@@3oool00`00
0000oooo0?ooo`3o0?ooool0oooo=P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
00@0oooo00110?ooo`030000003oool0oooo0?l0ooooo`3ooolf0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0o`3ooooo0?ooocH0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`040?ooo`00@@3oool300000?l0ooooo`3o
oolf0?ooo`030000003oool0oooo02`0oooo0`0000060?ooo`00@@3oool00`000000oooo0?ooo`3o
0?ooool0oooo=P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00@0oooo00110?oo
o`030000003oool0oooo0?l0ooooo`3ooolf0?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool0103oool00440oooo00<000000?ooo`3oool0o`3ooooo0?ooocD0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0oooo
=@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003o
ool0oooo0?l0ooooo`3ooole0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0103o
ool002P0oooo0`0000030?ooo`040000003oool0oooo0?ooo`<00000303oool00`000000oooo0?oo
o`3o0?ooool0oooo=@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00@0oooo000Y
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o
0?ooool0oooo=03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00@0oooo000Y0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?oo
ool0oooo=03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00@0oooo000M0?ooo`L0
00001@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo1@00003o0?ooool0
oooo<P3oool00`000000oooo0?ooo`0]0?ooo`@000001P3oool002T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooo`3ooold0?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool0103oool002T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0ooooo`3ooolc0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool0103oool002T0oooo00<000000?ooo`3oool01P3oool3
000000`0oooo00<000000?ooo`3oool0o`3ooooo0?oooc<0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`040?ooo`00:@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0o`3ooooo0?oooc<0oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`040?ooo`00:03oool2000000T0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`3o0?ooool0oooo<`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00@0
oooo000Y0?ooo`030000003oool0oooo00L0oooo1000000:0?ooo`030000003oool0oooo0?l0oooo
o`3ooolb0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0103oool00440oooo00<0
00000?ooo`3oool0o`3ooooo0?oooc80oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?oo
o`040?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0oooo<P3oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo0?l0ooooo`3ooola0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool0103oool00440oooo0`00003o0?ooool0
oooo<@3oool00`000000oooo0?ooo`0a0?ooo`<000001P3oool00440oooo00<000000?ooo`3oool0
o`3ooooo0?oooc40oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`040?ooo`00@@3o
ool00`000000oooo0?ooo`3o0?ooool0oooo<03oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo00@0oooo00110?ooo`030000003oool0oooo0?l0ooooo`3oool`0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0o`3ooooo0?oo
oc00oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`040?ooo`00@@3oool00`000000
oooo0?ooo`3o0?ooool0oooo;`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00@0
oooo00110?ooo`030000003oool0oooo0?l0ooooo`3oool_0?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0o`3ooooo0?ooobl0oooo00<0
00000?ooo`3oool0=@3oool00`000000oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3o
0?ooool0oooo;P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00@0oooo00110?oo
o`030000003oool0oooo0?l0ooooo`3oool^0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool0103oool00440oooo0`00003o0?ooool0oooo;P3oool00`000000oooo0?ooo`0d0?ooo`<0
00001P3oool00440oooo00<000000?ooo`3oool0o`3ooooo0?ooobd0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0oooo;@3o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0
oooo0?l0ooooo`3oool]0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0103oool0
0440oooo00<000000?ooo`3oool0o`3ooooo0?ooob`0oooo00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0oooo;03oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo0?l0oooo
o`3oool/0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0103oool00440oooo00<0
00000?ooo`3oool0o`3ooooo0?ooob/0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`040?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0oooo:`3oool00`000000oooo0?ooo`0i
0?ooo`030000003oool0oooo00@0oooo00110?ooo`<00000o`3ooooo0?ooob/0oooo00<000000?oo
o`3oool0=`3oool3000000H0oooo00110?ooo`030000003oool0oooo0?l0ooooo`3ooolZ0?ooo`03
0000003oool0oooo03X0oooo00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0
o`3ooooo0?ooobX0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`040?ooo`00@@3o
ool00`000000oooo0?ooo`3o0?ooool0oooo:@3oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo00@0oooo00110?ooo`030000003oool0oooo0?l0ooooo`3ooolY0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0o`3ooooo0?oo
obP0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`040?ooo`00@@3oool00`000000
oooo0?ooo`3o0?ooool0oooo:03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00@0
oooo00110?ooo`030000003oool0oooo0?l0ooooo`3ooolW0?ooo`030000003oool0oooo03d0oooo
00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0o`3ooooo0?ooobL0oooo00<0
00000?ooo`3oool0?@3oool00`000000oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3o
0?ooool0oooo9P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00@0oooo00110?oo
o`<00000o`3ooooo0?ooobH0oooo00<000000?ooo`3oool0?03oool3000000H0oooo00110?ooo`03
0000003oool0oooo0?l0ooooo`3ooolU0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0103oool00440oooo00<000000?ooo`3oool0o`3ooooo0?ooobD0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0oooo903o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0
oooo0?l0ooooo`3ooolT0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0103oool0
0440oooo00<000000?ooo`3oool0o`3ooooo0?ooob<0oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`040?ooo`00<P3oool3000000`0oooo00<000000?ooo`3oool0o`3ooooo0?ooob80
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`040?ooo`00<`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`030000003oool0oooo04<0oooo
00<000000?ooo`3oool0103oool003<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`3o0?ooool0oooo8@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00@0oooo000X
0?ooo`L00000103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooo`3ooolP
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0103oool003<0oooo00<000000?oo
o`3oool02`3oool500000?l0ooooo`3ooolM0?ooo`030000003oool0oooo0480oooo100000060?oo
o`00<`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooo`3ooolO0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool0103oool003<0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`3o0?ooool0oooo7P3oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo00@0oooo000c0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3o
oooo0?oooad0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`040?ooo`00<P3oool2
000000d0oooo00<000000?ooo`3oool0o`3ooooo0?oooad0oooo00<000000?ooo`3oool0A`3oool0
0`000000oooo0?ooo`040?ooo`00<`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0?l0ooooo`3ooolL0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0103oool00440
oooo00<000000?ooo`3oool0o`3ooooo0?oooa/0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0oooo6`3oool00`000000oooo
0?ooo`190?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo0?l0ooooo`3o
oolJ0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0103oool00440oooo00<00000
0?ooo`3oool0o`3ooooo0?oooaT0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`04
0?ooo`00@@3oool300000?l0ooooo`3ooolI0?ooo`030000003oool0oooo04T0oooo0`0000060?oo
o`00@@3oool00`000000oooo0?ooo`3o0?ooool0oooo603oool00`000000oooo0?ooo`1<0?ooo`03
0000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`030000
003oool0oooo04d0oooo00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0o`3o
oooo0?oooaH0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`040?ooo`00@@3oool0
0`000000oooo0?ooo`3o0?ooool0oooo5@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo00@0oooo00110?ooo`030000003oool0oooo0?l0ooooo`3ooolE0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0o`3ooooo0?oooa@0
oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`040?ooo`00@@3oool00`000000oooo
0?ooo`3o0?ooool0oooo4`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo00@0oooo
00110?ooo`030000003oool0oooo0?l0ooooo`3ooolB0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool0103oool00440oooo0`00003o0?ooool0oooo4@3oool00`000000oooo0?ooo`1A
0?ooo`<000001P3oool00440oooo00<000000?ooo`3oool0o`3ooooo0?oooa00oooo00<000000?oo
o`3oool0E03oool00`000000oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0
oooo403oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000
003oool0oooo0?l0ooooo`3oool?0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0
103oool00440oooo00<000000?ooo`3oool0o`3ooooo0?ooo`h0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0oooo3@3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo
0?l0ooooo`3oool<0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0103oool00440
oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo0P00001K0?ooo`030000003oool0oooo00@0
oooo00110?ooo`030000003oool0oooo0?l0ooooo`3oool90?ooo`030000003oool0oooo05/0oooo
00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0o`3ooooo0?ooo`P0oooo00<0
00000?ooo`3oool0G03oool00`000000oooo0?ooo`040?ooo`00@@3oool300000?l0ooooo`3oool7
0?ooo`030000003oool0oooo05/0oooo0`0000060?ooo`00@@3oool00`000000oooo0?ooo`3o0?oo
ool0oooo1P3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo00@0oooo00110?ooo`03
0000003oool0oooo0?l0ooooo`3oool40?ooo`800000H@3oool00`000000oooo0?ooo`040?ooo`00
@@3oool00`000000oooo0?ooo`3o0?ooool0oooo0`3oool00`000000oooo0?ooo`1Q0?ooo`030000
003oool0oooo00@0oooo00110?ooo`030000003oool0oooo0?l0ooooo`3oool20?ooo`030000003o
ool0oooo0680oooo00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0o`3ooooo
0?ooo`40oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`040?ooo`00@@3oool00`00
0000oooo0?ooo`3o0?ooool0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`040?oo
o`00@@3oool00`000000oooo0?ooo`3o0?ooood0oooo0P00001W0?ooo`030000003oool0oooo00@0
oooo00110?ooo`030000003oool0oooo0?l0ooooo03oool00`000000oooo0?ooo`1W0?ooo`030000
003oool0oooo00@0oooo00110?ooo`030000003oool0oooo0?l0oooon`3oool00`000000oooo0?oo
o`1X0?ooo`030000003oool0oooo00@0oooo00110?ooo`<00000o`3ooooj0?ooo`030000003oool0
oooo06L0oooo0`0000060?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooooT0oooo00<000000?oo
o`3oool0JP3oool00`000000oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooooL0
oooo0P00001]0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo0?l0oooo
mP3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003o
ool0oooo0?l0oooom@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo00@0oooo0011
0?ooo`030000003oool0oooo0?l0ooool`3oool200000740oooo00<000000?ooo`3oool0103oool0
02P0oooo0`0000030?ooo`040000003oool0oooo0?ooo`<00000303oool00`000000oooo0?ooo`3o
0?oooo80oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`040?ooo`009`3oool01@00
0000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o
0?oooo00oooo0P00001d0?ooo`030000003oool0oooo00@0oooo000W0?ooo`050000003oool0oooo
0?ooo`0000002P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooook`3oool0
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo00@0oooo000M0?ooo`L000000`3oool01@00
0000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0203oool500000?l0ooooj`3oool2
000007@0oooo100000060?ooo`009`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooon`0oooo00<000000?ooo`3oool0M`3oool0
0`000000oooo0?ooo`040?ooo`009`3oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooonX0oooo0P00001j0?ooo`030000003oool0
oooo00@0oooo000W0?ooo`050000003oool0oooo0?ooo`0000001P3oool3000000`0oooo00<00000
0?ooo`3oool0o`3ooooX0?ooo`800000O03oool00`000000oooo0?ooo`040?ooo`009`3oool01@00
0000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o
0?ooonL0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`040?ooo`009`3oool01@00
0000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o
0?ooonD0oooo0P00001o0?ooo`030000003oool0oooo00@0oooo000X0?ooo`<00000203oool40000
00X0oooo00<000000?ooo`3oool0o`3ooooT0?ooo`030000003oool0oooo07l0oooo00<000000?oo
o`3oool0103oool00440oooo00<000000?ooo`3oool0o`3ooooR0?ooo`800000PP3oool00`000000
oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooon40oooo00<000000?ooo`3oool0
PP3oool00`000000oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3o0?oooml0oooo0P00
00250?ooo`030000003oool0oooo00@0oooo00110?ooo`<00000o`3ooooN0?ooo`030000003oool0
oooo08<0oooo0`0000060?ooo`00203oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
0?l0oooog03oool2000008P0oooo00<000000?ooo`3oool0103oool000P0oooo0`00000f0?ooo`03
0000003oool0oooo0?l0oooofP3oool2000008X0oooo00<000000?ooo`3oool0103oool000P0oooo
00<000000?ooo`3oool00`00000c0?ooo`030000003oool0oooo0?l0oooof03oool2000008`0oooo
00<000000?ooo`3oool0103oool000h0oooo0P00000a0?ooo`030000003oool0oooo0?l0ooooeP3o
ool2000008h0oooo00<000000?ooo`3oool0103oool00100oooo0P00000_0?ooo`030000003oool0
oooo0?l0ooooe03oool200000900oooo00<000000?ooo`3oool0103oool000h0oooo0P00000a0?oo
o`030000003oool0oooo0?l0oooodP3oool200000980oooo00<000000?ooo`3oool0103oool000P0
oooo00<000000?ooo`3oool00`00000c0?ooo`030000003oool0oooo0?l0ooood03oool2000009@0
oooo00<000000?ooo`3oool0103oool000P0oooo0`00000f0?ooo`030000003oool0oooo0?l0oooo
cP3oool2000009H0oooo00<000000?ooo`3oool0103oool000P0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`3o0?oool`0oooo0P00002H0?ooo`030000003oool0oooo00@0oooo0011
0?ooo`<00000o`3oooo:0?ooo`800000V03oool3000000H0oooo00110?ooo`030000003oool0oooo
0?l0oooob03oool2000009`0oooo00<000000?ooo`3oool0103oool000X0oooo2@00000^0?ooo`03
0000003oool0oooo0?l0ooooaP3oool2000009h0oooo00<000000?ooo`3oool0103oool000T0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0oooo
a03oool200000:00oooo00<000000?ooo`3oool0103oool000P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0?l0oooo`P3oool200000:80oooo00<0
00000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0o`3oooo00?ooo`800000Y03oool0
0`000000oooo0?ooo`040?ooo`003@3oool400000300oooo00<000000?ooo`3oool0o`3ooonn0?oo
o`800000YP3oool00`000000oooo0?ooo`040?ooo`00303oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000002`0oooo00<000000?ooo`3oool0o`3ooonl0?ooo`800000Z03oool00`00
0000oooo0?ooo`040?ooo`002`3oool00`000000oooo0?ooo`020?ooo`@00000;@3oool00`000000
oooo0?ooo`3o0?oookX0oooo0P00002Z0?ooo`030000003oool0oooo00@0oooo000;0?ooo`D00000
00<0oooo0000003oool0;P3oool00`000000oooo0?ooo`3o0?oookP0oooo0P00002/0?ooo`030000
003oool0oooo00@0oooo00090?ooo`<000001@3oool00`000000oooo0?ooo`0]0?ooo`<00000o`3o
oonf0?ooo`800000[03oool3000000H0oooo000;0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`3o0?oook@0oooo0P00002`0?ooo`030000003oool0
oooo00@0oooo000<0?ooo`@00000<@3oool00`000000oooo0?ooo`3o0?oook80oooo0P00002b0?oo
o`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo0?l0oooo[`3oool300000;@0
oooo00<000000?ooo`3oool0103oool000X0oooo2@00000^0?ooo`030000003oool0oooo0?l0oooo
[@3oool200000;L0oooo00<000000?ooo`3oool0103oool000T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0ooooZ`3oool200000;T0oooo00<0
00000?ooo`3oool0103oool000P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo0?l0ooooZ03oool300000;/0oooo00<000000?ooo`3oool0103oool0
0440oooo00<000000?ooo`3oool0o`3ooonV0?ooo`800000_P3oool00`000000oooo0?ooo`040?oo
o`002`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0?l0ooooY03oool200000<00
oooo00<000000?ooo`3oool0103oool000T0oooo2@00000_0?ooo`<00000o`3ooonR0?ooo`800000
`03oool3000000H0oooo000;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`3o0?oooil0oooo0`0000340?ooo`030000003oool0oooo00@0oooo000@
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0o`3ooonM0?ooo`800000a`3oool0
0`000000oooo0?ooo`040?ooo`00203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0o`3ooonK0?ooo`8000006P3oool200000:d0oooo00<000000?oo
o`3oool0103oool000T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo0?l0ooooV03oool3000001/0oooo00<000000?ooo`3oool0[@3oool00`000000
oooo0?ooo`040?ooo`002P3oool9000002h0oooo00<000000?ooo`3oool0o`3ooonF0?ooo`800000
7@3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo00@0oooo000b0?ooo`<00000303o
ool00`000000oooo0?ooo`3o0?oooi<0oooo0`00000M0?ooo`@000001@3oool2000000030?ooo`00
0000oooo00H0000000D0oooo00000000000000000?ooo`02000000<0oooo0`0000020?ooo`<00000
0`3oool3000000@0oooo0`0000001@3oool00000000000000000oooo00<000000P3oool3000000@0
oooo0`0000060?ooo`<00000303oool3000005@0oooo00<000000?ooo`3oool0103oool000P0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0J0?ooo`050000003oool0oooo0?ooo`00
00002`3oool00`000000oooo0?ooo`3o0?oooi40oooo0P00000O0?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000020?ooo`<0000000D0oooo0000003oool0oooo00000003
0?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`030000003oool000000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
000000<0oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool000000?ooo`07000000@0oooo00<000000?ooo`3o
ool0D`3oool00`000000oooo0?ooo`040?ooo`002@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo01/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`030000003oool0oooo0?l0
ooooSP3oool300000200oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000030?oo
o`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003o
ool0oooo0?ooo`000000203oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000D0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo05<0oooo00<000000?oo
o`3oool0103oool000X0oooo2@00000N0?ooo`050000003oool0oooo0?ooo`0000002`3oool00`00
0000oooo0?ooo`3o0?oooh/0oooo0`00000S0?ooo`030000003oool0oooo00@0oooo00@000000?oo
o`3oool000000`3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`000000
0P3oool01@000000oooo0?ooo`3oool0000000H0oooo0P0000040?ooo`8000000`3oool00`000000
oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00P0oooo0P00000=0?ooo`030000003oool0oooo05<0oooo00<000000?oo
o`3oool0103oool00340oooo00D000000?ooo`3oool0oooo0000000;0?ooo`D00000o`3ooon70?oo
o`8000009P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000<0oooo00@00000
0?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
oooo1@0000000`3oool000000?ooo`040?ooo`030000003oool0oooo00<0oooo1@0000000`3oool0
00000?ooo`020?ooo`040000003oool0oooo000000H0oooo1@0000050?ooo`030000003oool0oooo
0080oooo1`0000040?ooo`030000003oool0oooo0500oooo100000060?ooo`00<@3oool01@000000
oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool0o`3ooon60?ooo`<00000:03oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`00000000000?oo
o`0300000080oooo00@000000?ooo`3oool000000`3oool01`000000oooo0?ooo`3oool000000?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo1000
00020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo000000`0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`040?ooo`00<@3oool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?oo
o`3oool0o`3ooon40?ooo`800000:`3oool00`000000oooo0?ooo`040?ooo`040000003oool00000
00000080oooo0P0000020?ooo`050000003oool0oooo0000003oool00P0000020?ooo`<000000`3o
ool3000000<0oooo0`0000030?ooo`<000000`3oool300000080oooo00@000000?ooo`0000000000
103oool3000000@0oooo0`0000070?ooo`<00000303oool00`000000oooo0?ooo`1C0?ooo`030000
003oool0oooo00@0oooo000a0?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000oooo
0?ooo`3o0?oooh40oooo0`00000]0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0
103oool00340oooo00D000000?ooo`3oool0oooo0000000;0?ooo`030000003oool0oooo0?l0oooo
OP3oool300000340oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo0400oooo0P00001E0?ooo`030000003oool0oooo00@0oooo000b0?ooo`<00000303o
ool00`000000oooo0?ooo`3o0?ooog/0oooo0`00000e0?ooo`@000002`3oool00`000000oooo0?oo
o`1;0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0103oool00440oooo00<00000
0?ooo`3oool0o`3ooomh0?ooo`<00000j`3oool00`000000oooo0?ooo`040?ooo`00@@3oool00`00
0000oooo0?ooo`3o0?ooogH0oooo0P00003^0?ooo`030000003oool0oooo00@0oooo00110?ooo`03
0000003oool0oooo0?l0ooooL`3oool300000?00oooo00<000000?ooo`3oool0103oool00440oooo
00<000000?ooo`3oool0o`3ooom`0?ooo`<00000l`3oool00`000000oooo0?ooo`040?ooo`00@@3o
ool300000?l0ooooK@3oool300000?@0oooo0`0000060?ooo`00@@3oool00`000000oooo0?ooo`3o
0?ooofX0oooo0`00003i0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo
0?l0ooooI`3oool300000?`0oooo00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3o
ool0o`3ooomT0?ooo`<00000o`3oool00`000000oooo0?ooo`040?ooo`00@@3oool00`000000oooo
0?ooo`3o0?ooof40oooo0`00003o0?ooo`<0oooo00<000000?ooo`3oool0103oool00440oooo00<0
00000?ooo`3oool0o`3ooomN0?ooo`<00000o`3oool60?ooo`030000003oool0oooo00@0oooo0011
0?ooo`030000003oool0oooo0?l0ooooF`3oool300000?l0oooo2@3oool00`000000oooo0?ooo`04
0?ooo`00@@3oool00`000000oooo0?ooo`3o0?oooeP0oooo0`00003o0?ooo``0oooo00<000000?oo
o`3oool0103oool00440oooo00<000000?ooo`3oool0o`3ooomE0?ooo`<00000o`3oool?0?ooo`03
0000003oool0oooo00@0oooo00110?ooo`<00000o`3ooomB0?ooo`<00000o`3oool@0?ooo`<00000
1P3oool00440oooo00<000000?ooo`3oool0o`3ooom?0?ooo`<00000o`3ooolE0?ooo`030000003o
ool0oooo00@0oooo00110?ooo`030000003oool0oooo0?l0ooooB`3oool400000?l0oooo603oool0
0`000000oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooodP0oooo0`00003o0?oo
oa`0oooo00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0o`3ooom50?ooo`<0
0000o`3ooolO0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo0?l0oooo
@@3oool400000?l0oooo8P3oool00`000000oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?oo
o`3o0?oooch0oooo0`00003o0?ooobH0oooo00<000000?ooo`3oool0103oool00440oooo00<00000
0?ooo`3oool0o`3ooolk0?ooo`<00000o`3ooolY0?ooo`030000003oool0oooo00@0oooo00110?oo
o`030000003oool0oooo0?l0oooo=`3oool400000?l0oooo;03oool00`000000oooo0?ooo`040?oo
o`00@@3oool00`000000oooo0?ooo`3o0?oooc<0oooo1000003o0?oooc00oooo00<000000?ooo`3o
ool0103oool00440oooo0`00003o0?ooobl0oooo1000003o0?oooc80oooo0`0000060?ooo`00@@3o
ool00`000000oooo0?ooo`3o0?ooob/0oooo1000003o0?ooocP0oooo00<000000?ooo`3oool0103o
ool00440oooo00<000000?ooo`3oool0o`3ooolW0?ooo`@00000o`3oooll0?ooo`030000003oool0
oooo00@0oooo00110?ooo`030000003oool0oooo0?l0oooo8`3oool400000?l0oooo@03oool00`00
0000oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3o0?oooal0oooo1000003o0?oood@0
oooo00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0o`3ooolK0?ooo`@00000
o`3ooom80?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo0?l0oooo603o
ool300000?l0ooooC03oool00`000000oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3o
0?oooa@0oooo1000003o0?ooodl0oooo00<000000?ooo`3oool0103oool00440oooo00<000000?oo
o`3oool0o`3oool@0?ooo`@00000o`3ooomC0?ooo`030000003oool0oooo00@0oooo00110?ooo`03
0000003oool0oooo0?l0oooo3@3oool300000?l0ooooE`3oool00`000000oooo0?ooo`040?ooo`00
@@3oool300000?l0oooo2@3oool400000?l0ooooF03oool3000000H0oooo00110?ooo`030000003o
ool0oooo0?l0oooo1@3oool400000?l0ooooGP3oool00`000000oooo0?ooo`040?ooo`00@@3oool0
0`000000oooo0?ooo`3o0?ooo`40oooo1000003o0?ooof80oooo00<000000?ooo`3oool0103oool0
0440oooo00<000000?ooo`3oool0o03oool400000?l0ooooIP3oool00`000000oooo0?ooo`040?oo
o`00@@3oool00`000000oooo0?ooo`3h0?ooo`@00000o`3ooomZ0?ooo`030000003oool0oooo00@0
oooo00110?ooo`030000003oool0oooo0?D0oooo0`00003o0?ooofh0oooo00<000000?ooo`3oool0
103oool002P0oooo0`0000030?ooo`040000003oool0oooo0?ooo`<00000303oool00`000000oooo
0?ooo`3a0?ooo`@00000o`3oooma0?ooo`030000003oool0oooo00@0oooo000W0?ooo`050000003o
ool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0>d0oooo
1000003o0?ooogD0oooo00<000000?ooo`3oool0103oool002L0oooo00D000000?ooo`3oool0oooo
0000000:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0j@3oool400000?l0oooo
N@3oool00`000000oooo0?ooo`040?ooo`009`3oool01@000000oooo0?ooo`3oool0000000X0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3U0?ooo`@00000o`3ooomm0?ooo`030000
003oool0oooo00@0oooo000W0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo
0?ooo`080?ooo`D00000g`3oool400000?l0ooooOP3oool4000000H0oooo000W0?ooo`050000003o
ool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0=`0oooo
1@00003o0?ooohD0oooo00<000000?ooo`3oool0103oool002L0oooo00D000000?ooo`3oool0oooo
000000060?ooo`<00000303oool00`000000oooo0?ooo`3H0?ooo`@00000o`3ooon:0?ooo`030000
003oool0oooo00@0oooo000W0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo0=<0oooo1@00003o0?ooohh0oooo00<000000?ooo`3oool0
103oool002L0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0cP3oool500000?l0ooooT`3oool00`000000oooo0?ooo`040?ooo`00:03o
ool3000000P0oooo1000000:0?ooo`030000003oool0oooo0<X0oooo1000003o0?oooiP0oooo00<0
00000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0a@3oool500000?l0ooooW03oool0
0`000000oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`310?ooo`@00000o`3ooonQ0?oo
o`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo0;`0oooo1@00003o0?ooojD0
oooo00<000000?ooo`3oool0103oool00440oooo0`00000<0?oooa000000V`3oool500000?l0oooo
Z03oool3000000H0oooo00110?ooo`030000003oool0oooo01`0oooo6`00001l0?ooo`@00000o`3o
oon_0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo03L0oooo3@00001Y
0?ooo`H00000o`3ooonc0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo
04@0oooo3000001G0?ooo`H00000o`3oooni0?ooo`030000003oool0oooo00@0oooo00110?ooo`03
0000003oool0oooo0500oooo2P0000170?ooo`H00000o`3ooono0?ooo`030000003oool0oooo00@0
oooo00110?ooo`030000003oool0oooo05X0oooo2000000i0?ooo`H00000o`3oooo50?ooo`030000
003oool0oooo00@0oooo00110?ooo`030000003oool0oooo0680oooo2000000[0?ooo`H00000o`3o
ooo;0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo06X0oooo2000000M
0?ooo`H00000o`3ooooA0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo
0780oooo1P00000A0?ooo`H00000o`3ooooG0?ooo`030000003oool0oooo00@0oooo00110?ooo`03
0000003oool0oooo07P0oooo1P0000050?ooo`H00000o`3ooooM0?ooo`030000003oool0oooo00@0
oooo00110?ooo`<00000OP3oool600000?l0ooooh03oool3000000H0oooo00110?ooo`030000003o
ool0oooo07P0oooo1P0000060?ooo`H00000o`3ooooL0?ooo`030000003oool0oooo00@0oooo0011
0?ooo`030000003oool0oooo0780oooo1P00000B0?ooo`H00000o`3ooooF0?ooo`030000003oool0
oooo00@0oooo00110?ooo`030000003oool0oooo06`0oooo1P00000N0?ooo`H00000o`3oooo@0?oo
o`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo06@0oooo2000000Z0?ooo`H0
0000o`3oooo:0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo05P0oooo
3000000h0?ooo`H00000o`3oooo40?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003o
ool0oooo04d0oooo2`00001:0?ooo`D00000o`3ooono0?ooo`030000003oool0oooo00@0oooo0011
0?ooo`030000003oool0oooo0440oooo3000001J0?ooo`D00000o`3ooonj0?ooo`030000003oool0
oooo00@0oooo00110?ooo`030000003oool0oooo03D0oooo3000001[0?ooo`D00000o`3ooone0?oo
o`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo01`0oooo6@00001l0?ooo`D0
0000o`3ooon`0?ooo`030000003oool0oooo00@0oooo00110?ooo`<00000303oool@000009X0oooo
1@00003o0?ooojT0oooo0`0000060?ooo`00@@3oool00`000000oooo0?ooo`2k0?ooo`D00000o`3o
oonV0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo0<00oooo1@00003o
0?oooj40oooo00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0a@3oool50000
0?l0ooooW03oool00`000000oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3:0?ooo`D0
0000o`3ooonG0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo0<l0oooo
1@00003o0?oooi80oooo00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0e03o
ool500000?l0ooooS@3oool00`000000oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3I
0?ooo`@00000o`3ooon90?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo
0=d0oooo1@00003o0?oooh@0oooo00<000000?ooo`3oool0103oool00440oooo0`00003R0?ooo`D0
0000o`3ooomm0?ooo`<000001P3oool00440oooo00<000000?ooo`3oool0i`3oool500000?l0oooo
NP3oool00`000000oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3/0?ooo`@00000o`3o
oomf0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo0?00oooo1000003o
0?ooog80oooo00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0m03oool40000
0?l0ooooKP3oool00`000000oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3h0?ooo`@0
0000o`3ooomZ0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo0?`0oooo
1000003o0?ooofH0oooo00<000000?ooo`3oool0103oool00380oooo0`00000<0?ooo`030000003o
ool0oooo0?l0oooo0@3oool500000?l0ooooH@3oool00`000000oooo0?ooo`040?ooo`00<`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo1P3oool500000?l0ooooG03oool0
0`000000oooo0?ooo`040?ooo`00<`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0?l0oooo2`3oool400000?l0ooooF03oool00`000000oooo0?ooo`040?ooo`00<`3oool00`000000
oooo0?ooo`0;0?ooo`D00000o`3oool=0?ooo`D00000o`3ooom@0?ooo`@000001P3oool003<0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?oooa@0oooo1@00003o0?ooodh0oooo
00<000000?ooo`3oool0103oool003<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`3o0?oooaT0oooo1@00003o0?ooodT0oooo00<000000?ooo`3oool0103oool003<0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?oooah0oooo1@00003o0?oood@0oooo00<00000
0?ooo`3oool0103oool003<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?oo
ob<0oooo1000003o0?oood00oooo00<000000?ooo`3oool0103oool00380oooo0P00000=0?ooo`03
0000003oool0oooo0?l0oooo9`3oool500000?l0oooo>`3oool00`000000oooo0?ooo`040?ooo`00
<`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo;03oool500000?l0oooo
=P3oool00`000000oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3o0?oooc40oooo1@00
003o0?oooc40oooo00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0o`3ooolf
0?ooo`@00000o`3oool]0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo
0?l0oooo>P3oool400000?l0oooo:@3oool00`000000oooo0?ooo`040?ooo`00@@3oool300000?l0
oooo?P3oool400000?l0oooo8`3oool3000000H0oooo00110?ooo`030000003oool0oooo0?l0oooo
@P3oool400000?l0oooo8@3oool00`000000oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?oo
o`3o0?ooodH0oooo1000003o0?oooad0oooo00<000000?ooo`3oool0103oool00440oooo00<00000
0?ooo`3oool0o`3ooom:0?ooo`D00000o`3ooolH0?ooo`030000003oool0oooo00@0oooo00110?oo
o`030000003oool0oooo0?l0ooooC`3oool500000?l0oooo4`3oool00`000000oooo0?ooo`040?oo
o`00@@3oool00`000000oooo0?ooo`3o0?oooe@0oooo1000003o0?ooo`l0oooo00<000000?ooo`3o
ool0103oool00440oooo00<000000?ooo`3oool0o`3ooomH0?ooo`D00000o`3oool:0?ooo`030000
003oool0oooo00@0oooo00110?ooo`030000003oool0oooo0?l0ooooG@3oool500000?l0oooo1@3o
ool00`000000oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooof80oooo1@00003o
0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo0?l0ooooI`3oool50000
0?X0oooo00<000000?ooo`3oool0103oool00440oooo0`00003o0?ooof`0oooo1@00003c0?ooo`<0
00001P3oool00440oooo00<000000?ooo`3oool0o`3oooma0?ooo`D00000l03oool00`000000oooo
0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooogH0oooo1@00003[0?ooo`030000003o
ool0oooo00@0oooo00110?ooo`030000003oool0oooo0?l0ooooN`3oool500000>H0oooo00<00000
0?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0o`3oooln0?ooo`030000003oool0oooo
03l0oooo1000003R0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo0?l0
oooo?`3oool00`000000oooo0?ooo`120?ooo`@00000gP3oool00`000000oooo0?ooo`040?ooo`00
@@3oool00`000000oooo0?ooo`3o0?ooo`/0oooo0`0000050?ooo`<0000000D0oooo000000000000
00000?ooo`08000000050?ooo`00000000000000003oool00P0000030?ooo`<000000P3oool30000
00050?ooo`00000000000000003oool00`0000000`3oool00000000000050?ooo`<00000303oool3
00000340oooo1000003J0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo
0?l0oooo303oool00`000000oooo0?ooo`050?ooo`070000003oool0oooo0?ooo`000000oooo0000
00030?ooo`040000003oool0oooo000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo
000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000T0oooo
00D000000?ooo`3oool000000?ooo`07000000@0oooo00<000000?ooo`3oool0=03oool400000=H0
oooo00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0o`3oool<0?ooo`030000
003oool0oooo00D0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00@000000?oo
o`3oool000000`3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`000000
0P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo03P0oooo1000003B0?ooo`030000003oool0oooo00@0
oooo00110?ooo`<00000o`3oool<0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`@000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?oo
o`3oool0oooo000000030?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo
0000000:0?ooo`8000003@3oool00`000000oooo0?ooo`0l0?ooo`D00000b`3oool3000000H0oooo
00110?ooo`030000003oool0oooo0?l0oooo303oool5000000<0oooo00D000000?ooo`3oool0oooo
000000050?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000000`3oool01@00
0000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00P3oool7000000@0oooo00<000000?ooo`3oool0@@3o
ool600000<L0oooo00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0o`3oool<
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0
000000<0oooo00<000000?ooo`0000000P0000020?ooo`040000003oool0oooo000000<0oooo00H0
00000?ooo`3oool0oooo0000003oool300000080oooo0P0000020?ooo`030000003oool0oooo00L0
oooo00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`170?ooo`H00000`@3oool00`00
0000oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooo``0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`000000oooo008000000`3oool3000000<0oooo00@000000?oo
o`00000000000P3oool3000000<0oooo0`0000030?ooo`040000003oool0000000000080oooo0P00
000;0?ooo`<00000303oool00`000000oooo0?ooo`1=0?ooo`H00000^`3oool00`000000oooo0?oo
o`040?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooo``0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`00000C0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0D`3o
ool500000;H0oooo00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0o`3oool<
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`00000000004`3oool00`000000oooo0?oo
o`0Y0?ooo`800000FP3oool500000;40oooo00<000000?ooo`3oool0103oool00440oooo00<00000
0?ooo`3oool0o`3oool;0?ooo`H000000`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo05d0oooo1@00002/0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo
0?l0oooo^P3oool600000:H0oooo00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3o
ool0o`3oooo00?ooo`D00000X@3oool00`000000oooo0?ooo`040?ooo`00@@3oool00`000000oooo
0?ooo`3o0?ooolD0oooo1@00002L0?ooo`030000003oool0oooo00@0oooo00110?ooo`<00000o`3o
ooo:0?ooo`D00000U@3oool3000000H0oooo00110?ooo`030000003oool0oooo0?l0ooooc`3oool4
000009<0oooo00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0o`3ooooC0?oo
o`D00000SP3oool00`000000oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooomP0
oooo1@0000290?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo0?l0oooo
g@3oool5000008@0oooo00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0o`3o
oooR0?ooo`@00000P03oool00`000000oooo0?ooo`040?ooo`00:03oool3000000<0oooo00@00000
0?ooo`3oool0oooo0`00000<0?ooo`030000003oool0oooo0?l0ooooiP3oool5000007/0oooo00<0
00000?ooo`3oool0103oool002T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0?l0ooooj`3oool5000007H0oooo00<000000?ooo`3oool0103oool0
02T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0?l0ooool03oool400000780oooo00<000000?ooo`3oool0103oool002T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooom03oool6000006`0
oooo00<000000?ooo`3oool0103oool002T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`080?ooo`D00000o`3ooooh0?ooo`H00000H`3oool4000000H0oooo000Y0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooool0oooo0@3o
ool600000600oooo00<000000?ooo`3oool0103oool002T0oooo00<000000?ooo`3oool01P3oool3
000000`0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`L0oooo1P00001J0?ooo`030000003oool0
oooo00@0oooo000Y0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`3o0?ooool0oooo3@3oool6000005@0oooo00<000000?ooo`3oool0103oool002P0
oooo0P0000090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooooo0?oooa<0
oooo1@00001?0?ooo`030000003oool0oooo00@0oooo000Y0?ooo`030000003oool0oooo00L0oooo
1000000:0?ooo`030000003oool0oooo0?l0ooooo`3ooolH0?ooo`@00000B`3oool00`000000oooo
0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0oooo703oool5000004H0oooo00<0
00000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo1@000011
0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo0?l0ooooo`3ooolV0?oo
o`H00000>`3oool00`000000oooo0?ooo`040?ooo`00@@3oool300000?l0ooooo`3oool/0?ooo`H0
0000<`3oool3000000H0oooo00110?ooo`030000003oool0oooo0?l0ooooo`3ooolb0?ooo`H00000
;`3oool00`000000oooo0?ooo`040?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0oooo>03o
ool6000002T0oooo00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0o`3ooooo
0?oooch0oooo1P00000S0?ooo`030000003oool0oooo00@0oooo00110?ooo`030000003oool0oooo
0?l0ooooo`3ooom40?ooo`H000007@3oool00`000000oooo0?ooo`040?ooo`00@@3oool00`000000
oooo0?ooo`3o0?ooool0ooooBP3oool6000001L0oooo00<000000?ooo`3oool0103oool00440oooo
00<000000?ooo`3oool0o`3ooooo0?oooe00oooo1P00000A0?ooo`030000003oool0oooo00@0oooo
00110?ooo`030000003oool0oooo0?l0ooooo`3ooomF0?ooo`@000003@3oool00`000000oooo0?oo
o`040?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0ooooI`3oool00`000000oooo0?ooo`04
0?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0ooooI`3oool00`000000oooo0?ooo`040?oo
o`00@@3oool300000?l0ooooo`3ooomU0?ooo`<000001P3oool00440oooo00<000000?ooo`3oool0
o`3ooooo0?ooofL0oooo00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0o`3o
oooo0?ooofL0oooo00<000000?ooo`3oool0103oool00440oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`2@0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0T03oool0
0`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0103oool0
0440oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`040?ooo`00@@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00@0oooo00110?ooool00000o`00001[000000H0oooo
0000\
\>"],
  ImageRangeCache->{{{0, 687.063}, {424.25, 0}} -> {-0.547079, -2.60295, \
0.00681442, 0.0102978}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowSize->{1016, 647},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {None, Inherited, None}},
PageHeaderLines->{Inherited, False},
PrintingOptions->{"PrintingMargins"->{{0, 0}, {0, 72}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FirstPageFooter"->False}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 726, 13, 230, "Input"],
Cell[2446, 64, 285, 4, 30, "Input"],
Cell[2734, 70, 439, 7, 90, "Input"],
Cell[3176, 79, 566, 9, 90, "Input"],
Cell[3745, 90, 199, 4, 50, "Input"],

Cell[CellGroupData[{
Cell[3969, 98, 315, 6, 70, "Input"],
Cell[4287, 106, 90, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4414, 112, 52, 1, 30, "Input"],
Cell[4469, 115, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4559, 121, 3066, 60, 850, "Input"],
Cell[7628, 183, 53, 1, 29, "Output"],
Cell[7684, 186, 45889, 1192, 316, 14322, 798, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[53610, 1383, 1044, 21, 270, "Input"],
Cell[54657, 1406, 53, 1, 29, "Output"],
Cell[54713, 1409, 55, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54805, 1415, 3285, 61, 870, "Input"],
Cell[58093, 1478, 34197, 858, 334, 9836, 553, "GraphicsData", "PostScript", \
"Graphics"],
Cell[92293, 2338, 53, 1, 29, "Output"],
Cell[92349, 2341, 53, 1, 29, "Output"],
Cell[92405, 2344, 46309, 1170, 334, 13424, 760, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[138751, 3519, 1044, 21, 270, "Input"],
Cell[139798, 3542, 53, 1, 29, "Output"],
Cell[139854, 3545, 55, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[139946, 3551, 3205, 60, 850, "Input"],
Cell[143154, 3613, 53, 1, 29, "Output"],
Cell[143210, 3616, 53, 1, 29, "Output"],
Cell[143266, 3619, 47489, 1238, 354, 14600, 828, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[190792, 4862, 1044, 21, 270, "Input"],
Cell[191839, 4885, 52, 1, 29, "Output"],
Cell[191894, 4888, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[191984, 4894, 3208, 60, 850, "Input"],
Cell[195195, 4956, 53, 1, 29, "Output"],
Cell[195251, 4959, 53, 1, 29, "Output"],
Cell[195307, 4962, 46439, 1241, 328, 14768, 846, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[241783, 6208, 1045, 21, 270, "Input"],
Cell[242831, 6231, 53, 1, 29, "Output"],
Cell[242887, 6234, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[242977, 6240, 3469, 68, 870, "Input"],
Cell[246449, 6310, 51964, 1539, 298, 19714, 1136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[298416, 7851, 185, 3, 24, "Message"],
Cell[298604, 7856, 56546, 1664, 298, 20744, 1218, "GraphicsData", \
"PostScript", "Graphics"],
Cell[355153, 9522, 53, 1, 29, "Output"],
Cell[355209, 9525, 53, 1, 29, "Output"],
Cell[355265, 9528, 44224, 1172, 298, 14313, 798, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[399504, 10703, 70, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[399599, 10708, 39, 1, 30, "Input"],
Cell[399641, 10711, 52, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[399730, 10717, 1044, 21, 270, "Input"],
Cell[400777, 10740, 53, 1, 29, "Output"],
Cell[400833, 10743, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[400923, 10749, 3206, 60, 850, "Input"],
Cell[404132, 10811, 53, 1, 29, "Output"],
Cell[404188, 10814, 53, 1, 29, "Output"],
Cell[404244, 10817, 50206, 1340, 331, 16479, 919, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[454487, 12162, 1042, 21, 270, "Input"],
Cell[455532, 12185, 52, 1, 29, "Output"],
Cell[455587, 12188, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[455677, 12194, 3206, 60, 850, "Input"],
Cell[458886, 12256, 53, 1, 29, "Output"],
Cell[458942, 12259, 53, 1, 29, "Output"],
Cell[458998, 12262, 49348, 1218, 369, 13568, 772, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[508383, 13485, 1044, 21, 270, "Input"],
Cell[509430, 13508, 53, 1, 29, "Output"],
Cell[509486, 13511, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[509576, 13517, 3202, 60, 850, "Input"],
Cell[512781, 13579, 53, 1, 29, "Output"],
Cell[512837, 13582, 53, 1, 29, "Output"],
Cell[512893, 13585, 185, 3, 24, "Message"],
Cell[513081, 13590, 53210, 1430, 370, 17043, 979, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[566328, 15025, 1042, 21, 270, "Input"],
Cell[567373, 15048, 53, 1, 29, "Output"],
Cell[567429, 15051, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[567519, 15057, 3205, 60, 850, "Input"],
Cell[570727, 15119, 53, 1, 29, "Output"],
Cell[570783, 15122, 53, 1, 29, "Output"],
Cell[570839, 15125, 50425, 1298, 347, 14822, 854, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[621301, 16428, 1042, 21, 270, "Input"],
Cell[622346, 16451, 53, 1, 29, "Output"],
Cell[622402, 16454, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[622492, 16460, 3199, 60, 850, "Input"],
Cell[625694, 16522, 53, 1, 29, "Output"],
Cell[625750, 16525, 51, 1, 29, "Output"],
Cell[625804, 16528, 65527, 1624, 434, 18062, 1034, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[691368, 18157, 1044, 21, 270, "Input"],
Cell[692415, 18180, 53, 1, 29, "Output"],
Cell[692471, 18183, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[692561, 18189, 353, 6, 70, "Input"],
Cell[692917, 18197, 373, 6, 48, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[693327, 18208, 228, 5, 31, "Input"],
Cell[693558, 18215, 69556, 1589, 489, 15826, 921, "GraphicsData", \
"PostScript", "Graphics"],
Cell[763117, 19806, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[763284, 19814, 1279, 23, 230, "Input"],
Cell[764566, 19839, 86275, 1943, 521, 20595, 1128, "GraphicsData", \
"PostScript", "Graphics"],
Cell[850844, 21784, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[851011, 21792, 415, 8, 70, "Input"],
Cell[851429, 21802, 25117, 1269, 473, 24990, 1265, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[876549, 23073, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[876716, 23081, 3320, 65, 930, "Input"],
Cell[880039, 23148, 53, 1, 29, "Output"],
Cell[880095, 23151, 53, 1, 29, "Output"],

Cell[CellGroupData[{
Cell[880173, 23156, 32007, 753, 269, 8203, 455, "GraphicsData", "PostScript", \
"Graphics"],
Cell[912183, 23911, 38069, 1066, 269, 13393, 757, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[950279, 24981, 264, 5, 90, "Input"],
Cell[950546, 24988, 571, 11, 110, "Input"],

Cell[CellGroupData[{
Cell[951142, 25003, 265, 5, 70, "Input"],
Cell[951410, 25010, 53, 1, 29, "Output"],
Cell[951466, 25013, 60, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[951563, 25019, 3320, 65, 930, "Input"],
Cell[954886, 25086, 53, 1, 29, "Output"],
Cell[954942, 25089, 52, 1, 29, "Output"],

Cell[CellGroupData[{
Cell[955019, 25094, 29940, 728, 275, 8205, 455, "GraphicsData", "PostScript", \
"Graphics"],
Cell[984962, 25824, 39879, 1142, 275, 14573, 825, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[1024868, 26970, 264, 5, 90, "Input"],
Cell[1025135, 26977, 569, 11, 110, "Input"],

Cell[CellGroupData[{
Cell[1025729, 26992, 265, 5, 70, "Input"],
Cell[1025997, 26999, 53, 1, 29, "Output"],
Cell[1026053, 27002, 59, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1026149, 27008, 3320, 65, 930, "Input"],
Cell[1029472, 27075, 53, 1, 29, "Output"],
Cell[1029528, 27078, 53, 1, 29, "Output"],

Cell[CellGroupData[{
Cell[1029606, 27083, 27995, 704, 269, 8201, 455, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1057604, 27789, 41596, 1163, 269, 14573, 825, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[1099227, 28956, 264, 5, 90, "Input"],
Cell[1099494, 28963, 569, 11, 110, "Input"],

Cell[CellGroupData[{
Cell[1100088, 28978, 265, 5, 70, "Input"],
Cell[1100356, 28985, 53, 1, 29, "Output"],
Cell[1100412, 28988, 59, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1100508, 28994, 3828, 76, 1010, "Input"],

Cell[CellGroupData[{
Cell[1104361, 29074, 34123, 1084, 186, 15186, 846, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1138487, 30160, 32990, 1090, 186, 15063, 864, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1171492, 31253, 53, 1, 29, "Output"],
Cell[1171548, 31256, 53, 1, 29, "Output"],

Cell[CellGroupData[{
Cell[1171626, 31261, 28299, 857, 186, 11713, 648, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1199928, 32120, 33161, 1033, 186, 14253, 795, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[1233116, 33157, 264, 5, 90, "Input"],
Cell[1233383, 33164, 569, 11, 110, "Input"],

Cell[CellGroupData[{
Cell[1233977, 33179, 265, 5, 70, "Input"],
Cell[1234245, 33186, 53, 1, 29, "Output"],
Cell[1234301, 33189, 60, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1234398, 33195, 3319, 65, 930, "Input"],
Cell[1237720, 33262, 53, 1, 29, "Output"],
Cell[1237776, 33265, 53, 1, 29, "Output"],

Cell[CellGroupData[{
Cell[1237854, 33270, 38145, 979, 271, 11716, 648, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1276002, 34251, 38981, 1088, 271, 13534, 769, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[1315010, 35343, 264, 5, 90, "Input"],
Cell[1315277, 35350, 569, 11, 110, "Input"],

Cell[CellGroupData[{
Cell[1315871, 35365, 265, 5, 70, "Input"],
Cell[1316139, 35372, 52, 1, 29, "Output"],
Cell[1316194, 35375, 51, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1316282, 35381, 3316, 65, 930, "Input"],
Cell[1319601, 35448, 53, 1, 29, "Output"],
Cell[1319657, 35451, 51, 1, 29, "Output"],

Cell[CellGroupData[{
Cell[1319733, 35456, 38156, 996, 272, 12043, 669, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1357892, 36454, 47408, 1419, 272, 18466, 1057, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[1405327, 37877, 264, 5, 90, "Input"],
Cell[1405594, 37884, 569, 11, 110, "Input"],

Cell[CellGroupData[{
Cell[1406188, 37899, 265, 5, 70, "Input"],
Cell[1406456, 37906, 52, 1, 29, "Output"],
Cell[1406511, 37909, 51, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1406599, 37915, 3327, 65, 930, "Input"],
Cell[1409929, 37982, 53, 1, 29, "Output"],
Cell[1409985, 37985, 53, 1, 29, "Output"],

Cell[CellGroupData[{
Cell[1410063, 37990, 32633, 784, 271, 8631, 483, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1442699, 38776, 45073, 1303, 271, 16746, 949, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[1487799, 40083, 264, 5, 90, "Input"],
Cell[1488066, 40090, 569, 11, 110, "Input"],

Cell[CellGroupData[{
Cell[1488660, 40105, 265, 5, 70, "Input"],
Cell[1488928, 40112, 53, 1, 29, "Output"],
Cell[1488984, 40115, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1489074, 40121, 307, 5, 70, "Input"],
Cell[1489384, 40128, 284, 5, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1489705, 40138, 228, 5, 31, "Input"],
Cell[1489936, 40145, 67469, 1489, 489, 14120, 826, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1557408, 41636, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1557575, 41644, 1282, 24, 250, "Input"],
Cell[1558860, 41670, 82673, 1825, 489, 18884, 1033, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1641536, 43497, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1641703, 43505, 299, 6, 50, "Input"],
Cell[1642005, 43513, 76884, 1851, 497, 22110, 1170, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1718892, 45366, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1719059, 45374, 1062, 18, 150, "Input"],
Cell[1720124, 45394, 124166, 3016, 548, 40524, 1979, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1844293, 48412, 130, 3, 29, "Output"]
}, Open  ]],
Cell[1844438, 48418, 538, 9, 70, "Input"],
Cell[1844979, 48429, 723, 13, 110, "Input"],
Cell[1845705, 48444, 212, 4, 50, "Input"],

Cell[CellGroupData[{
Cell[1845942, 48452, 394, 8, 70, "Input"],
Cell[1846339, 48462, 133, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1846509, 48469, 62, 1, 30, "Input"],
Cell[1846574, 48472, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1846669, 48478, 845, 17, 110, "Input"],
Cell[1847517, 48497, 52917, 1491, 336, 18270, 1059, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1900437, 49990, 130, 3, 29, "Output"]
}, Open  ]],
Cell[1900582, 49996, 465, 9, 70, "Input"],
Cell[1901050, 50007, 725, 13, 110, "Input"],
Cell[1901778, 50022, 212, 4, 50, "Input"],

Cell[CellGroupData[{
Cell[1902015, 50030, 394, 8, 70, "Input"],
Cell[1902412, 50040, 134, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1902583, 50047, 64, 1, 30, "Input"],
Cell[1902650, 50050, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1902745, 50056, 764, 16, 110, "Input"],
Cell[1903512, 50074, 62128, 1599, 401, 18087, 1051, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1965643, 51675, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1965810, 51683, 1093, 18, 134, "Input"],
Cell[1966906, 51703, 98914, 2373, 480, 29132, 1507, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2065823, 54078, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2065990, 54086, 3878, 75, 890, "Input"],
Cell[2069871, 54163, 52, 1, 29, "Output"],
Cell[2069926, 54166, 52, 1, 29, "Output"],
Cell[2069981, 54169, 46718, 1197, 358, 14233, 792, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2116736, 55371, 3870, 75, 890, "Input"],
Cell[2120609, 55448, 53, 1, 29, "Output"],
Cell[2120665, 55451, 53, 1, 29, "Output"],
Cell[2120721, 55454, 59337, 1491, 377, 17442, 969, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2180095, 56950, 280, 5, 50, "Input"],
Cell[2180378, 56957, 80933, 1872, 533, 20941, 1127, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2261314, 58831, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2261481, 58839, 314, 6, 50, "Input"],
Cell[2261798, 58847, 42372, 1353, 186, 19512, 1066, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2304173, 60202, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2304340, 60210, 333, 6, 70, "Input"],
Cell[2304676, 60218, 71780, 1836, 434, 22359, 1221, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2376459, 62056, 130, 3, 29, "Output"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

